@@ -12,6 +12,7 @@ from pandas import (
     DataFrame,
     concat,
     date_range,
+    period_range,
     read_csv,
     to_datetime,
 )
@@ -23,7 +24,6 @@ from ..pandas_vb_common import (
 
 
 class ToCSV(BaseIO):
-
     fname = "__test__.csv"
     params = ["wide", "long", "mixed"]
     param_names = ["kind"]
@@ -56,7 +56,6 @@ class ToCSV(BaseIO):
 
 
 class ToCSVMultiIndexUnusedLevels(BaseIO):
-
     fname = "__test__.csv"
 
     def setup(self):
@@ -76,7 +75,6 @@ class ToCSVMultiIndexUnusedLevels(BaseIO):
 
 
 class ToCSVDatetime(BaseIO):
-
     fname = "__test__.csv"
 
     def setup(self):
@@ -88,7 +86,6 @@ class ToCSVDatetime(BaseIO):
 
 
 class ToCSVDatetimeIndex(BaseIO):
-
     fname = "__test__.csv"
 
     def setup(self):
@@ -102,30 +99,80 @@ class ToCSVDatetimeIndex(BaseIO):
         self.data.to_csv(self.fname)
 
 
-class ToCSVDatetimeBig(BaseIO):
+class ToCSVPeriod(BaseIO):
+    fname = "__test__.csv"
 
+    params = ([1000, 10000], ["D", "H"])
+    param_names = ["nobs", "freq"]
+
+    def setup(self, nobs, freq):
+        rng = period_range(start="2000-01-01", periods=nobs, freq=freq)
+        self.data = DataFrame(rng)
+        if freq == "D":
+            self.default_fmt = "%Y-%m-%d"
+        elif freq == "H":
+            self.default_fmt = "%Y-%m-%d %H:00"
+
+    def time_frame_period_formatting_default(self, nobs, freq):
+        self.data.to_csv(self.fname)
+
+    def time_frame_period_formatting_default_explicit(self, nobs, freq):
+        self.data.to_csv(self.fname, date_format=self.default_fmt)
+
+    def time_frame_period_formatting(self, nobs, freq):
+        # Nb: `date_format` is not actually taken into account here today, so the
+        # performance is currently identical to `time_frame_period_formatting_default`
+        # above. This timer is therefore expected to degrade when GH#51621 is fixed.
+        # (Remove this comment when GH#51621 is fixed.)
+        self.data.to_csv(self.fname, date_format="%Y-%m-%d___%H:%M:%S")
+
+
+class ToCSVPeriodIndex(BaseIO):
+    fname = "__test__.csv"
+
+    params = ([1000, 10000], ["D", "H"])
+    param_names = ["nobs", "freq"]
+
+    def setup(self, nobs, freq):
+        rng = period_range(start="2000-01-01", periods=nobs, freq=freq)
+        self.data = DataFrame({"a": 1}, index=rng)
+        if freq == "D":
+            self.default_fmt = "%Y-%m-%d"
+        elif freq == "H":
+            self.default_fmt = "%Y-%m-%d %H:00"
+
+    def time_frame_period_formatting_index(self, nobs, freq):
+        self.data.to_csv(self.fname, date_format="%Y-%m-%d___%H:%M:%S")
+
+    def time_frame_period_formatting_index_default(self, nobs, freq):
+        self.data.to_csv(self.fname)
+
+    def time_frame_period_formatting_index_default_explicit(self, nobs, freq):
+        self.data.to_csv(self.fname, date_format=self.default_fmt)
+
+
+class ToCSVDatetimeBig(BaseIO):
     fname = "__test__.csv"
     timeout = 1500
     params = [1000, 10000, 100000]
-    param_names = ["obs"]
+    param_names = ["nobs"]
 
-    def setup(self, obs):
+    def setup(self, nobs):
         d = "2018-11-29"
         dt = "2018-11-26 11:18:27.0"
         self.data = DataFrame(
             {
-                "dt": [np.datetime64(dt)] * obs,
-                "d": [np.datetime64(d)] * obs,
-                "r": [np.random.uniform()] * obs,
+                "dt": [np.datetime64(dt)] * nobs,
+                "d": [np.datetime64(d)] * nobs,
+                "r": [np.random.uniform()] * nobs,
             }
         )
 
-    def time_frame(self, obs):
+    def time_frame(self, nobs):
         self.data.to_csv(self.fname)
 
 
 class ToCSVIndexes(BaseIO):
-
     fname = "__test__.csv"
 
     @staticmethod
@@ -179,13 +226,13 @@ class StringIORewind:
 
 
 class ReadCSVDInferDatetimeFormat(StringIORewind):
+    params = [None, "custom", "iso8601", "ymd"]
+    param_names = ["format"]
 
-    params = ([True, False], ["custom", "iso8601", "ymd"])
-    param_names = ["infer_datetime_format", "format"]
-
-    def setup(self, infer_datetime_format, format):
+    def setup(self, format):
         rng = date_range("1/1/2000", periods=1000)
         formats = {
+            None: None,
             "custom": "%m/%d/%Y %H:%M:%S.%f",
             "iso8601": "%Y-%m-%d %H:%M:%S",
             "ymd": "%Y%m%d",
@@ -193,18 +240,16 @@ class ReadCSVDInferDatetimeFormat(StringIORewind):
         dt_format = formats[format]
         self.StringIO_input = StringIO("\n".join(rng.strftime(dt_format).tolist()))
 
-    def time_read_csv(self, infer_datetime_format, format):
+    def time_read_csv(self, format):
         read_csv(
             self.data(self.StringIO_input),
             header=None,
             names=["foo"],
             parse_dates=["foo"],
-            infer_datetime_format=infer_datetime_format,
         )
 
 
 class ReadCSVConcatDatetime(StringIORewind):
-
     iso8601 = "%Y-%m-%d %H:%M:%S"
 
     def setup(self):
@@ -217,12 +262,10 @@ class ReadCSVConcatDatetime(StringIORewind):
             header=None,
             names=["foo"],
             parse_dates=["foo"],
-            infer_datetime_format=False,
         )
 
 
 class ReadCSVConcatDatetimeBadDateValue(StringIORewind):
-
     params = (["nan", "0", ""],)
     param_names = ["bad_date_value"]
 
@@ -235,12 +278,10 @@ class ReadCSVConcatDatetimeBadDateValue(StringIORewind):
             header=None,
             names=["foo", "bar"],
             parse_dates=["foo"],
-            infer_datetime_format=False,
         )
 
 
 class ReadCSVSkipRows(BaseIO):
-
     fname = "__test__.csv"
     params = ([None, 10000], ["c", "python", "pyarrow"])
     param_names = ["skiprows", "engine"]
@@ -286,7 +327,6 @@ class ReadUint64Integers(StringIORewind):
 
 
 class ReadCSVThousands(BaseIO):
-
     fname = "__test__.csv"
     params = ([",", "|"], [None, ","], ["c", "python"])
     param_names = ["sep", "thousands", "engine"]
@@ -299,7 +339,7 @@ class ReadCSVThousands(BaseIO):
         if thousands is not None:
             fmt = f":{thousands}"
             fmt = "{" + fmt + "}"
-            df = df.applymap(lambda x: fmt.format(x))
+            df = df.map(lambda x: fmt.format(x))
         df.to_csv(self.fname, sep=sep)
 
     def time_thousands(self, sep, thousands, engine):
@@ -321,7 +361,6 @@ class ReadCSVComment(StringIORewind):
 
 
 class ReadCSVFloatPrecision(StringIORewind):
-
     params = ([",", ";"], [".", "_"], [None, "high", "round_trip"])
     param_names = ["sep", "decimal", "float_precision"]
 
@@ -330,7 +369,7 @@ class ReadCSVFloatPrecision(StringIORewind):
             "".join([random.choice(string.digits) for _ in range(28)])
             for _ in range(15)
         ]
-        rows = sep.join([f"0{decimal}" + "{}"] * 3) + "\n"
+        rows = sep.join([f"0{decimal}{{}}"] * 3) + "\n"
         data = rows * 5
         data = data.format(*floats) * 200  # 1000 x 3 strings csv
         self.StringIO_input = StringIO(data)
@@ -373,7 +412,6 @@ class ReadCSVEngine(StringIORewind):
 
 
 class ReadCSVCategorical(BaseIO):
-
     fname = "__test__.csv"
     params = ["c", "python"]
     param_names = ["engine"]
@@ -450,7 +488,6 @@ class ReadCSVCachedParseDates(StringIORewind):
 
 
 class ReadCSVMemoryGrowth(BaseIO):
-
     chunksize = 20
     num_rows = 1000
     fname = "__test__.csv"
@@ -458,7 +495,7 @@ class ReadCSVMemoryGrowth(BaseIO):
     param_names = ["engine"]
 
     def setup(self, engine):
-        with open(self.fname, "w") as f:
+        with open(self.fname, "w", encoding="utf-8") as f:
             for i in range(self.num_rows):
                 f.write(f"{i}\n")
 
@@ -496,7 +533,6 @@ class ReadCSVParseSpecialDate(StringIORewind):
 
 
 class ReadCSVMemMapUTF8:
-
     fname = "__test__.csv"
     number = 5
 
@@ -570,4 +606,19 @@ class ReadCSVIndexCol(StringIORewind):
         read_csv(self.StringIO_input, index_col="a")
 
 
+class ReadCSVDatePyarrowEngine(StringIORewind):
+    def setup(self):
+        count_elem = 100_000
+        data = "a\n" + "2019-12-31\n" * count_elem
+        self.StringIO_input = StringIO(data)
+
+    def time_read_csv_index_col(self):
+        read_csv(
+            self.StringIO_input,
+            parse_dates=["a"],
+            engine="pyarrow",
+            dtype_backend="pyarrow",
+        )
+
+
 from ..pandas_vb_common import setup  # noqa: F401 isort:skip
