@@ -25,7 +25,6 @@ except ImportError:
 
 
 class PeriodProperties:
-
     params = (
         ["M", "min"],
         [
@@ -56,12 +55,15 @@ class PeriodProperties:
 
 
 class PeriodUnaryMethods:
-
     params = ["M", "min"]
     param_names = ["freq"]
 
     def setup(self, freq):
         self.per = Period("2012-06-01", freq=freq)
+        if freq == "M":
+            self.default_fmt = "%Y-%m"
+        elif freq == "min":
+            self.default_fmt = "%Y-%m-%d %H:%M"
 
     def time_to_timestamp(self, freq):
         self.per.to_timestamp()
@@ -72,6 +74,21 @@ class PeriodUnaryMethods:
     def time_asfreq(self, freq):
         self.per.asfreq("A")
 
+    def time_str(self, freq):
+        str(self.per)
+
+    def time_repr(self, freq):
+        repr(self.per)
+
+    def time_strftime_default(self, freq):
+        self.per.strftime(None)
+
+    def time_strftime_default_explicit(self, freq):
+        self.per.strftime(self.default_fmt)
+
+    def time_strftime_custom(self, freq):
+        self.per.strftime("%b. %d, %Y was a %A")
+
 
 class PeriodConstructor:
     params = [["D"], [True, False]]
