@@ -50,62 +50,58 @@ class TimestampConstruction:
 
 
 class TimestampProperties:
-    _freqs = [None, "B"]
-    params = [_tzs, _freqs]
-    param_names = ["tz", "freq"]
+    params = [_tzs]
+    param_names = ["tz"]
 
-    def setup(self, tz, freq):
-        self.ts = Timestamp("2017-08-25 08:16:14", tzinfo=tz, freq=freq)
+    def setup(self, tz):
+        self.ts = Timestamp("2017-08-25 08:16:14", tzinfo=tz)
 
-    def time_tz(self, tz, freq):
+    def time_tz(self, tz):
         self.ts.tz
 
-    def time_dayofweek(self, tz, freq):
+    def time_dayofweek(self, tz):
         self.ts.dayofweek
 
-    def time_dayofyear(self, tz, freq):
+    def time_dayofyear(self, tz):
         self.ts.dayofyear
 
-    def time_week(self, tz, freq):
+    def time_week(self, tz):
         self.ts.week
 
-    def time_quarter(self, tz, freq):
+    def time_quarter(self, tz):
         self.ts.quarter
 
-    def time_days_in_month(self, tz, freq):
+    def time_days_in_month(self, tz):
         self.ts.days_in_month
 
-    def time_freqstr(self, tz, freq):
-        self.ts.freqstr
-
-    def time_is_month_start(self, tz, freq):
+    def time_is_month_start(self, tz):
         self.ts.is_month_start
 
-    def time_is_month_end(self, tz, freq):
+    def time_is_month_end(self, tz):
         self.ts.is_month_end
 
-    def time_is_quarter_start(self, tz, freq):
+    def time_is_quarter_start(self, tz):
         self.ts.is_quarter_start
 
-    def time_is_quarter_end(self, tz, freq):
+    def time_is_quarter_end(self, tz):
         self.ts.is_quarter_end
 
-    def time_is_year_start(self, tz, freq):
+    def time_is_year_start(self, tz):
         self.ts.is_year_start
 
-    def time_is_year_end(self, tz, freq):
+    def time_is_year_end(self, tz):
         self.ts.is_year_end
 
-    def time_is_leap_year(self, tz, freq):
+    def time_is_leap_year(self, tz):
         self.ts.is_leap_year
 
-    def time_microsecond(self, tz, freq):
+    def time_microsecond(self, tz):
         self.ts.microsecond
 
-    def time_month_name(self, tz, freq):
+    def time_month_name(self, tz):
         self.ts.month_name()
 
-    def time_weekday_name(self, tz, freq):
+    def time_weekday_name(self, tz):
         self.ts.day_name()
 
 
