@@ -17,13 +17,13 @@ GitHub. See Python Software Foundation License and BSD licenses for these.
 
 */
 
-#include "tokenizer.h"
+#include "pandas/parser/tokenizer.h"
 
 #include <ctype.h>
 #include <float.h>
 #include <math.h>
 
-#include "../headers/portable.h"
+#include "pandas/portable.h"
 
 void coliter_setup(coliter_t *self, parser_t *parser, int64_t i,
                    int64_t start) {
@@ -105,7 +105,7 @@ void parser_set_default_options(parser_t *self) {
     self->skip_footer = 0;
 }
 
-parser_t *parser_new() { return (parser_t *)calloc(1, sizeof(parser_t)); }
+parser_t *parser_new(void) { return (parser_t *)calloc(1, sizeof(parser_t)); }
 
 int parser_clear_data_buffers(parser_t *self) {
     free_if_not_null((void *)&self->stream);
@@ -664,9 +664,8 @@ static int parser_buffer_bytes(parser_t *self, size_t nbytes,
     ((!self->delim_whitespace && c == ' ' && self->skipinitialspace))
 
 // applied when in a field
-#define IS_DELIMITER(c)                                   \
-    ((!self->delim_whitespace && c == self->delimiter) || \
-     (self->delim_whitespace && isblank(c)))
+#define IS_DELIMITER(c) \
+    ((!delim_whitespace && c == delimiter) || (delim_whitespace && isblank(c)))
 
 #define _TOKEN_CLEANUP()                                                \
     self->stream_len = slen;                                            \
@@ -721,6 +720,9 @@ int tokenize_bytes(parser_t *self,
     const char lineterminator = (self->lineterminator == '\0') ?
             '\n' : self->lineterminator;
 
+    const int delim_whitespace = self->delim_whitespace;
+    const char delimiter = self->delimiter;
+
     // 1000 is something that couldn't fit in "char"
     // thus comparing a char to it would always be "false"
     const int carriage_symbol = (self->lineterminator == '\0') ? '\r' : 1000;
@@ -1828,7 +1830,7 @@ char* _str_copy_decimal_str_c(const char *s, char **endpos, char decimal,
 double round_trip(const char *p, char **q, char decimal, char sci, char tsep,
                   int skip_trailing, int *error, int *maybe_int) {
     // 'normalize' representation to C-locale; replace decimal with '.' and
-    // remove t(housand)sep.
+    // remove thousands separator.
     char *endptr;
     char *pc = _str_copy_decimal_str_c(p, &endptr, decimal, tsep);
     // This is called from a nogil block in parsers.pyx
