@@ -2,8 +2,15 @@
 from __future__ import annotations
 
 import ast
+from decimal import (
+    Decimal,
+    InvalidOperation,
+)
 from functools import partial
-from typing import Any
+from typing import (
+    TYPE_CHECKING,
+    Any,
+)
 
 import numpy as np
 
@@ -11,7 +18,7 @@ from pandas._libs.tslibs import (
     Timedelta,
     Timestamp,
 )
-from pandas.compat.chainmap import DeepChainMap
+from pandas.errors import UndefinedVariableError
 
 from pandas.core.dtypes.common import is_list_like
 
@@ -23,10 +30,7 @@ from pandas.core.computation import (
 )
 from pandas.core.computation.common import ensure_decoded
 from pandas.core.computation.expr import BaseExprVisitor
-from pandas.core.computation.ops import (
-    UndefinedVariableError,
-    is_term,
-)
+from pandas.core.computation.ops import is_term
 from pandas.core.construction import extract_array
 from pandas.core.indexes.base import Index
 
@@ -35,6 +39,9 @@ from pandas.io.formats.printing import (
     pprint_thing_encoded,
 )
 
+if TYPE_CHECKING:
+    from pandas._typing import npt
+
 
 class PyTablesScope(_scope.Scope):
     __slots__ = ("queryables",)
@@ -47,7 +54,7 @@ class PyTablesScope(_scope.Scope):
         global_dict=None,
         local_dict=None,
         queryables: dict[str, Any] | None = None,
-    ):
+    ) -> None:
         super().__init__(level + 1, global_dict=global_dict, local_dict=local_dict)
         self.queryables = queryables or {}
 
@@ -62,7 +69,7 @@ class Term(ops.Term):
             klass = Constant
         return object.__new__(klass)
 
-    def __init__(self, name, env: PyTablesScope, side=None, encoding=None):
+    def __init__(self, name, env: PyTablesScope, side=None, encoding=None) -> None:
         super().__init__(name, env, side=side, encoding=encoding)
 
     def _resolve_name(self):
@@ -86,29 +93,28 @@ class Term(ops.Term):
 
 
 class Constant(Term):
-    def __init__(self, value, env: PyTablesScope, side=None, encoding=None):
+    def __init__(self, name, env: PyTablesScope, side=None, encoding=None) -> None:
         assert isinstance(env, PyTablesScope), type(env)
-        super().__init__(value, env, side=side, encoding=encoding)
+        super().__init__(name, env, side=side, encoding=encoding)
 
     def _resolve_name(self):
         return self._name
 
 
 class BinOp(ops.BinOp):
-
     _max_selectors = 31
 
     op: str
     queryables: dict[str, Any]
     condition: str | None
 
-    def __init__(self, op: str, lhs, rhs, queryables: dict[str, Any], encoding):
+    def __init__(self, op: str, lhs, rhs, queryables: dict[str, Any], encoding) -> None:
         super().__init__(op, lhs, rhs)
         self.queryables = queryables
         self.encoding = encoding
         self.condition = None
 
-    def _disallow_scalar_only_bool_ops(self):
+    def _disallow_scalar_only_bool_ops(self) -> None:
         pass
 
     def prune(self, klass):
@@ -207,36 +213,45 @@ class BinOp(ops.BinOp):
 
         kind = ensure_decoded(self.kind)
         meta = ensure_decoded(self.meta)
-        if kind == "datetime64" or kind == "datetime":
+        if kind in ("datetime64", "datetime"):
             if isinstance(v, (int, float)):
                 v = stringify(v)
             v = ensure_decoded(v)
-            v = Timestamp(v)
+            v = Timestamp(v).as_unit("ns")
             if v.tz is not None:
                 v = v.tz_convert("UTC")
-            return TermValue(v, v.value, kind)
-        elif kind == "timedelta64" or kind == "timedelta":
+            return TermValue(v, v._value, kind)
+        elif kind in ("timedelta64", "timedelta"):
             if isinstance(v, str):
-                v = Timedelta(v).value
+                v = Timedelta(v)
             else:
-                v = Timedelta(v, unit="s").value
+                v = Timedelta(v, unit="s")
+            v = v.as_unit("ns")._value
             return TermValue(int(v), v, kind)
         elif meta == "category":
             metadata = extract_array(self.metadata, extract_numpy=True)
+            result: npt.NDArray[np.intp] | np.intp | int
             if v not in metadata:
                 result = -1
             else:
                 result = metadata.searchsorted(v, side="left")
             return TermValue(result, result, "integer")
         elif kind == "integer":
-            v = int(float(v))
+            try:
+                v_dec = Decimal(v)
+            except InvalidOperation:
+                # GH 54186
+                # convert v to float to raise float's ValueError
+                float(v)
+            else:
+                v = int(v_dec.to_integral_exact(rounding="ROUND_HALF_EVEN"))
             return TermValue(v, v, kind)
         elif kind == "float":
             v = float(v)
             return TermValue(v, v, kind)
         elif kind == "bool":
             if isinstance(v, str):
-                v = not v.strip().lower() in [
+                v = v.strip().lower() not in [
                     "false",
                     "f",
                     "no",
@@ -256,7 +271,7 @@ class BinOp(ops.BinOp):
         else:
             raise TypeError(f"Cannot compare {v} of type {type(v)} to {kind} column")
 
-    def convert_values(self):
+    def convert_values(self) -> None:
         pass
 
 
@@ -283,7 +298,6 @@ class FilterBinOp(BinOp):
         return [self.filter]
 
     def evaluate(self):
-
         if not self.is_valid:
             raise ValueError(f"query term is not valid [{self}]")
 
@@ -291,10 +305,8 @@ class FilterBinOp(BinOp):
         values = list(rhs)
 
         if self.is_in_table:
-
             # if too many values to create the expression, use a filter instead
             if self.op in ["==", "!="] and len(values) > self._max_selectors:
-
                 filter_op = self.generate_filter_op()
                 self.filter = (self.lhs, filter_op, Index(values))
 
@@ -303,7 +315,6 @@ class FilterBinOp(BinOp):
 
         # equality conditions
         if self.op in ["==", "!="]:
-
             filter_op = self.generate_filter_op()
             self.filter = (self.lhs, filter_op, Index(values))
 
@@ -347,7 +358,6 @@ class ConditionBinOp(BinOp):
         return self.condition
 
     def evaluate(self):
-
         if not self.is_valid:
             raise ValueError(f"query term is not valid [{self}]")
 
@@ -360,7 +370,6 @@ class ConditionBinOp(BinOp):
 
         # equality conditions
         if self.op in ["==", "!="]:
-
             # too many values to create the expression?
             if len(values) <= self._max_selectors:
                 vs = [self.generate(v) for v in values]
@@ -383,7 +392,6 @@ class JointConditionBinOp(ConditionBinOp):
 
 class UnaryOp(ops.UnaryOp):
     def prune(self, klass):
-
         if self.op != "~":
             raise NotImplementedError("UnaryOp only support invert type ops")
 
@@ -405,7 +413,7 @@ class PyTablesExprVisitor(BaseExprVisitor):
     const_type = Constant
     term_type = Term
 
-    def __init__(self, env, engine, parser, **kwargs):
+    def __init__(self, env, engine, parser, **kwargs) -> None:
         super().__init__(env, engine, parser)
         for bin_op in self.binary_ops:
             bin_node = self.binary_op_nodes_map[bin_op]
@@ -465,13 +473,12 @@ class PyTablesExprVisitor(BaseExprVisitor):
             # try to get the value to see if we are another expression
             try:
                 resolved = resolved.value
-            except (AttributeError):
+            except AttributeError:
                 pass
 
             try:
                 return self.term_type(getattr(resolved, attr), self.env)
             except AttributeError:
-
                 # something like datetime.datetime where scope is overridden
                 if isinstance(value, ast.Name) and value.id == attr:
                     return resolved
@@ -550,8 +557,7 @@ class PyTablesExpr(expr.Expr):
         queryables: dict[str, Any] | None = None,
         encoding=None,
         scope_level: int = 0,
-    ):
-
+    ) -> None:
         where = _validate_where(where)
 
         self.encoding = encoding
@@ -561,7 +567,7 @@ class PyTablesExpr(expr.Expr):
         self._visitor = None
 
         # capture the environment if needed
-        local_dict: DeepChainMap[Any, Any] = DeepChainMap()
+        local_dict: _scope.DeepChainMap[Any, Any] | None = None
 
         if isinstance(where, PyTablesExpr):
             local_dict = where.env.scope
@@ -573,9 +579,8 @@ class PyTablesExpr(expr.Expr):
                 if isinstance(w, PyTablesExpr):
                     local_dict = w.env.scope
                 else:
-                    w = _validate_where(w)
-                    where[idx] = w
-            _where = " & ".join(f"({w})" for w in com.flatten(where))
+                    where[idx] = _validate_where(w)
+            _where = " & ".join([f"({w})" for w in com.flatten(where)])
         else:
             # _validate_where ensures we otherwise have a string
             _where = where
@@ -622,7 +627,7 @@ class PyTablesExpr(expr.Expr):
 class TermValue:
     """hold a term value the we use to construct a condition/filter"""
 
-    def __init__(self, value, converted, kind: str):
+    def __init__(self, value, converted, kind: str) -> None:
         assert isinstance(kind, str), kind
         self.value = value
         self.converted = converted
@@ -645,7 +650,7 @@ def maybe_expression(s) -> bool:
     """loose checking if s is a pytables-acceptable expression"""
     if not isinstance(s, str):
         return False
-    ops = PyTablesExprVisitor.binary_ops + PyTablesExprVisitor.unary_ops + ("=",)
+    operations = PyTablesExprVisitor.binary_ops + PyTablesExprVisitor.unary_ops + ("=",)
 
     # make sure we have an op at least
-    return any(op in s for op in ops)
+    return any(op in s for op in operations)
