@@ -1,14 +1,21 @@
 """ basic inference routines """
 
+from __future__ import annotations
+
 from collections import abc
 from numbers import Number
 import re
-from typing import Pattern
+from re import Pattern
+from typing import TYPE_CHECKING
 
 import numpy as np
 
 from pandas._libs import lib
-from pandas._typing import ArrayLike
+
+if TYPE_CHECKING:
+    from collections.abc import Hashable
+
+    from pandas._typing import TypeGuard
 
 is_bool = lib.is_bool
 
@@ -29,7 +36,7 @@ is_list_like = lib.is_list_like
 is_iterator = lib.is_iterator
 
 
-def is_number(obj) -> bool:
+def is_number(obj) -> TypeGuard[Number | np.number]:
     """
     Check if the object is a number.
 
@@ -42,7 +49,7 @@ def is_number(obj) -> bool:
 
     Returns
     -------
-    is_number : bool
+    bool
         Whether `obj` is a number or not.
 
     See Also
@@ -112,12 +119,13 @@ def is_file_like(obj) -> bool:
 
     Returns
     -------
-    is_file_like : bool
+    bool
         Whether `obj` has file-like properties.
 
     Examples
     --------
     >>> import io
+    >>> from pandas.api.types import is_file_like
     >>> buffer = io.StringIO("data")
     >>> is_file_like(buffer)
     True
@@ -130,7 +138,7 @@ def is_file_like(obj) -> bool:
     return bool(hasattr(obj, "__iter__"))
 
 
-def is_re(obj) -> bool:
+def is_re(obj) -> TypeGuard[Pattern]:
     """
     Check if the object is a regex pattern instance.
 
@@ -140,11 +148,13 @@ def is_re(obj) -> bool:
 
     Returns
     -------
-    is_regex : bool
+    bool
         Whether `obj` is a regex pattern.
 
     Examples
     --------
+    >>> from pandas.api.types import is_re
+    >>> import re
     >>> is_re(re.compile(".*"))
     True
     >>> is_re("foo")
@@ -163,11 +173,12 @@ def is_re_compilable(obj) -> bool:
 
     Returns
     -------
-    is_regex_compilable : bool
+    bool
         Whether `obj` can be compiled as a regex pattern.
 
     Examples
     --------
+    >>> from pandas.api.types import is_re_compilable
     >>> is_re_compilable(".*")
     True
     >>> is_re_compilable(1)
@@ -269,11 +280,12 @@ def is_dict_like(obj) -> bool:
 
     Returns
     -------
-    is_dict_like : bool
+    bool
         Whether `obj` has dict-like properties.
 
     Examples
     --------
+    >>> from pandas.api.types import is_dict_like
     >>> is_dict_like({1: 2})
     True
     >>> is_dict_like([1, 2, 3])
@@ -301,12 +313,13 @@ def is_named_tuple(obj) -> bool:
 
     Returns
     -------
-    is_named_tuple : bool
+    bool
         Whether `obj` is a named tuple.
 
     Examples
     --------
     >>> from collections import namedtuple
+    >>> from pandas.api.types import is_named_tuple
     >>> Point = namedtuple("Point", ["x", "y"])
     >>> p = Point(1, 2)
     >>>
@@ -315,10 +328,10 @@ def is_named_tuple(obj) -> bool:
     >>> is_named_tuple((1, 2))
     False
     """
-    return isinstance(obj, tuple) and hasattr(obj, "_fields")
+    return isinstance(obj, abc.Sequence) and hasattr(obj, "_fields")
 
 
-def is_hashable(obj) -> bool:
+def is_hashable(obj) -> TypeGuard[Hashable]:
     """
     Return True if hash(obj) will succeed, False otherwise.
 
@@ -335,6 +348,7 @@ def is_hashable(obj) -> bool:
     Examples
     --------
     >>> import collections
+    >>> from pandas.api.types import is_hashable
     >>> a = ([],)
     >>> isinstance(a, collections.abc.Hashable)
     True
@@ -416,36 +430,8 @@ def is_dataclass(item):
 
     """
     try:
-        from dataclasses import is_dataclass
+        import dataclasses
 
-        return is_dataclass(item) and not isinstance(item, type)
+        return dataclasses.is_dataclass(item) and not isinstance(item, type)
     except ImportError:
         return False
-
-
-def is_inferred_bool_dtype(arr: ArrayLike) -> bool:
-    """
-    Check if this is a ndarray[bool] or an ndarray[object] of bool objects.
-
-    Parameters
-    ----------
-    arr : np.ndarray or ExtensionArray
-
-    Returns
-    -------
-    bool
-
-    Notes
-    -----
-    This does not include the special treatment is_bool_dtype uses for
-    Categorical.
-    """
-    if not isinstance(arr, np.ndarray):
-        return False
-
-    dtype = arr.dtype
-    if dtype == np.dtype(bool):
-        return True
-    elif dtype == np.dtype("object"):
-        return lib.is_bool_array(arr.ravel("K"))
-    return False
