@@ -1,47 +1,36 @@
 from __future__ import annotations
 
 from typing import (
+    TYPE_CHECKING,
     Any,
-    Hashable,
+    Literal,
+    cast,
 )
-import warnings
 
 import numpy as np
 
-from pandas._config import get_option
-
 from pandas._libs import index as libindex
-from pandas._typing import (
-    ArrayLike,
-    Dtype,
-    DtypeObj,
-)
 from pandas.util._decorators import (
-    Appender,
+    cache_readonly,
     doc,
 )
 
-from pandas.core.dtypes.common import (
-    ensure_platform_int,
-    is_categorical_dtype,
-    is_scalar,
-)
+from pandas.core.dtypes.common import is_scalar
+from pandas.core.dtypes.concat import concat_compat
+from pandas.core.dtypes.dtypes import CategoricalDtype
 from pandas.core.dtypes.missing import (
     is_valid_na_for_dtype,
     isna,
     notna,
 )
 
-from pandas.core import accessor
 from pandas.core.arrays.categorical import (
     Categorical,
     contains,
 )
 from pandas.core.construction import extract_array
-import pandas.core.indexes.base as ibase
 from pandas.core.indexes.base import (
     Index,
-    _index_shared_docs,
     maybe_extract_name,
 )
 from pandas.core.indexes.extension import (
@@ -49,29 +38,34 @@ from pandas.core.indexes.extension import (
     inherit_names,
 )
 
-_index_doc_kwargs: dict[str, str] = dict(ibase._index_doc_kwargs)
-_index_doc_kwargs.update({"target_klass": "CategoricalIndex"})
+from pandas.io.formats.printing import pprint_thing
+
+if TYPE_CHECKING:
+    from collections.abc import Hashable
+
+    from pandas._typing import (
+        Dtype,
+        DtypeObj,
+        npt,
+    )
 
 
 @inherit_names(
     [
         "argsort",
-        "_internal_get_values",
         "tolist",
         "codes",
         "categories",
         "ordered",
         "_reverse_indexer",
         "searchsorted",
-        "is_dtype_equal",
         "min",
         "max",
     ],
     Categorical,
 )
-@accessor.delegate_names(
-    delegate=Categorical,
-    accessors=[
+@inherit_names(
+    [
         "rename_categories",
         "reorder_categories",
         "add_categories",
@@ -81,10 +75,10 @@ _index_doc_kwargs.update({"target_klass": "CategoricalIndex"})
         "as_ordered",
         "as_unordered",
     ],
-    typ="method",
-    overwrite=True,
+    Categorical,
+    wrap=True,
 )
-class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
+class CategoricalIndex(NDArrayBackedExtensionIndex):
     """
     Index based on an underlying :class:`Categorical`.
 
@@ -184,13 +178,18 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
     def _can_hold_strings(self):
         return self.categories._can_hold_strings
 
+    @cache_readonly
+    def _should_fallback_to_positional(self) -> bool:
+        return self.categories._should_fallback_to_positional
+
     codes: np.ndarray
     categories: Index
+    ordered: bool | None
     _data: Categorical
     _values: Categorical
 
     @property
-    def _engine_type(self):
+    def _engine_type(self) -> type[libindex.IndexEngine]:
         # self.codes can have dtype int8, int16, int32 or int64, so we need
         # to return the corresponding engine type (libindex.Int8Engine, etc.).
         return {
@@ -200,8 +199,6 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
             np.int64: libindex.Int64Engine,
         }[self.codes.dtype.type]
 
-    _attributes = ["name"]
-
     # --------------------------------------------------------------------
     # Constructors
 
@@ -212,24 +209,13 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
         ordered=None,
         dtype: Dtype | None = None,
         copy: bool = False,
-        name: Hashable = None,
+        name: Hashable | None = None,
     ) -> CategoricalIndex:
-
         name = maybe_extract_name(name, data, cls)
 
-        if data is None:
-            # GH#38944
-            warnings.warn(
-                "Constructing a CategoricalIndex without passing data is "
-                "deprecated and will raise in a future version. "
-                "Use CategoricalIndex([], ...) instead",
-                FutureWarning,
-                stacklevel=2,
-            )
-            data = []
-
         if is_scalar(data):
-            raise cls._scalar_data_error(data)
+            # GH#38944 include None here, which pre-2.0 subbed in []
+            cls._raise_scalar_data_error(data)
 
         data = Categorical(
             data, categories=categories, ordered=ordered, dtype=dtype, copy=copy
@@ -239,7 +225,7 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
 
     # --------------------------------------------------------------------
 
-    def _is_dtype_compat(self, other) -> Categorical:
+    def _is_dtype_compat(self, other: Index) -> Categorical:
         """
         *this is an internal non-public method*
 
@@ -258,9 +244,10 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
         ------
         TypeError if the dtypes are not compatible
         """
-        if is_categorical_dtype(other):
-            other = extract_array(other)
-            if not other._categories_match_up_to_permutation(self):
+        if isinstance(other.dtype, CategoricalDtype):
+            cat = extract_array(other)
+            cat = cast(Categorical, cat)
+            if not cat._categories_match_up_to_permutation(self._values):
                 raise TypeError(
                     "categories must match existing categories when appending"
                 )
@@ -277,15 +264,15 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
                 raise TypeError(
                     "cannot append a non-category item to a CategoricalIndex"
                 )
-            other = other._values
+            cat = other._values
 
-            if not ((other == values) | (isna(other) & isna(values))).all():
+            if not ((cat == values) | (isna(cat) & isna(values))).all():
                 # GH#37667 see test_equals_non_category
                 raise TypeError(
                     "categories must match existing categories when appending"
                 )
 
-        return other
+        return cat
 
     def equals(self, other: object) -> bool:
         """
@@ -294,8 +281,43 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
         Returns
         -------
         bool
-            If two CategoricalIndex objects have equal elements True,
-            otherwise False.
+            ``True`` if two :class:`pandas.CategoricalIndex` objects have equal
+            elements, ``False`` otherwise.
+
+        Examples
+        --------
+        >>> ci = pd.CategoricalIndex(['a', 'b', 'c', 'a', 'b', 'c'])
+        >>> ci2 = pd.CategoricalIndex(pd.Categorical(['a', 'b', 'c', 'a', 'b', 'c']))
+        >>> ci.equals(ci2)
+        True
+
+        The order of elements matters.
+
+        >>> ci3 = pd.CategoricalIndex(['c', 'b', 'a', 'a', 'b', 'c'])
+        >>> ci.equals(ci3)
+        False
+
+        The orderedness also matters.
+
+        >>> ci4 = ci.as_ordered()
+        >>> ci.equals(ci4)
+        False
+
+        The categories matter, but the order of the categories matters only when
+        ``ordered=True``.
+
+        >>> ci5 = ci.set_categories(['a', 'b', 'c', 'd'])
+        >>> ci.equals(ci5)
+        False
+
+        >>> ci6 = ci.set_categories(['b', 'c', 'a'])
+        >>> ci.equals(ci6)
+        True
+        >>> ci_ordered = pd.CategoricalIndex(['a', 'b', 'c', 'a', 'b', 'c'],
+        ...                                  ordered=True)
+        >>> ci2_ordered = ci_ordered.set_categories(['b', 'c', 'a'])
+        >>> ci_ordered.equals(ci2_ordered)
+        False
         """
         if self.is_(other):
             return True
@@ -321,25 +343,19 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
         """
         Return a list of tuples of the (attr,formatted_value)
         """
-        max_categories = (
-            10
-            if get_option("display.max_categories") == 0
-            else get_option("display.max_categories")
-        )
+        attrs: list[tuple[str, str | int | bool | None]]
+
         attrs = [
             (
                 "categories",
-                ibase.default_pprint(self.categories, max_seq_items=max_categories),
+                f"[{', '.join(self._data._repr_categories())}]",
             ),
-            # error: "CategoricalIndex" has no attribute "ordered"
-            ("ordered", self.ordered),  # type: ignore[attr-defined]
+            ("ordered", self.ordered),
         ]
         extra = super()._format_attrs()
         return attrs + extra
 
-    def _format_with_header(self, header: list[str], na_rep: str = "NaN") -> list[str]:
-        from pandas.io.formats.printing import pprint_thing
-
+    def _format_with_header(self, header: list[str], na_rep: str) -> list[str]:
         result = [
             pprint_thing(x, escape_chars=("\t", "\r", "\n")) if notna(x) else na_rep
             for x in self._values
@@ -360,23 +376,9 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
 
         return contains(self, key, container=self._engine)
 
-    @doc(Index.fillna)
-    def fillna(self, value, downcast=None):
-        value = self._require_scalar(value)
-        try:
-            cat = self._data.fillna(value)
-        except (ValueError, TypeError):
-            # invalid fill_value
-            if not self.isna().any():
-                # nothing to fill, we can get away without casting
-                return self.copy()
-            return self.astype(object).fillna(value, downcast=downcast)
-
-        return type(self)._simple_new(cat, name=self.name)
-
     def reindex(
-        self, target, method=None, level=None, limit=None, tolerance=None
-    ) -> tuple[Index, np.ndarray | None]:
+        self, target, method=None, level=None, limit: int | None = None, tolerance=None
+    ) -> tuple[Index, npt.NDArray[np.intp] | None]:
         """
         Create index with target's values (move/add/delete values as necessary)
 
@@ -400,79 +402,7 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
             raise NotImplementedError(
                 "argument limit is not implemented for CategoricalIndex.reindex"
             )
-
-        target = ibase.ensure_index(target)
-
-        if self.equals(target):
-            indexer = None
-            missing = np.array([], dtype=np.intp)
-        else:
-            indexer, missing = self.get_indexer_non_unique(np.array(target))
-
-        if len(self.codes) and indexer is not None:
-            new_target = self.take(indexer)
-        else:
-            new_target = target
-
-        # filling in missing if needed
-        if len(missing):
-            cats = self.categories.get_indexer(target)
-
-            if not isinstance(cats, CategoricalIndex) or (cats == -1).any():
-                # coerce to a regular index here!
-                result = Index(np.array(self), name=self.name)
-                new_target, indexer, _ = result._reindex_non_unique(target)
-            else:
-
-                codes = new_target.codes.copy()
-                codes[indexer == -1] = cats[missing]
-                cat = self._data._from_backing_data(codes)
-                new_target = type(self)._simple_new(cat, name=self.name)
-
-        # we always want to return an Index type here
-        # to be consistent with .reindex for other index types (e.g. they don't
-        # coerce based on the actual values, only on the dtype)
-        # unless we had an initial Categorical to begin with
-        # in which case we are going to conform to the passed Categorical
-        new_target = np.asarray(new_target)
-        if is_categorical_dtype(target):
-            cat = Categorical(new_target, dtype=target.dtype)
-            new_target = type(self)._simple_new(cat, name=self.name)
-        else:
-            new_target = Index(new_target, name=self.name)
-
-        return new_target, indexer
-
-    # error: Return type "Tuple[Index, Optional[ndarray], Optional[ndarray]]"
-    # of "_reindex_non_unique" incompatible with return type
-    # "Tuple[Index, ndarray, Optional[ndarray]]" in supertype "Index"
-    def _reindex_non_unique(  # type: ignore[override]
-        self, target: Index
-    ) -> tuple[Index, np.ndarray | None, np.ndarray | None]:
-        """
-        reindex from a non-unique; which CategoricalIndex's are almost
-        always
-        """
-        # TODO: rule out `indexer is None` here to make the signature
-        #  match the parent class's signature. This should be equivalent
-        #  to ruling out `self.equals(target)`
-        new_target, indexer = self.reindex(target)
-        new_indexer = None
-
-        check = indexer == -1
-        # error: Item "bool" of "Union[Any, bool]" has no attribute "any"
-        if check.any():  # type: ignore[union-attr]
-            new_indexer = np.arange(len(self.take(indexer)), dtype=np.intp)
-            new_indexer[check] = -1
-
-        cats = self.categories.get_indexer(target)
-        if not (cats == -1).any():
-            # .reindex returns normal Index. Revert to CategoricalIndex if
-            # all targets are included in my categories
-            cat = Categorical(new_target, dtype=self.dtype)
-            new_target = type(self)._simple_new(cat, name=self.name)
-
-        return new_target, indexer, new_indexer
+        return super().reindex(target)
 
     # --------------------------------------------------------------------
     # Indexing Methods
@@ -502,67 +432,14 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
             cat = self._data._from_backing_data(codes)
         return type(self)._simple_new(cat)
 
-    def _get_indexer(
-        self,
-        target: Index,
-        method: str | None = None,
-        limit: int | None = None,
-        tolerance=None,
-    ) -> np.ndarray:
-        # returned ndarray is np.intp
-
-        if self.equals(target):
-            return np.arange(len(self), dtype="intp")
-
-        return self._get_indexer_non_unique(target._values)[0]
-
-    @Appender(_index_shared_docs["get_indexer_non_unique"] % _index_doc_kwargs)
-    def get_indexer_non_unique(self, target) -> tuple[np.ndarray, np.ndarray]:
-        # both returned ndarrays are np.intp
-        target = ibase.ensure_index(target)
-        return self._get_indexer_non_unique(target._values)
-
-    def _get_indexer_non_unique(
-        self, values: ArrayLike
-    ) -> tuple[np.ndarray, np.ndarray]:
-        # both returned ndarrays are np.intp
-        """
-        get_indexer_non_unique but after unrapping the target Index object.
-        """
-        # Note: we use engine.get_indexer_non_unique for get_indexer in addition
-        #  to get_indexer_non_unique because, even if `target` is unique, any
-        #  non-category entries in it will be encoded as -1  so `codes` may
-        #  not be unique.
-
-        if isinstance(values, Categorical):
-            # Indexing on codes is more efficient if categories are the same,
-            #  so we can apply some optimizations based on the degree of
-            #  dtype-matching.
-            cat = self._data._encode_with_my_categories(values)
-            codes = cat._codes
-        else:
-            codes = self.categories.get_indexer(values)
-
-        indexer, missing = self._engine.get_indexer_non_unique(codes)
-        return ensure_platform_int(indexer), ensure_platform_int(missing)
-
     # --------------------------------------------------------------------
 
     def _is_comparable_dtype(self, dtype: DtypeObj) -> bool:
         return self.categories._is_comparable_dtype(dtype)
 
-    def take_nd(self, *args, **kwargs):
-        """Alias for `take`"""
-        warnings.warn(
-            "CategoricalIndex.take_nd is deprecated, use CategoricalIndex.take instead",
-            FutureWarning,
-            stacklevel=2,
-        )
-        return self.take(*args, **kwargs)
-
-    def map(self, mapper):
+    def map(self, mapper, na_action: Literal["ignore"] | None = None):
         """
-        Map values using input correspondence (a dict, Series, or function).
+        Map values using input an input mapping or function.
 
         Maps the values (their categories, not the codes) of the index to new
         categories. If the mapping correspondence is one-to-one the result is a
@@ -627,29 +504,19 @@ class CategoricalIndex(NDArrayBackedExtensionIndex, accessor.PandasDelegate):
         >>> idx.map({'a': 'first', 'b': 'second'})
         Index(['first', 'second', nan], dtype='object')
         """
-        mapped = self._values.map(mapper)
+        mapped = self._values.map(mapper, na_action=na_action)
         return Index(mapped, name=self.name)
 
     def _concat(self, to_concat: list[Index], name: Hashable) -> Index:
         # if calling index is category, don't check dtype of others
         try:
-            codes = np.concatenate([self._is_dtype_compat(c).codes for c in to_concat])
+            cat = Categorical._concat_same_type(
+                [self._is_dtype_compat(c) for c in to_concat]
+            )
         except TypeError:
             # not all to_concat elements are among our categories (or NA)
-            from pandas.core.dtypes.concat import concat_compat
 
-            res = concat_compat(to_concat)
+            res = concat_compat([x._values for x in to_concat])
             return Index(res, name=name)
         else:
-            cat = self._data._from_backing_data(codes)
             return type(self)._simple_new(cat, name=name)
-
-    def _delegate_method(self, name: str, *args, **kwargs):
-        """method delegation to the ._values"""
-        method = getattr(self._values, name)
-        if "inplace" in kwargs:
-            raise ValueError("cannot use inplace with CategoricalIndex")
-        res = method(*args, **kwargs)
-        if is_scalar(res):
-            return res
-        return CategoricalIndex(res, name=self.name)
