@@ -4,15 +4,11 @@ from datetime import (
     datetime,
     timedelta,
 )
-from typing import Hashable
-import warnings
+from typing import TYPE_CHECKING
 
 import numpy as np
 
-from pandas._libs import (
-    index as libindex,
-    lib,
-)
+from pandas._libs import index as libindex
 from pandas._libs.tslibs import (
     BaseOffset,
     NaT,
@@ -20,24 +16,14 @@ from pandas._libs.tslibs import (
     Resolution,
     Tick,
 )
-from pandas._libs.tslibs.parsing import (
-    DateParseError,
-    parse_time_string,
+from pandas.util._decorators import (
+    cache_readonly,
+    doc,
 )
-from pandas._typing import (
-    Dtype,
-    DtypeObj,
-)
-from pandas.errors import InvalidIndexError
-from pandas.util._decorators import doc
 
-from pandas.core.dtypes.common import (
-    is_datetime64_any_dtype,
-    is_integer,
-    is_scalar,
-    pandas_dtype,
-)
+from pandas.core.dtypes.common import is_integer
 from pandas.core.dtypes.dtypes import PeriodDtype
+from pandas.core.dtypes.generic import ABCSeries
 from pandas.core.dtypes.missing import is_valid_na_for_dtype
 
 from pandas.core.arrays.period import (
@@ -55,7 +41,17 @@ from pandas.core.indexes.datetimes import (
     Index,
 )
 from pandas.core.indexes.extension import inherit_names
-from pandas.core.indexes.numeric import Int64Index
+
+if TYPE_CHECKING:
+    from collections.abc import Hashable
+
+    from pandas._typing import (
+        Dtype,
+        DtypeObj,
+        Self,
+        npt,
+    )
+
 
 _index_doc_kwargs = dict(ibase._index_doc_kwargs)
 _index_doc_kwargs.update({"target_klass": "PeriodIndex or list of Periods"})
@@ -71,7 +67,8 @@ def _new_PeriodIndex(cls, **d):
     values = d.pop("data")
     if values.dtype == "int64":
         freq = d.pop("freq", None)
-        values = PeriodArray(values, freq=freq)
+        dtype = PeriodDtype(freq)
+        values = PeriodArray(values, dtype=dtype)
         return cls._simple_new(values, **d)
     else:
         return cls(values, **d)
@@ -154,15 +151,23 @@ class PeriodIndex(DatetimeIndexOpsMixin):
     """
 
     _typ = "periodindex"
-    _attributes = ["name"]
 
     _data: PeriodArray
     freq: BaseOffset
+    dtype: PeriodDtype
 
     _data_cls = PeriodArray
-    _engine_type = libindex.PeriodEngine
     _supports_partial_string_indexing = True
 
+    @property
+    def _engine_type(self) -> type[libindex.PeriodEngine]:
+        return libindex.PeriodEngine
+
+    @cache_readonly
+    def _resolution_obj(self) -> Resolution:
+        # for compat with DatetimeIndex
+        return self.dtype._resolution_obj
+
     # --------------------------------------------------------------------
     # methods that dispatch to array and wrap result in Index
     # These are defined here instead of via inherit_names for mypy
@@ -173,35 +178,29 @@ class PeriodIndex(DatetimeIndexOpsMixin):
         other_name="PeriodArray",
         **_shared_doc_kwargs,
     )
-    def asfreq(self, freq=None, how: str = "E") -> PeriodIndex:
+    def asfreq(self, freq=None, how: str = "E") -> Self:
         arr = self._data.asfreq(freq, how)
         return type(self)._simple_new(arr, name=self.name)
 
     @doc(PeriodArray.to_timestamp)
-    def to_timestamp(self, freq=None, how="start") -> DatetimeIndex:
+    def to_timestamp(self, freq=None, how: str = "start") -> DatetimeIndex:
         arr = self._data.to_timestamp(freq, how)
         return DatetimeIndex._simple_new(arr, name=self.name)
 
-    # https://github.com/python/mypy/issues/1362
-    # error: Decorated property not supported
-    @property  # type:ignore[misc]
+    @property
     @doc(PeriodArray.hour.fget)
-    def hour(self) -> Int64Index:
-        return Int64Index(self._data.hour, name=self.name)
+    def hour(self) -> Index:
+        return Index(self._data.hour, name=self.name)
 
-    # https://github.com/python/mypy/issues/1362
-    # error: Decorated property not supported
-    @property  # type:ignore[misc]
+    @property
     @doc(PeriodArray.minute.fget)
-    def minute(self) -> Int64Index:
-        return Int64Index(self._data.minute, name=self.name)
+    def minute(self) -> Index:
+        return Index(self._data.minute, name=self.name)
 
-    # https://github.com/python/mypy/issues/1362
-    # error: Decorated property not supported
-    @property  # type:ignore[misc]
+    @property
     @doc(PeriodArray.second.fget)
-    def second(self) -> Int64Index:
-        return Int64Index(self._data.second, name=self.name)
+    def second(self) -> Index:
+        return Index(self._data.second, name=self.name)
 
     # ------------------------------------------------------------------------
     # Index Constructors
@@ -213,10 +212,9 @@ class PeriodIndex(DatetimeIndexOpsMixin):
         freq=None,
         dtype: Dtype | None = None,
         copy: bool = False,
-        name: Hashable = None,
+        name: Hashable | None = None,
         **fields,
-    ) -> PeriodIndex:
-
+    ) -> Self:
         valid_field_set = {
             "year",
             "month",
@@ -227,20 +225,29 @@ class PeriodIndex(DatetimeIndexOpsMixin):
             "second",
         }
 
+        refs = None
+        if not copy and isinstance(data, (Index, ABCSeries)):
+            refs = data._references
+
         if not set(fields).issubset(valid_field_set):
-            argument = list(set(fields) - valid_field_set)[0]
+            argument = next(iter(set(fields) - valid_field_set))
             raise TypeError(f"__new__() got an unexpected keyword argument {argument}")
 
         name = maybe_extract_name(name, data, cls)
 
         if data is None and ordinal is None:
             # range-based.
+            if not fields:
+                # test_pickle_compat_construction
+                cls._raise_scalar_data_error(None)
+
             data, freq2 = PeriodArray._generate_range(None, None, None, freq, fields)
             # PeriodArray._generate range does validation that fields is
             # empty when really using the range-based constructor.
             freq = freq2
 
-            data = PeriodArray(data, freq=freq)
+            dtype = PeriodDtype(freq)
+            data = PeriodArray(data, dtype=dtype)
         else:
             freq = validate_dtype_freq(dtype, freq)
 
@@ -255,7 +262,8 @@ class PeriodIndex(DatetimeIndexOpsMixin):
             if data is None and ordinal is not None:
                 # we strangely ignore `ordinal` if data is passed.
                 ordinal = np.asarray(ordinal, dtype=np.int64)
-                data = PeriodArray(ordinal, freq=freq)
+                dtype = PeriodDtype(freq)
+                data = PeriodArray(ordinal, dtype=dtype)
             else:
                 # don't pass copy here, since we copy later.
                 data = period_array(data=data, freq=freq)
@@ -263,16 +271,16 @@ class PeriodIndex(DatetimeIndexOpsMixin):
         if copy:
             data = data.copy()
 
-        return cls._simple_new(data, name=name)
+        return cls._simple_new(data, name=name, refs=refs)
 
     # ------------------------------------------------------------------------
     # Data
 
     @property
-    def values(self) -> np.ndarray:
+    def values(self) -> npt.NDArray[np.object_]:
         return np.asarray(self, dtype=object)
 
-    def _maybe_convert_timedelta(self, other):
+    def _maybe_convert_timedelta(self, other) -> int | npt.NDArray[np.int64]:
         """
         Convert timedelta-like input to an integer multiple of self.freq
 
@@ -300,9 +308,7 @@ class PeriodIndex(DatetimeIndexOpsMixin):
 
             raise raise_on_incompatible(self, other)
         elif is_integer(other):
-            # integer is passed to .shift via
-            # _add_datetimelike_methods basically
-            # but ufunc may pass integer to _add_delta
+            assert isinstance(other, int)
             return other
 
         # raise when input doesn't have freq
@@ -312,14 +318,12 @@ class PeriodIndex(DatetimeIndexOpsMixin):
         """
         Can we compare values of the given dtype to our own?
         """
-        if not isinstance(dtype, PeriodDtype):
-            return False
-        return dtype.freq == self.freq
+        return self.dtype == dtype
 
     # ------------------------------------------------------------------------
     # Index Methods
 
-    def asof_locs(self, where: Index, mask: np.ndarray) -> np.ndarray:
+    def asof_locs(self, where: Index, mask: npt.NDArray[np.bool_]) -> np.ndarray:
         """
         where : array of timestamps
         mask : np.ndarray[bool]
@@ -332,29 +336,6 @@ class PeriodIndex(DatetimeIndexOpsMixin):
 
         return super().asof_locs(where, mask)
 
-    @doc(Index.astype)
-    def astype(self, dtype, copy: bool = True, how=lib.no_default):
-        dtype = pandas_dtype(dtype)
-
-        if how is not lib.no_default:
-            # GH#37982
-            warnings.warn(
-                "The 'how' keyword in PeriodIndex.astype is deprecated and "
-                "will be removed in a future version. "
-                "Use index.to_timestamp(how=how) instead",
-                FutureWarning,
-                stacklevel=2,
-            )
-        else:
-            how = "start"
-
-        if is_datetime64_any_dtype(dtype):
-            # 'how' is index-specific, isn't part of the EA interface.
-            tz = getattr(dtype, "tz", None)
-            return self.to_timestamp(how=how).tz_localize(tz)
-
-        return super().astype(dtype, copy=copy)
-
     @property
     def is_full(self) -> bool:
         """
@@ -366,7 +347,7 @@ class PeriodIndex(DatetimeIndexOpsMixin):
         if not self.is_monotonic_increasing:
             raise ValueError("Index is not monotonic")
         values = self.asi8
-        return ((values[1:] - values[:-1]) < 2).all()
+        return bool(((values[1:] - values[:-1]) < 2).all())
 
     @property
     def inferred_type(self) -> str:
@@ -390,7 +371,7 @@ class PeriodIndex(DatetimeIndexOpsMixin):
 
         return tolerance
 
-    def get_loc(self, key, method=None, tolerance=None):
+    def get_loc(self, key):
         """
         Get integer location for requested label.
 
@@ -412,145 +393,84 @@ class PeriodIndex(DatetimeIndexOpsMixin):
         """
         orig_key = key
 
-        if not is_scalar(key):
-            raise InvalidIndexError(key)
+        self._check_indexing_error(key)
 
         if is_valid_na_for_dtype(key, self.dtype):
             key = NaT
 
         elif isinstance(key, str):
-
             try:
-                loc = self._get_string_slice(key)
-                return loc
-            except (TypeError, ValueError):
-                pass
-
-            try:
-                asdt, reso_str = parse_time_string(key, self.freq)
-            except (ValueError, DateParseError) as err:
+                parsed, reso = self._parse_with_reso(key)
+            except ValueError as err:
                 # A string with invalid format
                 raise KeyError(f"Cannot interpret '{key}' as period") from err
 
-            reso = Resolution.from_attrname(reso_str)
-            grp = reso.freq_group.value
-            freqn = self.dtype.freq_group_code
+            if self._can_partial_date_slice(reso):
+                try:
+                    return self._partial_date_slice(reso, parsed)
+                except KeyError as err:
+                    raise KeyError(key) from err
 
-            # _get_string_slice will handle cases where grp < freqn
-            assert grp >= freqn
-
-            # BusinessDay is a bit strange. It has a *lower* code, but we never parse
-            # a string as "BusinessDay" resolution, just Day.
-            if grp == freqn or (
-                reso == Resolution.RESO_DAY and self.dtype.freq.name == "B"
-            ):
-                key = Period(asdt, freq=self.freq)
-                loc = self.get_loc(key, method=method, tolerance=tolerance)
-                return loc
-            elif method is None:
-                raise KeyError(key)
+            if reso == self._resolution_obj:
+                # the reso < self._resolution_obj case goes
+                #  through _get_string_slice
+                key = self._cast_partial_indexing_scalar(parsed)
             else:
-                key = asdt
+                raise KeyError(key)
 
         elif isinstance(key, Period):
-            sfreq = self.freq
-            kfreq = key.freq
-            if not (
-                sfreq.n == kfreq.n
-                and sfreq._period_dtype_code == kfreq._period_dtype_code
-            ):
-                # GH#42247 For the subset of DateOffsets that can be Period freqs,
-                #  checking these two attributes is sufficient to check equality,
-                #  and much more performant than `self.freq == key.freq`
-                raise KeyError(key)
+            self._disallow_mismatched_indexing(key)
+
         elif isinstance(key, datetime):
-            try:
-                key = Period(key, freq=self.freq)
-            except ValueError as err:
-                # we cannot construct the Period
-                raise KeyError(orig_key) from err
+            key = self._cast_partial_indexing_scalar(key)
+
         else:
             # in particular integer, which Period constructor would cast to string
             raise KeyError(key)
 
         try:
-            key = Period(key, freq=self.freq)
+            return Index.get_loc(self, key)
+        except KeyError as err:
+            raise KeyError(orig_key) from err
+
+    def _disallow_mismatched_indexing(self, key: Period) -> None:
+        if key._dtype != self.dtype:
+            raise KeyError(key)
+
+    def _cast_partial_indexing_scalar(self, label: datetime) -> Period:
+        try:
+            period = Period(label, freq=self.freq)
         except ValueError as err:
             # we cannot construct the Period
-            raise KeyError(orig_key) from err
-
-        try:
-            return Index.get_loc(self, key, method, tolerance)
-        except KeyError as err:
-            raise KeyError(orig_key) from err
-
-    def _maybe_cast_slice_bound(self, label, side: str, kind=lib.no_default):
-        """
-        If label is a string or a datetime, cast it to Period.ordinal according
-        to resolution.
-
-        Parameters
-        ----------
-        label : object
-        side : {'left', 'right'}
-        kind : {'loc', 'getitem'}, or None
-
-        Returns
-        -------
-        bound : Period or object
-
-        Notes
-        -----
-        Value of `side` parameter should be validated in caller.
-
-        """
-        assert kind in ["loc", "getitem", None, lib.no_default]
-        self._deprecated_arg(kind, "kind", "_maybe_cast_slice_bound")
+            raise KeyError(label) from err
+        return period
 
+    @doc(DatetimeIndexOpsMixin._maybe_cast_slice_bound)
+    def _maybe_cast_slice_bound(self, label, side: str):
         if isinstance(label, datetime):
-            return Period(label, freq=self.freq)
-        elif isinstance(label, str):
-            try:
-                parsed, reso_str = parse_time_string(label, self.freq)
-            except ValueError as err:
-                # string cannot be parsed as datetime-like
-                raise self._invalid_indexer("slice", label) from err
+            label = self._cast_partial_indexing_scalar(label)
 
-            reso = Resolution.from_attrname(reso_str)
-            lower, upper = self._parsed_string_to_bounds(reso, parsed)
-            return lower if side == "left" else upper
-        elif not isinstance(label, self._data._recognized_scalars):
-            raise self._invalid_indexer("slice", label)
-
-        return label
+        return super()._maybe_cast_slice_bound(label, side)
 
     def _parsed_string_to_bounds(self, reso: Resolution, parsed: datetime):
-        grp = reso.freq_group
-        iv = Period(parsed, freq=grp.value)
+        iv = Period(parsed, freq=reso.attr_abbrev)
         return (iv.asfreq(self.freq, how="start"), iv.asfreq(self.freq, how="end"))
 
-    def _validate_partial_date_slice(self, reso: Resolution):
-        assert isinstance(reso, Resolution), (type(reso), reso)
-        grp = reso.freq_group
-        freqn = self.dtype.freq_group_code
-
-        if not grp.value < freqn:
-            # TODO: we used to also check for
-            #  reso in ["day", "hour", "minute", "second"]
-            #  why is that check not needed?
-            raise ValueError
-
-    def _get_string_slice(self, key: str):
-        parsed, reso_str = parse_time_string(key, self.freq)
-        reso = Resolution.from_attrname(reso_str)
-        try:
-            return self._partial_date_slice(reso, parsed)
-        except KeyError as err:
-            raise KeyError(key) from err
+    @doc(DatetimeIndexOpsMixin.shift)
+    def shift(self, periods: int = 1, freq=None) -> Self:
+        if freq is not None:
+            raise TypeError(
+                f"`freq` argument is not supported for {type(self).__name__}.shift"
+            )
+        return self + periods
 
 
 def period_range(
-    start=None, end=None, periods: int | None = None, freq=None, name=None
+    start=None,
+    end=None,
+    periods: int | None = None,
+    freq=None,
+    name: Hashable | None = None,
 ) -> PeriodIndex:
     """
     Return a fixed frequency PeriodIndex.
@@ -559,9 +479,9 @@ def period_range(
 
     Parameters
     ----------
-    start : str or period-like, default None
+    start : str, datetime, date, pandas.Timestamp, or period-like, default None
         Left bound for generating periods.
-    end : str or period-like, default None
+    end : str, datetime, date, pandas.Timestamp, or period-like, default None
         Right bound for generating periods.
     periods : int, default None
         Number of periods to generate.
@@ -610,5 +530,6 @@ def period_range(
         freq = "D"
 
     data, freq = PeriodArray._generate_range(start, end, periods, freq, fields={})
-    data = PeriodArray(data, freq=freq)
+    dtype = PeriodDtype(freq)
+    data = PeriodArray(data, dtype=dtype)
     return PeriodIndex(data, name=name)
