@@ -10,28 +10,35 @@ from functools import (
 from typing import (
     TYPE_CHECKING,
     Any,
+    Literal,
     cast,
 )
 
 import numpy as np
 
 from pandas._libs import (
+    NaT,
     algos,
     lib,
 )
 from pandas._typing import (
     ArrayLike,
-    Axis,
+    AxisInt,
     F,
+    ReindexMethod,
+    npt,
 )
 from pandas.compat._optional import import_optional_dependency
 
 from pandas.core.dtypes.cast import infer_dtype_from
 from pandas.core.dtypes.common import (
     is_array_like,
+    is_numeric_dtype,
     is_numeric_v_string_like,
+    is_object_dtype,
     needs_i8_conversion,
 )
+from pandas.core.dtypes.dtypes import DatetimeTZDtype
 from pandas.core.dtypes.missing import (
     is_valid_na_for_dtype,
     isna,
@@ -42,7 +49,7 @@ if TYPE_CHECKING:
     from pandas import Index
 
 
-def check_value_size(value, mask: np.ndarray, length: int):
+def check_value_size(value, mask: npt.NDArray[np.bool_], length: int):
     """
     Validate the size of the values passed to ExtensionArray.fillna.
     """
@@ -57,7 +64,7 @@ def check_value_size(value, mask: np.ndarray, length: int):
     return value
 
 
-def mask_missing(arr: ArrayLike, values_to_mask) -> np.ndarray:
+def mask_missing(arr: ArrayLike, values_to_mask) -> npt.NDArray[np.bool_]:
     """
     Return a masking array of same size/shape as arr
     with entries equaling any member of values_to_mask set to True
@@ -75,11 +82,20 @@ def mask_missing(arr: ArrayLike, values_to_mask) -> np.ndarray:
     #  known to be holdable by arr.
     # When called from Series._single_replace, values_to_mask is tuple or list
     dtype, values_to_mask = infer_dtype_from(values_to_mask)
-    # error: Argument "dtype" to "array" has incompatible type "Union[dtype[Any],
-    # ExtensionDtype]"; expected "Union[dtype[Any], None, type, _SupportsDType, str,
-    # Union[Tuple[Any, int], Tuple[Any, Union[int, Sequence[int]]], List[Any],
-    # _DTypeDict, Tuple[Any, Any]]]"
-    values_to_mask = np.array(values_to_mask, dtype=dtype)  # type: ignore[arg-type]
+
+    if isinstance(dtype, np.dtype):
+        values_to_mask = np.array(values_to_mask, dtype=dtype)
+    else:
+        cls = dtype.construct_array_type()
+        if not lib.is_list_like(values_to_mask):
+            values_to_mask = [values_to_mask]
+        values_to_mask = cls._from_sequence(values_to_mask, dtype=dtype, copy=False)
+
+    potential_na = False
+    if is_object_dtype(arr.dtype):
+        # pre-compute mask to avoid comparison to NA
+        potential_na = True
+        arr_mask = ~isna(arr)
 
     na_mask = isna(values_to_mask)
     nonna = values_to_mask[~na_mask]
@@ -91,7 +107,16 @@ def mask_missing(arr: ArrayLike, values_to_mask) -> np.ndarray:
             # GH#29553 prevent numpy deprecation warnings
             pass
         else:
-            mask |= arr == x
+            if potential_na:
+                new_mask = np.zeros(arr.shape, dtype=np.bool_)
+                new_mask[arr_mask] = arr[arr_mask] == x
+            else:
+                new_mask = arr == x
+
+                if not isinstance(new_mask, np.ndarray):
+                    # usually BooleanArray
+                    new_mask = new_mask.to_numpy(dtype=bool, na_value=False)
+            mask |= new_mask
 
     if na_mask.any():
         mask |= isna(arr)
@@ -99,11 +124,7 @@ def mask_missing(arr: ArrayLike, values_to_mask) -> np.ndarray:
     return mask
 
 
-def clean_fill_method(method, allow_nearest: bool = False):
-    # asfreq is compat for resampling
-    if method in [None, "asfreq"]:
-        return None
-
+def clean_fill_method(method: str, allow_nearest: bool = False):
     if isinstance(method, str):
         method = method.lower()
         if method == "ffill":
@@ -156,7 +177,7 @@ def clean_interp_method(method: str, index: Index, **kwargs) -> str:
         raise ValueError(f"method must be one of {valid}. Got '{method}' instead.")
 
     if method in ("krogh", "piecewise_polynomial", "pchip"):
-        if not index.is_monotonic:
+        if not index.is_monotonic_increasing:
             raise ValueError(
                 f"{method} interpolation requires that the index be monotonic."
             )
@@ -164,15 +185,16 @@ def clean_interp_method(method: str, index: Index, **kwargs) -> str:
     return method
 
 
-def find_valid_index(values, *, how: str) -> int | None:
+def find_valid_index(how: str, is_valid: npt.NDArray[np.bool_]) -> int | None:
     """
-    Retrieves the index of the first valid value.
+    Retrieves the positional index of the first valid value.
 
     Parameters
     ----------
-    values : ndarray or ExtensionArray
     how : {'first', 'last'}
         Use this parameter to change between the first or last valid index.
+    is_valid: np.ndarray
+        Mask to find na_values.
 
     Returns
     -------
@@ -180,162 +202,30 @@ def find_valid_index(values, *, how: str) -> int | None:
     """
     assert how in ["first", "last"]
 
-    if len(values) == 0:  # early stop
+    if len(is_valid) == 0:  # early stop
         return None
 
-    is_valid = ~isna(values)
-
-    if values.ndim == 2:
-        is_valid = is_valid.any(1)  # reduce axis 1
+    if is_valid.ndim == 2:
+        is_valid = is_valid.any(axis=1)  # reduce axis 1
 
     if how == "first":
         idxpos = is_valid[::].argmax()
 
     elif how == "last":
-        idxpos = len(values) - 1 - is_valid[::-1].argmax()
+        idxpos = len(is_valid) - 1 - is_valid[::-1].argmax()
 
     chk_notna = is_valid[idxpos]
 
     if not chk_notna:
         return None
-    return idxpos
+    # Incompatible return value type (got "signedinteger[Any]",
+    # expected "Optional[int]")
+    return idxpos  # type: ignore[return-value]
 
 
-def interpolate_array_2d(
-    data: np.ndarray,
-    method: str = "pad",
-    axis: int = 0,
-    index: Index | None = None,
-    limit: int | None = None,
-    limit_direction: str = "forward",
-    limit_area: str | None = None,
-    fill_value: Any | None = None,
-    coerce: bool = False,
-    downcast: str | None = None,
-    **kwargs,
-):
-    """
-    Wrapper to dispatch to either interpolate_2d or interpolate_2d_with_fill.
-    """
-    try:
-        m = clean_fill_method(method)
-    except ValueError:
-        m = None
-
-    if m is not None:
-        if fill_value is not None:
-            # similar to validate_fillna_kwargs
-            raise ValueError("Cannot pass both fill_value and method")
-
-        interp_values = interpolate_2d(
-            data,
-            method=m,
-            axis=axis,
-            limit=limit,
-            limit_area=limit_area,
-        )
-    else:
-        assert index is not None  # for mypy
-
-        interp_values = interpolate_2d_with_fill(
-            data=data,
-            index=index,
-            axis=axis,
-            method=method,
-            limit=limit,
-            limit_direction=limit_direction,
-            limit_area=limit_area,
-            fill_value=fill_value,
-            **kwargs,
-        )
-    return interp_values
-
-
-def interpolate_2d_with_fill(
-    data: np.ndarray,  # floating dtype
-    index: Index,
-    axis: int,
-    method: str = "linear",
-    limit: int | None = None,
-    limit_direction: str = "forward",
-    limit_area: str | None = None,
-    fill_value: Any | None = None,
-    **kwargs,
-) -> np.ndarray:
-    """
-    Column-wise application of interpolate_1d.
-
-    Notes
-    -----
-    The signature does differs from interpolate_1d because it only
-    includes what is needed for Block.interpolate.
-    """
-    # validate the interp method
-    clean_interp_method(method, index, **kwargs)
-
-    if is_valid_na_for_dtype(fill_value, data.dtype):
-        fill_value = na_value_for_dtype(data.dtype, compat=False)
-
-    def func(yvalues: np.ndarray) -> np.ndarray:
-        # process 1-d slices in the axis direction, returning it
-
-        # should the axis argument be handled below in apply_along_axis?
-        # i.e. not an arg to interpolate_1d
-        return interpolate_1d(
-            xvalues=index,
-            yvalues=yvalues,
-            method=method,
-            limit=limit,
-            limit_direction=limit_direction,
-            limit_area=limit_area,
-            fill_value=fill_value,
-            bounds_error=False,
-            **kwargs,
-        )
-
-    # interp each column independently
-    return np.apply_along_axis(func, axis, data)
-
-
-def interpolate_1d(
-    xvalues: Index,
-    yvalues: np.ndarray,
-    method: str | None = "linear",
-    limit: int | None = None,
-    limit_direction: str = "forward",
-    limit_area: str | None = None,
-    fill_value: Any | None = None,
-    bounds_error: bool = False,
-    order: int | None = None,
-    **kwargs,
-):
-    """
-    Logic for the 1-d interpolation.  The result should be 1-d, inputs
-    xvalues and yvalues will each be 1-d arrays of the same length.
-
-    Bounds_error is currently hardcoded to False since non-scipy ones don't
-    take it as an argument.
-    """
-    invalid = isna(yvalues)
-    valid = ~invalid
-
-    if not valid.any():
-        result = np.empty(xvalues.shape, dtype=np.float64)
-        result.fill(np.nan)
-        return result
-
-    if valid.all():
-        return yvalues
-
-    if method == "time":
-        if not needs_i8_conversion(xvalues.dtype):
-            raise ValueError(
-                "time-weighted interpolation only works "
-                "on Series or DataFrames with a "
-                "DatetimeIndex"
-            )
-        method = "values"
-
+def validate_limit_direction(
+    limit_direction: str,
+) -> Literal["forward", "backward", "both"]:
     valid_limit_directions = ["forward", "backward", "both"]
     limit_direction = limit_direction.lower()
     if limit_direction not in valid_limit_directions:
@@ -343,7 +233,12 @@ def interpolate_1d(
             "Invalid limit_direction: expecting one of "
             f"{valid_limit_directions}, got '{limit_direction}'."
         )
+    # error: Incompatible return value type (got "str", expected
+    # "Literal['forward', 'backward', 'both']")
+    return limit_direction  # type: ignore[return-value]
 
+
+def validate_limit_area(limit_area: str | None) -> Literal["inside", "outside"] | None:
     if limit_area is not None:
         valid_limit_areas = ["inside", "outside"]
         limit_area = limit_area.lower()
@@ -352,32 +247,204 @@ def interpolate_1d(
                 f"Invalid limit_area: expecting one of {valid_limit_areas}, got "
                 f"{limit_area}."
             )
+    # error: Incompatible return value type (got "Optional[str]", expected
+    # "Optional[Literal['inside', 'outside']]")
+    return limit_area  # type: ignore[return-value]
+
+
+def infer_limit_direction(limit_direction, method):
+    # Set `limit_direction` depending on `method`
+    if limit_direction is None:
+        if method in ("backfill", "bfill"):
+            limit_direction = "backward"
+        else:
+            limit_direction = "forward"
+    else:
+        if method in ("pad", "ffill") and limit_direction != "forward":
+            raise ValueError(
+                f"`limit_direction` must be 'forward' for method `{method}`"
+            )
+        if method in ("backfill", "bfill") and limit_direction != "backward":
+            raise ValueError(
+                f"`limit_direction` must be 'backward' for method `{method}`"
+            )
+    return limit_direction
+
+
+def get_interp_index(method, index: Index) -> Index:
+    # create/use the index
+    if method == "linear":
+        # prior default
+        from pandas import Index
+
+        index = Index(np.arange(len(index)))
+    else:
+        methods = {"index", "values", "nearest", "time"}
+        is_numeric_or_datetime = (
+            is_numeric_dtype(index.dtype)
+            or isinstance(index.dtype, DatetimeTZDtype)
+            or lib.is_np_dtype(index.dtype, "mM")
+        )
+        if method not in methods and not is_numeric_or_datetime:
+            raise ValueError(
+                "Index column must be numeric or datetime type when "
+                f"using {method} method other than linear. "
+                "Try setting a numeric or datetime index column before "
+                "interpolating."
+            )
+
+    if isna(index).any():
+        raise NotImplementedError(
+            "Interpolation with NaNs in the index "
+            "has not been implemented. Try filling "
+            "those NaNs before interpolating."
+        )
+    return index
+
+
+def interpolate_2d_inplace(
+    data: np.ndarray,  # floating dtype
+    index: Index,
+    axis: AxisInt,
+    method: str = "linear",
+    limit: int | None = None,
+    limit_direction: str = "forward",
+    limit_area: str | None = None,
+    fill_value: Any | None = None,
+    **kwargs,
+) -> None:
+    """
+    Column-wise application of _interpolate_1d.
+
+    Notes
+    -----
+    Alters 'data' in-place.
+
+    The signature does differ from _interpolate_1d because it only
+    includes what is needed for Block.interpolate.
+    """
+    # validate the interp method
+    clean_interp_method(method, index, **kwargs)
+
+    if is_valid_na_for_dtype(fill_value, data.dtype):
+        fill_value = na_value_for_dtype(data.dtype, compat=False)
+
+    if method == "time":
+        if not needs_i8_conversion(index.dtype):
+            raise ValueError(
+                "time-weighted interpolation only works "
+                "on Series or DataFrames with a "
+                "DatetimeIndex"
+            )
+        method = "values"
+
+    limit_direction = validate_limit_direction(limit_direction)
+    limit_area_validated = validate_limit_area(limit_area)
 
     # default limit is unlimited GH #16282
     limit = algos.validate_limit(nobs=None, limit=limit)
 
+    indices = _index_to_interp_indices(index, method)
+
+    def func(yvalues: np.ndarray) -> None:
+        # process 1-d slices in the axis direction
+
+        _interpolate_1d(
+            indices=indices,
+            yvalues=yvalues,
+            method=method,
+            limit=limit,
+            limit_direction=limit_direction,
+            limit_area=limit_area_validated,
+            fill_value=fill_value,
+            bounds_error=False,
+            **kwargs,
+        )
+
+    # error: Argument 1 to "apply_along_axis" has incompatible type
+    # "Callable[[ndarray[Any, Any]], None]"; expected "Callable[...,
+    # Union[_SupportsArray[dtype[<nothing>]], Sequence[_SupportsArray
+    # [dtype[<nothing>]]], Sequence[Sequence[_SupportsArray[dtype[<nothing>]]]],
+    # Sequence[Sequence[Sequence[_SupportsArray[dtype[<nothing>]]]]],
+    # Sequence[Sequence[Sequence[Sequence[_SupportsArray[dtype[<nothing>]]]]]]]]"
+    np.apply_along_axis(func, axis, data)  # type: ignore[arg-type]
+
+
+def _index_to_interp_indices(index: Index, method: str) -> np.ndarray:
+    """
+    Convert Index to ndarray of indices to pass to NumPy/SciPy.
+    """
+    xarr = index._values
+    if needs_i8_conversion(xarr.dtype):
+        # GH#1646 for dt64tz
+        xarr = xarr.view("i8")
+
+    if method == "linear":
+        inds = xarr
+        inds = cast(np.ndarray, inds)
+    else:
+        inds = np.asarray(xarr)
+
+        if method in ("values", "index"):
+            if inds.dtype == np.object_:
+                inds = lib.maybe_convert_objects(inds)
+
+    return inds
+
+
+def _interpolate_1d(
+    indices: np.ndarray,
+    yvalues: np.ndarray,
+    method: str = "linear",
+    limit: int | None = None,
+    limit_direction: str = "forward",
+    limit_area: Literal["inside", "outside"] | None = None,
+    fill_value: Any | None = None,
+    bounds_error: bool = False,
+    order: int | None = None,
+    **kwargs,
+) -> None:
+    """
+    Logic for the 1-d interpolation.  The input
+    indices and yvalues will each be 1-d arrays of the same length.
+
+    Bounds_error is currently hardcoded to False since non-scipy ones don't
+    take it as an argument.
+
+    Notes
+    -----
+    Fills 'yvalues' in-place.
+    """
+
+    invalid = isna(yvalues)
+    valid = ~invalid
+
+    if not valid.any():
+        return
+
+    if valid.all():
+        return
+
     # These are sets of index pointers to invalid values... i.e. {0, 1, etc...
     all_nans = set(np.flatnonzero(invalid))
 
-    first_valid_index = find_valid_index(yvalues, how="first")
+    first_valid_index = find_valid_index(how="first", is_valid=valid)
     if first_valid_index is None:  # no nan found in start
         first_valid_index = 0
     start_nans = set(range(first_valid_index))
 
-    last_valid_index = find_valid_index(yvalues, how="last")
+    last_valid_index = find_valid_index(how="last", is_valid=valid)
     if last_valid_index is None:  # no nan found in end
         last_valid_index = len(yvalues)
     end_nans = set(range(1 + last_valid_index, len(valid)))
 
-    mid_nans = all_nans - start_nans - end_nans
-
     # Like the sets above, preserve_nans contains indices of invalid values,
     # but in this case, it is the final set of indices that need to be
     # preserved as NaN after the interpolation.
 
     # For example if limit_direction='forward' then preserve_nans will
     # contain indices of NaNs at the beginning of the series, and NaNs that
-    # are more than'limit' away from the prior non-NaN.
+    # are more than 'limit' away from the prior non-NaN.
 
     # set preserve_nans based on direction using _interp_limit
     preserve_nans: list | set
@@ -396,44 +463,29 @@ def interpolate_1d(
         preserve_nans |= start_nans | end_nans
     elif limit_area == "outside":
         # preserve NaNs on the inside
+        mid_nans = all_nans - start_nans - end_nans
         preserve_nans |= mid_nans
 
-    # sort preserve_nans and covert to list
+    # sort preserve_nans and convert to list
     preserve_nans = sorted(preserve_nans)
 
-    result = yvalues.copy()
+    is_datetimelike = yvalues.dtype.kind in "mM"
 
-    # xarr to pass to NumPy/SciPy
-    xarr = xvalues._values
-    if needs_i8_conversion(xarr.dtype):
-        # GH#1646 for dt64tz
-        xarr = xarr.view("i8")
-
-    if method == "linear":
-        inds = xarr
-    else:
-        inds = np.asarray(xarr)
-
-        if method in ("values", "index"):
-            if inds.dtype == np.object_:
-                inds = lib.maybe_convert_objects(inds)
+    if is_datetimelike:
+        yvalues = yvalues.view("i8")
 
     if method in NP_METHODS:
         # np.interp requires sorted X values, #21037
 
-        # error: Argument 1 to "argsort" has incompatible type "Union[ExtensionArray,
-        # Any]"; expected "Union[Union[int, float, complex, str, bytes, generic],
-        # Sequence[Union[int, float, complex, str, bytes, generic]],
-        # Sequence[Sequence[Any]], _SupportsArray]"
-        indexer = np.argsort(inds[valid])  # type: ignore[arg-type]
-        result[invalid] = np.interp(
-            inds[invalid], inds[valid][indexer], yvalues[valid][indexer]
+        indexer = np.argsort(indices[valid])
+        yvalues[invalid] = np.interp(
+            indices[invalid], indices[valid][indexer], yvalues[valid][indexer]
         )
     else:
-        result[invalid] = _interpolate_scipy_wrapper(
-            inds[valid],
+        yvalues[invalid] = _interpolate_scipy_wrapper(
+            indices[valid],
             yvalues[valid],
-            inds[invalid],
+            indices[invalid],
             method=method,
             fill_value=fill_value,
             bounds_error=bounds_error,
@@ -441,12 +493,22 @@ def interpolate_1d(
             **kwargs,
         )
 
-    result[preserve_nans] = np.nan
-    return result
+    if is_datetimelike:
+        yvalues[preserve_nans] = NaT.value
+    else:
+        yvalues[preserve_nans] = np.nan
+    return
 
 
 def _interpolate_scipy_wrapper(
-    x, y, new_x, method, fill_value=None, bounds_error=False, order=None, **kwargs
+    x: np.ndarray,
+    y: np.ndarray,
+    new_x: np.ndarray,
+    method: str,
+    fill_value=None,
+    bounds_error: bool = False,
+    order=None,
+    **kwargs,
 ):
     """
     Passed off to scipy.interpolate.interp1d. method is scipy's kind.
@@ -465,19 +527,11 @@ def _interpolate_scipy_wrapper(
         "krogh": interpolate.krogh_interpolate,
         "from_derivatives": _from_derivatives,
         "piecewise_polynomial": _from_derivatives,
+        "cubicspline": _cubicspline_interpolate,
+        "akima": _akima_interpolate,
+        "pchip": interpolate.pchip_interpolate,
     }
 
-    if getattr(x, "_is_all_dates", False):
-        # GH 5975, scipy.interp1d can't handle datetime64s
-        x, new_x = x._values.astype("i8"), new_x.astype("i8")
-
-    if method == "pchip":
-        alt_methods["pchip"] = interpolate.pchip_interpolate
-    elif method == "akima":
-        alt_methods["akima"] = _akima_interpolate
-    elif method == "cubicspline":
-        alt_methods["cubicspline"] = _cubicspline_interpolate
-
     interp1d_methods = [
         "nearest",
         "zero",
@@ -488,9 +542,11 @@ def _interpolate_scipy_wrapper(
     ]
     if method in interp1d_methods:
         if method == "polynomial":
-            method = order
+            kind = order
+        else:
+            kind = method
         terp = interpolate.interp1d(
-            x, y, kind=method, fill_value=fill_value, bounds_error=bounds_error
+            x, y, kind=kind, fill_value=fill_value, bounds_error=bounds_error
         )
         new_y = terp(new_x)
     elif method == "spline":
@@ -510,12 +566,19 @@ def _interpolate_scipy_wrapper(
             y = y.copy()
         if not new_x.flags.writeable:
             new_x = new_x.copy()
-        method = alt_methods[method]
-        new_y = method(x, y, new_x, **kwargs)
+        terp = alt_methods[method]
+        new_y = terp(x, y, new_x, **kwargs)
     return new_y
 
 
-def _from_derivatives(xi, yi, x, order=None, der=0, extrapolate=False):
+def _from_derivatives(
+    xi: np.ndarray,
+    yi: np.ndarray,
+    x: np.ndarray,
+    order=None,
+    der: int | list[int] | None = 0,
+    extrapolate: bool = False,
+):
     """
     Convenience function for interpolate.BPoly.from_derivatives.
 
@@ -558,7 +621,13 @@ def _from_derivatives(xi, yi, x, order=None, der=0, extrapolate=False):
     return m(x)
 
 
-def _akima_interpolate(xi, yi, x, der=0, axis=0):
+def _akima_interpolate(
+    xi: np.ndarray,
+    yi: np.ndarray,
+    x: np.ndarray,
+    der: int | list[int] | None = 0,
+    axis: AxisInt = 0,
+):
     """
     Convenience function for akima interpolation.
     xi and yi are arrays of values used to approximate some function f,
@@ -568,13 +637,13 @@ def _akima_interpolate(xi, yi, x, der=0, axis=0):
 
     Parameters
     ----------
-    xi : array-like
+    xi : np.ndarray
         A sorted list of x-coordinates, of length N.
-    yi : array-like
+    yi : np.ndarray
         A 1-D array of real values.  `yi`'s length along the interpolation
         axis must be equal to the length of `xi`. If N-D array, use axis
         parameter to select correct axis.
-    x : scalar or array-like
+    x : np.ndarray
         Of length M.
     der : int, optional
         How many derivatives to extract; None for all potentially
@@ -601,7 +670,14 @@ def _akima_interpolate(xi, yi, x, der=0, axis=0):
     return P(x, nu=der)
 
 
-def _cubicspline_interpolate(xi, yi, x, axis=0, bc_type="not-a-knot", extrapolate=None):
+def _cubicspline_interpolate(
+    xi: np.ndarray,
+    yi: np.ndarray,
+    x: np.ndarray,
+    axis: AxisInt = 0,
+    bc_type: str | tuple[Any, Any] = "not-a-knot",
+    extrapolate=None,
+):
     """
     Convenience function for cubic spline data interpolator.
 
@@ -609,14 +685,14 @@ def _cubicspline_interpolate(xi, yi, x, axis=0, bc_type="not-a-knot", extrapolat
 
     Parameters
     ----------
-    xi : array-like, shape (n,)
+    xi : np.ndarray, shape (n,)
         1-d array containing values of the independent variable.
         Values must be real, finite and in strictly increasing order.
-    yi : array-like
+    yi : np.ndarray
         Array containing values of the dependent variable. It can have
         arbitrary number of dimensions, but the length along ``axis``
         (see below) must match the length of ``x``. Values must be finite.
-    x : scalar or array-like, shape (m,)
+    x : np.ndarray, shape (m,)
     axis : int, optional
         Axis along which `y` is assumed to be varying. Meaning that for
         ``x[i]`` the corresponding values are ``np.take(y, i, axis=axis)``.
@@ -681,39 +757,42 @@ def _cubicspline_interpolate(xi, yi, x, axis=0, bc_type="not-a-knot", extrapolat
 
 
 def _interpolate_with_limit_area(
-    values: ArrayLike, method: str, limit: int | None, limit_area: str | None
-) -> ArrayLike:
+    values: np.ndarray,
+    method: Literal["pad", "backfill"],
+    limit: int | None,
+    limit_area: Literal["inside", "outside"],
+) -> None:
     """
     Apply interpolation and limit_area logic to values along a to-be-specified axis.
 
     Parameters
     ----------
-    values: array-like
+    values: np.ndarray
         Input array.
     method: str
         Interpolation method. Could be "bfill" or "pad"
     limit: int, optional
         Index limit on interpolation.
-    limit_area: str
-        Limit area for interpolation. Can be "inside" or "outside"
+    limit_area: {'inside', 'outside'}
+        Limit area for interpolation.
 
-    Returns
-    -------
-    values: array-like
-        Interpolated array.
+    Notes
+    -----
+    Modifies values in-place.
     """
 
     invalid = isna(values)
+    is_valid = ~invalid
 
     if not invalid.all():
-        first = find_valid_index(values, how="first")
+        first = find_valid_index(how="first", is_valid=is_valid)
         if first is None:
             first = 0
-        last = find_valid_index(values, how="last")
+        last = find_valid_index(how="last", is_valid=is_valid)
         if last is None:
             last = len(values)
 
-        values = interpolate_2d(
+        pad_or_backfill_inplace(
             values,
             method=method,
             limit=limit,
@@ -723,26 +802,26 @@ def _interpolate_with_limit_area(
             invalid[first : last + 1] = False
         elif limit_area == "outside":
             invalid[:first] = invalid[last + 1 :] = False
+        else:
+            raise ValueError("limit_area should be 'inside' or 'outside'")
 
         values[invalid] = np.nan
 
-    return values
 
-
-def interpolate_2d(
-    values,
-    method: str = "pad",
-    axis: Axis = 0,
+def pad_or_backfill_inplace(
+    values: np.ndarray,
+    method: Literal["pad", "backfill"] = "pad",
+    axis: AxisInt = 0,
     limit: int | None = None,
-    limit_area: str | None = None,
-):
+    limit_area: Literal["inside", "outside"] | None = None,
+) -> None:
     """
     Perform an actual interpolation of values, values will be make 2-d if
     needed fills inplace, returns the result.
 
     Parameters
     ----------
-    values: array-like
+    values: np.ndarray
         Input array.
     method: str, default "pad"
         Interpolation method. Could be "bfill" or "pad"
@@ -753,14 +832,21 @@ def interpolate_2d(
     limit_area: str, optional
         Limit area for interpolation. Can be "inside" or "outside"
 
-    Returns
-    -------
-    values: array-like
-        Interpolated array.
+    Notes
+    -----
+    Modifies values in-place.
     """
     if limit_area is not None:
-        return np.apply_along_axis(
-            partial(
+        np.apply_along_axis(
+            # error: Argument 1 to "apply_along_axis" has incompatible type
+            # "partial[None]"; expected
+            # "Callable[..., Union[_SupportsArray[dtype[<nothing>]],
+            # Sequence[_SupportsArray[dtype[<nothing>]]],
+            # Sequence[Sequence[_SupportsArray[dtype[<nothing>]]]],
+            # Sequence[Sequence[Sequence[_SupportsArray[dtype[<nothing>]]]]],
+            # Sequence[Sequence[Sequence[Sequence[_
+            # SupportsArray[dtype[<nothing>]]]]]]]]"
+            partial(  # type: ignore[arg-type]
                 _interpolate_with_limit_area,
                 method=method,
                 limit=limit,
@@ -769,11 +855,11 @@ def interpolate_2d(
             axis,
             values,
         )
+        return
 
     transf = (lambda x: x) if axis == 0 else (lambda x: x.T)
 
     # reshape a 1 dim if needed
-    ndim = values.ndim
     if values.ndim == 1:
         if axis != 0:  # pragma: no cover
             raise AssertionError("cannot interpolate on a ndim == 1 with axis != 0")
@@ -781,20 +867,16 @@ def interpolate_2d(
 
     method = clean_fill_method(method)
     tvalues = transf(values)
-    if method == "pad":
-        result, _ = _pad_2d(tvalues, limit=limit)
-    else:
-        result, _ = _backfill_2d(tvalues, limit=limit)
 
-    result = transf(result)
-    # reshape back
-    if ndim == 1:
-        result = result[0]
-
-    return result
+    func = get_fill_func(method, ndim=2)
+    # _pad_2d and _backfill_2d both modify tvalues inplace
+    func(tvalues, limit=limit)
+    return
 
 
-def _fillna_prep(values, mask: np.ndarray | None = None) -> np.ndarray:
+def _fillna_prep(
+    values, mask: npt.NDArray[np.bool_] | None = None
+) -> npt.NDArray[np.bool_]:
     # boilerplate for _pad_1d, _backfill_1d, _pad_2d, _backfill_2d
 
     if mask is None:
@@ -810,7 +892,7 @@ def _datetimelike_compat(func: F) -> F:
     """
 
     @wraps(func)
-    def new_func(values, limit=None, mask=None):
+    def new_func(values, limit: int | None = None, mask=None):
         if needs_i8_conversion(values.dtype):
             if mask is None:
                 # This needs to occur before casting to int64
@@ -828,8 +910,8 @@ def _datetimelike_compat(func: F) -> F:
 def _pad_1d(
     values: np.ndarray,
     limit: int | None = None,
-    mask: np.ndarray | None = None,
-) -> tuple[np.ndarray, np.ndarray]:
+    mask: npt.NDArray[np.bool_] | None = None,
+) -> tuple[np.ndarray, npt.NDArray[np.bool_]]:
     mask = _fillna_prep(values, mask)
     algos.pad_inplace(values, mask, limit=limit)
     return values, mask
@@ -839,18 +921,22 @@ def _pad_1d(
 def _backfill_1d(
     values: np.ndarray,
     limit: int | None = None,
-    mask: np.ndarray | None = None,
-) -> tuple[np.ndarray, np.ndarray]:
+    mask: npt.NDArray[np.bool_] | None = None,
+) -> tuple[np.ndarray, npt.NDArray[np.bool_]]:
     mask = _fillna_prep(values, mask)
     algos.backfill_inplace(values, mask, limit=limit)
     return values, mask
 
 
 @_datetimelike_compat
-def _pad_2d(values, limit=None, mask=None):
+def _pad_2d(
+    values: np.ndarray,
+    limit: int | None = None,
+    mask: npt.NDArray[np.bool_] | None = None,
+):
     mask = _fillna_prep(values, mask)
 
-    if np.all(values.shape):
+    if values.size:
         algos.pad_2d_inplace(values, mask, limit=limit)
     else:
         # for test coverage
@@ -859,10 +945,12 @@ def _pad_2d(values, limit=None, mask=None):
 
 
 @_datetimelike_compat
-def _backfill_2d(values, limit=None, mask=None):
+def _backfill_2d(
+    values, limit: int | None = None, mask: npt.NDArray[np.bool_] | None = None
+):
     mask = _fillna_prep(values, mask)
 
-    if np.all(values.shape):
+    if values.size:
         algos.backfill_2d_inplace(values, mask, limit=limit)
     else:
         # for test coverage
@@ -880,11 +968,15 @@ def get_fill_func(method, ndim: int = 1):
     return {"pad": _pad_2d, "backfill": _backfill_2d}[method]
 
 
-def clean_reindex_fill_method(method):
+def clean_reindex_fill_method(method) -> ReindexMethod | None:
+    if method is None:
+        return None
     return clean_fill_method(method, allow_nearest=True)
 
 
-def _interp_limit(invalid: np.ndarray, fw_limit, bw_limit):
+def _interp_limit(
+    invalid: npt.NDArray[np.bool_], fw_limit: int | None, bw_limit: int | None
+):
     """
     Get indexers of values that won't be filled
     because they exceed the limits.
@@ -919,7 +1011,7 @@ def _interp_limit(invalid: np.ndarray, fw_limit, bw_limit):
     f_idx = set()
     b_idx = set()
 
-    def inner(invalid, limit):
+    def inner(invalid, limit: int):
         limit = min(limit, N)
         windowed = _rolling_window(invalid, limit + 1).all(1)
         idx = set(np.where(windowed)[0] + limit) | set(
@@ -928,14 +1020,12 @@ def _interp_limit(invalid: np.ndarray, fw_limit, bw_limit):
         return idx
 
     if fw_limit is not None:
-
         if fw_limit == 0:
             f_idx = set(np.where(invalid)[0])
         else:
             f_idx = inner(invalid, fw_limit)
 
     if bw_limit is not None:
-
         if bw_limit == 0:
             # then we don't even need to care about backwards
             # just use forwards
@@ -949,7 +1039,7 @@ def _interp_limit(invalid: np.ndarray, fw_limit, bw_limit):
     return f_idx & b_idx
 
 
-def _rolling_window(a: np.ndarray, window: int):
+def _rolling_window(a: npt.NDArray[np.bool_], window: int) -> npt.NDArray[np.bool_]:
     """
     [True, True, False, True, False], 2 ->
 
