@@ -3,44 +3,45 @@ from __future__ import annotations
 import datetime
 from functools import partial
 from textwrap import dedent
-import warnings
+from typing import TYPE_CHECKING
 
 import numpy as np
 
 from pandas._libs.tslibs import Timedelta
 import pandas._libs.window.aggregations as window_aggregations
-from pandas._typing import (
-    Axis,
-    FrameOrSeries,
-    FrameOrSeriesUnion,
-    TimedeltaConvertibleTypes,
-)
-from pandas.compat.numpy import function as nv
 from pandas.util._decorators import doc
 
-from pandas.core.dtypes.common import is_datetime64_ns_dtype
+from pandas.core.dtypes.common import (
+    is_datetime64_ns_dtype,
+    is_numeric_dtype,
+)
 from pandas.core.dtypes.missing import isna
 
-import pandas.core.common as common  # noqa: PDF018
-from pandas.core.util.numba_ import maybe_use_numba
+from pandas.core import common
+from pandas.core.indexers.objects import (
+    BaseIndexer,
+    ExponentialMovingWindowIndexer,
+    GroupbyIndexer,
+)
+from pandas.core.util.numba_ import (
+    get_jit_arguments,
+    maybe_use_numba,
+)
 from pandas.core.window.common import zsqrt
 from pandas.core.window.doc import (
     _shared_docs,
-    args_compat,
     create_section_header,
-    kwargs_compat,
+    kwargs_numeric_only,
     numba_notes,
     template_header,
     template_returns,
     template_see_also,
     window_agg_numba_parameters,
 )
-from pandas.core.window.indexers import (
-    BaseIndexer,
-    ExponentialMovingWindowIndexer,
-    GroupbyIndexer,
+from pandas.core.window.numba_ import (
+    generate_numba_ewm_func,
+    generate_numba_ewm_table_func,
 )
-from pandas.core.window.numba_ import generate_numba_ewma_func
 from pandas.core.window.online import (
     EWMMeanState,
     generate_online_numba_ewma_func,
@@ -50,6 +51,18 @@ from pandas.core.window.rolling import (
     BaseWindowGroupby,
 )
 
+if TYPE_CHECKING:
+    from pandas._typing import (
+        Axis,
+        TimedeltaConvertibleTypes,
+    )
+
+    from pandas import (
+        DataFrame,
+        Series,
+    )
+    from pandas.core.generic import NDFrame
+
 
 def get_center_of_mass(
     comass: float | None,
@@ -85,7 +98,7 @@ def get_center_of_mass(
 
 
 def _calculate_deltas(
-    times: str | np.ndarray | FrameOrSeries | None,
+    times: np.ndarray | NDFrame,
     halflife: float | TimedeltaConvertibleTypes | None,
 ) -> np.ndarray:
     """
@@ -94,7 +107,7 @@ def _calculate_deltas(
 
     Parameters
     ----------
-    times : str, np.ndarray, Series, default None
+    times : np.ndarray, Series
         Times corresponding to the observations. Must be monotonically increasing
         and ``datetime64[ns]`` dtype.
     halflife : float, str, timedelta, optional
@@ -105,51 +118,51 @@ def _calculate_deltas(
     np.ndarray
         Diff of the times divided by the half-life
     """
-    # error: Item "str" of "Union[str, ndarray, FrameOrSeries, None]" has no
-    # attribute "view"
-    # error: Item "None" of "Union[str, ndarray, FrameOrSeries, None]" has no
-    # attribute "view"
-    _times = np.asarray(
-        times.view(np.int64), dtype=np.float64  # type: ignore[union-attr]
-    )
-    _halflife = float(Timedelta(halflife).value)
+    _times = np.asarray(times.view(np.int64), dtype=np.float64)
+    # TODO: generalize to non-nano?
+    _halflife = float(Timedelta(halflife).as_unit("ns")._value)
     return np.diff(_times) / _halflife
 
 
 class ExponentialMovingWindow(BaseWindow):
     r"""
-    Provide exponential weighted (EW) functions.
+    Provide exponentially weighted (EW) calculations.
 
-    Available EW functions: ``mean()``, ``var()``, ``std()``, ``corr()``, ``cov()``.
-
-    Exactly one parameter: ``com``, ``span``, ``halflife``, or ``alpha`` must be
-    provided.
+    Exactly one of ``com``, ``span``, ``halflife``, or ``alpha`` must be
+    provided if ``times`` is not provided. If ``times`` is provided,
+    ``halflife`` and one of ``com``, ``span`` or ``alpha`` may be provided.
 
     Parameters
     ----------
     com : float, optional
-        Specify decay in terms of center of mass,
+        Specify decay in terms of center of mass
+
         :math:`\alpha = 1 / (1 + com)`, for :math:`com \geq 0`.
+
     span : float, optional
-        Specify decay in terms of span,
+        Specify decay in terms of span
+
         :math:`\alpha = 2 / (span + 1)`, for :math:`span \geq 1`.
+
     halflife : float, str, timedelta, optional
-        Specify decay in terms of half-life,
+        Specify decay in terms of half-life
+
         :math:`\alpha = 1 - \exp\left(-\ln(2) / halflife\right)`, for
         :math:`halflife > 0`.
 
-        If ``times`` is specified, the time unit (str or timedelta) over which an
-        observation decays to half its value. Only applicable to ``mean()``
+        If ``times`` is specified, a timedelta convertible unit over which an
+        observation decays to half its value. Only applicable to ``mean()``,
         and halflife value will not apply to the other functions.
 
-        .. versionadded:: 1.1.0
-
     alpha : float, optional
-        Specify smoothing factor :math:`\alpha` directly,
+        Specify smoothing factor :math:`\alpha` directly
+
         :math:`0 < \alpha \leq 1`.
+
     min_periods : int, default 0
-        Minimum number of observations in window required to have a value
-        (otherwise result is NA).
+        Minimum number of observations in window required to have a value;
+        otherwise, result is ``np.nan``.
+
     adjust : bool, default True
         Divide by decaying adjustment factor in beginning periods to account
         for imbalance in relative weightings (viewing EWMA as a moving average).
@@ -171,8 +184,7 @@ class ExponentialMovingWindow(BaseWindow):
                 y_t &= (1 - \alpha) y_{t-1} + \alpha x_t,
             \end{split}
     ignore_na : bool, default False
-        Ignore missing values when calculating weights; specify ``True`` to reproduce
-        pre-0.15.0 behavior.
+        Ignore missing values when calculating weights.
 
         - When ``ignore_na=False`` (default), weights are based on absolute positions.
           For example, the weights of :math:`x_0` and :math:`x_2` used in calculating
@@ -180,31 +192,42 @@ class ExponentialMovingWindow(BaseWindow):
           :math:`(1-\alpha)^2` and :math:`1` if ``adjust=True``, and
           :math:`(1-\alpha)^2` and :math:`\alpha` if ``adjust=False``.
 
-        - When ``ignore_na=True`` (reproducing pre-0.15.0 behavior), weights are based
+        - When ``ignore_na=True``, weights are based
           on relative positions. For example, the weights of :math:`x_0` and :math:`x_2`
           used in calculating the final weighted average of
           [:math:`x_0`, None, :math:`x_2`] are :math:`1-\alpha` and :math:`1` if
           ``adjust=True``, and :math:`1-\alpha` and :math:`\alpha` if ``adjust=False``.
-    axis : {0, 1}, default 0
-        The axis to use. The value 0 identifies the rows, and 1
-        identifies the columns.
-    times : str, np.ndarray, Series, default None
 
-        .. versionadded:: 1.1.0
+    axis : {0, 1}, default 0
+        If ``0`` or ``'index'``, calculate across the rows.
+
+        If ``1`` or ``'columns'``, calculate across the columns.
+
+        For `Series` this parameter is unused and defaults to 0.
+
+    times : np.ndarray, Series, default None
+
+        Only applicable to ``mean()``.
 
         Times corresponding to the observations. Must be monotonically increasing and
         ``datetime64[ns]`` dtype.
 
-        If str, the name of the column in the DataFrame representing the times.
-
         If 1-D array like, a sequence with the same shape as the observations.
 
-        Only applicable to ``mean()``.
+    method : str {'single', 'table'}, default 'single'
+        .. versionadded:: 1.4.0
+
+        Execute the rolling operation per single column or row (``'single'``)
+        or over the entire object (``'table'``).
+
+        This argument is only implemented when specifying ``engine='numba'``
+        in the method call.
+
+        Only applicable to ``mean()``
 
     Returns
     -------
-    DataFrame
-        A Window sub-classed for the particular operation.
+    pandas.api.typing.ExponentialMovingWindow
 
     See Also
     --------
@@ -213,9 +236,8 @@ class ExponentialMovingWindow(BaseWindow):
 
     Notes
     -----
-
-    More details can be found at:
-    :ref:`Exponentially weighted windows <window.exponentially_weighted>`.
+    See :ref:`Windowing Operations <window.exponentially_weighted>`
+    for further usage details and examples.
 
     Examples
     --------
@@ -235,8 +257,52 @@ class ExponentialMovingWindow(BaseWindow):
     2  1.615385
     3  1.615385
     4  3.670213
+    >>> df.ewm(alpha=2 / 3).mean()
+              B
+    0  0.000000
+    1  0.750000
+    2  1.615385
+    3  1.615385
+    4  3.670213
 
-    Specifying ``times`` with a timedelta ``halflife`` when computing mean.
+    **adjust**
+
+    >>> df.ewm(com=0.5, adjust=True).mean()
+              B
+    0  0.000000
+    1  0.750000
+    2  1.615385
+    3  1.615385
+    4  3.670213
+    >>> df.ewm(com=0.5, adjust=False).mean()
+              B
+    0  0.000000
+    1  0.666667
+    2  1.555556
+    3  1.555556
+    4  3.650794
+
+    **ignore_na**
+
+    >>> df.ewm(com=0.5, ignore_na=True).mean()
+              B
+    0  0.000000
+    1  0.750000
+    2  1.615385
+    3  1.615385
+    4  3.225000
+    >>> df.ewm(com=0.5, ignore_na=False).mean()
+              B
+    0  0.000000
+    1  0.750000
+    2  1.615385
+    3  1.615385
+    4  3.670213
+
+    **times**
+
+    Exponentially weighted mean with weights calculated with a timedelta ``halflife``
+    relative to ``times``.
 
     >>> times = ['2020-01-01', '2020-01-03', '2020-01-10', '2020-01-15', '2020-01-17']
     >>> df.ewm(halflife='4 days', times=pd.DatetimeIndex(times)).mean()
@@ -258,11 +324,12 @@ class ExponentialMovingWindow(BaseWindow):
         "ignore_na",
         "axis",
         "times",
+        "method",
     ]
 
     def __init__(
         self,
-        obj: FrameOrSeries,
+        obj: NDFrame,
         com: float | None = None,
         span: float | None = None,
         halflife: float | TimedeltaConvertibleTypes | None = None,
@@ -271,17 +338,18 @@ class ExponentialMovingWindow(BaseWindow):
         adjust: bool = True,
         ignore_na: bool = False,
         axis: Axis = 0,
-        times: str | np.ndarray | FrameOrSeries | None = None,
+        times: np.ndarray | NDFrame | None = None,
+        method: str = "single",
         *,
         selection=None,
-    ):
+    ) -> None:
         super().__init__(
             obj=obj,
             min_periods=1 if min_periods is None else max(int(min_periods), 1),
             on=None,
             center=False,
             closed=None,
-            method="single",
+            method=method,
             axis=axis,
             selection=selection,
         )
@@ -295,18 +363,12 @@ class ExponentialMovingWindow(BaseWindow):
         if self.times is not None:
             if not self.adjust:
                 raise NotImplementedError("times is not supported with adjust=False.")
-            if isinstance(self.times, str):
-                self.times = self._selected_obj[self.times]
             if not is_datetime64_ns_dtype(self.times):
                 raise ValueError("times must be datetime64[ns] dtype.")
-            # error: Argument 1 to "len" has incompatible type "Union[str, ndarray,
-            # FrameOrSeries, None]"; expected "Sized"
-            if len(self.times) != len(obj):  # type: ignore[arg-type]
+            if len(self.times) != len(obj):
                 raise ValueError("times must be the same length as the object.")
-            if not isinstance(self.halflife, (str, datetime.timedelta)):
-                raise ValueError(
-                    "halflife must be a string or datetime.timedelta object"
-                )
+            if not isinstance(self.halflife, (str, datetime.timedelta, np.timedelta64)):
+                raise ValueError("halflife must be a timedelta convertible object")
             if isna(self.times).any():
                 raise ValueError("Cannot convert NaT values to integer")
             self._deltas = _calculate_deltas(self.times, self.halflife)
@@ -318,14 +380,16 @@ class ExponentialMovingWindow(BaseWindow):
                 self._com = 1.0
         else:
             if self.halflife is not None and isinstance(
-                self.halflife, (str, datetime.timedelta)
+                self.halflife, (str, datetime.timedelta, np.timedelta64)
             ):
                 raise ValueError(
                     "halflife can only be a timedelta convertible argument if "
                     "times is not None."
                 )
             # Without times, points are equally spaced
-            self._deltas = np.ones(max(len(self.obj) - 1, 0), dtype=np.float64)
+            self._deltas = np.ones(
+                max(self.obj.shape[self.axis] - 1, 0), dtype=np.float64
+            )
             self._com = get_center_of_mass(
                 # error: Argument 3 to "get_center_of_mass" has incompatible type
                 # "Union[float, Any, None, timedelta64, signedinteger[_64Bit]]";
@@ -336,13 +400,22 @@ class ExponentialMovingWindow(BaseWindow):
                 self.alpha,
             )
 
+    def _check_window_bounds(
+        self, start: np.ndarray, end: np.ndarray, num_vals: int
+    ) -> None:
+        # emw algorithms are iterative with each point
+        # ExponentialMovingWindowIndexer "bounds" are the entire window
+        pass
+
     def _get_window_indexer(self) -> BaseIndexer:
         """
         Return an indexer class that will compute the window start and end bounds
         """
         return ExponentialMovingWindowIndexer()
 
-    def online(self, engine="numba", engine_kwargs=None):
+    def online(
+        self, engine: str = "numba", engine_kwargs=None
+    ) -> OnlineExponentialMovingWindow:
         """
         Return an ``OnlineExponentialMovingWindow`` object to calculate
         exponentially moving window aggregations in an online method.
@@ -422,42 +495,130 @@ class ExponentialMovingWindow(BaseWindow):
     @doc(
         template_header,
         create_section_header("Parameters"),
-        args_compat,
-        window_agg_numba_parameters,
-        kwargs_compat,
+        kwargs_numeric_only,
+        window_agg_numba_parameters(),
         create_section_header("Returns"),
         template_returns,
         create_section_header("See Also"),
         template_see_also,
         create_section_header("Notes"),
-        numba_notes.replace("\n", "", 1),
+        numba_notes,
+        create_section_header("Examples"),
+        dedent(
+            """\
+        >>> ser = pd.Series([1, 2, 3, 4])
+        >>> ser.ewm(alpha=.2).mean()
+        0    1.000000
+        1    1.555556
+        2    2.147541
+        3    2.775068
+        dtype: float64
+        """
+        ),
         window_method="ewm",
         aggregation_description="(exponential weighted moment) mean",
         agg_method="mean",
     )
-    def mean(self, *args, engine=None, engine_kwargs=None, **kwargs):
+    def mean(
+        self,
+        numeric_only: bool = False,
+        engine=None,
+        engine_kwargs=None,
+    ):
         if maybe_use_numba(engine):
-            ewma_func = generate_numba_ewma_func(
-                engine_kwargs, self._com, self.adjust, self.ignore_na, self._deltas
-            )
-            return self._apply(
-                ewma_func,
-                numba_cache_key=(lambda x: x, "ewma"),
+            if self.method == "single":
+                func = generate_numba_ewm_func
+            else:
+                func = generate_numba_ewm_table_func
+            ewm_func = func(
+                **get_jit_arguments(engine_kwargs),
+                com=self._com,
+                adjust=self.adjust,
+                ignore_na=self.ignore_na,
+                deltas=tuple(self._deltas),
+                normalize=True,
             )
+            return self._apply(ewm_func, name="mean")
         elif engine in ("cython", None):
             if engine_kwargs is not None:
                 raise ValueError("cython engine does not accept engine_kwargs")
-            nv.validate_window_func("mean", args, kwargs)
 
             deltas = None if self.times is None else self._deltas
             window_func = partial(
-                window_aggregations.ewma,
+                window_aggregations.ewm,
                 com=self._com,
                 adjust=self.adjust,
                 ignore_na=self.ignore_na,
                 deltas=deltas,
+                normalize=True,
             )
-            return self._apply(window_func)
+            return self._apply(window_func, name="mean", numeric_only=numeric_only)
+        else:
+            raise ValueError("engine must be either 'numba' or 'cython'")
+
+    @doc(
+        template_header,
+        create_section_header("Parameters"),
+        kwargs_numeric_only,
+        window_agg_numba_parameters(),
+        create_section_header("Returns"),
+        template_returns,
+        create_section_header("See Also"),
+        template_see_also,
+        create_section_header("Notes"),
+        numba_notes,
+        create_section_header("Examples"),
+        dedent(
+            """\
+        >>> ser = pd.Series([1, 2, 3, 4])
+        >>> ser.ewm(alpha=.2).sum()
+        0    1.000
+        1    2.800
+        2    5.240
+        3    8.192
+        dtype: float64
+        """
+        ),
+        window_method="ewm",
+        aggregation_description="(exponential weighted moment) sum",
+        agg_method="sum",
+    )
+    def sum(
+        self,
+        numeric_only: bool = False,
+        engine=None,
+        engine_kwargs=None,
+    ):
+        if not self.adjust:
+            raise NotImplementedError("sum is not implemented with adjust=False")
+        if maybe_use_numba(engine):
+            if self.method == "single":
+                func = generate_numba_ewm_func
+            else:
+                func = generate_numba_ewm_table_func
+            ewm_func = func(
+                **get_jit_arguments(engine_kwargs),
+                com=self._com,
+                adjust=self.adjust,
+                ignore_na=self.ignore_na,
+                deltas=tuple(self._deltas),
+                normalize=False,
+            )
+            return self._apply(ewm_func, name="sum")
+        elif engine in ("cython", None):
+            if engine_kwargs is not None:
+                raise ValueError("cython engine does not accept engine_kwargs")
+
+            deltas = None if self.times is None else self._deltas
+            window_func = partial(
+                window_aggregations.ewm,
+                com=self._com,
+                adjust=self.adjust,
+                ignore_na=self.ignore_na,
+                deltas=deltas,
+                normalize=False,
+            )
+            return self._apply(window_func, name="sum", numeric_only=numeric_only)
         else:
             raise ValueError("engine must be either 'numba' or 'cython'")
 
@@ -465,57 +626,75 @@ class ExponentialMovingWindow(BaseWindow):
         template_header,
         create_section_header("Parameters"),
         dedent(
-            """
+            """\
         bias : bool, default False
             Use a standard estimation bias correction.
         """
-        ).replace("\n", "", 1),
-        args_compat,
-        kwargs_compat,
+        ),
+        kwargs_numeric_only,
         create_section_header("Returns"),
         template_returns,
         create_section_header("See Also"),
-        template_see_also[:-1],
+        template_see_also,
+        create_section_header("Examples"),
+        dedent(
+            """\
+        >>> ser = pd.Series([1, 2, 3, 4])
+        >>> ser.ewm(alpha=.2).std()
+        0         NaN
+        1    0.707107
+        2    0.995893
+        3    1.277320
+        dtype: float64
+        """
+        ),
         window_method="ewm",
         aggregation_description="(exponential weighted moment) standard deviation",
         agg_method="std",
     )
-    def std(self, bias: bool = False, *args, **kwargs):
-        nv.validate_window_func("std", args, kwargs)
-        return zsqrt(self.var(bias=bias, **kwargs))
-
-    def vol(self, bias: bool = False, *args, **kwargs):
-        warnings.warn(
-            (
-                "vol is deprecated will be removed in a future version. "
-                "Use std instead."
-            ),
-            FutureWarning,
-            stacklevel=2,
-        )
-        return self.std(bias, *args, **kwargs)
+    def std(self, bias: bool = False, numeric_only: bool = False):
+        if (
+            numeric_only
+            and self._selected_obj.ndim == 1
+            and not is_numeric_dtype(self._selected_obj.dtype)
+        ):
+            # Raise directly so error message says std instead of var
+            raise NotImplementedError(
+                f"{type(self).__name__}.std does not implement numeric_only"
+            )
+        return zsqrt(self.var(bias=bias, numeric_only=numeric_only))
 
     @doc(
         template_header,
         create_section_header("Parameters"),
         dedent(
-            """
+            """\
         bias : bool, default False
             Use a standard estimation bias correction.
         """
-        ).replace("\n", "", 1),
-        args_compat,
-        kwargs_compat,
+        ),
+        kwargs_numeric_only,
         create_section_header("Returns"),
         template_returns,
         create_section_header("See Also"),
-        template_see_also[:-1],
+        template_see_also,
+        create_section_header("Examples"),
+        dedent(
+            """\
+        >>> ser = pd.Series([1, 2, 3, 4])
+        >>> ser.ewm(alpha=.2).var()
+        0         NaN
+        1    0.500000
+        2    0.991803
+        3    1.631547
+        dtype: float64
+        """
+        ),
         window_method="ewm",
         aggregation_description="(exponential weighted moment) variance",
         agg_method="var",
     )
-    def var(self, bias: bool = False, *args, **kwargs):
-        nv.validate_window_func("var", args, kwargs)
+    def var(self, bias: bool = False, numeric_only: bool = False):
         window_func = window_aggregations.ewmcov
         wfunc = partial(
             window_func,
@@ -528,13 +707,13 @@ class ExponentialMovingWindow(BaseWindow):
         def var_func(values, begin, end, min_periods):
             return wfunc(values, begin, end, min_periods, values)
 
-        return self._apply(var_func)
+        return self._apply(var_func, name="var", numeric_only=numeric_only)
 
     @doc(
         template_header,
         create_section_header("Parameters"),
         dedent(
-            """
+            """\
         other : Series or DataFrame , optional
             If not supplied then will default to self and produce pairwise
             output.
@@ -548,25 +727,40 @@ class ExponentialMovingWindow(BaseWindow):
         bias : bool, default False
             Use a standard estimation bias correction.
         """
-        ).replace("\n", "", 1),
-        kwargs_compat,
+        ),
+        kwargs_numeric_only,
         create_section_header("Returns"),
         template_returns,
         create_section_header("See Also"),
-        template_see_also[:-1],
+        template_see_also,
+        create_section_header("Examples"),
+        dedent(
+            """\
+        >>> ser1 = pd.Series([1, 2, 3, 4])
+        >>> ser2 = pd.Series([10, 11, 13, 16])
+        >>> ser1.ewm(alpha=.2).cov(ser2)
+        0         NaN
+        1    0.500000
+        2    1.524590
+        3    3.408836
+        dtype: float64
+        """
+        ),
         window_method="ewm",
         aggregation_description="(exponential weighted moment) sample covariance",
         agg_method="cov",
     )
     def cov(
         self,
-        other: FrameOrSeriesUnion | None = None,
+        other: DataFrame | Series | None = None,
         pairwise: bool | None = None,
         bias: bool = False,
-        **kwargs,
+        numeric_only: bool = False,
     ):
         from pandas import Series
 
+        self._validate_numeric_only("cov", numeric_only)
+
         def cov_func(x, y):
             x_array = self._prep_values(x)
             y_array = self._prep_values(y)
@@ -581,6 +775,7 @@ class ExponentialMovingWindow(BaseWindow):
                 min_periods=min_periods,
                 center=self.center,
                 closed=self.closed,
+                step=self.step,
             )
             result = window_aggregations.ewmcov(
                 x_array,
@@ -595,15 +790,17 @@ class ExponentialMovingWindow(BaseWindow):
                 self.ignore_na,
                 bias,
             )
-            return Series(result, index=x.index, name=x.name)
+            return Series(result, index=x.index, name=x.name, copy=False)
 
-        return self._apply_pairwise(self._selected_obj, other, pairwise, cov_func)
+        return self._apply_pairwise(
+            self._selected_obj, other, pairwise, cov_func, numeric_only
+        )
 
     @doc(
         template_header,
         create_section_header("Parameters"),
         dedent(
-            """
+            """\
         other : Series or DataFrame, optional
             If not supplied then will default to self and produce pairwise
             output.
@@ -615,24 +812,39 @@ class ExponentialMovingWindow(BaseWindow):
             inputs. In the case of missing elements, only complete pairwise
             observations will be used.
         """
-        ).replace("\n", "", 1),
-        kwargs_compat,
+        ),
+        kwargs_numeric_only,
         create_section_header("Returns"),
         template_returns,
         create_section_header("See Also"),
-        template_see_also[:-1],
+        template_see_also,
+        create_section_header("Examples"),
+        dedent(
+            """\
+        >>> ser1 = pd.Series([1, 2, 3, 4])
+        >>> ser2 = pd.Series([10, 11, 13, 16])
+        >>> ser1.ewm(alpha=.2).corr(ser2)
+        0         NaN
+        1    1.000000
+        2    0.982821
+        3    0.977802
+        dtype: float64
+        """
+        ),
         window_method="ewm",
         aggregation_description="(exponential weighted moment) sample correlation",
         agg_method="corr",
     )
     def corr(
         self,
-        other: FrameOrSeriesUnion | None = None,
+        other: DataFrame | Series | None = None,
         pairwise: bool | None = None,
-        **kwargs,
+        numeric_only: bool = False,
     ):
         from pandas import Series
 
+        self._validate_numeric_only("corr", numeric_only)
+
         def cov_func(x, y):
             x_array = self._prep_values(x)
             y_array = self._prep_values(y)
@@ -647,6 +859,7 @@ class ExponentialMovingWindow(BaseWindow):
                 min_periods=min_periods,
                 center=self.center,
                 closed=self.closed,
+                step=self.step,
             )
 
             def _cov(X, Y):
@@ -667,9 +880,11 @@ class ExponentialMovingWindow(BaseWindow):
                 x_var = _cov(x_array, x_array)
                 y_var = _cov(y_array, y_array)
                 result = cov / zsqrt(x_var * y_var)
-            return Series(result, index=x.index, name=x.name)
+            return Series(result, index=x.index, name=x.name, copy=False)
 
-        return self._apply_pairwise(self._selected_obj, other, pairwise, cov_func)
+        return self._apply_pairwise(
+            self._selected_obj, other, pairwise, cov_func, numeric_only
+        )
 
 
 class ExponentialMovingWindowGroupby(BaseWindowGroupby, ExponentialMovingWindow):
@@ -679,14 +894,14 @@ class ExponentialMovingWindowGroupby(BaseWindowGroupby, ExponentialMovingWindow)
 
     _attributes = ExponentialMovingWindow._attributes + BaseWindowGroupby._attributes
 
-    def __init__(self, obj, *args, _grouper=None, **kwargs):
+    def __init__(self, obj, *args, _grouper=None, **kwargs) -> None:
         super().__init__(obj, *args, _grouper=_grouper, **kwargs)
 
         if not obj.empty and self.times is not None:
             # sort the times and recalculate the deltas according to the groups
             groupby_order = np.concatenate(list(self._grouper.indices.values()))
             self._deltas = _calculate_deltas(
-                self.times.take(groupby_order),  # type: ignore[union-attr]
+                self.times.take(groupby_order),
                 self.halflife,
             )
 
@@ -708,7 +923,7 @@ class ExponentialMovingWindowGroupby(BaseWindowGroupby, ExponentialMovingWindow)
 class OnlineExponentialMovingWindow(ExponentialMovingWindow):
     def __init__(
         self,
-        obj: FrameOrSeries,
+        obj: NDFrame,
         com: float | None = None,
         span: float | None = None,
         halflife: float | TimedeltaConvertibleTypes | None = None,
@@ -717,12 +932,12 @@ class OnlineExponentialMovingWindow(ExponentialMovingWindow):
         adjust: bool = True,
         ignore_na: bool = False,
         axis: Axis = 0,
-        times: str | np.ndarray | FrameOrSeries | None = None,
+        times: np.ndarray | NDFrame | None = None,
         engine: str = "numba",
         engine_kwargs: dict[str, bool] | None = None,
         *,
         selection=None,
-    ):
+    ) -> None:
         if times is not None:
             raise NotImplementedError(
                 "times is not implemented with online operations."
@@ -749,37 +964,37 @@ class OnlineExponentialMovingWindow(ExponentialMovingWindow):
         else:
             raise ValueError("'numba' is the only supported engine")
 
-    def reset(self):
+    def reset(self) -> None:
         """
         Reset the state captured by `update` calls.
         """
         self._mean.reset()
 
     def aggregate(self, func, *args, **kwargs):
-        return NotImplementedError
+        raise NotImplementedError("aggregate is not implemented.")
 
     def std(self, bias: bool = False, *args, **kwargs):
-        return NotImplementedError
+        raise NotImplementedError("std is not implemented.")
 
     def corr(
         self,
-        other: FrameOrSeriesUnion | None = None,
+        other: DataFrame | Series | None = None,
         pairwise: bool | None = None,
-        **kwargs,
+        numeric_only: bool = False,
     ):
-        return NotImplementedError
+        raise NotImplementedError("corr is not implemented.")
 
     def cov(
         self,
-        other: FrameOrSeriesUnion | None = None,
+        other: DataFrame | Series | None = None,
         pairwise: bool | None = None,
         bias: bool = False,
-        **kwargs,
+        numeric_only: bool = False,
     ):
-        return NotImplementedError
+        raise NotImplementedError("cov is not implemented.")
 
-    def var(self, bias: bool = False, *args, **kwargs):
-        return NotImplementedError
+    def var(self, bias: bool = False, numeric_only: bool = False):
+        raise NotImplementedError("var is not implemented.")
 
     def mean(self, *args, update=None, update_times=None, **kwargs):
         """
@@ -826,13 +1041,12 @@ class OnlineExponentialMovingWindow(ExponentialMovingWindow):
         1  0.75  5.75
         """
         result_kwargs = {}
-        is_frame = True if self._selected_obj.ndim == 2 else False
+        is_frame = self._selected_obj.ndim == 2
         if update_times is not None:
             raise NotImplementedError("update_times is not implemented.")
-        else:
-            update_deltas = np.ones(
-                max(self._selected_obj.shape[self.axis - 1] - 1, 0), dtype=np.float64
-            )
+        update_deltas = np.ones(
+            max(self._selected_obj.shape[self.axis - 1] - 1, 0), dtype=np.float64
+        )
         if update is not None:
             if self._mean.last_ewm is None:
                 raise ValueError(
@@ -855,7 +1069,9 @@ class OnlineExponentialMovingWindow(ExponentialMovingWindow):
             else:
                 result_kwargs["name"] = self._selected_obj.name
             np_array = self._selected_obj.astype(np.float64).to_numpy()
-        ewma_func = generate_online_numba_ewma_func(self.engine_kwargs)
+        ewma_func = generate_online_numba_ewma_func(
+            **get_jit_arguments(self.engine_kwargs)
+        )
         result = self._mean.run_ewm(
             np_array if is_frame else np_array[:, np.newaxis],
             update_deltas,
