@@ -3,39 +3,56 @@ from __future__ import annotations
 from collections import defaultdict
 import datetime
 from typing import (
+    TYPE_CHECKING,
     Any,
     DefaultDict,
+    cast,
+    overload,
 )
 
-import pandas._libs.json as json
-from pandas._typing import StorageOptions
+from pandas._libs import json
 
 from pandas.io.excel._base import ExcelWriter
-from pandas.io.excel._util import validate_freeze_panes
-from pandas.io.formats.excel import ExcelCell
+from pandas.io.excel._util import (
+    combine_kwargs,
+    validate_freeze_panes,
+)
+
+if TYPE_CHECKING:
+    from pandas._typing import (
+        ExcelWriterIfSheetExists,
+        FilePath,
+        StorageOptions,
+        WriteExcelBuffer,
+    )
+
+    from pandas.io.formats.excel import ExcelCell
 
 
 class ODSWriter(ExcelWriter):
-    engine = "odf"
-    supported_extensions = (".ods",)
+    _engine = "odf"
+    _supported_extensions = (".ods",)
 
     def __init__(
         self,
-        path: str,
+        path: FilePath | WriteExcelBuffer | ExcelWriter,
         engine: str | None = None,
-        date_format=None,
+        date_format: str | None = None,
         datetime_format=None,
         mode: str = "w",
-        storage_options: StorageOptions = None,
-        if_sheet_exists: str | None = None,
+        storage_options: StorageOptions | None = None,
+        if_sheet_exists: ExcelWriterIfSheetExists | None = None,
         engine_kwargs: dict[str, Any] | None = None,
         **kwargs,
-    ):
+    ) -> None:
         from odf.opendocument import OpenDocumentSpreadsheet
 
         if mode == "a":
             raise ValueError("Append mode is not supported with odf!")
 
+        engine_kwargs = combine_kwargs(engine_kwargs, kwargs)
+        self._book = OpenDocumentSpreadsheet(**engine_kwargs)
+
         super().__init__(
             path,
             mode=mode,
@@ -44,18 +61,37 @@ class ODSWriter(ExcelWriter):
             engine_kwargs=engine_kwargs,
         )
 
-        self.book = OpenDocumentSpreadsheet()
         self._style_dict: dict[str, str] = {}
 
-    def save(self) -> None:
+    @property
+    def book(self):
+        """
+        Book instance of class odf.opendocument.OpenDocumentSpreadsheet.
+
+        This attribute can be used to access engine-specific features.
+        """
+        return self._book
+
+    @property
+    def sheets(self) -> dict[str, Any]:
+        """Mapping of sheet names to sheet objects."""
+        from odf.table import Table
+
+        result = {
+            sheet.getAttribute("name"): sheet
+            for sheet in self.book.getElementsByType(Table)
+        }
+        return result
+
+    def _save(self) -> None:
         """
         Save workbook to disk.
         """
         for sheet in self.sheets.values():
             self.book.spreadsheet.addElement(sheet)
-        self.book.save(self.handles.handle)
+        self.book.save(self._handles.handle)
 
-    def write_cells(
+    def _write_cells(
         self,
         cells: list[ExcelCell],
         sheet_name: str | None = None,
@@ -80,10 +116,10 @@ class ODSWriter(ExcelWriter):
             wks = self.sheets[sheet_name]
         else:
             wks = Table(name=sheet_name)
-            self.sheets[sheet_name] = wks
+            self.book.spreadsheet.addElement(wks)
 
         if validate_freeze_panes(freeze_panes):
-            assert freeze_panes is not None
+            freeze_panes = cast(tuple[int, int], freeze_panes)
             self._create_freeze_panes(sheet_name, freeze_panes)
 
         for _ in range(startrow):
@@ -110,8 +146,9 @@ class ODSWriter(ExcelWriter):
             tc.addElement(p)
 
         # add all rows to the sheet
-        for row_nr in range(max(rows.keys()) + 1):
-            wks.addElement(rows[row_nr])
+        if len(rows) > 0:
+            for row_nr in range(max(rows.keys()) + 1):
+                wks.addElement(rows[row_nr])
 
     def _make_table_cell_attributes(self, cell) -> dict[str, int | str]:
         """Convert cell attributes to OpenDocument attributes
@@ -135,7 +172,7 @@ class ODSWriter(ExcelWriter):
             attributes["numbercolumnsspanned"] = cell.mergeend
         return attributes
 
-    def _make_table_cell(self, cell) -> tuple[str, Any]:
+    def _make_table_cell(self, cell) -> tuple[object, Any]:
         """Convert cell data to an OpenDocument spreadsheet cell
 
         Parameters
@@ -157,14 +194,18 @@ class ODSWriter(ExcelWriter):
             value = str(val).lower()
             pvalue = str(val).upper()
         if isinstance(val, datetime.datetime):
+            # Fast formatting
             value = val.isoformat()
+            # Slow but locale-dependent
             pvalue = val.strftime("%c")
             return (
                 pvalue,
                 TableCell(valuetype="date", datevalue=value, attributes=attributes),
             )
         elif isinstance(val, datetime.date):
-            value = val.strftime("%Y-%m-%d")
+            # Fast formatting
+            value = f"{val.year}-{val.month:02d}-{val.day:02d}"
+            # Slow but locale-dependent
             pvalue = val.strftime("%x")
             return (
                 pvalue,
@@ -186,7 +227,15 @@ class ODSWriter(ExcelWriter):
                 ),
             )
 
+    @overload
     def _process_style(self, style: dict[str, Any]) -> str:
+        ...
+
+    @overload
+    def _process_style(self, style: None) -> None:
+        ...
+
+    def _process_style(self, style: dict[str, Any] | None) -> str | None:
         """Convert a style dictionary to a OpenDocument style sheet
 
         Parameters
@@ -208,7 +257,7 @@ class ODSWriter(ExcelWriter):
 
         if style is None:
             return None
-        style_key = json.dumps(style)
+        style_key = json.ujson_dumps(style)
         if style_key in self._style_dict:
             return self._style_dict[style_key]
         name = f"pd{len(self._style_dict)+1}"
