@@ -1,6 +1,9 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import (
+    TYPE_CHECKING,
+    Literal,
+)
 
 import numpy as np
 
@@ -22,6 +25,11 @@ from pandas.plotting._matplotlib.core import (
     LinePlot,
     MPLPlot,
 )
+from pandas.plotting._matplotlib.groupby import (
+    create_iter_data_given_by,
+    reformat_hist_y_given_by,
+)
+from pandas.plotting._matplotlib.misc import unpack_single_str_list
 from pandas.plotting._matplotlib.tools import (
     create_subplots,
     flatten_axes,
@@ -32,45 +40,71 @@ from pandas.plotting._matplotlib.tools import (
 if TYPE_CHECKING:
     from matplotlib.axes import Axes
 
+    from pandas._typing import PlottingOrientation
+
+    from pandas import DataFrame
+
 
 class HistPlot(LinePlot):
-    _kind = "hist"
+    @property
+    def _kind(self) -> Literal["hist", "kde"]:
+        return "hist"
 
-    def __init__(self, data, bins=10, bottom=0, **kwargs):
+    def __init__(
+        self,
+        data,
+        bins: int | np.ndarray | list[np.ndarray] = 10,
+        bottom: int | np.ndarray = 0,
+        **kwargs,
+    ) -> None:
         self.bins = bins  # use mpl default
         self.bottom = bottom
+        self.xlabel = kwargs.get("xlabel")
+        self.ylabel = kwargs.get("ylabel")
         # Do not call LinePlot.__init__ which may fill nan
-        MPLPlot.__init__(self, data, **kwargs)
+        MPLPlot.__init__(self, data, **kwargs)  # pylint: disable=non-parent-init-called
 
-    def _args_adjust(self):
+    def _args_adjust(self) -> None:
+        # calculate bin number separately in different subplots
+        # where subplots are created based on by argument
         if is_integer(self.bins):
-            # create common bin edge
-            values = self.data._convert(datetime=True)._get_numeric_data()
-            values = np.ravel(values)
-            values = values[~isna(values)]
-
-            _, self.bins = np.histogram(
-                values, bins=self.bins, range=self.kwds.get("range", None)
-            )
+            if self.by is not None:
+                by_modified = unpack_single_str_list(self.by)
+                grouped = self.data.groupby(by_modified)[self.columns]
+                self.bins = [self._calculate_bins(group) for key, group in grouped]
+            else:
+                self.bins = self._calculate_bins(self.data)
 
         if is_list_like(self.bottom):
             self.bottom = np.array(self.bottom)
 
+    def _calculate_bins(self, data: DataFrame) -> np.ndarray:
+        """Calculate bins given data"""
+        nd_values = data.infer_objects(copy=False)._get_numeric_data()
+        values = np.ravel(nd_values)
+        values = values[~isna(values)]
+
+        hist, bins = np.histogram(
+            values, bins=self.bins, range=self.kwds.get("range", None)
+        )
+        return bins
+
+    # error: Signature of "_plot" incompatible with supertype "LinePlot"
     @classmethod
-    def _plot(
+    def _plot(  # type: ignore[override]
         cls,
         ax,
         y,
         style=None,
-        bins=None,
-        bottom=0,
-        column_num=0,
+        bottom: int | np.ndarray = 0,
+        column_num: int = 0,
         stacking_id=None,
+        *,
+        bins,
         **kwds,
     ):
         if column_num == 0:
             cls._initialize_stacker(ax, stacking_id, len(bins) - 1)
-        y = y[~isna(y)]
 
         base = np.zeros(len(bins) - 1)
         bottom = bottom + cls._get_stacked_values(ax, stacking_id, base, kwds["label"])
@@ -79,11 +113,18 @@ class HistPlot(LinePlot):
         cls._update_stacker(ax, stacking_id, n)
         return patches
 
-    def _make_plot(self):
+    def _make_plot(self) -> None:
         colors = self._get_colors()
         stacking_id = self._get_stacking_id()
 
-        for i, (label, y) in enumerate(self._iter_data()):
+        # Re-create iterated data if `by` is assigned by users
+        data = (
+            create_iter_data_given_by(self.data, self._kind)
+            if self.by is not None
+            else self.data
+        )
+
+        for i, (label, y) in enumerate(self._iter_data(data=data)):
             ax = self._get_ax(i)
 
             kwds = self.kwds.copy()
@@ -98,14 +139,37 @@ class HistPlot(LinePlot):
 
             kwds = self._make_plot_keywords(kwds, y)
 
+            # the bins is multi-dimension array now and each plot need only 1-d and
+            # when by is applied, label should be columns that are grouped
+            if self.by is not None:
+                kwds["bins"] = kwds["bins"][i]
+                kwds["label"] = self.columns
+                kwds.pop("color")
+
             # We allow weights to be a multi-dimensional array, e.g. a (10, 2) array,
             # and each sub-array (10,) will be called in each iteration. If users only
             # provide 1D array, we assume the same weights is used for all iterations
             weights = kwds.get("weights", None)
-            if weights is not None and np.ndim(weights) != 1:
-                kwds["weights"] = weights[:, i]
+            if weights is not None:
+                if np.ndim(weights) != 1 and np.shape(weights)[-1] != 1:
+                    try:
+                        weights = weights[:, i]
+                    except IndexError as err:
+                        raise ValueError(
+                            "weights must have the same shape as data, "
+                            "or be a single column"
+                        ) from err
+                weights = weights[~isna(y)]
+                kwds["weights"] = weights
+
+            y = reformat_hist_y_given_by(y, self.by)
 
             artists = self._plot(ax, y, column_num=i, stacking_id=stacking_id, **kwds)
+
+            # when by is applied, show title for subplots to know which group it is
+            if self.by is not None:
+                ax.set_title(pprint_thing(label))
+
             self._append_legend_handles_labels(artists[0], label)
 
     def _make_plot_keywords(self, kwds, y):
@@ -115,14 +179,16 @@ class HistPlot(LinePlot):
         kwds["bins"] = self.bins
         return kwds
 
-    def _post_plot_logic(self, ax: Axes, data):
+    def _post_plot_logic(self, ax: Axes, data) -> None:
         if self.orientation == "horizontal":
-            ax.set_xlabel("Frequency")
+            ax.set_xlabel("Frequency" if self.xlabel is None else self.xlabel)
+            ax.set_ylabel(self.ylabel)
         else:
-            ax.set_ylabel("Frequency")
+            ax.set_xlabel(self.xlabel)
+            ax.set_ylabel("Frequency" if self.ylabel is None else self.ylabel)
 
     @property
-    def orientation(self):
+    def orientation(self) -> PlottingOrientation:
         if self.kwds.get("orientation", None) == "horizontal":
             return "horizontal"
         else:
@@ -130,15 +196,21 @@ class HistPlot(LinePlot):
 
 
 class KdePlot(HistPlot):
-    _kind = "kde"
-    orientation = "vertical"
+    @property
+    def _kind(self) -> Literal["kde"]:
+        return "kde"
 
-    def __init__(self, data, bw_method=None, ind=None, **kwargs):
-        MPLPlot.__init__(self, data, **kwargs)
+    @property
+    def orientation(self) -> Literal["vertical"]:
+        return "vertical"
+
+    def __init__(self, data, bw_method=None, ind=None, **kwargs) -> None:
+        # Do not call LinePlot.__init__ which may fill nan
+        MPLPlot.__init__(self, data, **kwargs)  # pylint: disable=non-parent-init-called
         self.bw_method = bw_method
         self.ind = ind
 
-    def _args_adjust(self):
+    def _args_adjust(self) -> None:
         pass
 
     def _get_ind(self, y):
@@ -187,7 +259,7 @@ class KdePlot(HistPlot):
         kwds["ind"] = self._get_ind(y)
         return kwds
 
-    def _post_plot_logic(self, ax, data):
+    def _post_plot_logic(self, ax, data) -> None:
         ax.set_ylabel("Density")
 
 
@@ -196,17 +268,18 @@ def _grouped_plot(
     data,
     column=None,
     by=None,
-    numeric_only=True,
-    figsize=None,
-    sharex=True,
-    sharey=True,
+    numeric_only: bool = True,
+    figsize: tuple[float, float] | None = None,
+    sharex: bool = True,
+    sharey: bool = True,
     layout=None,
-    rot=0,
+    rot: float = 0,
     ax=None,
     **kwargs,
 ):
-
-    if figsize == "default":
+    # error: Non-overlapping equality check (left operand type: "Optional[Tuple[float,
+    # float]]", right operand type: "Literal['default']")
+    if figsize == "default":  # type: ignore[comparison-overlap]
         # allowed to specify mpl default with 'default'
         raise ValueError(
             "figsize='default' is no longer supported. "
@@ -239,18 +312,18 @@ def _grouped_hist(
     column=None,
     by=None,
     ax=None,
-    bins=50,
-    figsize=None,
+    bins: int = 50,
+    figsize: tuple[float, float] | None = None,
     layout=None,
-    sharex=False,
-    sharey=False,
-    rot=90,
-    grid=True,
-    xlabelsize=None,
+    sharex: bool = False,
+    sharey: bool = False,
+    rot: float = 90,
+    grid: bool = True,
+    xlabelsize: int | None = None,
     xrot=None,
-    ylabelsize=None,
+    ylabelsize: int | None = None,
     yrot=None,
-    legend=False,
+    legend: bool = False,
     **kwargs,
 ):
     """
@@ -267,7 +340,7 @@ def _grouped_hist(
     layout : optional
     sharex : bool, default False
     sharey : bool, default False
-    rot : int, default 90
+    rot : float, default 90
     grid : bool, default True
     legend: : bool, default False
     kwargs : dict, keyword arguments passed to matplotlib.Axes.hist
@@ -285,7 +358,7 @@ def _grouped_hist(
         else:
             kwargs["label"] = column
 
-    def plot_group(group, ax):
+    def plot_group(group, ax) -> None:
         ax.hist(group.dropna().values, bins=bins, **kwargs)
         if legend:
             ax.legend()
@@ -320,13 +393,13 @@ def hist_series(
     self,
     by=None,
     ax=None,
-    grid=True,
-    xlabelsize=None,
+    grid: bool = True,
+    xlabelsize: int | None = None,
     xrot=None,
-    ylabelsize=None,
+    ylabelsize: int | None = None,
     yrot=None,
-    figsize=None,
-    bins=10,
+    figsize: tuple[float, float] | None = None,
+    bins: int = 10,
     legend: bool = False,
     **kwds,
 ):
@@ -392,17 +465,17 @@ def hist_frame(
     data,
     column=None,
     by=None,
-    grid=True,
-    xlabelsize=None,
+    grid: bool = True,
+    xlabelsize: int | None = None,
     xrot=None,
-    ylabelsize=None,
+    ylabelsize: int | None = None,
     yrot=None,
     ax=None,
-    sharex=False,
-    sharey=False,
-    figsize=None,
+    sharex: bool = False,
+    sharey: bool = False,
+    figsize: tuple[float, float] | None = None,
     layout=None,
-    bins=10,
+    bins: int = 10,
     legend: bool = False,
     **kwds,
 ):
