@@ -25,29 +25,24 @@ from pandas import (
 )
 
 
-@pytest.fixture(params=[True, False])
-def pandas_dtype(request):
-    return request.param
-
-
-def test_infer_dtype_from_int_scalar(any_int_dtype):
+def test_infer_dtype_from_int_scalar(any_int_numpy_dtype):
     # Test that infer_dtype_from_scalar is
     # returning correct dtype for int and float.
-    data = np.dtype(any_int_dtype).type(12)
+    data = np.dtype(any_int_numpy_dtype).type(12)
     dtype, val = infer_dtype_from_scalar(data)
     assert dtype == type(data)
 
 
-def test_infer_dtype_from_float_scalar(float_dtype):
-    float_dtype = np.dtype(float_dtype).type
-    data = float_dtype(12)
+def test_infer_dtype_from_float_scalar(float_numpy_dtype):
+    float_numpy_dtype = np.dtype(float_numpy_dtype).type
+    data = float_numpy_dtype(12)
 
     dtype, val = infer_dtype_from_scalar(data)
-    assert dtype == float_dtype
+    assert dtype == float_numpy_dtype
 
 
 @pytest.mark.parametrize(
-    "data,exp_dtype", [(12, np.int64), (np.float_(12), np.float64)]
+    "data,exp_dtype", [(12, np.int64), (np.float64(12), np.float64)]
 )
 def test_infer_dtype_from_python_scalar(data, exp_dtype):
     dtype, val = infer_dtype_from_scalar(data)
@@ -63,54 +58,64 @@ def test_infer_dtype_from_boolean(bool_val):
 def test_infer_dtype_from_complex(complex_dtype):
     data = np.dtype(complex_dtype).type(1)
     dtype, val = infer_dtype_from_scalar(data)
-    assert dtype == np.complex_
+    assert dtype == np.complex128
 
 
-@pytest.mark.parametrize(
-    "data", [np.datetime64(1, "ns"), Timestamp(1), datetime(2000, 1, 1, 0, 0)]
-)
-def test_infer_dtype_from_datetime(data):
-    dtype, val = infer_dtype_from_scalar(data)
+def test_infer_dtype_from_datetime():
+    dt64 = np.datetime64(1, "ns")
+    dtype, val = infer_dtype_from_scalar(dt64)
     assert dtype == "M8[ns]"
 
+    ts = Timestamp(1)
+    dtype, val = infer_dtype_from_scalar(ts)
+    assert dtype == "M8[ns]"
 
-@pytest.mark.parametrize("data", [np.timedelta64(1, "ns"), Timedelta(1), timedelta(1)])
-def test_infer_dtype_from_timedelta(data):
-    dtype, val = infer_dtype_from_scalar(data)
+    dt = datetime(2000, 1, 1, 0, 0)
+    dtype, val = infer_dtype_from_scalar(dt)
+    assert dtype == "M8[us]"
+
+
+def test_infer_dtype_from_timedelta():
+    td64 = np.timedelta64(1, "ns")
+    dtype, val = infer_dtype_from_scalar(td64)
+    assert dtype == "m8[ns]"
+
+    pytd = timedelta(1)
+    dtype, val = infer_dtype_from_scalar(pytd)
+    assert dtype == "m8[us]"
+
+    td = Timedelta(1)
+    dtype, val = infer_dtype_from_scalar(td)
     assert dtype == "m8[ns]"
 
 
 @pytest.mark.parametrize("freq", ["M", "D"])
-def test_infer_dtype_from_period(freq, pandas_dtype):
+def test_infer_dtype_from_period(freq):
     p = Period("2011-01-01", freq=freq)
-    dtype, val = infer_dtype_from_scalar(p, pandas_dtype=pandas_dtype)
+    dtype, val = infer_dtype_from_scalar(p)
 
-    if pandas_dtype:
-        exp_dtype = f"period[{freq}]"
-    else:
-        exp_dtype = np.object_
+    exp_dtype = f"period[{freq}]"
 
     assert dtype == exp_dtype
     assert val == p
 
 
-@pytest.mark.parametrize(
-    "data", [date(2000, 1, 1), "foo", Timestamp(1, tz="US/Eastern")]
-)
-def test_infer_dtype_misc(data):
-    dtype, val = infer_dtype_from_scalar(data)
+def test_infer_dtype_misc():
+    dt = date(2000, 1, 1)
+    dtype, val = infer_dtype_from_scalar(dt)
     assert dtype == np.object_
 
+    ts = Timestamp(1, tz="US/Eastern")
+    dtype, val = infer_dtype_from_scalar(ts)
+    assert dtype == "datetime64[ns, US/Eastern]"
+
 
 @pytest.mark.parametrize("tz", ["UTC", "US/Eastern", "Asia/Tokyo"])
-def test_infer_from_scalar_tz(tz, pandas_dtype):
+def test_infer_from_scalar_tz(tz):
     dt = Timestamp(1, tz=tz)
-    dtype, val = infer_dtype_from_scalar(dt, pandas_dtype=pandas_dtype)
+    dtype, val = infer_dtype_from_scalar(dt)
 
-    if pandas_dtype:
-        exp_dtype = f"datetime64[ns, {tz}]"
-    else:
-        exp_dtype = np.object_
+    exp_dtype = f"datetime64[ns, {tz}]"
 
     assert dtype == exp_dtype
     assert val == dt
@@ -126,11 +131,11 @@ def test_infer_from_scalar_tz(tz, pandas_dtype):
         (Timedelta(0), Timedelta(1), "timedelta64[ns]"),
     ],
 )
-def test_infer_from_interval(left, right, subtype, closed, pandas_dtype):
+def test_infer_from_interval(left, right, subtype, closed):
     # GH 30337
     interval = Interval(left, right, closed)
-    result_dtype, result_value = infer_dtype_from_scalar(interval, pandas_dtype)
-    expected_dtype = f"interval[{subtype}, {closed}]" if pandas_dtype else np.object_
+    result_dtype, result_value = infer_dtype_from_scalar(interval)
+    expected_dtype = f"interval[{subtype}, {closed}]"
     assert result_dtype == expected_dtype
     assert result_value == interval
 
@@ -143,54 +148,49 @@ def test_infer_dtype_from_scalar_errors():
 
 
 @pytest.mark.parametrize(
-    "value, expected, pandas_dtype",
+    "value, expected",
     [
-        ("foo", np.object_, False),
-        (b"foo", np.object_, False),
-        (1, np.int64, False),
-        (1.5, np.float_, False),
-        (np.datetime64("2016-01-01"), np.dtype("M8[ns]"), False),
-        (Timestamp("20160101"), np.dtype("M8[ns]"), False),
-        (Timestamp("20160101", tz="UTC"), np.object_, False),
-        (Timestamp("20160101", tz="UTC"), "datetime64[ns, UTC]", True),
+        ("foo", np.object_),
+        (b"foo", np.object_),
+        (1, np.int64),
+        (1.5, np.float64),
+        (np.datetime64("2016-01-01"), np.dtype("M8[s]")),
+        (Timestamp("20160101"), np.dtype("M8[s]")),
+        (Timestamp("20160101", tz="UTC"), "datetime64[s, UTC]"),
     ],
 )
-def test_infer_dtype_from_scalar(value, expected, pandas_dtype):
-    dtype, _ = infer_dtype_from_scalar(value, pandas_dtype=pandas_dtype)
+def test_infer_dtype_from_scalar(value, expected):
+    dtype, _ = infer_dtype_from_scalar(value)
     assert is_dtype_equal(dtype, expected)
 
     with pytest.raises(TypeError, match="must be list-like"):
-        infer_dtype_from_array(value, pandas_dtype=pandas_dtype)
+        infer_dtype_from_array(value)
 
 
 @pytest.mark.parametrize(
-    "arr, expected, pandas_dtype",
+    "arr, expected",
     [
-        ([1], np.int_, False),
-        (np.array([1], dtype=np.int64), np.int64, False),
-        ([np.nan, 1, ""], np.object_, False),
-        (np.array([[1.0, 2.0]]), np.float_, False),
-        (Categorical(list("aabc")), np.object_, False),
-        (Categorical([1, 2, 3]), np.int64, False),
-        (Categorical(list("aabc")), "category", True),
-        (Categorical([1, 2, 3]), "category", True),
-        (date_range("20160101", periods=3), np.dtype("=M8[ns]"), False),
+        ([1], np.dtype(int)),
+        (np.array([1], dtype=np.int64), np.int64),
+        ([np.nan, 1, ""], np.object_),
+        (np.array([[1.0, 2.0]]), np.float64),
+        (Categorical(list("aabc")), "category"),
+        (Categorical([1, 2, 3]), "category"),
+        (date_range("20160101", periods=3), np.dtype("=M8[ns]")),
         (
             date_range("20160101", periods=3, tz="US/Eastern"),
             "datetime64[ns, US/Eastern]",
-            True,
         ),
-        (Series([1.0, 2, 3]), np.float64, False),
-        (Series(list("abc")), np.object_, False),
+        (Series([1.0, 2, 3]), np.float64),
+        (Series(list("abc")), np.object_),
         (
             Series(date_range("20160101", periods=3, tz="US/Eastern")),
             "datetime64[ns, US/Eastern]",
-            True,
         ),
     ],
 )
-def test_infer_dtype_from_array(arr, expected, pandas_dtype):
-    dtype, _ = infer_dtype_from_array(arr, pandas_dtype=pandas_dtype)
+def test_infer_dtype_from_array(arr, expected):
+    dtype, _ = infer_dtype_from_array(arr)
     assert is_dtype_equal(dtype, expected)
 
 
