@@ -11,58 +11,11 @@ import pytest
 from pandas._libs.tslibs import NaT
 
 from pandas.core.dtypes.cast import maybe_promote
-from pandas.core.dtypes.common import (
-    is_complex_dtype,
-    is_datetime64_dtype,
-    is_datetime_or_timedelta_dtype,
-    is_float_dtype,
-    is_integer_dtype,
-    is_object_dtype,
-    is_scalar,
-    is_timedelta64_dtype,
-)
+from pandas.core.dtypes.common import is_scalar
 from pandas.core.dtypes.dtypes import DatetimeTZDtype
 from pandas.core.dtypes.missing import isna
 
 import pandas as pd
-import pandas._testing as tm
-
-
-@pytest.fixture(
-    params=[
-        bool,
-        "uint8",
-        "int32",
-        "uint64",
-        "float32",
-        "float64",
-        "complex64",
-        "complex128",
-        "M8[ns]",
-        "m8[ns]",
-        str,
-        bytes,
-        object,
-    ]
-)
-def any_numpy_dtype_reduced(request):
-    """
-    Parameterized fixture for numpy dtypes, reduced from any_numpy_dtype.
-
-    * bool
-    * 'int32'
-    * 'uint64'
-    * 'float32'
-    * 'float64'
-    * 'complex64'
-    * 'complex128'
-    * 'M8[ns]'
-    * 'M8[ns]'
-    * str
-    * bytes
-    * object
-    """
-    return request.param
 
 
 def _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar=None):
@@ -240,9 +193,9 @@ def test_maybe_promote_int_with_int(dtype, fill_value, expected_dtype):
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_int_with_float(any_int_dtype, float_dtype):
-    dtype = np.dtype(any_int_dtype)
-    fill_dtype = np.dtype(float_dtype)
+def test_maybe_promote_int_with_float(any_int_numpy_dtype, float_numpy_dtype):
+    dtype = np.dtype(any_int_numpy_dtype)
+    fill_dtype = np.dtype(float_numpy_dtype)
 
     # create array of given dtype; casts "1" to correct dtype
     fill_value = np.array([1], dtype=fill_dtype)[0]
@@ -255,10 +208,9 @@ def test_maybe_promote_int_with_float(any_int_dtype, float_dtype):
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_float_with_int(float_dtype, any_int_dtype):
-
-    dtype = np.dtype(float_dtype)
-    fill_dtype = np.dtype(any_int_dtype)
+def test_maybe_promote_float_with_int(float_numpy_dtype, any_int_numpy_dtype):
+    dtype = np.dtype(float_numpy_dtype)
+    fill_dtype = np.dtype(any_int_numpy_dtype)
 
     # create array of given dtype; casts "1" to correct dtype
     fill_value = np.array([1], dtype=fill_dtype)[0]
@@ -298,7 +250,6 @@ def test_maybe_promote_float_with_int(float_dtype, any_int_dtype):
     ],
 )
 def test_maybe_promote_float_with_float(dtype, fill_value, expected_dtype):
-
     dtype = np.dtype(dtype)
     expected_dtype = np.dtype(expected_dtype)
 
@@ -308,9 +259,9 @@ def test_maybe_promote_float_with_float(dtype, fill_value, expected_dtype):
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_bool_with_any(any_numpy_dtype_reduced):
+def test_maybe_promote_bool_with_any(any_numpy_dtype):
     dtype = np.dtype(bool)
-    fill_dtype = np.dtype(any_numpy_dtype_reduced)
+    fill_dtype = np.dtype(any_numpy_dtype)
 
     # create array of given dtype; casts "1" to correct dtype
     fill_value = np.array([1], dtype=fill_dtype)[0]
@@ -322,8 +273,8 @@ def test_maybe_promote_bool_with_any(any_numpy_dtype_reduced):
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_any_with_bool(any_numpy_dtype_reduced):
-    dtype = np.dtype(any_numpy_dtype_reduced)
+def test_maybe_promote_any_with_bool(any_numpy_dtype):
+    dtype = np.dtype(any_numpy_dtype)
     fill_value = True
 
     # filling anything but bool with bool casts to object
@@ -334,9 +285,9 @@ def test_maybe_promote_any_with_bool(any_numpy_dtype_reduced):
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_bytes_with_any(bytes_dtype, any_numpy_dtype_reduced):
+def test_maybe_promote_bytes_with_any(bytes_dtype, any_numpy_dtype):
     dtype = np.dtype(bytes_dtype)
-    fill_dtype = np.dtype(any_numpy_dtype_reduced)
+    fill_dtype = np.dtype(any_numpy_dtype)
 
     # create array of given dtype; casts "1" to correct dtype
     fill_value = np.array([1], dtype=fill_dtype)[0]
@@ -348,8 +299,8 @@ def test_maybe_promote_bytes_with_any(bytes_dtype, any_numpy_dtype_reduced):
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_any_with_bytes(any_numpy_dtype_reduced, bytes_dtype):
-    dtype = np.dtype(any_numpy_dtype_reduced)
+def test_maybe_promote_any_with_bytes(any_numpy_dtype):
+    dtype = np.dtype(any_numpy_dtype)
 
     # create array of given dtype
     fill_value = b"abc"
@@ -362,15 +313,15 @@ def test_maybe_promote_any_with_bytes(any_numpy_dtype_reduced, bytes_dtype):
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_datetime64_with_any(datetime64_dtype, any_numpy_dtype_reduced):
+def test_maybe_promote_datetime64_with_any(datetime64_dtype, any_numpy_dtype):
     dtype = np.dtype(datetime64_dtype)
-    fill_dtype = np.dtype(any_numpy_dtype_reduced)
+    fill_dtype = np.dtype(any_numpy_dtype)
 
     # create array of given dtype; casts "1" to correct dtype
     fill_value = np.array([1], dtype=fill_dtype)[0]
 
     # filling datetime with anything but datetime casts to object
-    if is_datetime64_dtype(fill_dtype):
+    if fill_dtype.kind == "M":
         expected_dtype = dtype
         # for datetime dtypes, scalar values get cast to to_datetime64
         exp_val_for_scalar = pd.Timestamp(fill_value).to_datetime64()
@@ -391,13 +342,11 @@ def test_maybe_promote_datetime64_with_any(datetime64_dtype, any_numpy_dtype_red
     ],
     ids=["pd.Timestamp", "np.datetime64", "datetime.datetime", "datetime.date"],
 )
-def test_maybe_promote_any_with_datetime64(
-    any_numpy_dtype_reduced, datetime64_dtype, fill_value
-):
-    dtype = np.dtype(any_numpy_dtype_reduced)
+def test_maybe_promote_any_with_datetime64(any_numpy_dtype, fill_value):
+    dtype = np.dtype(any_numpy_dtype)
 
     # filling datetime with anything but datetime casts to object
-    if is_datetime64_dtype(dtype):
+    if dtype.kind == "M":
         expected_dtype = dtype
         # for datetime dtypes, scalar values get cast to pd.Timestamp.value
         exp_val_for_scalar = pd.Timestamp(fill_value).to_datetime64()
@@ -405,31 +354,28 @@ def test_maybe_promote_any_with_datetime64(
         expected_dtype = np.dtype(object)
         exp_val_for_scalar = fill_value
 
-    warn = None
-    msg = "Using a `date` object for fill_value"
     if type(fill_value) is datetime.date and dtype.kind == "M":
-        # Casting date to dt64 is deprecated
-        warn = FutureWarning
+        # Casting date to dt64 is deprecated, in 2.0 enforced to cast to object
+        expected_dtype = np.dtype(object)
+        exp_val_for_scalar = fill_value
 
-    with tm.assert_produces_warning(warn, match=msg, check_stacklevel=False):
-        # stacklevel is chosen to make sense when called from higher-level functions
-        _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
+    _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
 @pytest.mark.parametrize(
     "fill_value",
     [
-        pd.Timestamp("now"),
-        np.datetime64("now"),
-        datetime.datetime.now(),
-        datetime.date.today(),
+        pd.Timestamp(2023, 1, 1),
+        np.datetime64("2023-01-01"),
+        datetime.datetime(2023, 1, 1),
+        datetime.date(2023, 1, 1),
     ],
     ids=["pd.Timestamp", "np.datetime64", "datetime.datetime", "datetime.date"],
 )
 def test_maybe_promote_any_numpy_dtype_with_datetimetz(
-    any_numpy_dtype_reduced, tz_aware_fixture, fill_value
+    any_numpy_dtype, tz_aware_fixture, fill_value
 ):
-    dtype = np.dtype(any_numpy_dtype_reduced)
+    dtype = np.dtype(any_numpy_dtype)
     fill_dtype = DatetimeTZDtype(tz=tz_aware_fixture)
 
     fill_value = pd.Series([fill_value], dtype=fill_dtype)[0]
@@ -441,15 +387,15 @@ def test_maybe_promote_any_numpy_dtype_with_datetimetz(
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_timedelta64_with_any(timedelta64_dtype, any_numpy_dtype_reduced):
+def test_maybe_promote_timedelta64_with_any(timedelta64_dtype, any_numpy_dtype):
     dtype = np.dtype(timedelta64_dtype)
-    fill_dtype = np.dtype(any_numpy_dtype_reduced)
+    fill_dtype = np.dtype(any_numpy_dtype)
 
     # create array of given dtype; casts "1" to correct dtype
     fill_value = np.array([1], dtype=fill_dtype)[0]
 
     # filling timedelta with anything but timedelta casts to object
-    if is_timedelta64_dtype(fill_dtype):
+    if fill_dtype.kind == "m":
         expected_dtype = dtype
         # for timedelta dtypes, scalar values get cast to pd.Timedelta.value
         exp_val_for_scalar = pd.Timedelta(fill_value).to_timedelta64()
@@ -465,13 +411,11 @@ def test_maybe_promote_timedelta64_with_any(timedelta64_dtype, any_numpy_dtype_r
     [pd.Timedelta(days=1), np.timedelta64(24, "h"), datetime.timedelta(1)],
     ids=["pd.Timedelta", "np.timedelta64", "datetime.timedelta"],
 )
-def test_maybe_promote_any_with_timedelta64(
-    any_numpy_dtype_reduced, timedelta64_dtype, fill_value
-):
-    dtype = np.dtype(any_numpy_dtype_reduced)
+def test_maybe_promote_any_with_timedelta64(any_numpy_dtype, fill_value):
+    dtype = np.dtype(any_numpy_dtype)
 
     # filling anything but timedelta with timedelta casts to object
-    if is_timedelta64_dtype(dtype):
+    if dtype.kind == "m":
         expected_dtype = dtype
         # for timedelta dtypes, scalar values get cast to pd.Timedelta.value
         exp_val_for_scalar = pd.Timedelta(fill_value).to_timedelta64()
@@ -482,9 +426,9 @@ def test_maybe_promote_any_with_timedelta64(
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_string_with_any(string_dtype, any_numpy_dtype_reduced):
+def test_maybe_promote_string_with_any(string_dtype, any_numpy_dtype):
     dtype = np.dtype(string_dtype)
-    fill_dtype = np.dtype(any_numpy_dtype_reduced)
+    fill_dtype = np.dtype(any_numpy_dtype)
 
     # create array of given dtype; casts "1" to correct dtype
     fill_value = np.array([1], dtype=fill_dtype)[0]
@@ -496,8 +440,8 @@ def test_maybe_promote_string_with_any(string_dtype, any_numpy_dtype_reduced):
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_any_with_string(any_numpy_dtype_reduced, string_dtype):
-    dtype = np.dtype(any_numpy_dtype_reduced)
+def test_maybe_promote_any_with_string(any_numpy_dtype):
+    dtype = np.dtype(any_numpy_dtype)
 
     # create array of given dtype
     fill_value = "abc"
@@ -509,9 +453,9 @@ def test_maybe_promote_any_with_string(any_numpy_dtype_reduced, string_dtype):
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_object_with_any(object_dtype, any_numpy_dtype_reduced):
+def test_maybe_promote_object_with_any(object_dtype, any_numpy_dtype):
     dtype = np.dtype(object_dtype)
-    fill_dtype = np.dtype(any_numpy_dtype_reduced)
+    fill_dtype = np.dtype(any_numpy_dtype)
 
     # create array of given dtype; casts "1" to correct dtype
     fill_value = np.array([1], dtype=fill_dtype)[0]
@@ -523,8 +467,8 @@ def test_maybe_promote_object_with_any(object_dtype, any_numpy_dtype_reduced):
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_any_with_object(any_numpy_dtype_reduced, object_dtype):
-    dtype = np.dtype(any_numpy_dtype_reduced)
+def test_maybe_promote_any_with_object(any_numpy_dtype):
+    dtype = np.dtype(any_numpy_dtype)
 
     # create array of object dtype from a scalar value (i.e. passing
     # dtypes.common.is_scalar), which can however not be cast to int/float etc.
@@ -537,16 +481,16 @@ def test_maybe_promote_any_with_object(any_numpy_dtype_reduced, object_dtype):
     _check_promote(dtype, fill_value, expected_dtype, exp_val_for_scalar)
 
 
-def test_maybe_promote_any_numpy_dtype_with_na(any_numpy_dtype_reduced, nulls_fixture):
+def test_maybe_promote_any_numpy_dtype_with_na(any_numpy_dtype, nulls_fixture):
     fill_value = nulls_fixture
-    dtype = np.dtype(any_numpy_dtype_reduced)
+    dtype = np.dtype(any_numpy_dtype)
 
     if isinstance(fill_value, Decimal):
         # Subject to change, but ATM (When Decimal(NAN) is being added to nulls_fixture)
         #  this is the existing behavior in maybe_promote,
         #  hinges on is_valid_na_for_dtype
-        if dtype.kind in ["i", "u", "f", "c"]:
-            if dtype.kind in ["i", "u"]:
+        if dtype.kind in "iufc":
+            if dtype.kind in "iu":
                 expected_dtype = np.dtype(np.float64)
             else:
                 expected_dtype = dtype
@@ -554,16 +498,16 @@ def test_maybe_promote_any_numpy_dtype_with_na(any_numpy_dtype_reduced, nulls_fi
         else:
             expected_dtype = np.dtype(object)
             exp_val_for_scalar = fill_value
-    elif is_integer_dtype(dtype) and fill_value is not NaT:
+    elif dtype.kind in "iu" and fill_value is not NaT:
         # integer + other missing value (np.nan / None) casts to float
         expected_dtype = np.float64
         exp_val_for_scalar = np.nan
-    elif is_object_dtype(dtype) and fill_value is NaT:
+    elif dtype == object and fill_value is NaT:
         # inserting into object does not cast the value
         # but *does* cast None to np.nan
         expected_dtype = np.dtype(object)
         exp_val_for_scalar = fill_value
-    elif is_datetime_or_timedelta_dtype(dtype):
+    elif dtype.kind in "mM":
         # datetime / timedelta cast all missing values to dtyped-NaT
         expected_dtype = dtype
         exp_val_for_scalar = dtype.type("NaT", "ns")
@@ -571,7 +515,7 @@ def test_maybe_promote_any_numpy_dtype_with_na(any_numpy_dtype_reduced, nulls_fi
         # NaT upcasts everything that's not datetime/timedelta to object
         expected_dtype = np.dtype(object)
         exp_val_for_scalar = NaT
-    elif is_float_dtype(dtype) or is_complex_dtype(dtype):
+    elif dtype.kind in "fc":
         # float / complex + missing value (!= NaT) stays the same
         expected_dtype = dtype
         exp_val_for_scalar = np.nan
