@@ -19,27 +19,33 @@ from collections import (
 )
 import itertools
 import numbers
-import random
 import string
 import sys
 from typing import (
+    TYPE_CHECKING,
     Any,
-    Mapping,
 )
 
 import numpy as np
 
-from pandas._typing import type_t
-
 from pandas.core.dtypes.cast import construct_1d_object_array_from_listlike
-from pandas.core.dtypes.common import pandas_dtype
+from pandas.core.dtypes.common import (
+    is_bool_dtype,
+    is_list_like,
+    pandas_dtype,
+)
 
 import pandas as pd
 from pandas.api.extensions import (
     ExtensionArray,
     ExtensionDtype,
 )
-from pandas.api.types import is_bool_dtype
+from pandas.core.indexers import unpack_tuple_and_ellipses
+
+if TYPE_CHECKING:
+    from collections.abc import Mapping
+
+    from pandas._typing import type_t
 
 
 class JSONDtype(ExtensionDtype):
@@ -63,7 +69,7 @@ class JSONArray(ExtensionArray):
     dtype = JSONDtype()
     __array_priority__ = 1000
 
-    def __init__(self, values, dtype=None, copy=False):
+    def __init__(self, values, dtype=None, copy=False) -> None:
         for val in values:
             if not isinstance(val, self.dtype.type):
                 raise TypeError("All values must be of type " + str(self.dtype.type))
@@ -86,14 +92,7 @@ class JSONArray(ExtensionArray):
 
     def __getitem__(self, item):
         if isinstance(item, tuple):
-            if len(item) > 1:
-                if item[0] is Ellipsis:
-                    item = item[1:]
-                elif item[-1] is Ellipsis:
-                    item = item[:-1]
-            if len(item) > 1:
-                raise IndexError("too many indices for array.")
-            item = item[0]
+            item = unpack_tuple_and_ellipses(item)
 
         if isinstance(item, numbers.Integral):
             return self.data[item]
@@ -103,6 +102,13 @@ class JSONArray(ExtensionArray):
         elif isinstance(item, slice):
             # slice
             return type(self)(self.data[item])
+        elif not is_list_like(item):
+            # e.g. "foo" or 2.5
+            # exception message copied from numpy
+            raise IndexError(
+                r"only integers, slices (`:`), ellipsis (`...`), numpy.newaxis "
+                r"(`None`) and integer or boolean arrays are valid indices"
+            )
         else:
             item = pd.api.indexers.check_array_indexer(self, item)
             if is_bool_dtype(item.dtype):
@@ -110,7 +116,7 @@ class JSONArray(ExtensionArray):
             # integer
             return type(self)([self.data[i] for i in item])
 
-    def __setitem__(self, key, value):
+    def __setitem__(self, key, value) -> None:
         if isinstance(key, numbers.Integral):
             self.data[key] = value
         else:
@@ -141,6 +147,9 @@ class JSONArray(ExtensionArray):
     def __array__(self, dtype=None):
         if dtype is None:
             dtype = object
+        if dtype == object:
+            # on py38 builds it looks like numpy is inferring to a non-1D array
+            return construct_1d_object_array_from_listlike(list(self))
         return np.asarray(self.data, dtype=dtype)
 
     @property
@@ -196,7 +205,7 @@ class JSONArray(ExtensionArray):
                 return self.copy()
             return self
         elif isinstance(dtype, StringDtype):
-            value = self.astype(str)  # numpy doesn'y like nested dicts
+            value = self.astype(str)  # numpy doesn't like nested dicts
             return dtype.construct_array_type()._from_sequence(value, copy=False)
 
         return np.array([dict(x) for x in self], dtype=dtype, copy=copy)
@@ -226,11 +235,12 @@ class JSONArray(ExtensionArray):
 
 def make_data():
     # TODO: Use a regular dict. See _NDFrameIndexer._setitem_with_indexer
+    rng = np.random.default_rng(2)
     return [
         UserDict(
             [
-                (random.choice(string.ascii_letters), random.randint(0, 100))
-                for _ in range(random.randint(0, 10))
+                (rng.choice(list(string.ascii_letters)), rng.integers(0, 100))
+                for _ in range(rng.integers(0, 10))
             ]
         )
         for _ in range(100)
