@@ -441,7 +441,6 @@ def test_drop_duplicates_null_in_object_column(nulls_fixture):
     tm.assert_frame_equal(result, df)
 
 
-@pytest.mark.parametrize("keep", ["first", "last", False])
 def test_drop_duplicates_series_vs_dataframe(keep):
     # GH#14192
     df = DataFrame(
@@ -472,17 +471,3 @@ def test_drop_duplicates_non_boolean_ignore_index(arg):
     msg = '^For argument "ignore_index" expected type bool, received type .*.$'
     with pytest.raises(ValueError, match=msg):
         df.drop_duplicates(ignore_index=arg)
-
-
-def test_drop_duplicates_pos_args_deprecation():
-    # GH#41485
-    df = DataFrame({"a": [1, 1, 2], "b": [1, 1, 3], "c": [1, 1, 3]})
-    msg = (
-        "In a future version of pandas all arguments of "
-        "DataFrame.drop_duplicates except for the argument 'subset' "
-        "will be keyword-only"
-    )
-    with tm.assert_produces_warning(FutureWarning, match=msg):
-        result = df.drop_duplicates(["b", "c"], "last")
-    expected = DataFrame({"a": [1, 2], "b": [1, 3], "c": [1, 3]}, index=[1, 2])
-    tm.assert_frame_equal(expected, result)
