@@ -1,8 +1,6 @@
 import numpy as np
 import pytest
 
-from pandas.compat.numpy import np_percentile_argname
-
 import pandas as pd
 from pandas import (
     DataFrame,
@@ -13,6 +11,14 @@ from pandas import (
 import pandas._testing as tm
 
 
+@pytest.fixture(
+    params=[["linear", "single"], ["nearest", "table"]], ids=lambda x: "-".join(x)
+)
+def interp_method(request):
+    """(interpolation, method) arguments for quantile"""
+    return request.param
+
+
 class TestDataFrameQuantile:
     @pytest.mark.parametrize(
         "df,expected",
@@ -36,69 +42,143 @@ class TestDataFrameQuantile:
         # GH#17198
         # GH#24600
         result = df.quantile()
-
+        expected = expected.astype("Sparse[float]")
         tm.assert_series_equal(result, expected)
 
-    def test_quantile(self, datetime_frame):
-        from numpy import percentile
-
+    def test_quantile(
+        self, datetime_frame, interp_method, using_array_manager, request
+    ):
+        interpolation, method = interp_method
         df = datetime_frame
-        q = df.quantile(0.1, axis=0)
-        assert q["A"] == percentile(df["A"], 10)
-        tm.assert_index_equal(q.index, df.columns)
+        result = df.quantile(
+            0.1, axis=0, numeric_only=True, interpolation=interpolation, method=method
+        )
+        expected = Series(
+            [np.percentile(df[col], 10) for col in df.columns],
+            index=df.columns,
+            name=0.1,
+        )
+        if interpolation == "linear":
+            # np.percentile values only comparable to linear interpolation
+            tm.assert_series_equal(result, expected)
+        else:
+            tm.assert_index_equal(result.index, expected.index)
+            request.node.add_marker(
+                pytest.mark.xfail(
+                    using_array_manager, reason="Name set incorrectly for arraymanager"
+                )
+            )
+            assert result.name == expected.name
 
-        q = df.quantile(0.9, axis=1)
-        assert q["2000-01-17"] == percentile(df.loc["2000-01-17"], 90)
-        tm.assert_index_equal(q.index, df.index)
+        result = df.quantile(
+            0.9, axis=1, numeric_only=True, interpolation=interpolation, method=method
+        )
+        expected = Series(
+            [np.percentile(df.loc[date], 90) for date in df.index],
+            index=df.index,
+            name=0.9,
+        )
+        if interpolation == "linear":
+            # np.percentile values only comparable to linear interpolation
+            tm.assert_series_equal(result, expected)
+        else:
+            tm.assert_index_equal(result.index, expected.index)
+            request.node.add_marker(
+                pytest.mark.xfail(
+                    using_array_manager, reason="Name set incorrectly for arraymanager"
+                )
+            )
+            assert result.name == expected.name
 
-        # test degenerate case
-        q = DataFrame({"x": [], "y": []}).quantile(0.1, axis=0)
+    def test_empty(self, interp_method):
+        interpolation, method = interp_method
+        q = DataFrame({"x": [], "y": []}).quantile(
+            0.1, axis=0, numeric_only=True, interpolation=interpolation, method=method
+        )
         assert np.isnan(q["x"]) and np.isnan(q["y"])
 
-        # non-numeric exclusion
+    def test_non_numeric_exclusion(self, interp_method, request, using_array_manager):
+        interpolation, method = interp_method
         df = DataFrame({"col1": ["A", "A", "B", "B"], "col2": [1, 2, 3, 4]})
-        rs = df.quantile(0.5)
-        with tm.assert_produces_warning(FutureWarning, match="Select only valid"):
-            xp = df.median().rename(0.5)
+        rs = df.quantile(
+            0.5, numeric_only=True, interpolation=interpolation, method=method
+        )
+        xp = df.median(numeric_only=True).rename(0.5)
+        if interpolation == "nearest":
+            xp = (xp + 0.5).astype(np.int64)
+        if method == "table" and using_array_manager:
+            request.node.add_marker(
+                pytest.mark.xfail(reason="Axis name incorrectly set.")
+            )
         tm.assert_series_equal(rs, xp)
 
+    def test_axis(self, interp_method, request, using_array_manager):
         # axis
+        interpolation, method = interp_method
         df = DataFrame({"A": [1, 2, 3], "B": [2, 3, 4]}, index=[1, 2, 3])
-        result = df.quantile(0.5, axis=1)
+        result = df.quantile(0.5, axis=1, interpolation=interpolation, method=method)
         expected = Series([1.5, 2.5, 3.5], index=[1, 2, 3], name=0.5)
+        if interpolation == "nearest":
+            expected = expected.astype(np.int64)
+        if method == "table" and using_array_manager:
+            request.node.add_marker(
+                pytest.mark.xfail(reason="Axis name incorrectly set.")
+            )
         tm.assert_series_equal(result, expected)
 
-        result = df.quantile([0.5, 0.75], axis=1)
+        result = df.quantile(
+            [0.5, 0.75], axis=1, interpolation=interpolation, method=method
+        )
         expected = DataFrame(
             {1: [1.5, 1.75], 2: [2.5, 2.75], 3: [3.5, 3.75]}, index=[0.5, 0.75]
         )
+        if interpolation == "nearest":
+            expected.iloc[0, :] -= 0.5
+            expected.iloc[1, :] += 0.25
+            expected = expected.astype(np.int64)
         tm.assert_frame_equal(result, expected, check_index_type=True)
 
+    def test_axis_numeric_only_true(self, interp_method, request, using_array_manager):
         # We may want to break API in the future to change this
         # so that we exclude non-numeric along the same axis
         # See GH #7312
+        interpolation, method = interp_method
         df = DataFrame([[1, 2, 3], ["a", "b", 4]])
-        result = df.quantile(0.5, axis=1)
+        result = df.quantile(
+            0.5, axis=1, numeric_only=True, interpolation=interpolation, method=method
+        )
         expected = Series([3.0, 4.0], index=[0, 1], name=0.5)
+        if interpolation == "nearest":
+            expected = expected.astype(np.int64)
+        if method == "table" and using_array_manager:
+            request.node.add_marker(
+                pytest.mark.xfail(reason="Axis name incorrectly set.")
+            )
         tm.assert_series_equal(result, expected)
 
-    def test_quantile_date_range(self):
+    def test_quantile_date_range(self, interp_method, request, using_array_manager):
         # GH 2460
-
+        interpolation, method = interp_method
         dti = pd.date_range("2016-01-01", periods=3, tz="US/Pacific")
         ser = Series(dti)
         df = DataFrame(ser)
 
-        result = df.quantile(numeric_only=False)
+        result = df.quantile(
+            numeric_only=False, interpolation=interpolation, method=method
+        )
         expected = Series(
             ["2016-01-02 00:00:00"], name=0.5, dtype="datetime64[ns, US/Pacific]"
         )
+        if method == "table" and using_array_manager:
+            request.node.add_marker(
+                pytest.mark.xfail(reason="Axis name incorrectly set.")
+            )
 
         tm.assert_series_equal(result, expected)
 
-    def test_quantile_axis_mixed(self):
-
+    def test_quantile_axis_mixed(self, interp_method, request, using_array_manager):
         # mixed on axis=1
+        interpolation, method = interp_method
         df = DataFrame(
             {
                 "A": [1, 2, 3],
@@ -107,8 +187,16 @@ class TestDataFrameQuantile:
                 "D": ["foo", "bar", "baz"],
             }
         )
-        result = df.quantile(0.5, axis=1)
+        result = df.quantile(
+            0.5, axis=1, numeric_only=True, interpolation=interpolation, method=method
+        )
         expected = Series([1.5, 2.5, 3.5], name=0.5)
+        if interpolation == "nearest":
+            expected -= 0.5
+        if method == "table" and using_array_manager:
+            request.node.add_marker(
+                pytest.mark.xfail(reason="Axis name incorrectly set.")
+            )
         tm.assert_series_equal(result, expected)
 
         # must raise
@@ -116,30 +204,44 @@ class TestDataFrameQuantile:
         with pytest.raises(TypeError, match=msg):
             df.quantile(0.5, axis=1, numeric_only=False)
 
-    def test_quantile_axis_parameter(self):
+    def test_quantile_axis_parameter(self, interp_method, request, using_array_manager):
         # GH 9543/9544
-
+        interpolation, method = interp_method
+        if method == "table" and using_array_manager:
+            request.node.add_marker(
+                pytest.mark.xfail(reason="Axis name incorrectly set.")
+            )
         df = DataFrame({"A": [1, 2, 3], "B": [2, 3, 4]}, index=[1, 2, 3])
 
-        result = df.quantile(0.5, axis=0)
+        result = df.quantile(0.5, axis=0, interpolation=interpolation, method=method)
 
         expected = Series([2.0, 3.0], index=["A", "B"], name=0.5)
+        if interpolation == "nearest":
+            expected = expected.astype(np.int64)
         tm.assert_series_equal(result, expected)
 
-        expected = df.quantile(0.5, axis="index")
+        expected = df.quantile(
+            0.5, axis="index", interpolation=interpolation, method=method
+        )
+        if interpolation == "nearest":
+            expected = expected.astype(np.int64)
         tm.assert_series_equal(result, expected)
 
-        result = df.quantile(0.5, axis=1)
+        result = df.quantile(0.5, axis=1, interpolation=interpolation, method=method)
 
         expected = Series([1.5, 2.5, 3.5], index=[1, 2, 3], name=0.5)
+        if interpolation == "nearest":
+            expected = expected.astype(np.int64)
         tm.assert_series_equal(result, expected)
 
-        result = df.quantile(0.5, axis="columns")
+        result = df.quantile(
+            0.5, axis="columns", interpolation=interpolation, method=method
+        )
         tm.assert_series_equal(result, expected)
 
         msg = "No axis named -1 for object type DataFrame"
         with pytest.raises(ValueError, match=msg):
-            df.quantile(0.1, axis=-1)
+            df.quantile(0.1, axis=-1, interpolation=interpolation, method=method)
         msg = "No axis named column for object type DataFrame"
         with pytest.raises(ValueError, match=msg):
             df.quantile(0.1, axis="column")
@@ -158,7 +260,7 @@ class TestDataFrameQuantile:
             np.array([[1, 2, 3], [2, 3, 4]]),
             0.5,
             axis=0,
-            **{np_percentile_argname: "nearest"},
+            method="nearest",
         )
         expected = Series(exp, index=[1, 2, 3], name=0.5, dtype="int64")
         tm.assert_series_equal(result, expected)
@@ -172,7 +274,7 @@ class TestDataFrameQuantile:
             np.array([[1.0, 2.0, 3.0], [2.0, 3.0, 4.0]]),
             0.5,
             axis=0,
-            **{np_percentile_argname: "nearest"},
+            method="nearest",
         )
         expected = Series(exp, index=[1, 2, 3], name=0.5, dtype="float64")
         tm.assert_series_equal(result, expected)
@@ -206,7 +308,7 @@ class TestDataFrameQuantile:
 
         # interpolation = linear (default case)
         df = datetime_frame
-        q = df.quantile(0.1, axis=0, interpolation="linear")
+        q = df.quantile(0.1, axis=0, numeric_only=True, interpolation="linear")
         assert q["A"] == np.percentile(df["A"], 10)
 
     def test_quantile_interpolation_int(self, int_frame):
@@ -222,24 +324,45 @@ class TestDataFrameQuantile:
         assert q1["A"] == np.percentile(df["A"], 10)
         tm.assert_series_equal(q, q1)
 
-    def test_quantile_multi(self):
+    def test_quantile_multi(self, interp_method, request, using_array_manager):
+        interpolation, method = interp_method
         df = DataFrame([[1, 1, 1], [2, 2, 2], [3, 3, 3]], columns=["a", "b", "c"])
-        result = df.quantile([0.25, 0.5])
+        result = df.quantile([0.25, 0.5], interpolation=interpolation, method=method)
         expected = DataFrame(
             [[1.5, 1.5, 1.5], [2.0, 2.0, 2.0]],
             index=[0.25, 0.5],
             columns=["a", "b", "c"],
         )
+        if interpolation == "nearest":
+            expected = expected.astype(np.int64)
+        if method == "table" and using_array_manager:
+            request.node.add_marker(
+                pytest.mark.xfail(reason="Axis name incorrectly set.")
+            )
         tm.assert_frame_equal(result, expected)
 
-        # axis = 1
-        result = df.quantile([0.25, 0.5], axis=1)
-        expected = DataFrame(
-            [[1.5, 1.5, 1.5], [2.0, 2.0, 2.0]], index=[0.25, 0.5], columns=[0, 1, 2]
+    def test_quantile_multi_axis_1(self, interp_method, request, using_array_manager):
+        interpolation, method = interp_method
+        df = DataFrame([[1, 1, 1], [2, 2, 2], [3, 3, 3]], columns=["a", "b", "c"])
+        result = df.quantile(
+            [0.25, 0.5], axis=1, interpolation=interpolation, method=method
         )
+        expected = DataFrame(
+            [[1.0, 2.0, 3.0]] * 2, index=[0.25, 0.5], columns=[0, 1, 2]
+        )
+        if interpolation == "nearest":
+            expected = expected.astype(np.int64)
+        if method == "table" and using_array_manager:
+            request.node.add_marker(
+                pytest.mark.xfail(reason="Axis name incorrectly set.")
+            )
+        tm.assert_frame_equal(result, expected)
 
-        # empty
-        result = DataFrame({"x": [], "y": []}).quantile([0.1, 0.9], axis=0)
+    def test_quantile_multi_empty(self, interp_method):
+        interpolation, method = interp_method
+        result = DataFrame({"x": [], "y": []}).quantile(
+            [0.1, 0.9], axis=0, interpolation=interpolation, method=method
+        )
         expected = DataFrame(
             {"x": [np.nan, np.nan], "y": [np.nan, np.nan]}, index=[0.1, 0.9]
         )
@@ -249,8 +372,9 @@ class TestDataFrameQuantile:
         df = DataFrame({"a": pd.to_datetime(["2010", "2011"]), "b": [0, 5]})
 
         # exclude datetime
-        result = df.quantile(0.5)
-        expected = Series([2.5], index=["b"])
+        result = df.quantile(0.5, numeric_only=True)
+        expected = Series([2.5], index=["b"], name=0.5)
+        tm.assert_series_equal(result, expected)
 
         # datetime
         result = df.quantile(0.5, numeric_only=False)
@@ -285,17 +409,58 @@ class TestDataFrameQuantile:
         tm.assert_frame_equal(result, expected)
 
         # empty when numeric_only=True
-        # FIXME (gives empty frame in 0.18.1, broken in 0.19.0)
-        # result = df[['a', 'c']].quantile(.5)
-        # result = df[['a', 'c']].quantile([.5])
+        result = df[["a", "c"]].quantile(0.5, numeric_only=True)
+        expected = Series([], index=[], dtype=np.float64, name=0.5)
+        tm.assert_series_equal(result, expected)
 
-    def test_quantile_invalid(self, datetime_frame):
+        result = df[["a", "c"]].quantile([0.5], numeric_only=True)
+        expected = DataFrame(index=[0.5], columns=[])
+        tm.assert_frame_equal(result, expected)
+
+    @pytest.mark.parametrize(
+        "dtype",
+        [
+            "datetime64[ns]",
+            "datetime64[ns, US/Pacific]",
+            "timedelta64[ns]",
+            "Period[D]",
+        ],
+    )
+    def test_quantile_dt64_empty(self, dtype, interp_method):
+        # GH#41544
+        interpolation, method = interp_method
+        df = DataFrame(columns=["a", "b"], dtype=dtype)
+
+        res = df.quantile(
+            0.5, axis=1, numeric_only=False, interpolation=interpolation, method=method
+        )
+        expected = Series([], index=[], name=0.5, dtype=dtype)
+        tm.assert_series_equal(res, expected)
+
+        # no columns in result, so no dtype preservation
+        res = df.quantile(
+            [0.5],
+            axis=1,
+            numeric_only=False,
+            interpolation=interpolation,
+            method=method,
+        )
+        expected = DataFrame(index=[0.5], columns=[])
+        tm.assert_frame_equal(res, expected)
+
+    @pytest.mark.parametrize("invalid", [-1, 2, [0.5, -1], [0.5, 2]])
+    def test_quantile_invalid(self, invalid, datetime_frame, interp_method):
         msg = "percentiles should all be in the interval \\[0, 1\\]"
-        for invalid in [-1, 2, [0.5, -1], [0.5, 2]]:
-            with pytest.raises(ValueError, match=msg):
-                datetime_frame.quantile(invalid)
+        interpolation, method = interp_method
+        with pytest.raises(ValueError, match=msg):
+            datetime_frame.quantile(invalid, interpolation=interpolation, method=method)
 
-    def test_quantile_box(self):
+    def test_quantile_box(self, interp_method, request, using_array_manager):
+        interpolation, method = interp_method
+        if method == "table" and using_array_manager:
+            request.node.add_marker(
+                pytest.mark.xfail(reason="Axis name incorrectly set.")
+            )
         df = DataFrame(
             {
                 "A": [
@@ -316,7 +481,9 @@ class TestDataFrameQuantile:
             }
         )
 
-        res = df.quantile(0.5, numeric_only=False)
+        res = df.quantile(
+            0.5, numeric_only=False, interpolation=interpolation, method=method
+        )
 
         exp = Series(
             [
@@ -329,7 +496,9 @@ class TestDataFrameQuantile:
         )
         tm.assert_series_equal(res, exp)
 
-        res = df.quantile([0.5], numeric_only=False)
+        res = df.quantile(
+            [0.5], numeric_only=False, interpolation=interpolation, method=method
+        )
         exp = DataFrame(
             [
                 [
@@ -343,6 +512,7 @@ class TestDataFrameQuantile:
         )
         tm.assert_frame_equal(res, exp)
 
+    def test_quantile_box_nat(self):
         # DatetimeLikeBlock may be consolidated and contain NaT in different loc
         df = DataFrame(
             {
@@ -418,49 +588,73 @@ class TestDataFrameQuantile:
         )
         tm.assert_frame_equal(res, exp)
 
-    def test_quantile_nan(self):
-
+    def test_quantile_nan(self, interp_method, request, using_array_manager):
+        interpolation, method = interp_method
+        if method == "table" and using_array_manager:
+            request.node.add_marker(
+                pytest.mark.xfail(reason="Axis name incorrectly set.")
+            )
         # GH 14357 - float block where some cols have missing values
         df = DataFrame({"a": np.arange(1, 6.0), "b": np.arange(1, 6.0)})
         df.iloc[-1, 1] = np.nan
 
-        res = df.quantile(0.5)
-        exp = Series([3.0, 2.5], index=["a", "b"], name=0.5)
+        res = df.quantile(0.5, interpolation=interpolation, method=method)
+        exp = Series(
+            [3.0, 2.5 if interpolation == "linear" else 3.0], index=["a", "b"], name=0.5
+        )
         tm.assert_series_equal(res, exp)
 
-        res = df.quantile([0.5, 0.75])
-        exp = DataFrame({"a": [3.0, 4.0], "b": [2.5, 3.25]}, index=[0.5, 0.75])
+        res = df.quantile([0.5, 0.75], interpolation=interpolation, method=method)
+        exp = DataFrame(
+            {
+                "a": [3.0, 4.0],
+                "b": [2.5, 3.25] if interpolation == "linear" else [3.0, 4.0],
+            },
+            index=[0.5, 0.75],
+        )
         tm.assert_frame_equal(res, exp)
 
-        res = df.quantile(0.5, axis=1)
+        res = df.quantile(0.5, axis=1, interpolation=interpolation, method=method)
         exp = Series(np.arange(1.0, 6.0), name=0.5)
         tm.assert_series_equal(res, exp)
 
-        res = df.quantile([0.5, 0.75], axis=1)
+        res = df.quantile(
+            [0.5, 0.75], axis=1, interpolation=interpolation, method=method
+        )
         exp = DataFrame([np.arange(1.0, 6.0)] * 2, index=[0.5, 0.75])
+        if interpolation == "nearest":
+            exp.iloc[1, -1] = np.nan
         tm.assert_frame_equal(res, exp)
 
         # full-nan column
         df["b"] = np.nan
 
-        res = df.quantile(0.5)
+        res = df.quantile(0.5, interpolation=interpolation, method=method)
         exp = Series([3.0, np.nan], index=["a", "b"], name=0.5)
         tm.assert_series_equal(res, exp)
 
-        res = df.quantile([0.5, 0.75])
+        res = df.quantile([0.5, 0.75], interpolation=interpolation, method=method)
         exp = DataFrame({"a": [3.0, 4.0], "b": [np.nan, np.nan]}, index=[0.5, 0.75])
         tm.assert_frame_equal(res, exp)
 
-    def test_quantile_nat(self):
-
+    def test_quantile_nat(self, interp_method, request, using_array_manager):
+        interpolation, method = interp_method
+        if method == "table" and using_array_manager:
+            request.node.add_marker(
+                pytest.mark.xfail(reason="Axis name incorrectly set.")
+            )
         # full NaT column
         df = DataFrame({"a": [pd.NaT, pd.NaT, pd.NaT]})
 
-        res = df.quantile(0.5, numeric_only=False)
+        res = df.quantile(
+            0.5, numeric_only=False, interpolation=interpolation, method=method
+        )
         exp = Series([pd.NaT], index=["a"], name=0.5)
         tm.assert_series_equal(res, exp)
 
-        res = df.quantile([0.5], numeric_only=False)
+        res = df.quantile(
+            [0.5], numeric_only=False, interpolation=interpolation, method=method
+        )
         exp = DataFrame({"a": [pd.NaT]}, index=[0.5])
         tm.assert_frame_equal(res, exp)
 
@@ -476,76 +670,138 @@ class TestDataFrameQuantile:
             }
         )
 
-        res = df.quantile(0.5, numeric_only=False)
+        res = df.quantile(
+            0.5, numeric_only=False, interpolation=interpolation, method=method
+        )
         exp = Series([Timestamp("2012-01-02"), pd.NaT], index=["a", "b"], name=0.5)
         tm.assert_series_equal(res, exp)
 
-        res = df.quantile([0.5], numeric_only=False)
+        res = df.quantile(
+            [0.5], numeric_only=False, interpolation=interpolation, method=method
+        )
         exp = DataFrame(
             [[Timestamp("2012-01-02"), pd.NaT]], index=[0.5], columns=["a", "b"]
         )
         tm.assert_frame_equal(res, exp)
 
-    def test_quantile_empty_no_rows(self):
+    def test_quantile_empty_no_rows_floats(self, interp_method):
+        interpolation, method = interp_method
 
-        # floats
         df = DataFrame(columns=["a", "b"], dtype="float64")
 
-        res = df.quantile(0.5)
+        res = df.quantile(0.5, interpolation=interpolation, method=method)
         exp = Series([np.nan, np.nan], index=["a", "b"], name=0.5)
         tm.assert_series_equal(res, exp)
 
-        res = df.quantile([0.5])
+        res = df.quantile([0.5], interpolation=interpolation, method=method)
         exp = DataFrame([[np.nan, np.nan]], columns=["a", "b"], index=[0.5])
         tm.assert_frame_equal(res, exp)
 
-        # FIXME (gives empty frame in 0.18.1, broken in 0.19.0)
-        # res = df.quantile(0.5, axis=1)
-        # res = df.quantile([0.5], axis=1)
+        res = df.quantile(0.5, axis=1, interpolation=interpolation, method=method)
+        exp = Series([], index=[], dtype="float64", name=0.5)
+        tm.assert_series_equal(res, exp)
 
-        # ints
+        res = df.quantile([0.5], axis=1, interpolation=interpolation, method=method)
+        exp = DataFrame(columns=[], index=[0.5])
+        tm.assert_frame_equal(res, exp)
+
+    def test_quantile_empty_no_rows_ints(self, interp_method):
+        interpolation, method = interp_method
         df = DataFrame(columns=["a", "b"], dtype="int64")
 
-        # FIXME (gives empty frame in 0.18.1, broken in 0.19.0)
-        # res = df.quantile(0.5)
+        res = df.quantile(0.5, interpolation=interpolation, method=method)
+        exp = Series([np.nan, np.nan], index=["a", "b"], name=0.5)
+        tm.assert_series_equal(res, exp)
 
+    def test_quantile_empty_no_rows_dt64(self, interp_method):
+        interpolation, method = interp_method
         # datetimes
         df = DataFrame(columns=["a", "b"], dtype="datetime64[ns]")
 
-        # FIXME (gives NaNs instead of NaT in 0.18.1 or 0.19.0)
-        # res = df.quantile(0.5, numeric_only=False)
+        res = df.quantile(
+            0.5, numeric_only=False, interpolation=interpolation, method=method
+        )
+        exp = Series(
+            [pd.NaT, pd.NaT], index=["a", "b"], dtype="datetime64[ns]", name=0.5
+        )
+        tm.assert_series_equal(res, exp)
 
-    def test_quantile_empty_no_columns(self):
+        # Mixed dt64/dt64tz
+        df["a"] = df["a"].dt.tz_localize("US/Central")
+        res = df.quantile(
+            0.5, numeric_only=False, interpolation=interpolation, method=method
+        )
+        exp = exp.astype(object)
+        if interpolation == "nearest":
+            # GH#18463 TODO: would we prefer NaTs here?
+            msg = "The 'downcast' keyword in fillna is deprecated"
+            with tm.assert_produces_warning(FutureWarning, match=msg):
+                exp = exp.fillna(np.nan, downcast=False)
+        tm.assert_series_equal(res, exp)
+
+        # both dt64tz
+        df["b"] = df["b"].dt.tz_localize("US/Central")
+        res = df.quantile(
+            0.5, numeric_only=False, interpolation=interpolation, method=method
+        )
+        exp = exp.astype(df["b"].dtype)
+        tm.assert_series_equal(res, exp)
+
+    def test_quantile_empty_no_columns(self, interp_method):
         # GH#23925 _get_numeric_data may drop all columns
+        interpolation, method = interp_method
         df = DataFrame(pd.date_range("1/1/18", periods=5))
         df.columns.name = "captain tightpants"
-        result = df.quantile(0.5)
+        result = df.quantile(
+            0.5, numeric_only=True, interpolation=interpolation, method=method
+        )
         expected = Series([], index=[], name=0.5, dtype=np.float64)
         expected.index.name = "captain tightpants"
         tm.assert_series_equal(result, expected)
 
-        result = df.quantile([0.5])
+        result = df.quantile(
+            [0.5], numeric_only=True, interpolation=interpolation, method=method
+        )
         expected = DataFrame([], index=[0.5], columns=[])
         expected.columns.name = "captain tightpants"
         tm.assert_frame_equal(result, expected)
 
-    def test_quantile_item_cache(self, using_array_manager):
+    def test_quantile_item_cache(
+        self, using_array_manager, interp_method, using_copy_on_write
+    ):
         # previous behavior incorrect retained an invalid _item_cache entry
-        df = DataFrame(np.random.randn(4, 3), columns=["A", "B", "C"])
+        interpolation, method = interp_method
+        df = DataFrame(
+            np.random.default_rng(2).standard_normal((4, 3)), columns=["A", "B", "C"]
+        )
         df["D"] = df["A"] * 2
         ser = df["A"]
         if not using_array_manager:
             assert len(df._mgr.blocks) == 2
 
-        df.quantile(numeric_only=False)
-        ser.values[0] = 99
+        df.quantile(numeric_only=False, interpolation=interpolation, method=method)
 
-        assert df.iloc[0, 0] == df["A"][0]
+        if using_copy_on_write:
+            ser.iloc[0] = 99
+            assert df.iloc[0, 0] == df["A"][0]
+            assert df.iloc[0, 0] != 99
+        else:
+            ser.values[0] = 99
+            assert df.iloc[0, 0] == df["A"][0]
+            assert df.iloc[0, 0] == 99
+
+    def test_invalid_method(self):
+        with pytest.raises(ValueError, match="Invalid method: foo"):
+            DataFrame(range(1)).quantile(0.5, method="foo")
+
+    def test_table_invalid_interpolation(self):
+        with pytest.raises(ValueError, match="Invalid interpolation: foo"):
+            DataFrame(range(1)).quantile(0.5, method="table", interpolation="foo")
 
 
 class TestQuantileExtensionDtype:
     # TODO: tests for axis=1?
-    # TODO: empty case?  might as well do dt64 and td64 here too
+    # TODO: empty case?
 
     @pytest.fixture(
         params=[
@@ -555,6 +811,7 @@ class TestQuantileExtensionDtype:
             ),
             pd.period_range("2016-01-01", periods=9, freq="D"),
             pd.date_range("2016-01-01", periods=9, tz="US/Pacific"),
+            pd.timedelta_range("1 Day", periods=9),
             pd.array(np.arange(9), dtype="Int64"),
             pd.array(np.arange(9), dtype="Float64"),
         ],
@@ -584,32 +841,35 @@ class TestQuantileExtensionDtype:
             result = obj.quantile(qs, numeric_only=False)
         return result
 
-    def test_quantile_ea(self, obj, index):
-
+    def test_quantile_ea(self, request, obj, index):
         # result should be invariant to shuffling
         indexer = np.arange(len(index), dtype=np.intp)
-        np.random.shuffle(indexer)
+        np.random.default_rng(2).shuffle(indexer)
         obj = obj.iloc[indexer]
 
         qs = [0.5, 0, 1]
         result = self.compute_quantile(obj, qs)
 
+        exp_dtype = index.dtype
+        if index.dtype == "Int64":
+            # match non-nullable casting behavior
+            exp_dtype = "Float64"
+
         # expected here assumes len(index) == 9
         expected = Series(
-            [index[4], index[0], index[-1]], dtype=index.dtype, index=qs, name="A"
+            [index[4], index[0], index[-1]], dtype=exp_dtype, index=qs, name="A"
         )
         expected = type(obj)(expected)
 
         tm.assert_equal(result, expected)
 
     def test_quantile_ea_with_na(self, obj, index):
-
         obj.iloc[0] = index._na_value
         obj.iloc[-1] = index._na_value
 
         # result should be invariant to shuffling
         indexer = np.arange(len(index), dtype=np.intp)
-        np.random.shuffle(indexer)
+        np.random.default_rng(2).shuffle(indexer)
         obj = obj.iloc[indexer]
 
         qs = [0.5, 0, 1]
@@ -622,19 +882,14 @@ class TestQuantileExtensionDtype:
         expected = type(obj)(expected)
         tm.assert_equal(result, expected)
 
-    # TODO: filtering can be removed after GH#39763 is fixed
-    @pytest.mark.filterwarnings("ignore:Using .astype to convert:FutureWarning")
-    def test_quantile_ea_all_na(self, obj, index, frame_or_series):
-
+    def test_quantile_ea_all_na(self, request, obj, index):
         obj.iloc[:] = index._na_value
-
-        # TODO(ArrayManager): this casting should be unnecessary after GH#39763 is fixed
-        obj[:] = obj.astype(index.dtype)
+        # Check dtypes were preserved; this was once a problem see GH#39763
         assert np.all(obj.dtypes == index.dtype)
 
         # result should be invariant to shuffling
         indexer = np.arange(len(index), dtype=np.intp)
-        np.random.shuffle(indexer)
+        np.random.default_rng(2).shuffle(indexer)
         obj = obj.iloc[indexer]
 
         qs = [0.5, 0, 1]
@@ -645,18 +900,22 @@ class TestQuantileExtensionDtype:
         expected = type(obj)(expected)
         tm.assert_equal(result, expected)
 
-    def test_quantile_ea_scalar(self, obj, index):
+    def test_quantile_ea_scalar(self, request, obj, index):
         # scalar qs
 
         # result should be invariant to shuffling
         indexer = np.arange(len(index), dtype=np.intp)
-        np.random.shuffle(indexer)
+        np.random.default_rng(2).shuffle(indexer)
         obj = obj.iloc[indexer]
 
         qs = 0.5
         result = self.compute_quantile(obj, qs)
 
-        expected = Series({"A": index[4]}, dtype=index.dtype, name=0.5)
+        exp_dtype = index.dtype
+        if index.dtype == "Int64":
+            exp_dtype = "Float64"
+
+        expected = Series({"A": index[4]}, dtype=exp_dtype, name=0.5)
         if isinstance(obj, Series):
             expected = expected["A"]
             assert result == expected
@@ -684,14 +943,7 @@ class TestQuantileExtensionDtype:
     @pytest.mark.parametrize(
         "dtype, expected_data, expected_index, axis, expected_dtype",
         [
-            pytest.param(
-                "datetime64[ns]",
-                [],
-                [],
-                1,
-                "datetime64[ns]",
-                marks=pytest.mark.xfail(reason="#GH 41544"),
-            ),
+            ["datetime64[ns]", [], [], 1, "datetime64[ns]"],
             ["datetime64[ns]", [pd.NaT, pd.NaT], ["a", "b"], 0, "datetime64[ns]"],
         ],
     )
@@ -722,7 +974,7 @@ class TestQuantileExtensionDtype:
                 "c": pd.to_datetime(["2011", "2012"]),
             }
         )
-        result = df[["a", "c"]].quantile(0.5, axis=axis)
+        result = df[["a", "c"]].quantile(0.5, axis=axis, numeric_only=True)
         expected = Series(
             expected_data, name=0.5, index=Index(expected_index), dtype=np.float64
         )
