@@ -16,13 +16,11 @@ class TestTZConvert:
         rng = date_range("1/1/2011", periods=200, freq="D", tz="US/Eastern")
 
         obj = DataFrame({"a": 1}, index=rng)
-        if frame_or_series is not DataFrame:
-            obj = obj["a"]
+        obj = tm.get_obj(obj, frame_or_series)
 
         result = obj.tz_convert("Europe/Berlin")
         expected = DataFrame({"a": 1}, rng.tz_convert("Europe/Berlin"))
-        if frame_or_series is not DataFrame:
-            expected = expected["a"]
+        expected = tm.get_obj(expected, frame_or_series)
 
         assert result.index.tz.zone == "Europe/Berlin"
         tm.assert_equal(result, expected)
@@ -61,7 +59,6 @@ class TestTZConvert:
             l1 = l1.tz_localize("UTC")
 
         for idx in [l0, l1]:
-
             l0_expected = getattr(idx, fn)("US/Pacific")
             l1_expected = getattr(idx, fn)("US/Pacific")
 
@@ -94,7 +91,7 @@ class TestTZConvert:
             df4 = DataFrame(np.ones(5), MultiIndex.from_arrays([int_idx, l0]))
 
             # TODO: untested
-            df5 = getattr(df4, fn)("US/Pacific", level=1)  # noqa
+            getattr(df4, fn)("US/Pacific", level=1)
 
             tm.assert_index_equal(df3.index.levels[0], l0)
             assert not df3.index.levels[0].equals(l0_expected)
@@ -106,17 +103,17 @@ class TestTZConvert:
         # Not DatetimeIndex / PeriodIndex
         with pytest.raises(TypeError, match="DatetimeIndex"):
             df = DataFrame(index=int_idx)
-            df = getattr(df, fn)("US/Pacific")
+            getattr(df, fn)("US/Pacific")
 
         # Not DatetimeIndex / PeriodIndex
         with pytest.raises(TypeError, match="DatetimeIndex"):
             df = DataFrame(np.ones(5), MultiIndex.from_arrays([int_idx, l0]))
-            df = getattr(df, fn)("US/Pacific", level=0)
+            getattr(df, fn)("US/Pacific", level=0)
 
         # Invalid level
         with pytest.raises(ValueError, match="not valid"):
             df = DataFrame(index=l0)
-            df = getattr(df, fn)("US/Pacific", level=1)
+            getattr(df, fn)("US/Pacific", level=1)
 
     @pytest.mark.parametrize("copy", [True, False])
     def test_tz_convert_copy_inplace_mutate(self, copy, frame_or_series):
