@@ -1,15 +1,21 @@
+from string import ascii_lowercase
+
 import numpy as np
 import pytest
 
 import pandas as pd
-from pandas import DataFrame, Series, Timestamp
+from pandas import (
+    DataFrame,
+    Series,
+    Timestamp,
+)
 import pandas._testing as tm
 
 
 def test_filter_series():
-    s = pd.Series([1, 3, 20, 5, 22, 24, 7])
-    expected_odd = pd.Series([1, 3, 5, 7], index=[0, 1, 3, 6])
-    expected_even = pd.Series([20, 22, 24], index=[2, 4, 5])
+    s = Series([1, 3, 20, 5, 22, 24, 7])
+    expected_odd = Series([1, 3, 5, 7], index=[0, 1, 3, 6])
+    expected_even = Series([20, 22, 24], index=[2, 4, 5])
     grouper = s.apply(lambda x: x % 2)
     grouped = s.groupby(grouper)
     tm.assert_series_equal(grouped.filter(lambda x: x.mean() < 10), expected_odd)
@@ -26,9 +32,9 @@ def test_filter_series():
 
 
 def test_filter_single_column_df():
-    df = pd.DataFrame([1, 3, 20, 5, 22, 24, 7])
-    expected_odd = pd.DataFrame([1, 3, 5, 7], index=[0, 1, 3, 6])
-    expected_even = pd.DataFrame([20, 22, 24], index=[2, 4, 5])
+    df = DataFrame([1, 3, 20, 5, 22, 24, 7])
+    expected_odd = DataFrame([1, 3, 5, 7], index=[0, 1, 3, 6])
+    expected_even = DataFrame([20, 22, 24], index=[2, 4, 5])
     grouper = df[0].apply(lambda x: x % 2)
     grouped = df.groupby(grouper)
     tm.assert_frame_equal(grouped.filter(lambda x: x.mean() < 10), expected_odd)
@@ -45,41 +51,41 @@ def test_filter_single_column_df():
 
 
 def test_filter_multi_column_df():
-    df = pd.DataFrame({"A": [1, 12, 12, 1], "B": [1, 1, 1, 1]})
+    df = DataFrame({"A": [1, 12, 12, 1], "B": [1, 1, 1, 1]})
     grouper = df["A"].apply(lambda x: x % 2)
     grouped = df.groupby(grouper)
-    expected = pd.DataFrame({"A": [12, 12], "B": [1, 1]}, index=[1, 2])
+    expected = DataFrame({"A": [12, 12], "B": [1, 1]}, index=[1, 2])
     tm.assert_frame_equal(
         grouped.filter(lambda x: x["A"].sum() - x["B"].sum() > 10), expected
     )
 
 
 def test_filter_mixed_df():
-    df = pd.DataFrame({"A": [1, 12, 12, 1], "B": "a b c d".split()})
+    df = DataFrame({"A": [1, 12, 12, 1], "B": "a b c d".split()})
     grouper = df["A"].apply(lambda x: x % 2)
     grouped = df.groupby(grouper)
-    expected = pd.DataFrame({"A": [12, 12], "B": ["b", "c"]}, index=[1, 2])
+    expected = DataFrame({"A": [12, 12], "B": ["b", "c"]}, index=[1, 2])
     tm.assert_frame_equal(grouped.filter(lambda x: x["A"].sum() > 10), expected)
 
 
 def test_filter_out_all_groups():
-    s = pd.Series([1, 3, 20, 5, 22, 24, 7])
+    s = Series([1, 3, 20, 5, 22, 24, 7])
     grouper = s.apply(lambda x: x % 2)
     grouped = s.groupby(grouper)
     tm.assert_series_equal(grouped.filter(lambda x: x.mean() > 1000), s[[]])
-    df = pd.DataFrame({"A": [1, 12, 12, 1], "B": "a b c d".split()})
+    df = DataFrame({"A": [1, 12, 12, 1], "B": "a b c d".split()})
     grouper = df["A"].apply(lambda x: x % 2)
     grouped = df.groupby(grouper)
     tm.assert_frame_equal(grouped.filter(lambda x: x["A"].sum() > 1000), df.loc[[]])
 
 
 def test_filter_out_no_groups():
-    s = pd.Series([1, 3, 20, 5, 22, 24, 7])
+    s = Series([1, 3, 20, 5, 22, 24, 7])
     grouper = s.apply(lambda x: x % 2)
     grouped = s.groupby(grouper)
     filtered = grouped.filter(lambda x: x.mean() > 0)
     tm.assert_series_equal(filtered, s)
-    df = pd.DataFrame({"A": [1, 12, 12, 1], "B": "a b c d".split()})
+    df = DataFrame({"A": [1, 12, 12, 1], "B": "a b c d".split()})
     grouper = df["A"].apply(lambda x: x % 2)
     grouped = df.groupby(grouper)
     filtered = grouped.filter(lambda x: x["A"].mean() > 0)
@@ -88,16 +94,16 @@ def test_filter_out_no_groups():
 
 def test_filter_out_all_groups_in_df():
     # GH12768
-    df = pd.DataFrame({"a": [1, 1, 2], "b": [1, 2, 0]})
+    df = DataFrame({"a": [1, 1, 2], "b": [1, 2, 0]})
     res = df.groupby("a")
     res = res.filter(lambda x: x["b"].sum() > 5, dropna=False)
-    expected = pd.DataFrame({"a": [np.nan] * 3, "b": [np.nan] * 3})
+    expected = DataFrame({"a": [np.nan] * 3, "b": [np.nan] * 3})
     tm.assert_frame_equal(expected, res)
 
-    df = pd.DataFrame({"a": [1, 1, 2], "b": [1, 2, 0]})
+    df = DataFrame({"a": [1, 1, 2], "b": [1, 2, 0]})
     res = df.groupby("a")
     res = res.filter(lambda x: x["b"].sum() > 5, dropna=True)
-    expected = pd.DataFrame({"a": [], "b": []}, dtype="int64")
+    expected = DataFrame({"a": [], "b": []}, dtype="int64")
     tm.assert_frame_equal(expected, res)
 
 
@@ -105,10 +111,9 @@ def test_filter_condition_raises():
     def raise_if_sum_is_zero(x):
         if x.sum() == 0:
             raise ValueError
-        else:
-            return x.sum() > 0
+        return x.sum() > 0
 
-    s = pd.Series([-1, 0, 1, 2])
+    s = Series([-1, 0, 1, 2])
     grouper = s.apply(lambda x: x % 2)
     grouped = s.groupby(grouper)
     msg = "the filter must return a boolean result"
@@ -119,8 +124,12 @@ def test_filter_condition_raises():
 def test_filter_with_axis_in_groupby():
     # issue 11041
     index = pd.MultiIndex.from_product([range(10), [0, 1]])
-    data = pd.DataFrame(np.arange(100).reshape(-1, 20), columns=index, dtype="int64")
-    result = data.groupby(level=0, axis=1).filter(lambda x: x.iloc[0, 0] > 10)
+    data = DataFrame(np.arange(100).reshape(-1, 20), columns=index, dtype="int64")
+
+    msg = "DataFrame.groupby with axis=1"
+    with tm.assert_produces_warning(FutureWarning, match=msg):
+        gb = data.groupby(level=0, axis=1)
+    result = gb.filter(lambda x: x.iloc[0, 0] > 10)
     expected = data.iloc[:, 12:20]
     tm.assert_frame_equal(result, expected)
 
@@ -167,10 +176,23 @@ def test_filter_nan_is_false():
     tm.assert_series_equal(g_s.filter(f), s[[]])
 
 
+def test_filter_pdna_is_false():
+    # in particular, dont raise in filter trying to call bool(pd.NA)
+    df = DataFrame({"A": np.arange(8), "B": list("aabbbbcc"), "C": np.arange(8)})
+    ser = df["B"]
+    g_df = df.groupby(df["B"])
+    g_s = ser.groupby(ser)
+
+    func = lambda x: pd.NA
+    res = g_df.filter(func)
+    tm.assert_frame_equal(res, df.loc[[]])
+    res = g_s.filter(func)
+    tm.assert_series_equal(res, ser[[]])
+
+
 def test_filter_against_workaround():
-    np.random.seed(0)
     # Series of ints
-    s = Series(np.random.randint(0, 100, 1000))
+    s = Series(np.random.default_rng(2).integers(0, 100, 1000))
     grouper = s.apply(lambda x: np.round(x, -1))
     grouped = s.groupby(grouper)
     f = lambda x: x.mean() > 10
@@ -180,7 +202,7 @@ def test_filter_against_workaround():
     tm.assert_series_equal(new_way.sort_values(), old_way.sort_values())
 
     # Series of floats
-    s = 100 * Series(np.random.random(1000))
+    s = 100 * Series(np.random.default_rng(2).random(1000))
     grouper = s.apply(lambda x: np.round(x, -1))
     grouped = s.groupby(grouper)
     f = lambda x: x.mean() > 10
@@ -189,15 +211,15 @@ def test_filter_against_workaround():
     tm.assert_series_equal(new_way.sort_values(), old_way.sort_values())
 
     # Set up DataFrame of ints, floats, strings.
-    from string import ascii_lowercase
-
     letters = np.array(list(ascii_lowercase))
     N = 1000
-    random_letters = letters.take(np.random.randint(0, 26, N))
+    random_letters = letters.take(
+        np.random.default_rng(2).integers(0, 26, N, dtype=int)
+    )
     df = DataFrame(
         {
-            "ints": Series(np.random.randint(0, 100, N)),
-            "floats": N / 10 * Series(np.random.random(N)),
+            "ints": Series(np.random.default_rng(2).integers(0, 100, N)),
+            "floats": N / 10 * Series(np.random.default_rng(2).random(N)),
             "letters": Series(random_letters),
         }
     )
@@ -229,7 +251,7 @@ def test_filter_using_len():
     actual = grouped.filter(lambda x: len(x) > 2)
     expected = DataFrame(
         {"A": np.arange(2, 6), "B": list("bbbb"), "C": np.arange(2, 6)},
-        index=np.arange(2, 6),
+        index=np.arange(2, 6, dtype=np.int64),
     )
     tm.assert_frame_equal(actual, expected)
 
@@ -241,7 +263,7 @@ def test_filter_using_len():
     s = df["B"]
     grouped = s.groupby(s)
     actual = grouped.filter(lambda x: len(x) > 2)
-    expected = Series(4 * ["b"], index=np.arange(2, 6), name="B")
+    expected = Series(4 * ["b"], index=np.arange(2, 6, dtype=np.int64), name="B")
     tm.assert_series_equal(actual, expected)
 
     actual = grouped.filter(lambda x: len(x) > 4)
@@ -342,7 +364,8 @@ def test_filter_and_transform_with_non_unique_int_index():
     tm.assert_frame_equal(actual, expected)
 
     actual = grouped_df.filter(lambda x: len(x) > 1, dropna=False)
-    expected = df.copy()
+    # Cast to avoid upcast when setting nan below
+    expected = df.copy().astype("float64")
     expected.iloc[[0, 3, 5, 6]] = np.nan
     tm.assert_frame_equal(actual, expected)
 
@@ -352,8 +375,7 @@ def test_filter_and_transform_with_non_unique_int_index():
     tm.assert_series_equal(actual, expected)
 
     actual = grouped_ser.filter(lambda x: len(x) > 1, dropna=False)
-    NA = np.nan
-    expected = Series([NA, 1, 1, NA, 2, NA, NA, 3], index, name="pid")
+    expected = Series([np.nan, 1, 1, np.nan, 2, np.nan, np.nan, 3], index, name="pid")
     # ^ made manually because this can get confusing!
     tm.assert_series_equal(actual, expected)
 
@@ -385,7 +407,8 @@ def test_filter_and_transform_with_multiple_non_unique_int_index():
     tm.assert_frame_equal(actual, expected)
 
     actual = grouped_df.filter(lambda x: len(x) > 1, dropna=False)
-    expected = df.copy()
+    # Cast to avoid upcast when setting nan below
+    expected = df.copy().astype("float64")
     expected.iloc[[0, 3, 5, 6]] = np.nan
     tm.assert_frame_equal(actual, expected)
 
@@ -395,8 +418,7 @@ def test_filter_and_transform_with_multiple_non_unique_int_index():
     tm.assert_series_equal(actual, expected)
 
     actual = grouped_ser.filter(lambda x: len(x) > 1, dropna=False)
-    NA = np.nan
-    expected = Series([NA, 1, 1, NA, 2, NA, NA, 3], index, name="pid")
+    expected = Series([np.nan, 1, 1, np.nan, 2, np.nan, np.nan, 3], index, name="pid")
     # ^ made manually because this can get confusing!
     tm.assert_series_equal(actual, expected)
 
@@ -428,7 +450,8 @@ def test_filter_and_transform_with_non_unique_float_index():
     tm.assert_frame_equal(actual, expected)
 
     actual = grouped_df.filter(lambda x: len(x) > 1, dropna=False)
-    expected = df.copy()
+    # Cast to avoid upcast when setting nan below
+    expected = df.copy().astype("float64")
     expected.iloc[[0, 3, 5, 6]] = np.nan
     tm.assert_frame_equal(actual, expected)
 
@@ -438,8 +461,7 @@ def test_filter_and_transform_with_non_unique_float_index():
     tm.assert_series_equal(actual, expected)
 
     actual = grouped_ser.filter(lambda x: len(x) > 1, dropna=False)
-    NA = np.nan
-    expected = Series([NA, 1, 1, NA, 2, NA, NA, 3], index, name="pid")
+    expected = Series([np.nan, 1, 1, np.nan, 2, np.nan, np.nan, 3], index, name="pid")
     # ^ made manually because this can get confusing!
     tm.assert_series_equal(actual, expected)
 
@@ -474,7 +496,8 @@ def test_filter_and_transform_with_non_unique_timestamp_index():
     tm.assert_frame_equal(actual, expected)
 
     actual = grouped_df.filter(lambda x: len(x) > 1, dropna=False)
-    expected = df.copy()
+    # Cast to avoid upcast when setting nan below
+    expected = df.copy().astype("float64")
     expected.iloc[[0, 3, 5, 6]] = np.nan
     tm.assert_frame_equal(actual, expected)
 
@@ -484,8 +507,7 @@ def test_filter_and_transform_with_non_unique_timestamp_index():
     tm.assert_series_equal(actual, expected)
 
     actual = grouped_ser.filter(lambda x: len(x) > 1, dropna=False)
-    NA = np.nan
-    expected = Series([NA, 1, 1, NA, 2, NA, NA, 3], index, name="pid")
+    expected = Series([np.nan, 1, 1, np.nan, 2, np.nan, np.nan, 3], index, name="pid")
     # ^ made manually because this can get confusing!
     tm.assert_series_equal(actual, expected)
 
@@ -517,7 +539,8 @@ def test_filter_and_transform_with_non_unique_string_index():
     tm.assert_frame_equal(actual, expected)
 
     actual = grouped_df.filter(lambda x: len(x) > 1, dropna=False)
-    expected = df.copy()
+    # Cast to avoid upcast when setting nan below
+    expected = df.copy().astype("float64")
     expected.iloc[[0, 3, 5, 6]] = np.nan
     tm.assert_frame_equal(actual, expected)
 
@@ -527,8 +550,7 @@ def test_filter_and_transform_with_non_unique_string_index():
     tm.assert_series_equal(actual, expected)
 
     actual = grouped_ser.filter(lambda x: len(x) > 1, dropna=False)
-    NA = np.nan
-    expected = Series([NA, 1, 1, NA, 2, NA, NA, 3], index, name="pid")
+    expected = Series([np.nan, 1, 1, np.nan, 2, np.nan, np.nan, 3], index, name="pid")
     # ^ made manually because this can get confusing!
     tm.assert_series_equal(actual, expected)
 
@@ -551,7 +573,7 @@ def test_filter_has_access_to_grouped_cols():
 
 
 def test_filter_enforces_scalarness():
-    df = pd.DataFrame(
+    df = DataFrame(
         [
             ["best", "a", "x"],
             ["worst", "b", "y"],
@@ -568,7 +590,7 @@ def test_filter_enforces_scalarness():
 
 
 def test_filter_non_bool_raises():
-    df = pd.DataFrame(
+    df = DataFrame(
         [
             ["best", "a", 1],
             ["worst", "b", 1],
@@ -586,12 +608,25 @@ def test_filter_non_bool_raises():
 
 def test_filter_dropna_with_empty_groups():
     # GH 10780
-    data = pd.Series(np.random.rand(9), index=np.repeat([1, 2, 3], 3))
-    groupped = data.groupby(level=0)
-    result_false = groupped.filter(lambda x: x.mean() > 1, dropna=False)
-    expected_false = pd.Series([np.nan] * 9, index=np.repeat([1, 2, 3], 3))
+    data = Series(np.random.default_rng(2).random(9), index=np.repeat([1, 2, 3], 3))
+    grouped = data.groupby(level=0)
+    result_false = grouped.filter(lambda x: x.mean() > 1, dropna=False)
+    expected_false = Series([np.nan] * 9, index=np.repeat([1, 2, 3], 3))
     tm.assert_series_equal(result_false, expected_false)
 
-    result_true = groupped.filter(lambda x: x.mean() > 1, dropna=True)
-    expected_true = pd.Series(index=pd.Index([], dtype=int), dtype=np.float64)
+    result_true = grouped.filter(lambda x: x.mean() > 1, dropna=True)
+    expected_true = Series(index=pd.Index([], dtype=int), dtype=np.float64)
     tm.assert_series_equal(result_true, expected_true)
+
+
+def test_filter_consistent_result_before_after_agg_func():
+    # GH 17091
+    df = DataFrame({"data": range(6), "key": list("ABCABC")})
+    grouper = df.groupby("key")
+    result = grouper.filter(lambda x: True)
+    expected = DataFrame({"data": range(6), "key": list("ABCABC")})
+    tm.assert_frame_equal(result, expected)
+
+    grouper.sum()
+    result = grouper.filter(lambda x: True)
+    tm.assert_frame_equal(result, expected)
