@@ -1,40 +1,42 @@
-from datetime import date, datetime, time, timedelta
+from datetime import (
+    date,
+    datetime,
+    time,
+    timedelta,
+)
 
 import numpy as np
 import pytest
 
-from pandas.errors import InvalidIndexError
+from pandas.compat.numpy import np_long
 
 import pandas as pd
-from pandas import DatetimeIndex, Index, Timestamp, date_range, notna
+from pandas import (
+    DatetimeIndex,
+    Index,
+    Timestamp,
+    bdate_range,
+    date_range,
+    notna,
+)
 import pandas._testing as tm
 
-from pandas.tseries.offsets import BDay, CDay
+from pandas.tseries.frequencies import to_offset
 
 START, END = datetime(2009, 1, 1), datetime(2010, 1, 1)
 
 
 class TestGetItem:
-    def test_ellipsis(self):
-        # GH#21282
-        idx = pd.date_range(
-            "2011-01-01", "2011-01-31", freq="D", tz="Asia/Tokyo", name="idx"
-        )
-
-        result = idx[...]
-        assert result.equals(idx)
-        assert result is not idx
-
     def test_getitem_slice_keeps_name(self):
         # GH4226
-        st = pd.Timestamp("2013-07-01 00:00:00", tz="America/Los_Angeles")
-        et = pd.Timestamp("2013-07-02 00:00:00", tz="America/Los_Angeles")
-        dr = pd.date_range(st, et, freq="H", name="timebucket")
+        st = Timestamp("2013-07-01 00:00:00", tz="America/Los_Angeles")
+        et = Timestamp("2013-07-02 00:00:00", tz="America/Los_Angeles")
+        dr = date_range(st, et, freq="H", name="timebucket")
         assert dr[1:].name == dr.name
 
     def test_getitem(self):
-        idx1 = pd.date_range("2011-01-01", "2011-01-31", freq="D", name="idx")
-        idx2 = pd.date_range(
+        idx1 = date_range("2011-01-01", "2011-01-31", freq="D", name="idx")
+        idx2 = date_range(
             "2011-01-01", "2011-01-31", freq="D", tz="Asia/Tokyo", name="idx"
         )
 
@@ -43,21 +45,21 @@ class TestGetItem:
             assert result == Timestamp("2011-01-01", tz=idx.tz)
 
             result = idx[0:5]
-            expected = pd.date_range(
+            expected = date_range(
                 "2011-01-01", "2011-01-05", freq="D", tz=idx.tz, name="idx"
             )
             tm.assert_index_equal(result, expected)
             assert result.freq == expected.freq
 
             result = idx[0:10:2]
-            expected = pd.date_range(
+            expected = date_range(
                 "2011-01-01", "2011-01-09", freq="2D", tz=idx.tz, name="idx"
             )
             tm.assert_index_equal(result, expected)
             assert result.freq == expected.freq
 
             result = idx[-20:-5:3]
-            expected = pd.date_range(
+            expected = date_range(
                 "2011-01-12", "2011-01-24", freq="3D", tz=idx.tz, name="idx"
             )
             tm.assert_index_equal(result, expected)
@@ -73,17 +75,17 @@ class TestGetItem:
             tm.assert_index_equal(result, expected)
             assert result.freq == expected.freq
 
-    def test_dti_business_getitem(self):
-        rng = pd.bdate_range(START, END)
+    @pytest.mark.parametrize("freq", ["B", "C"])
+    def test_dti_business_getitem(self, freq):
+        rng = bdate_range(START, END, freq=freq)
         smaller = rng[:5]
-        exp = DatetimeIndex(rng.view(np.ndarray)[:5], freq="B")
+        exp = DatetimeIndex(rng.view(np.ndarray)[:5], freq=freq)
         tm.assert_index_equal(smaller, exp)
         assert smaller.freq == exp.freq
-
         assert smaller.freq == rng.freq
 
         sliced = rng[::5]
-        assert sliced.freq == BDay() * 5
+        assert sliced.freq == to_offset(freq) * 5
 
         fancy_indexed = rng[[4, 3, 2, 1, 0]]
         assert len(fancy_indexed) == 5
@@ -91,42 +93,14 @@ class TestGetItem:
         assert fancy_indexed.freq is None
 
         # 32-bit vs. 64-bit platforms
-        assert rng[4] == rng[np.int_(4)]
+        assert rng[4] == rng[np_long(4)]
 
-    def test_dti_business_getitem_matplotlib_hackaround(self):
-        rng = pd.bdate_range(START, END)
-        with tm.assert_produces_warning(FutureWarning):
+    @pytest.mark.parametrize("freq", ["B", "C"])
+    def test_dti_business_getitem_matplotlib_hackaround(self, freq):
+        rng = bdate_range(START, END, freq=freq)
+        with pytest.raises(ValueError, match="Multi-dimensional indexing"):
             # GH#30588 multi-dimensional indexing deprecated
-            values = rng[:, None]
-        expected = rng.values[:, None]
-        tm.assert_numpy_array_equal(values, expected)
-
-    def test_dti_custom_getitem(self):
-        rng = pd.bdate_range(START, END, freq="C")
-        smaller = rng[:5]
-        exp = DatetimeIndex(rng.view(np.ndarray)[:5], freq="C")
-        tm.assert_index_equal(smaller, exp)
-        assert smaller.freq == exp.freq
-        assert smaller.freq == rng.freq
-
-        sliced = rng[::5]
-        assert sliced.freq == CDay() * 5
-
-        fancy_indexed = rng[[4, 3, 2, 1, 0]]
-        assert len(fancy_indexed) == 5
-        assert isinstance(fancy_indexed, DatetimeIndex)
-        assert fancy_indexed.freq is None
-
-        # 32-bit vs. 64-bit platforms
-        assert rng[4] == rng[np.int_(4)]
-
-    def test_dti_custom_getitem_matplotlib_hackaround(self):
-        rng = pd.bdate_range(START, END, freq="C")
-        with tm.assert_produces_warning(FutureWarning):
-            # GH#30588 multi-dimensional indexing deprecated
-            values = rng[:, None]
-        expected = rng.values[:, None]
-        tm.assert_numpy_array_equal(values, expected)
+            rng[:, None]
 
     def test_getitem_int_list(self):
         dti = date_range(start="1/1/2005", end="12/1/2005", freq="M")
@@ -155,10 +129,10 @@ class TestWhere:
 
     def test_where_other(self):
         # other is ndarray or Index
-        i = pd.date_range("20130101", periods=3, tz="US/Eastern")
+        i = date_range("20130101", periods=3, tz="US/Eastern")
 
         for arr in [np.nan, pd.NaT]:
-            result = i.where(notna(i), other=np.nan)
+            result = i.where(notna(i), other=arr)
             expected = i
             tm.assert_index_equal(result, expected)
 
@@ -173,43 +147,61 @@ class TestWhere:
         tm.assert_index_equal(result, i2)
 
     def test_where_invalid_dtypes(self):
-        dti = pd.date_range("20130101", periods=3, tz="US/Eastern")
+        dti = date_range("20130101", periods=3, tz="US/Eastern")
 
-        i2 = Index([pd.NaT, pd.NaT] + dti[2:].tolist())
+        tail = dti[2:].tolist()
+        i2 = Index([pd.NaT, pd.NaT] + tail)
 
-        with pytest.raises(TypeError, match="Where requires matching dtype"):
-            # passing tz-naive ndarray to tzaware DTI
-            dti.where(notna(i2), i2.values)
+        mask = notna(i2)
 
-        with pytest.raises(TypeError, match="Where requires matching dtype"):
-            # passing tz-aware DTI to tznaive DTI
-            dti.tz_localize(None).where(notna(i2), i2)
+        # passing tz-naive ndarray to tzaware DTI
+        result = dti.where(mask, i2.values)
+        expected = Index([pd.NaT.asm8, pd.NaT.asm8] + tail, dtype=object)
+        tm.assert_index_equal(result, expected)
 
-        with pytest.raises(TypeError, match="Where requires matching dtype"):
-            dti.where(notna(i2), i2.tz_localize(None).to_period("D"))
+        # passing tz-aware DTI to tznaive DTI
+        naive = dti.tz_localize(None)
+        result = naive.where(mask, i2)
+        expected = Index([i2[0], i2[1]] + naive[2:].tolist(), dtype=object)
+        tm.assert_index_equal(result, expected)
 
-        with pytest.raises(TypeError, match="Where requires matching dtype"):
-            dti.where(notna(i2), i2.asi8.view("timedelta64[ns]"))
+        pi = i2.tz_localize(None).to_period("D")
+        result = dti.where(mask, pi)
+        expected = Index([pi[0], pi[1]] + tail, dtype=object)
+        tm.assert_index_equal(result, expected)
 
-        with pytest.raises(TypeError, match="Where requires matching dtype"):
-            dti.where(notna(i2), i2.asi8)
+        tda = i2.asi8.view("timedelta64[ns]")
+        result = dti.where(mask, tda)
+        expected = Index([tda[0], tda[1]] + tail, dtype=object)
+        assert isinstance(expected[0], np.timedelta64)
+        tm.assert_index_equal(result, expected)
 
-        with pytest.raises(TypeError, match="Where requires matching dtype"):
-            # non-matching scalar
-            dti.where(notna(i2), pd.Timedelta(days=4))
+        result = dti.where(mask, i2.asi8)
+        expected = Index([pd.NaT._value, pd.NaT._value] + tail, dtype=object)
+        assert isinstance(expected[0], int)
+        tm.assert_index_equal(result, expected)
+
+        # non-matching scalar
+        td = pd.Timedelta(days=4)
+        result = dti.where(mask, td)
+        expected = Index([td, td] + tail, dtype=object)
+        assert expected[0] is td
+        tm.assert_index_equal(result, expected)
 
     def test_where_mismatched_nat(self, tz_aware_fixture):
         tz = tz_aware_fixture
-        dti = pd.date_range("2013-01-01", periods=3, tz=tz)
+        dti = date_range("2013-01-01", periods=3, tz=tz)
         cond = np.array([True, False, True])
 
-        msg = "Where requires matching dtype"
-        with pytest.raises(TypeError, match=msg):
-            # wrong-dtyped NaT
-            dti.where(cond, np.timedelta64("NaT", "ns"))
+        tdnat = np.timedelta64("NaT", "ns")
+        expected = Index([dti[0], tdnat, dti[2]], dtype=object)
+        assert expected[1] is tdnat
+
+        result = dti.where(cond, tdnat)
+        tm.assert_index_equal(result, expected)
 
     def test_where_tz(self):
-        i = pd.date_range("20130101", periods=3, tz="US/Eastern")
+        i = date_range("20130101", periods=3, tz="US/Eastern")
         result = i.where(notna(i))
         expected = i
         tm.assert_index_equal(result, expected)
@@ -222,10 +214,16 @@ class TestWhere:
 
 
 class TestTake:
+    def test_take_nan_first_datetime(self):
+        index = DatetimeIndex([pd.NaT, Timestamp("20130101"), Timestamp("20130102")])
+        result = index.take([-1, 0, 1])
+        expected = DatetimeIndex([index[-1], index[0], index[1]])
+        tm.assert_index_equal(result, expected)
+
     def test_take(self):
         # GH#10295
-        idx1 = pd.date_range("2011-01-01", "2011-01-31", freq="D", name="idx")
-        idx2 = pd.date_range(
+        idx1 = date_range("2011-01-01", "2011-01-31", freq="D", name="idx")
+        idx2 = date_range(
             "2011-01-01", "2011-01-31", freq="D", tz="Asia/Tokyo", name="idx"
         )
 
@@ -234,21 +232,21 @@ class TestTake:
             assert result == Timestamp("2011-01-01", tz=idx.tz)
 
             result = idx.take([0, 1, 2])
-            expected = pd.date_range(
+            expected = date_range(
                 "2011-01-01", "2011-01-03", freq="D", tz=idx.tz, name="idx"
             )
             tm.assert_index_equal(result, expected)
             assert result.freq == expected.freq
 
             result = idx.take([0, 2, 4])
-            expected = pd.date_range(
+            expected = date_range(
                 "2011-01-01", "2011-01-05", freq="2D", tz=idx.tz, name="idx"
             )
             tm.assert_index_equal(result, expected)
             assert result.freq == expected.freq
 
             result = idx.take([7, 4, 1])
-            expected = pd.date_range(
+            expected = date_range(
                 "2011-01-08", "2011-01-02", freq="-3D", tz=idx.tz, name="idx"
             )
             tm.assert_index_equal(result, expected)
@@ -275,7 +273,7 @@ class TestTake:
             assert result.freq is None
 
     def test_take_invalid_kwargs(self):
-        idx = pd.date_range("2011-01-01", "2011-01-31", freq="D", name="idx")
+        idx = date_range("2011-01-01", "2011-01-31", freq="D", name="idx")
         indices = [1, 6, 5, 9, 10, 13, 15, 3]
 
         msg = r"take\(\) got an unexpected keyword argument 'foo'"
@@ -300,7 +298,7 @@ class TestTake:
             datetime(2010, 1, 1, 21),
         ]
 
-        idx = pd.date_range(
+        idx = date_range(
             start="2010-01-01 09:00",
             end="2010-02-01 09:00",
             freq="H",
@@ -321,23 +319,19 @@ class TestTake:
 
     def test_take_fill_value(self):
         # GH#12631
-        idx = pd.DatetimeIndex(["2011-01-01", "2011-02-01", "2011-03-01"], name="xxx")
+        idx = DatetimeIndex(["2011-01-01", "2011-02-01", "2011-03-01"], name="xxx")
         result = idx.take(np.array([1, 0, -1]))
-        expected = pd.DatetimeIndex(
-            ["2011-02-01", "2011-01-01", "2011-03-01"], name="xxx"
-        )
+        expected = DatetimeIndex(["2011-02-01", "2011-01-01", "2011-03-01"], name="xxx")
         tm.assert_index_equal(result, expected)
 
         # fill_value
         result = idx.take(np.array([1, 0, -1]), fill_value=True)
-        expected = pd.DatetimeIndex(["2011-02-01", "2011-01-01", "NaT"], name="xxx")
+        expected = DatetimeIndex(["2011-02-01", "2011-01-01", "NaT"], name="xxx")
         tm.assert_index_equal(result, expected)
 
         # allow_fill=False
         result = idx.take(np.array([1, 0, -1]), allow_fill=False, fill_value=True)
-        expected = pd.DatetimeIndex(
-            ["2011-02-01", "2011-01-01", "2011-03-01"], name="xxx"
-        )
+        expected = DatetimeIndex(["2011-02-01", "2011-01-01", "2011-03-01"], name="xxx")
         tm.assert_index_equal(result, expected)
 
         msg = (
@@ -354,25 +348,25 @@ class TestTake:
             idx.take(np.array([1, -5]))
 
     def test_take_fill_value_with_timezone(self):
-        idx = pd.DatetimeIndex(
+        idx = DatetimeIndex(
             ["2011-01-01", "2011-02-01", "2011-03-01"], name="xxx", tz="US/Eastern"
         )
         result = idx.take(np.array([1, 0, -1]))
-        expected = pd.DatetimeIndex(
+        expected = DatetimeIndex(
             ["2011-02-01", "2011-01-01", "2011-03-01"], name="xxx", tz="US/Eastern"
         )
         tm.assert_index_equal(result, expected)
 
         # fill_value
         result = idx.take(np.array([1, 0, -1]), fill_value=True)
-        expected = pd.DatetimeIndex(
+        expected = DatetimeIndex(
             ["2011-02-01", "2011-01-01", "NaT"], name="xxx", tz="US/Eastern"
         )
         tm.assert_index_equal(result, expected)
 
         # allow_fill=False
         result = idx.take(np.array([1, 0, -1]), allow_fill=False, fill_value=True)
-        expected = pd.DatetimeIndex(
+        expected = DatetimeIndex(
             ["2011-02-01", "2011-01-01", "2011-03-01"], name="xxx", tz="US/Eastern"
         )
         tm.assert_index_equal(result, expected)
@@ -392,106 +386,71 @@ class TestTake:
 
 
 class TestGetLoc:
-    @pytest.mark.parametrize("method", [None, "pad", "backfill", "nearest"])
-    def test_get_loc_method_exact_match(self, method):
-        idx = pd.date_range("2000-01-01", periods=3)
-        assert idx.get_loc(idx[1], method) == 1
-        assert idx.get_loc(idx[1].to_pydatetime(), method) == 1
-        assert idx.get_loc(str(idx[1]), method) == 1
+    def test_get_loc_key_unit_mismatch(self):
+        idx = date_range("2000-01-01", periods=3)
+        key = idx[1].as_unit("ms")
+        loc = idx.get_loc(key)
+        assert loc == 1
+        assert key in idx
 
-        if method is not None:
-            assert idx.get_loc(idx[1], method, tolerance=pd.Timedelta("0 days")) == 1
+    def test_get_loc_key_unit_mismatch_not_castable(self):
+        dta = date_range("2000-01-01", periods=3)._data.astype("M8[s]")
+        dti = DatetimeIndex(dta)
+        key = dta[0].as_unit("ns") + pd.Timedelta(1)
 
-    def test_get_loc(self):
-        idx = pd.date_range("2000-01-01", periods=3)
-
-        assert idx.get_loc("2000-01-01", method="nearest") == 0
-        assert idx.get_loc("2000-01-01T12", method="nearest") == 1
-
-        assert idx.get_loc("2000-01-01T12", method="nearest", tolerance="1 day") == 1
-        assert (
-            idx.get_loc("2000-01-01T12", method="nearest", tolerance=pd.Timedelta("1D"))
-            == 1
-        )
-        assert (
-            idx.get_loc(
-                "2000-01-01T12", method="nearest", tolerance=np.timedelta64(1, "D")
-            )
-            == 1
-        )
-        assert (
-            idx.get_loc("2000-01-01T12", method="nearest", tolerance=timedelta(1)) == 1
-        )
-        with pytest.raises(ValueError, match="unit abbreviation w/o a number"):
-            idx.get_loc("2000-01-01T12", method="nearest", tolerance="foo")
-        with pytest.raises(KeyError, match="'2000-01-01T03'"):
-            idx.get_loc("2000-01-01T03", method="nearest", tolerance="2 hours")
         with pytest.raises(
-            ValueError, match="tolerance size must match target index size"
+            KeyError, match=r"Timestamp\('2000-01-01 00:00:00.000000001'\)"
         ):
-            idx.get_loc(
-                "2000-01-01",
-                method="nearest",
-                tolerance=[
-                    pd.Timedelta("1day").to_timedelta64(),
-                    pd.Timedelta("1day").to_timedelta64(),
-                ],
-            )
+            dti.get_loc(key)
 
-        assert idx.get_loc("2000", method="nearest") == slice(0, 3)
-        assert idx.get_loc("2000-01", method="nearest") == slice(0, 3)
-
-        assert idx.get_loc("1999", method="nearest") == 0
-        assert idx.get_loc("2001", method="nearest") == 2
-
-        with pytest.raises(KeyError, match="'1999'"):
-            idx.get_loc("1999", method="pad")
-        with pytest.raises(KeyError, match="'2001'"):
-            idx.get_loc("2001", method="backfill")
-
-        with pytest.raises(KeyError, match="'foobar'"):
-            idx.get_loc("foobar")
-        with pytest.raises(InvalidIndexError, match=r"slice\(None, 2, None\)"):
-            idx.get_loc(slice(2))
-
-        idx = pd.to_datetime(["2000-01-01", "2000-01-04"])
-        assert idx.get_loc("2000-01-02", method="nearest") == 0
-        assert idx.get_loc("2000-01-03", method="nearest") == 1
-        assert idx.get_loc("2000-01", method="nearest") == slice(0, 2)
+        assert key not in dti
 
+    def test_get_loc_time_obj(self):
         # time indexing
-        idx = pd.date_range("2000-01-01", periods=24, freq="H")
-        tm.assert_numpy_array_equal(
-            idx.get_loc(time(12)), np.array([12]), check_dtype=False
-        )
-        tm.assert_numpy_array_equal(
-            idx.get_loc(time(12, 30)), np.array([]), check_dtype=False
-        )
-        msg = "cannot yet lookup inexact labels when key is a time object"
-        with pytest.raises(NotImplementedError, match=msg):
-            idx.get_loc(time(12, 30), method="pad")
+        idx = date_range("2000-01-01", periods=24, freq="H")
+
+        result = idx.get_loc(time(12))
+        expected = np.array([12])
+        tm.assert_numpy_array_equal(result, expected, check_dtype=False)
+
+        result = idx.get_loc(time(12, 30))
+        expected = np.array([])
+        tm.assert_numpy_array_equal(result, expected, check_dtype=False)
+
+    def test_get_loc_time_obj2(self):
+        # GH#8667
+
+        from pandas._libs.index import _SIZE_CUTOFF
+
+        ns = _SIZE_CUTOFF + np.array([-100, 100], dtype=np.int64)
+        key = time(15, 11, 30)
+        start = key.hour * 3600 + key.minute * 60 + key.second
+        step = 24 * 3600
+
+        for n in ns:
+            idx = date_range("2014-11-26", periods=n, freq="S")
+            ts = pd.Series(np.random.default_rng(2).standard_normal(n), index=idx)
+            locs = np.arange(start, n, step, dtype=np.intp)
+
+            result = ts.index.get_loc(key)
+            tm.assert_numpy_array_equal(result, locs)
+            tm.assert_series_equal(ts[key], ts.iloc[locs])
+
+            left, right = ts.copy(), ts.copy()
+            left[key] *= -10
+            right.iloc[locs] *= -10
+            tm.assert_series_equal(left, right)
 
     def test_get_loc_time_nat(self):
         # GH#35114
         # Case where key's total microseconds happens to match iNaT % 1e6 // 1000
         tic = time(minute=12, second=43, microsecond=145224)
-        dti = pd.DatetimeIndex([pd.NaT])
+        dti = DatetimeIndex([pd.NaT])
 
         loc = dti.get_loc(tic)
         expected = np.array([], dtype=np.intp)
         tm.assert_numpy_array_equal(loc, expected)
 
-    def test_get_loc_tz_aware(self):
-        # https://github.com/pandas-dev/pandas/issues/32140
-        dti = pd.date_range(
-            pd.Timestamp("2019-12-12 00:00:00", tz="US/Eastern"),
-            pd.Timestamp("2019-12-13 00:00:00", tz="US/Eastern"),
-            freq="5s",
-        )
-        key = pd.Timestamp("2019-12-12 10:19:25", tz="US/Eastern")
-        result = dti.get_loc(key, method="nearest")
-        assert result == 7433
-
     def test_get_loc_nat(self):
         # GH#20464
         index = DatetimeIndex(["1/3/2000", "NaT"])
@@ -511,7 +470,7 @@ class TestGetLoc:
     @pytest.mark.parametrize("key", [pd.Timedelta(0), pd.Timedelta(1), timedelta(0)])
     def test_get_loc_timedelta_invalid_key(self, key):
         # GH#20464
-        dti = pd.date_range("1970-01-01", periods=10)
+        dti = date_range("1970-01-01", periods=10)
         msg = "Cannot index DatetimeIndex with [Tt]imedelta"
         with pytest.raises(TypeError, match=msg):
             dti.get_loc(key)
@@ -522,6 +481,13 @@ class TestGetLoc:
         with pytest.raises(KeyError, match="2000"):
             index.get_loc("1/1/2000")
 
+    def test_get_loc_year_str(self):
+        rng = date_range("1/1/2000", "1/1/2010")
+
+        result = rng.get_loc("2009")
+        expected = slice(3288, 3653)
+        assert result == expected
+
 
 class TestContains:
     def test_dti_contains_with_duplicates(self):
@@ -546,8 +512,15 @@ class TestContains:
 
 
 class TestGetIndexer:
+    def test_get_indexer_date_objs(self):
+        rng = date_range("1/1/2000", periods=20)
+
+        result = rng.get_indexer(rng.map(lambda x: x.date()))
+        expected = rng.get_indexer(rng)
+        tm.assert_numpy_array_equal(result, expected)
+
     def test_get_indexer(self):
-        idx = pd.date_range("2000-01-01", periods=3)
+        idx = date_range("2000-01-01", periods=3)
         exp = np.array([0, 1, 2], dtype=np.intp)
         tm.assert_numpy_array_equal(idx.get_indexer(idx), exp)
 
@@ -581,7 +554,8 @@ class TestGetIndexer:
             pd.Timedelta("1 hour").to_timedelta64(),
             "foo",
         ]
-        with pytest.raises(ValueError, match="abbreviation w/o a number"):
+        msg = "Could not convert 'foo' to NumPy timedelta"
+        with pytest.raises(ValueError, match=msg):
             idx.get_indexer(target, "nearest", tolerance=tol_bad)
         with pytest.raises(ValueError, match="abbreviation w/o a number"):
             idx.get_indexer(idx[[0]], method="nearest", tolerance="foo")
@@ -589,15 +563,13 @@ class TestGetIndexer:
     @pytest.mark.parametrize(
         "target",
         [
-            [date(2020, 1, 1), pd.Timestamp("2020-01-02")],
-            [pd.Timestamp("2020-01-01"), date(2020, 1, 2)],
+            [date(2020, 1, 1), Timestamp("2020-01-02")],
+            [Timestamp("2020-01-01"), date(2020, 1, 2)],
         ],
     )
     def test_get_indexer_mixed_dtypes(self, target):
         # https://github.com/pandas-dev/pandas/issues/33741
-        values = pd.DatetimeIndex(
-            [pd.Timestamp("2020-01-01"), pd.Timestamp("2020-01-02")]
-        )
+        values = DatetimeIndex([Timestamp("2020-01-01"), Timestamp("2020-01-02")])
         result = values.get_indexer(target)
         expected = np.array([0, 1], dtype=np.intp)
         tm.assert_numpy_array_equal(result, expected)
@@ -605,63 +577,138 @@ class TestGetIndexer:
     @pytest.mark.parametrize(
         "target, positions",
         [
-            ([date(9999, 1, 1), pd.Timestamp("2020-01-01")], [-1, 0]),
-            ([pd.Timestamp("2020-01-01"), date(9999, 1, 1)], [0, -1]),
+            ([date(9999, 1, 1), Timestamp("2020-01-01")], [-1, 0]),
+            ([Timestamp("2020-01-01"), date(9999, 1, 1)], [0, -1]),
             ([date(9999, 1, 1), date(9999, 1, 1)], [-1, -1]),
         ],
     )
     def test_get_indexer_out_of_bounds_date(self, target, positions):
-        values = pd.DatetimeIndex(
-            [pd.Timestamp("2020-01-01"), pd.Timestamp("2020-01-02")]
-        )
+        values = DatetimeIndex([Timestamp("2020-01-01"), Timestamp("2020-01-02")])
+
         result = values.get_indexer(target)
         expected = np.array(positions, dtype=np.intp)
         tm.assert_numpy_array_equal(result, expected)
 
+    def test_get_indexer_pad_requires_monotonicity(self):
+        rng = date_range("1/1/2000", "3/1/2000", freq="B")
+
+        # neither monotonic increasing or decreasing
+        rng2 = rng[[1, 0, 2]]
+
+        msg = "index must be monotonic increasing or decreasing"
+        with pytest.raises(ValueError, match=msg):
+            rng2.get_indexer(rng, method="pad")
+
 
 class TestMaybeCastSliceBound:
     def test_maybe_cast_slice_bounds_empty(self):
         # GH#14354
         empty_idx = date_range(freq="1H", periods=0, end="2015")
 
-        right = empty_idx._maybe_cast_slice_bound("2015-01-02", "right", "loc")
+        right = empty_idx._maybe_cast_slice_bound("2015-01-02", "right")
         exp = Timestamp("2015-01-02 23:59:59.999999999")
         assert right == exp
 
-        left = empty_idx._maybe_cast_slice_bound("2015-01-02", "left", "loc")
+        left = empty_idx._maybe_cast_slice_bound("2015-01-02", "left")
         exp = Timestamp("2015-01-02 00:00:00")
         assert left == exp
 
     def test_maybe_cast_slice_duplicate_monotonic(self):
         # https://github.com/pandas-dev/pandas/issues/16515
         idx = DatetimeIndex(["2017", "2017"])
-        result = idx._maybe_cast_slice_bound("2017-01-01", "left", "loc")
+        result = idx._maybe_cast_slice_bound("2017-01-01", "left")
         expected = Timestamp("2017-01-01")
         assert result == expected
 
 
-class TestDatetimeIndex:
-    def test_get_value(self):
-        # specifically make sure we have test for np.datetime64 key
-        dti = pd.date_range("2016-01-01", periods=3)
+class TestGetSliceBounds:
+    @pytest.mark.parametrize("box", [date, datetime, Timestamp])
+    @pytest.mark.parametrize("side, expected", [("left", 4), ("right", 5)])
+    def test_get_slice_bounds_datetime_within(
+        self, box, side, expected, tz_aware_fixture
+    ):
+        # GH 35690
+        tz = tz_aware_fixture
+        index = bdate_range("2000-01-03", "2000-02-11").tz_localize(tz)
+        key = box(year=2000, month=1, day=7)
 
-        arr = np.arange(6, 9)
-        ser = pd.Series(arr, index=dti)
+        if tz is not None:
+            with pytest.raises(TypeError, match="Cannot compare tz-naive"):
+                # GH#36148 we require tzawareness-compat as of 2.0
+                index.get_slice_bound(key, side=side)
+        else:
+            result = index.get_slice_bound(key, side=side)
+            assert result == expected
 
-        key = dti[1]
+    @pytest.mark.parametrize("box", [datetime, Timestamp])
+    @pytest.mark.parametrize("side", ["left", "right"])
+    @pytest.mark.parametrize("year, expected", [(1999, 0), (2020, 30)])
+    def test_get_slice_bounds_datetime_outside(
+        self, box, side, year, expected, tz_aware_fixture
+    ):
+        # GH 35690
+        tz = tz_aware_fixture
+        index = bdate_range("2000-01-03", "2000-02-11").tz_localize(tz)
+        key = box(year=year, month=1, day=7)
 
-        with pytest.raises(AttributeError, match="has no attribute '_values'"):
-            with tm.assert_produces_warning(FutureWarning):
-                dti.get_value(arr, key)
+        if tz is not None:
+            with pytest.raises(TypeError, match="Cannot compare tz-naive"):
+                # GH#36148 we require tzawareness-compat as of 2.0
+                index.get_slice_bound(key, side=side)
+        else:
+            result = index.get_slice_bound(key, side=side)
+            assert result == expected
 
-        with tm.assert_produces_warning(FutureWarning):
-            result = dti.get_value(ser, key)
-        assert result == 7
+    @pytest.mark.parametrize("box", [datetime, Timestamp])
+    def test_slice_datetime_locs(self, box, tz_aware_fixture):
+        # GH 34077
+        tz = tz_aware_fixture
+        index = DatetimeIndex(["2010-01-01", "2010-01-03"]).tz_localize(tz)
+        key = box(2010, 1, 1)
 
-        with tm.assert_produces_warning(FutureWarning):
-            result = dti.get_value(ser, key.to_pydatetime())
-        assert result == 7
+        if tz is not None:
+            with pytest.raises(TypeError, match="Cannot compare tz-naive"):
+                # GH#36148 we require tzawareness-compat as of 2.0
+                index.slice_locs(key, box(2010, 1, 2))
+        else:
+            result = index.slice_locs(key, box(2010, 1, 2))
+            expected = (0, 1)
+            assert result == expected
 
-        with tm.assert_produces_warning(FutureWarning):
-            result = dti.get_value(ser, key.to_datetime64())
-        assert result == 7
+
+class TestIndexerBetweenTime:
+    def test_indexer_between_time(self):
+        # GH#11818
+        rng = date_range("1/1/2000", "1/5/2000", freq="5min")
+        msg = r"Cannot convert arg \[datetime\.datetime\(2010, 1, 2, 1, 0\)\] to a time"
+        with pytest.raises(ValueError, match=msg):
+            rng.indexer_between_time(datetime(2010, 1, 2, 1), datetime(2010, 1, 2, 5))
+
+    @pytest.mark.parametrize("unit", ["us", "ms", "s"])
+    def test_indexer_between_time_non_nano(self, unit):
+        # For simple cases like this, the non-nano indexer_between_time
+        #  should match the nano result
+
+        rng = date_range("1/1/2000", "1/5/2000", freq="5min")
+        arr_nano = rng._data._ndarray
+
+        arr = arr_nano.astype(f"M8[{unit}]")
+
+        dta = type(rng._data)._simple_new(arr, dtype=arr.dtype)
+        dti = DatetimeIndex(dta)
+        assert dti.dtype == arr.dtype
+
+        tic = time(1, 25)
+        toc = time(2, 29)
+
+        result = dti.indexer_between_time(tic, toc)
+        expected = rng.indexer_between_time(tic, toc)
+        tm.assert_numpy_array_equal(result, expected)
+
+        # case with non-zero micros in arguments
+        tic = time(1, 25, 0, 45678)
+        toc = time(2, 29, 0, 1234)
+
+        result = dti.indexer_between_time(tic, toc)
+        expected = rng.indexer_between_time(tic, toc)
+        tm.assert_numpy_array_equal(result, expected)
