@@ -37,7 +37,10 @@ class TestDatetimeIndexOps:
     @pytest.mark.parametrize("data", [["1400-01-01"], [datetime(1400, 1, 1)]])
     def test_dti_date_out_of_range(self, data):
         # GH#1475
-        msg = "Out of bounds nanosecond timestamp: 1400-01-01 00:00:00"
+        msg = (
+            "^Out of bounds nanosecond timestamp: "
+            "1400-01-01( 00:00:00)?, at position 0$"
+        )
         with pytest.raises(OutOfBoundsDatetime, match=msg):
             DatetimeIndex(data)
 
@@ -63,11 +66,7 @@ class TestDatetimeIndexOps:
         idx = tm.makeDateIndex(100)
         expected = getattr(idx, field)[-1]
 
-        warn = FutureWarning if field.startswith("is_") else None
-        with tm.assert_produces_warning(
-            warn, match="Timestamp.freq is deprecated", check_stacklevel=False
-        ):
-            result = getattr(Timestamp(idx[-1]), field)
+        result = getattr(Timestamp(idx[-1]), field)
         assert result == expected
 
     def test_dti_timestamp_isocalendar_fields(self):
@@ -76,22 +75,6 @@ class TestDatetimeIndexOps:
         result = idx[-1].isocalendar()
         assert result == expected
 
-    def test_dti_timestamp_freq_fields(self):
-        # extra fields from DatetimeIndex like quarter and week
-        idx = tm.makeDateIndex(100)
-
-        msg = "The 'freq' argument in Timestamp is deprecated"
-        with tm.assert_produces_warning(FutureWarning, match=msg):
-            ts = Timestamp(idx[-1], idx.freq)
-
-        msg2 = "Timestamp.freq is deprecated"
-        with tm.assert_produces_warning(FutureWarning, match=msg2):
-            assert idx.freq == ts.freq
-
-        msg3 = "Timestamp.freqstr is deprecated"
-        with tm.assert_produces_warning(FutureWarning, match=msg3):
-            assert idx.freqstr == ts.freqstr
-
     # ----------------------------------------------------------------
     # DatetimeIndex.round
 
@@ -332,33 +315,33 @@ class TestDateTimeIndexToJulianDate:
         dr = date_range(start=Timestamp("1710-10-01"), periods=5, freq="D")
         r1 = pd.Index([x.to_julian_date() for x in dr])
         r2 = dr.to_julian_date()
-        assert isinstance(r2, pd.Float64Index)
+        assert isinstance(r2, pd.Index) and r2.dtype == np.float64
         tm.assert_index_equal(r1, r2)
 
     def test_2000(self):
         dr = date_range(start=Timestamp("2000-02-27"), periods=5, freq="D")
         r1 = pd.Index([x.to_julian_date() for x in dr])
         r2 = dr.to_julian_date()
-        assert isinstance(r2, pd.Float64Index)
+        assert isinstance(r2, pd.Index) and r2.dtype == np.float64
         tm.assert_index_equal(r1, r2)
 
     def test_hour(self):
         dr = date_range(start=Timestamp("2000-02-27"), periods=5, freq="H")
         r1 = pd.Index([x.to_julian_date() for x in dr])
         r2 = dr.to_julian_date()
-        assert isinstance(r2, pd.Float64Index)
+        assert isinstance(r2, pd.Index) and r2.dtype == np.float64
         tm.assert_index_equal(r1, r2)
 
     def test_minute(self):
         dr = date_range(start=Timestamp("2000-02-27"), periods=5, freq="T")
         r1 = pd.Index([x.to_julian_date() for x in dr])
         r2 = dr.to_julian_date()
-        assert isinstance(r2, pd.Float64Index)
+        assert isinstance(r2, pd.Index) and r2.dtype == np.float64
         tm.assert_index_equal(r1, r2)
 
     def test_second(self):
         dr = date_range(start=Timestamp("2000-02-27"), periods=5, freq="S")
         r1 = pd.Index([x.to_julian_date() for x in dr])
         r2 = dr.to_julian_date()
-        assert isinstance(r2, pd.Float64Index)
+        assert isinstance(r2, pd.Index) and r2.dtype == np.float64
         tm.assert_index_equal(r1, r2)
