@@ -7,6 +7,8 @@ import itertools
 import numpy as np
 import pytest
 
+from pandas.compat import pa_version_under7p0
+
 from pandas.core.dtypes.cast import construct_1d_object_array_from_listlike
 
 import pandas as pd
@@ -57,7 +59,7 @@ def test_constructor_nonhashable_names():
         codes=[[0, 0, 1, 1], [0, 1, 0, 1]],
         names=("foo", "bar"),
     )
-    renamed = [["foor"], ["barr"]]
+    renamed = [["fooo"], ["barr"]]
     with pytest.raises(TypeError, match=msg):
         mi.rename(names=renamed)
 
@@ -495,7 +497,6 @@ def test_from_product_index_series_categorical(ordered, f):
 
 
 def test_from_product():
-
     first = ["foo", "bar", "buz"]
     second = ["a", "b", "c"]
     names = ["first", "second"]
@@ -594,7 +595,6 @@ def test_from_product_readonly():
 
 
 def test_create_index_existing_name(idx):
-
     # GH11193, when an existing index is passed, and a new name is not
     # specified, the new index should inherit the previous object name
     index = idx
@@ -648,6 +648,28 @@ def test_from_frame():
     tm.assert_index_equal(expected, result)
 
 
+@pytest.mark.skipif(pa_version_under7p0, reason="minimum pyarrow not installed")
+def test_from_frame_missing_values_multiIndex():
+    # GH 39984
+    import pyarrow as pa
+
+    df = pd.DataFrame(
+        {
+            "a": Series([1, 2, None], dtype="Int64"),
+            "b": pd.Float64Dtype().__from_arrow__(pa.array([0.2, np.nan, None])),
+        }
+    )
+    multi_indexed = MultiIndex.from_frame(df)
+    expected = MultiIndex.from_arrays(
+        [
+            Series([1, 2, None]).astype("Int64"),
+            pd.Float64Dtype().__from_arrow__(pa.array([0.2, np.nan, None])),
+        ],
+        names=["a", "b"],
+    )
+    tm.assert_index_equal(multi_indexed, expected)
+
+
 @pytest.mark.parametrize(
     "non_frame",
     [
@@ -785,7 +807,6 @@ def test_datetimeindex():
 
 
 def test_constructor_with_tz():
-
     index = pd.DatetimeIndex(
         ["2013/01/01 09:00", "2013/01/02 09:00"], name="dt1", tz="US/Pacific"
     )
@@ -827,3 +848,13 @@ def test_multiindex_inference_consistency():
     mi = MultiIndex.from_tuples([(x,) for x in arr])
     lev = mi.levels[0]
     assert lev.dtype == object
+
+
+def test_dtype_representation():
+    # GH#46900
+    pmidx = MultiIndex.from_arrays([[1], ["a"]], names=[("a", "b"), ("c", "d")])
+    result = pmidx.dtypes
+    expected = Series(
+        ["int64", "object"], index=MultiIndex.from_tuples([("a", "b"), ("c", "d")])
+    )
+    tm.assert_series_equal(result, expected)
