@@ -8,7 +8,6 @@ from pandas import (
 
 
 def test_iat(float_frame):
-
     for i, row in enumerate(float_frame.index):
         for j, col in enumerate(float_frame.columns):
             result = float_frame.iat[i, j]
@@ -25,7 +24,7 @@ def test_iat_duplicate_columns():
 def test_iat_getitem_series_with_period_index():
     # GH#4390, iat incorrectly indexing
     index = period_range("1/1/2001", periods=10)
-    ser = Series(np.random.randn(10), index=index)
+    ser = Series(np.random.default_rng(2).standard_normal(10), index=index)
     expected = ser[index[0]]
     result = ser.iat[0]
     assert expected == result
