@@ -27,10 +27,8 @@ def test_namespace():
     ]
     expected = [
         "Block",
-        "NumericBlock",
         "DatetimeTZBlock",
         "ExtensionBlock",
-        "ObjectBlock",
         "make_block",
         "DataManager",
         "ArrayManager",
@@ -39,7 +37,6 @@ def test_namespace():
         "SingleBlockManager",
         "SingleArrayManager",
         "concatenate_managers",
-        "create_block_manager_from_arrays",
         "create_block_manager_from_blocks",
     ]
 
