@@ -38,7 +38,7 @@ def assert_equal_cell_styles(cell1, cell2):
 def test_styler_to_excel_unstyled(engine):
     # compare DataFrame.to_excel and Styler.to_excel when no styles applied
     pytest.importorskip(engine)
-    df = DataFrame(np.random.randn(2, 2))
+    df = DataFrame(np.random.default_rng(2).standard_normal((2, 2)))
     with tm.ensure_clean(".xlsx") as path:
         with ExcelWriter(path, engine=engine) as writer:
             df.to_excel(writer, sheet_name="dataframe")
@@ -46,7 +46,6 @@ def test_styler_to_excel_unstyled(engine):
 
         openpyxl = pytest.importorskip("openpyxl")  # test loading only with openpyxl
         with contextlib.closing(openpyxl.load_workbook(path)) as wb:
-
             for col1, col2 in zip(wb["dataframe"].columns, wb["unstyled"].columns):
                 assert len(col1) == len(col2)
                 for cell1, cell2 in zip(col1, col2):
@@ -131,8 +130,8 @@ shared_style_params = [
 @pytest.mark.parametrize("css, attrs, expected", shared_style_params)
 def test_styler_to_excel_basic(engine, css, attrs, expected):
     pytest.importorskip(engine)
-    df = DataFrame(np.random.randn(1, 1))
-    styler = df.style.applymap(lambda x: css)
+    df = DataFrame(np.random.default_rng(2).standard_normal((1, 1)))
+    styler = df.style.map(lambda x: css)
 
     with tm.ensure_clean(".xlsx") as path:
         with ExcelWriter(path, engine=engine) as writer:
@@ -141,7 +140,6 @@ def test_styler_to_excel_basic(engine, css, attrs, expected):
 
         openpyxl = pytest.importorskip("openpyxl")  # test loading only with openpyxl
         with contextlib.closing(openpyxl.load_workbook(path)) as wb:
-
             # test unstyled data cell does not have expected styles
             # test styled cell has expected styles
             u_cell, s_cell = wb["dataframe"].cell(2, 2), wb["styled"].cell(2, 2)
@@ -163,16 +161,16 @@ def test_styler_to_excel_basic(engine, css, attrs, expected):
 @pytest.mark.parametrize("css, attrs, expected", shared_style_params)
 def test_styler_to_excel_basic_indexes(engine, css, attrs, expected):
     pytest.importorskip(engine)
-    df = DataFrame(np.random.randn(1, 1))
+    df = DataFrame(np.random.default_rng(2).standard_normal((1, 1)))
 
     styler = df.style
-    styler.applymap_index(lambda x: css, axis=0)
-    styler.applymap_index(lambda x: css, axis=1)
+    styler.map_index(lambda x: css, axis=0)
+    styler.map_index(lambda x: css, axis=1)
 
     null_styler = df.style
-    null_styler.applymap(lambda x: "null: css;")
-    null_styler.applymap_index(lambda x: "null: css;", axis=0)
-    null_styler.applymap_index(lambda x: "null: css;", axis=1)
+    null_styler.map(lambda x: "null: css;")
+    null_styler.map_index(lambda x: "null: css;", axis=0)
+    null_styler.map_index(lambda x: "null: css;", axis=1)
 
     with tm.ensure_clean(".xlsx") as path:
         with ExcelWriter(path, engine=engine) as writer:
@@ -181,7 +179,6 @@ def test_styler_to_excel_basic_indexes(engine, css, attrs, expected):
 
         openpyxl = pytest.importorskip("openpyxl")  # test loading only with openpyxl
         with contextlib.closing(openpyxl.load_workbook(path)) as wb:
-
             # test null styled index cells does not have expected styles
             # test styled cell has expected styles
             ui_cell, si_cell = wb["null_styled"].cell(2, 1), wb["styled"].cell(2, 1)
@@ -233,8 +230,8 @@ def test_styler_to_excel_border_style(engine, border_style):
     expected = border_style
 
     pytest.importorskip(engine)
-    df = DataFrame(np.random.randn(1, 1))
-    styler = df.style.applymap(lambda x: css)
+    df = DataFrame(np.random.default_rng(2).standard_normal((1, 1)))
+    styler = df.style.map(lambda x: css)
 
     with tm.ensure_clean(".xlsx") as path:
         with ExcelWriter(path, engine=engine) as writer:
@@ -243,7 +240,6 @@ def test_styler_to_excel_border_style(engine, border_style):
 
         openpyxl = pytest.importorskip("openpyxl")  # test loading only with openpyxl
         with contextlib.closing(openpyxl.load_workbook(path)) as wb:
-
             # test unstyled data cell does not have expected styles
             # test styled cell has expected styles
             u_cell, s_cell = wb["dataframe"].cell(2, 2), wb["styled"].cell(2, 2)
@@ -264,8 +260,8 @@ def test_styler_custom_converter():
     def custom_converter(css):
         return {"font": {"color": {"rgb": "111222"}}}
 
-    df = DataFrame(np.random.randn(1, 1))
-    styler = df.style.applymap(lambda x: "color: #888999")
+    df = DataFrame(np.random.default_rng(2).standard_normal((1, 1)))
+    styler = df.style.map(lambda x: "color: #888999")
     with tm.ensure_clean(".xlsx") as path:
         with ExcelWriter(path, engine="openpyxl") as writer:
             ExcelFormatter(styler, style_converter=custom_converter).write(
@@ -278,18 +274,16 @@ def test_styler_custom_converter():
 
 @pytest.mark.single_cpu
 @td.skip_if_not_us_locale
-def test_styler_to_s3(s3_resource, s3so):
+def test_styler_to_s3(s3_public_bucket, s3so):
     # GH#46381
 
-    mock_bucket_name, target_file = "pandas-test", "test.xlsx"
+    mock_bucket_name, target_file = s3_public_bucket.name, "test.xlsx"
     df = DataFrame({"x": [1, 2, 3], "y": [2, 4, 6]})
     styler = df.style.set_sticky(axis="index")
     styler.to_excel(f"s3://{mock_bucket_name}/{target_file}", storage_options=s3so)
     timeout = 5
     while True:
-        if target_file in (
-            obj.key for obj in s3_resource.Bucket("pandas-test").objects.all()
-        ):
+        if target_file in (obj.key for obj in s3_public_bucket.objects.all()):
             break
         time.sleep(0.1)
         timeout -= 0.1
