@@ -744,9 +744,9 @@ def test_apply_map_header_render_mi(df_ext, index, columns, siunitx):
     func = lambda v: "bfseries: --rwrap" if "A" in v or "Z" in v or "c" in v else None
 
     if index:
-        styler.applymap_index(func, axis="index")
+        styler.map_index(func, axis="index")
     if columns:
-        styler.applymap_index(func, axis="columns")
+        styler.map_index(func, axis="columns")
 
     result = styler.to_latex(siunitx=siunitx)
 
@@ -796,7 +796,7 @@ def test_siunitx_basic_headers(styler):
 
 @pytest.mark.parametrize("axis", ["index", "columns"])
 def test_css_convert_apply_index(styler, axis):
-    styler.applymap_index(lambda x: "font-weight: bold;", axis=axis)
+    styler.map_index(lambda x: "font-weight: bold;", axis=axis)
     for label in getattr(styler, axis):
         assert f"\\bfseries {label}" in styler.to_latex(convert_css=True)
 
@@ -829,8 +829,8 @@ def test_latex_hiding_index_columns_multiindex_alignment():
     styler.hide(level=1, axis=0).hide(level=0, axis=1)
     styler.hide([("i0", "i1", "i2")], axis=0)
     styler.hide([("c0", "c1", "c2")], axis=1)
-    styler.applymap(lambda x: "color:{red};" if x == 5 else "")
-    styler.applymap_index(lambda x: "color:{blue};" if "j" in x else "")
+    styler.map(lambda x: "color:{red};" if x == 5 else "")
+    styler.map_index(lambda x: "color:{blue};" if "j" in x else "")
     result = styler.to_latex()
     expected = dedent(
         """\
@@ -863,7 +863,7 @@ def test_apply_index_hidden_levels():
         columns=MultiIndex.from_tuples([(0, 1)], names=["c0", "c1"]),
     ).style
     styler.hide(level=1)
-    styler.applymap_index(lambda v: "color: red;", level=0, axis=1)
+    styler.map_index(lambda v: "color: red;", level=0, axis=1)
     result = styler.to_latex(convert_css=True)
     expected = dedent(
         """\
