@@ -1,11 +1,8 @@
-import datetime
+import contextlib
+import datetime as dt
 import hashlib
-import os
+import tempfile
 import time
-from warnings import (
-    catch_warnings,
-    simplefilter,
-)
 
 import numpy as np
 import pytest
@@ -25,14 +22,7 @@ from pandas import (
 import pandas._testing as tm
 from pandas.tests.io.pytables.common import (
     _maybe_remove,
-    ensure_clean_path,
     ensure_clean_store,
-    safe_close,
-)
-
-_default_compressor = "blosc"
-ignore_natural_naming_warning = pytest.mark.filterwarnings(
-    "ignore:object name:tables.exceptions.NaturalNameWarning"
 )
 
 from pandas.io.pytables import (
@@ -40,7 +30,9 @@ from pandas.io.pytables import (
     read_hdf,
 )
 
-pytestmark = pytest.mark.single
+pytestmark = pytest.mark.single_cpu
+
+tables = pytest.importorskip("tables")
 
 
 def test_context(setup_path):
@@ -57,8 +49,7 @@ def test_context(setup_path):
             assert type(tbl["a"]) == DataFrame
 
 
-def test_no_track_times(setup_path):
-
+def test_no_track_times(tmp_path, setup_path):
     # GH 32682
     # enables to set track_times (see `pytables` `create_table` documentation)
 
@@ -69,30 +60,30 @@ def test_no_track_times(setup_path):
                 h.update(chunk)
         return h.digest()
 
-    def create_h5_and_return_checksum(track_times):
-        with ensure_clean_path(setup_path) as path:
-            df = DataFrame({"a": [1]})
+    def create_h5_and_return_checksum(tmp_path, track_times):
+        path = tmp_path / setup_path
+        df = DataFrame({"a": [1]})
 
-            with HDFStore(path, mode="w") as hdf:
-                hdf.put(
-                    "table",
-                    df,
-                    format="table",
-                    data_columns=True,
-                    index=None,
-                    track_times=track_times,
-                )
+        with HDFStore(path, mode="w") as hdf:
+            hdf.put(
+                "table",
+                df,
+                format="table",
+                data_columns=True,
+                index=None,
+                track_times=track_times,
+            )
 
-            return checksum(path)
+        return checksum(path)
 
-    checksum_0_tt_false = create_h5_and_return_checksum(track_times=False)
-    checksum_0_tt_true = create_h5_and_return_checksum(track_times=True)
+    checksum_0_tt_false = create_h5_and_return_checksum(tmp_path, track_times=False)
+    checksum_0_tt_true = create_h5_and_return_checksum(tmp_path, track_times=True)
 
     # sleep is necessary to create h5 with different creation time
     time.sleep(1)
 
-    checksum_1_tt_false = create_h5_and_return_checksum(track_times=False)
-    checksum_1_tt_true = create_h5_and_return_checksum(track_times=True)
+    checksum_1_tt_false = create_h5_and_return_checksum(tmp_path, track_times=False)
+    checksum_1_tt_true = create_h5_and_return_checksum(tmp_path, track_times=True)
 
     # checksums are the same if track_time = False
     assert checksum_0_tt_false == checksum_1_tt_false
@@ -102,14 +93,12 @@ def test_no_track_times(setup_path):
 
 
 def test_iter_empty(setup_path):
-
     with ensure_clean_store(setup_path) as store:
         # GH 12221
         assert list(store) == []
 
 
 def test_repr(setup_path):
-
     with ensure_clean_store(setup_path) as store:
         repr(store)
         store.info()
@@ -127,13 +116,12 @@ def test_repr(setup_path):
         df["int2"] = 2
         df["timestamp1"] = Timestamp("20010102")
         df["timestamp2"] = Timestamp("20010103")
-        df["datetime1"] = datetime.datetime(2001, 1, 2, 0, 0)
-        df["datetime2"] = datetime.datetime(2001, 1, 3, 0, 0)
+        df["datetime1"] = dt.datetime(2001, 1, 2, 0, 0)
+        df["datetime2"] = dt.datetime(2001, 1, 3, 0, 0)
         df.loc[df.index[3:6], ["obj1"]] = np.nan
-        df = df._consolidate()._convert(datetime=True)
+        df = df._consolidate()
 
-        with catch_warnings(record=True):
-            simplefilter("ignore", pd.errors.PerformanceWarning)
+        with tm.assert_produces_warning(pd.errors.PerformanceWarning):
             store["df"] = df
 
         # make a random group in hdf space
@@ -145,7 +133,6 @@ def test_repr(setup_path):
 
     # storers
     with ensure_clean_store(setup_path) as store:
-
         df = tm.makeDataFrame()
         store.append("df", df)
 
@@ -154,9 +141,7 @@ def test_repr(setup_path):
         str(s)
 
 
-@pytest.mark.filterwarnings("ignore:object name:tables.exceptions.NaturalNameWarning")
 def test_contains(setup_path):
-
     with ensure_clean_store(setup_path) as store:
         store["a"] = tm.makeTimeSeries()
         store["b"] = tm.makeDataFrame()
@@ -170,13 +155,14 @@ def test_contains(setup_path):
         assert "bar" not in store
 
         # gh-2694: tables.NaturalNameWarning
-        with catch_warnings(record=True):
+        with tm.assert_produces_warning(
+            tables.NaturalNameWarning, check_stacklevel=False
+        ):
             store["node())"] = tm.makeDataFrame()
         assert "node())" in store
 
 
 def test_versioning(setup_path):
-
     with ensure_clean_store(setup_path) as store:
         store["a"] = tm.makeTimeSeries()
         store["b"] = tm.makeDataFrame()
@@ -223,7 +209,7 @@ def test_versioning(setup_path):
         ),
     ],
 )
-def test_walk(where, expected, setup_path):
+def test_walk(where, expected):
     # GH10143
     objs = {
         "df1": DataFrame([1, 2, 3]),
@@ -264,9 +250,7 @@ def test_walk(where, expected, setup_path):
 
 
 def test_getattr(setup_path):
-
     with ensure_clean_store(setup_path) as store:
-
         s = tm.makeTimeSeries()
         store["a"] = s
 
@@ -292,7 +276,7 @@ def test_getattr(setup_path):
             getattr(store, f"_{x}")
 
 
-def test_store_dropna(setup_path):
+def test_store_dropna(tmp_path, setup_path):
     df_with_missing = DataFrame(
         {"col1": [0.0, np.nan, 2.0], "col2": [1.0, np.nan, np.nan]},
         index=list("abc"),
@@ -303,83 +287,78 @@ def test_store_dropna(setup_path):
 
     # # Test to make sure defaults are to not drop.
     # # Corresponding to Issue 9382
-    with ensure_clean_path(setup_path) as path:
-        df_with_missing.to_hdf(path, "df", format="table")
-        reloaded = read_hdf(path, "df")
-        tm.assert_frame_equal(df_with_missing, reloaded)
+    path = tmp_path / setup_path
+    df_with_missing.to_hdf(path, "df", format="table")
+    reloaded = read_hdf(path, "df")
+    tm.assert_frame_equal(df_with_missing, reloaded)
 
-    with ensure_clean_path(setup_path) as path:
-        df_with_missing.to_hdf(path, "df", format="table", dropna=False)
-        reloaded = read_hdf(path, "df")
-        tm.assert_frame_equal(df_with_missing, reloaded)
+    path = tmp_path / setup_path
+    df_with_missing.to_hdf(path, "df", format="table", dropna=False)
+    reloaded = read_hdf(path, "df")
+    tm.assert_frame_equal(df_with_missing, reloaded)
 
-    with ensure_clean_path(setup_path) as path:
-        df_with_missing.to_hdf(path, "df", format="table", dropna=True)
-        reloaded = read_hdf(path, "df")
-        tm.assert_frame_equal(df_without_missing, reloaded)
+    path = tmp_path / setup_path
+    df_with_missing.to_hdf(path, "df", format="table", dropna=True)
+    reloaded = read_hdf(path, "df")
+    tm.assert_frame_equal(df_without_missing, reloaded)
 
 
-def test_to_hdf_with_min_itemsize(setup_path):
+def test_to_hdf_with_min_itemsize(tmp_path, setup_path):
+    path = tmp_path / setup_path
 
-    with ensure_clean_path(setup_path) as path:
+    # min_itemsize in index with to_hdf (GH 10381)
+    df = tm.makeMixedDataFrame().set_index("C")
+    df.to_hdf(path, "ss3", format="table", min_itemsize={"index": 6})
+    # just make sure there is a longer string:
+    df2 = df.copy().reset_index().assign(C="longer").set_index("C")
+    df2.to_hdf(path, "ss3", append=True, format="table")
+    tm.assert_frame_equal(read_hdf(path, "ss3"), concat([df, df2]))
 
-        # min_itemsize in index with to_hdf (GH 10381)
-        df = tm.makeMixedDataFrame().set_index("C")
-        df.to_hdf(path, "ss3", format="table", min_itemsize={"index": 6})
-        # just make sure there is a longer string:
-        df2 = df.copy().reset_index().assign(C="longer").set_index("C")
-        df2.to_hdf(path, "ss3", append=True, format="table")
-        tm.assert_frame_equal(read_hdf(path, "ss3"), concat([df, df2]))
-
-        # same as above, with a Series
-        df["B"].to_hdf(path, "ss4", format="table", min_itemsize={"index": 6})
-        df2["B"].to_hdf(path, "ss4", append=True, format="table")
-        tm.assert_series_equal(read_hdf(path, "ss4"), concat([df["B"], df2["B"]]))
+    # same as above, with a Series
+    df["B"].to_hdf(path, "ss4", format="table", min_itemsize={"index": 6})
+    df2["B"].to_hdf(path, "ss4", append=True, format="table")
+    tm.assert_series_equal(read_hdf(path, "ss4"), concat([df["B"], df2["B"]]))
 
 
 @pytest.mark.parametrize("format", ["fixed", "table"])
-def test_to_hdf_errors(format, setup_path):
-
+def test_to_hdf_errors(tmp_path, format, setup_path):
     data = ["\ud800foo"]
     ser = Series(data, index=Index(data))
-    with ensure_clean_path(setup_path) as path:
-        # GH 20835
-        ser.to_hdf(path, "table", format=format, errors="surrogatepass")
+    path = tmp_path / setup_path
+    # GH 20835
+    ser.to_hdf(path, "table", format=format, errors="surrogatepass")
 
-        result = read_hdf(path, "table", errors="surrogatepass")
-        tm.assert_series_equal(result, ser)
+    result = read_hdf(path, "table", errors="surrogatepass")
+    tm.assert_series_equal(result, ser)
 
 
 def test_create_table_index(setup_path):
-
     with ensure_clean_store(setup_path) as store:
 
-        with catch_warnings(record=True):
+        def col(t, column):
+            return getattr(store.get_storer(t).table.cols, column)
 
-            def col(t, column):
-                return getattr(store.get_storer(t).table.cols, column)
+        # data columns
+        df = tm.makeTimeDataFrame()
+        df["string"] = "foo"
+        df["string2"] = "bar"
+        store.append("f", df, data_columns=["string", "string2"])
+        assert col("f", "index").is_indexed is True
+        assert col("f", "string").is_indexed is True
+        assert col("f", "string2").is_indexed is True
 
-            # data columns
-            df = tm.makeTimeDataFrame()
-            df["string"] = "foo"
-            df["string2"] = "bar"
-            store.append("f", df, data_columns=["string", "string2"])
-            assert col("f", "index").is_indexed is True
-            assert col("f", "string").is_indexed is True
-            assert col("f", "string2").is_indexed is True
+        # specify index=columns
+        store.append("f2", df, index=["string"], data_columns=["string", "string2"])
+        assert col("f2", "index").is_indexed is False
+        assert col("f2", "string").is_indexed is True
+        assert col("f2", "string2").is_indexed is False
 
-            # specify index=columns
-            store.append("f2", df, index=["string"], data_columns=["string", "string2"])
-            assert col("f2", "index").is_indexed is False
-            assert col("f2", "string").is_indexed is True
-            assert col("f2", "string2").is_indexed is False
-
-            # try to index a non-table
-            _maybe_remove(store, "f2")
-            store.put("f2", df)
-            msg = "cannot create table index on a Fixed format store"
-            with pytest.raises(TypeError, match=msg):
-                store.create_table_index("f2")
+        # try to index a non-table
+        _maybe_remove(store, "f2")
+        store.put("f2", df)
+        msg = "cannot create table index on a Fixed format store"
+        with pytest.raises(TypeError, match=msg):
+            store.create_table_index("f2")
 
 
 def test_create_table_index_data_columns_argument(setup_path):
@@ -387,31 +366,29 @@ def test_create_table_index_data_columns_argument(setup_path):
 
     with ensure_clean_store(setup_path) as store:
 
-        with catch_warnings(record=True):
+        def col(t, column):
+            return getattr(store.get_storer(t).table.cols, column)
 
-            def col(t, column):
-                return getattr(store.get_storer(t).table.cols, column)
+        # data columns
+        df = tm.makeTimeDataFrame()
+        df["string"] = "foo"
+        df["string2"] = "bar"
+        store.append("f", df, data_columns=["string"])
+        assert col("f", "index").is_indexed is True
+        assert col("f", "string").is_indexed is True
 
-            # data columns
-            df = tm.makeTimeDataFrame()
-            df["string"] = "foo"
-            df["string2"] = "bar"
-            store.append("f", df, data_columns=["string"])
-            assert col("f", "index").is_indexed is True
-            assert col("f", "string").is_indexed is True
+        msg = "'Cols' object has no attribute 'string2'"
+        with pytest.raises(AttributeError, match=msg):
+            col("f", "string2").is_indexed
 
-            msg = "'Cols' object has no attribute 'string2'"
-            with pytest.raises(AttributeError, match=msg):
-                col("f", "string2").is_indexed
-
-            # try to index a col which isn't a data_column
-            msg = (
-                "column string2 is not a data_column.\n"
-                "In order to read column string2 you must reload the dataframe \n"
-                "into HDFStore and include string2 with the data_columns argument."
-            )
-            with pytest.raises(AttributeError, match=msg):
-                store.create_table_index("f", columns=["string2"])
+        # try to index a col which isn't a data_column
+        msg = (
+            "column string2 is not a data_column.\n"
+            "In order to read column string2 you must reload the dataframe \n"
+            "into HDFStore and include string2 with the data_columns argument."
+        )
+        with pytest.raises(AttributeError, match=msg):
+            store.create_table_index("f", columns=["string2"])
 
 
 def test_mi_data_columns(setup_path):
@@ -430,7 +407,6 @@ def test_mi_data_columns(setup_path):
 
 
 def test_table_mixed_dtypes(setup_path):
-
     # frame
     df = tm.makeDataFrame()
     df["obj1"] = "foo"
@@ -440,12 +416,12 @@ def test_table_mixed_dtypes(setup_path):
     df["bool3"] = True
     df["int1"] = 1
     df["int2"] = 2
-    df["timestamp1"] = Timestamp("20010102")
-    df["timestamp2"] = Timestamp("20010103")
-    df["datetime1"] = datetime.datetime(2001, 1, 2, 0, 0)
-    df["datetime2"] = datetime.datetime(2001, 1, 3, 0, 0)
+    df["timestamp1"] = Timestamp("20010102").as_unit("ns")
+    df["timestamp2"] = Timestamp("20010103").as_unit("ns")
+    df["datetime1"] = Timestamp("20010102").as_unit("ns")
+    df["datetime2"] = Timestamp("20010103").as_unit("ns")
     df.loc[df.index[3:6], ["obj1"]] = np.nan
-    df = df._consolidate()._convert(datetime=True)
+    df = df._consolidate()
 
     with ensure_clean_store(setup_path) as store:
         store.append("df1_mixed", df)
@@ -453,25 +429,23 @@ def test_table_mixed_dtypes(setup_path):
 
 
 def test_calendar_roundtrip_issue(setup_path):
-
     # 8591
     # doc example from tseries holiday section
     weekmask_egypt = "Sun Mon Tue Wed Thu"
     holidays = [
         "2012-05-01",
-        datetime.datetime(2013, 5, 1),
+        dt.datetime(2013, 5, 1),
         np.datetime64("2014-05-01"),
     ]
     bday_egypt = pd.offsets.CustomBusinessDay(
         holidays=holidays, weekmask=weekmask_egypt
     )
-    dt = datetime.datetime(2013, 4, 30)
-    dts = date_range(dt, periods=5, freq=bday_egypt)
+    mydt = dt.datetime(2013, 4, 30)
+    dts = date_range(mydt, periods=5, freq=bday_egypt)
 
     s = Series(dts.weekday, dts).map(Series("Mon Tue Wed Thu Fri Sat Sun".split()))
 
     with ensure_clean_store(setup_path) as store:
-
         store.put("fixed", s)
         result = store.select("fixed")
         tm.assert_series_equal(result, s)
@@ -482,9 +456,7 @@ def test_calendar_roundtrip_issue(setup_path):
 
 
 def test_remove(setup_path):
-
     with ensure_clean_store(setup_path) as store:
-
         ts = tm.makeTimeSeries()
         df = tm.makeDataFrame()
         store["a"] = ts
@@ -523,17 +495,19 @@ def test_remove(setup_path):
 
 
 def test_same_name_scoping(setup_path):
-
     with ensure_clean_store(setup_path) as store:
-
-        df = DataFrame(np.random.randn(20, 2), index=date_range("20130101", periods=20))
+        df = DataFrame(
+            np.random.default_rng(2).standard_normal((20, 2)),
+            index=date_range("20130101", periods=20),
+        )
         store.put("df", df, format="table")
         expected = df[df.index > Timestamp("20130105")]
 
         result = store.select("df", "index>datetime.datetime(2013,1,5)")
         tm.assert_frame_equal(result, expected)
 
-        from datetime import datetime  # noqa
+        # changes what 'datetime' points to in the namespace where
+        #  'select' does the lookup
 
         # technically an error, but allow it
         result = store.select("df", "index>datetime.datetime(2013,1,5)")
@@ -554,27 +528,27 @@ def test_store_index_name(setup_path):
 
 
 @pytest.mark.parametrize("table_format", ["table", "fixed"])
-def test_store_index_name_numpy_str(table_format, setup_path):
+def test_store_index_name_numpy_str(tmp_path, table_format, setup_path):
     # GH #13492
     idx = Index(
-        pd.to_datetime([datetime.date(2000, 1, 1), datetime.date(2000, 1, 2)]),
+        pd.to_datetime([dt.date(2000, 1, 1), dt.date(2000, 1, 2)]),
         name="cols\u05d2",
     )
     idx1 = Index(
-        pd.to_datetime([datetime.date(2010, 1, 1), datetime.date(2010, 1, 2)]),
+        pd.to_datetime([dt.date(2010, 1, 1), dt.date(2010, 1, 2)]),
         name="rows\u05d0",
     )
     df = DataFrame(np.arange(4).reshape(2, 2), columns=idx, index=idx1)
 
     # This used to fail, returning numpy strings instead of python strings.
-    with ensure_clean_path(setup_path) as path:
-        df.to_hdf(path, "df", format=table_format)
-        df2 = read_hdf(path, "df")
+    path = tmp_path / setup_path
+    df.to_hdf(path, "df", format=table_format)
+    df2 = read_hdf(path, "df")
 
-        tm.assert_frame_equal(df, df2, check_names=True)
+    tm.assert_frame_equal(df, df2, check_names=True)
 
-        assert type(df2.index.name) == str
-        assert type(df2.columns.name) == str
+    assert type(df2.index.name) == str
+    assert type(df2.columns.name) == str
 
 
 def test_store_series_name(setup_path):
@@ -587,9 +561,7 @@ def test_store_series_name(setup_path):
         tm.assert_series_equal(recons, series)
 
 
-@pytest.mark.filterwarnings("ignore:\\nduplicate:pandas.io.pytables.DuplicateWarning")
 def test_overwrite_node(setup_path):
-
     with ensure_clean_store(setup_path) as store:
         store["a"] = tm.makeTimeDataFrame()
         ts = tm.makeTimeSeries()
@@ -598,14 +570,10 @@ def test_overwrite_node(setup_path):
         tm.assert_series_equal(store["a"], ts)
 
 
-@pytest.mark.filterwarnings(
-    "ignore:\\nthe :pandas.io.pytables.AttributeConflictWarning"
-)
 def test_coordinates(setup_path):
     df = tm.makeTimeDataFrame()
 
     with ensure_clean_store(setup_path) as store:
-
         _maybe_remove(store, "df")
         store.append("df", df)
 
@@ -652,9 +620,9 @@ def test_coordinates(setup_path):
 
     # pass array/mask as the coordinates
     with ensure_clean_store(setup_path) as store:
-
         df = DataFrame(
-            np.random.randn(1000, 2), index=date_range("20000101", periods=1000)
+            np.random.default_rng(2).standard_normal((1000, 2)),
+            index=date_range("20000101", periods=1000),
         )
         store.append("df", df)
         c = store.select_column("df", "index")
@@ -693,7 +661,7 @@ def test_coordinates(setup_path):
         tm.assert_frame_equal(result, expected)
 
         # list
-        df = DataFrame(np.random.randn(10, 2))
+        df = DataFrame(np.random.default_rng(2).standard_normal((10, 2)))
         store.append("df2", df)
         result = store.select("df2", where=[0, 3, 5])
         expected = df.iloc[[0, 3, 5]]
@@ -713,11 +681,14 @@ def test_coordinates(setup_path):
 
 
 def test_start_stop_table(setup_path):
-
     with ensure_clean_store(setup_path) as store:
-
         # table
-        df = DataFrame({"A": np.random.rand(20), "B": np.random.rand(20)})
+        df = DataFrame(
+            {
+                "A": np.random.default_rng(2).random(20),
+                "B": np.random.default_rng(2).random(20),
+            }
+        )
         store.append("df", df)
 
         result = store.select("df", "columns=['A']", start=0, stop=5)
@@ -732,10 +703,8 @@ def test_start_stop_table(setup_path):
 
 
 def test_start_stop_multiple(setup_path):
-
     # GH 16209
     with ensure_clean_store(setup_path) as store:
-
         df = DataFrame({"foo": [1, 2], "bar": [1, 2]})
 
         store.append_to_multiple(
@@ -749,12 +718,13 @@ def test_start_stop_multiple(setup_path):
 
 
 def test_start_stop_fixed(setup_path):
-
     with ensure_clean_store(setup_path) as store:
-
         # fixed, GH 8287
         df = DataFrame(
-            {"A": np.random.rand(20), "B": np.random.rand(20)},
+            {
+                "A": np.random.default_rng(2).random(20),
+                "B": np.random.default_rng(2).random(20),
+            },
             index=date_range("20130101", periods=20),
         )
         store.put("df", df)
@@ -790,8 +760,7 @@ def test_start_stop_fixed(setup_path):
 
 
 def test_select_filter_corner(setup_path):
-
-    df = DataFrame(np.random.randn(50, 100))
+    df = DataFrame(np.random.default_rng(2).standard_normal((50, 100)))
     df.index = [f"{c:3d}" for c in df.index]
     df.columns = [f"{c:3d}" for c in df.columns]
 
@@ -807,7 +776,7 @@ def test_select_filter_corner(setup_path):
         tm.assert_frame_equal(result, df.loc[:, df.columns[:75:2]])
 
 
-def test_path_pathlib(setup_path):
+def test_path_pathlib():
     df = tm.makeDataFrame()
 
     result = tm.round_trip_pathlib(
@@ -833,7 +802,7 @@ def test_contiguous_mixed_data_table(start, stop, setup_path):
         tm.assert_frame_equal(df[start:stop], result)
 
 
-def test_path_pathlib_hdfstore(setup_path):
+def test_path_pathlib_hdfstore():
     df = tm.makeDataFrame()
 
     def writer(path):
@@ -848,7 +817,7 @@ def test_path_pathlib_hdfstore(setup_path):
     tm.assert_frame_equal(df, result)
 
 
-def test_pickle_path_localpath(setup_path):
+def test_pickle_path_localpath():
     df = tm.makeDataFrame()
     result = tm.round_trip_pathlib(
         lambda p: df.to_hdf(p, "df"), lambda p: read_hdf(p, "df")
@@ -856,7 +825,7 @@ def test_pickle_path_localpath(setup_path):
     tm.assert_frame_equal(df, result)
 
 
-def test_path_localpath_hdfstore(setup_path):
+def test_path_localpath_hdfstore():
     df = tm.makeDataFrame()
 
     def writer(path):
@@ -871,113 +840,92 @@ def test_path_localpath_hdfstore(setup_path):
     tm.assert_frame_equal(df, result)
 
 
-def test_copy(setup_path):
+@pytest.mark.parametrize("propindexes", [True, False])
+def test_copy(propindexes):
+    df = tm.makeDataFrame()
 
-    with catch_warnings(record=True):
-
-        def do_copy(f, new_f=None, keys=None, propindexes=True, **kwargs):
-            try:
-                store = HDFStore(f, "r")
-
-                if new_f is None:
-                    import tempfile
-
-                    fd, new_f = tempfile.mkstemp()
-                tstore = store.copy(new_f, keys=keys, propindexes=propindexes, **kwargs)
-
-                # check keys
-                if keys is None:
-                    keys = store.keys()
-                assert set(keys) == set(tstore.keys())
-
-                # check indices & nrows
-                for k in tstore.keys():
-                    if tstore.get_storer(k).is_table:
-                        new_t = tstore.get_storer(k)
-                        orig_t = store.get_storer(k)
-
-                        assert orig_t.nrows == new_t.nrows
-
-                        # check propindixes
-                        if propindexes:
-                            for a in orig_t.axes:
-                                if a.is_indexed:
-                                    assert new_t[a.name].is_indexed
-
-            finally:
-                safe_close(store)
-                safe_close(tstore)
-                try:
-                    os.close(fd)
-                except (OSError, ValueError):
-                    pass
-                os.remove(new_f)  # noqa: PDF008
-
-        # new table
-        df = tm.makeDataFrame()
-
-        with tm.ensure_clean() as path:
-            st = HDFStore(path)
+    with tm.ensure_clean() as path:
+        with HDFStore(path) as st:
             st.append("df", df, data_columns=["A"])
-            st.close()
-            do_copy(f=path)
-            do_copy(f=path, propindexes=False)
+        with tempfile.NamedTemporaryFile() as new_f:
+            with HDFStore(path) as store:
+                with contextlib.closing(
+                    store.copy(new_f.name, keys=None, propindexes=propindexes)
+                ) as tstore:
+                    # check keys
+                    keys = store.keys()
+                    assert set(keys) == set(tstore.keys())
+                    # check indices & nrows
+                    for k in tstore.keys():
+                        if tstore.get_storer(k).is_table:
+                            new_t = tstore.get_storer(k)
+                            orig_t = store.get_storer(k)
+
+                            assert orig_t.nrows == new_t.nrows
+
+                            # check propindixes
+                            if propindexes:
+                                for a in orig_t.axes:
+                                    if a.is_indexed:
+                                        assert new_t[a.name].is_indexed
 
 
-def test_duplicate_column_name(setup_path):
+def test_duplicate_column_name(tmp_path, setup_path):
     df = DataFrame(columns=["a", "a"], data=[[0, 0]])
 
-    with ensure_clean_path(setup_path) as path:
-        msg = "Columns index has to be unique for fixed format"
-        with pytest.raises(ValueError, match=msg):
-            df.to_hdf(path, "df", format="fixed")
+    path = tmp_path / setup_path
+    msg = "Columns index has to be unique for fixed format"
+    with pytest.raises(ValueError, match=msg):
+        df.to_hdf(path, "df", format="fixed")
 
-        df.to_hdf(path, "df", format="table")
-        other = read_hdf(path, "df")
+    df.to_hdf(path, "df", format="table")
+    other = read_hdf(path, "df")
 
-        tm.assert_frame_equal(df, other)
-        assert df.equals(other)
-        assert other.equals(df)
+    tm.assert_frame_equal(df, other)
+    assert df.equals(other)
+    assert other.equals(df)
 
 
 def test_preserve_timedeltaindex_type(setup_path):
     # GH9635
-    df = DataFrame(np.random.normal(size=(10, 5)))
+    df = DataFrame(np.random.default_rng(2).normal(size=(10, 5)))
     df.index = timedelta_range(start="0s", periods=10, freq="1s", name="example")
 
     with ensure_clean_store(setup_path) as store:
-
         store["df"] = df
         tm.assert_frame_equal(store["df"], df)
 
 
-def test_columns_multiindex_modified(setup_path):
+def test_columns_multiindex_modified(tmp_path, setup_path):
     # BUG: 7212
 
-    df = DataFrame(np.random.rand(4, 5), index=list("abcd"), columns=list("ABCDE"))
+    df = DataFrame(
+        np.random.default_rng(2).random((4, 5)),
+        index=list("abcd"),
+        columns=list("ABCDE"),
+    )
     df.index.name = "letters"
     df = df.set_index(keys="E", append=True)
 
     data_columns = df.index.names + df.columns.tolist()
-    with ensure_clean_path(setup_path) as path:
-        df.to_hdf(
-            path,
-            "df",
-            mode="a",
-            append=True,
-            data_columns=data_columns,
-            index=False,
-        )
-        cols2load = list("BCD")
-        cols2load_original = list(cols2load)
-        df_loaded = read_hdf(path, "df", columns=cols2load)  # noqa
-        assert cols2load_original == cols2load
+    path = tmp_path / setup_path
+    df.to_hdf(
+        path,
+        "df",
+        mode="a",
+        append=True,
+        data_columns=data_columns,
+        index=False,
+    )
+    cols2load = list("BCD")
+    cols2load_original = list(cols2load)
+    # GH#10055 make sure read_hdf call does not alter cols2load inplace
+    read_hdf(path, "df", columns=cols2load)
+    assert cols2load_original == cols2load
 
 
-pytest.mark.filterwarnings("ignore:object name:tables.exceptions.NaturalNameWarning")
-
-
-def test_to_hdf_with_object_column_names(setup_path):
+@pytest.mark.filterwarnings(r"ignore:PeriodDtype\[B\] is deprecated:FutureWarning")
+def test_to_hdf_with_object_column_names(tmp_path, setup_path):
     # GH9057
 
     types_should_fail = [
@@ -990,21 +938,43 @@ def test_to_hdf_with_object_column_names(setup_path):
     types_should_run = [
         tm.makeStringIndex,
         tm.makeCategoricalIndex,
-        tm.makeUnicodeIndex,
     ]
 
     for index in types_should_fail:
-        df = DataFrame(np.random.randn(10, 2), columns=index(2))
-        with ensure_clean_path(setup_path) as path:
-            with catch_warnings(record=True):
-                msg = "cannot have non-object label DataIndexableCol"
-                with pytest.raises(ValueError, match=msg):
-                    df.to_hdf(path, "df", format="table", data_columns=True)
+        df = DataFrame(
+            np.random.default_rng(2).standard_normal((10, 2)), columns=index(2)
+        )
+        path = tmp_path / setup_path
+        msg = "cannot have non-object label DataIndexableCol"
+        with pytest.raises(ValueError, match=msg):
+            df.to_hdf(path, "df", format="table", data_columns=True)
 
     for index in types_should_run:
-        df = DataFrame(np.random.randn(10, 2), columns=index(2))
-        with ensure_clean_path(setup_path) as path:
-            with catch_warnings(record=True):
-                df.to_hdf(path, "df", format="table", data_columns=True)
-                result = read_hdf(path, "df", where=f"index = [{df.index[0]}]")
-                assert len(result)
+        df = DataFrame(
+            np.random.default_rng(2).standard_normal((10, 2)), columns=index(2)
+        )
+        path = tmp_path / setup_path
+        df.to_hdf(path, "df", format="table", data_columns=True)
+        result = read_hdf(path, "df", where=f"index = [{df.index[0]}]")
+        assert len(result)
+
+
+def test_hdfstore_strides(setup_path):
+    # GH22073
+    df = DataFrame({"a": [1, 2, 3, 4], "b": [5, 6, 7, 8]})
+    with ensure_clean_store(setup_path) as store:
+        store.put("df", df)
+        assert df["a"].values.strides == store["df"]["a"].values.strides
+
+
+def test_store_bool_index(tmp_path, setup_path):
+    # GH#48667
+    df = DataFrame([[1]], columns=[True], index=Index([False], dtype="bool"))
+    expected = df.copy()
+
+    # # Test to make sure defaults are to not drop.
+    # # Corresponding to Issue 9382
+    path = tmp_path / setup_path
+    df.to_hdf(path, "a")
+    result = read_hdf(path, "a")
+    tm.assert_frame_equal(expected, result)
