@@ -11,14 +11,19 @@ from pandas import (
     Series,
     Timestamp,
     interval_range,
+    plotting,
 )
 import pandas._testing as tm
 from pandas.tests.plotting.common import (
-    TestPlotBase,
+    _check_colors,
+    _check_legend_labels,
     _check_plot_works,
+    _check_text_labels,
+    _check_ticks_props,
 )
 
-import pandas.plotting as plotting
+mpl = pytest.importorskip("matplotlib")
+cm = pytest.importorskip("matplotlib.cm")
 
 
 @td.skip_if_mpl
@@ -64,8 +69,7 @@ def test_get_accessor_args():
     assert len(kwargs) == 24
 
 
-@td.skip_if_no_mpl
-class TestSeriesPlots(TestPlotBase):
+class TestSeriesPlots:
     def test_autocorrelation_plot(self):
         from pandas.plotting import autocorrelation_plot
 
@@ -76,7 +80,7 @@ class TestSeriesPlots(TestPlotBase):
             _check_plot_works(autocorrelation_plot, series=ser.values)
 
             ax = autocorrelation_plot(ser, label="Test")
-        self._check_legend_labels(ax, labels=["Test"])
+        _check_legend_labels(ax, labels=["Test"])
 
     @pytest.mark.parametrize("kwargs", [{}, {"lag": 5}])
     def test_lag_plot(self, kwargs):
@@ -92,56 +96,59 @@ class TestSeriesPlots(TestPlotBase):
         _check_plot_works(bootstrap_plot, series=ser, size=10)
 
 
-@td.skip_if_no_mpl
-class TestDataFramePlots(TestPlotBase):
-    @td.skip_if_no_scipy
+class TestDataFramePlots:
     @pytest.mark.parametrize("pass_axis", [False, True])
     def test_scatter_matrix_axis(self, pass_axis):
+        pytest.importorskip("scipy")
         scatter_matrix = plotting.scatter_matrix
 
         ax = None
         if pass_axis:
-            _, ax = self.plt.subplots(3, 3)
+            _, ax = mpl.pyplot.subplots(3, 3)
 
-        with tm.RNGContext(42):
-            df = DataFrame(np.random.randn(100, 3))
+        df = DataFrame(np.random.default_rng(2).standard_normal((100, 3)))
 
         # we are plotting multiples on a sub-plot
         with tm.assert_produces_warning(UserWarning, check_stacklevel=False):
             axes = _check_plot_works(
                 scatter_matrix,
-                filterwarnings="always",
                 frame=df,
                 range_padding=0.1,
                 ax=ax,
             )
         axes0_labels = axes[0][0].yaxis.get_majorticklabels()
-
         # GH 5662
         expected = ["-2", "0", "2"]
-        self._check_text_labels(axes0_labels, expected)
-        self._check_ticks_props(axes, xlabelsize=8, xrot=90, ylabelsize=8, yrot=0)
+        _check_text_labels(axes0_labels, expected)
+        _check_ticks_props(axes, xlabelsize=8, xrot=90, ylabelsize=8, yrot=0)
 
+    @pytest.mark.parametrize("pass_axis", [False, True])
+    def test_scatter_matrix_axis_smaller(self, pass_axis):
+        pytest.importorskip("scipy")
+        scatter_matrix = plotting.scatter_matrix
+
+        ax = None
+        if pass_axis:
+            _, ax = mpl.pyplot.subplots(3, 3)
+
+        df = DataFrame(np.random.default_rng(11).standard_normal((100, 3)))
         df[0] = (df[0] - 2) / 3
 
         # we are plotting multiples on a sub-plot
         with tm.assert_produces_warning(UserWarning, check_stacklevel=False):
             axes = _check_plot_works(
                 scatter_matrix,
-                filterwarnings="always",
                 frame=df,
                 range_padding=0.1,
                 ax=ax,
             )
         axes0_labels = axes[0][0].yaxis.get_majorticklabels()
         expected = ["-1.0", "-0.5", "0.0"]
-        self._check_text_labels(axes0_labels, expected)
-        self._check_ticks_props(axes, xlabelsize=8, xrot=90, ylabelsize=8, yrot=0)
+        _check_text_labels(axes0_labels, expected)
+        _check_ticks_props(axes, xlabelsize=8, xrot=90, ylabelsize=8, yrot=0)
 
     @pytest.mark.slow
-    def test_andrews_curves(self, iris):
-        from matplotlib import cm
-
+    def test_andrews_curves_no_warning(self, iris):
         from pandas.plotting import andrews_curves
 
         df = iris
@@ -149,118 +156,130 @@ class TestDataFramePlots(TestPlotBase):
         with tm.assert_produces_warning(None):
             _check_plot_works(andrews_curves, frame=df, class_column="Name")
 
-        rgba = ("#556270", "#4ECDC4", "#C7F464")
+    @pytest.mark.slow
+    @pytest.mark.parametrize(
+        "linecolors",
+        [
+            ("#556270", "#4ECDC4", "#C7F464"),
+            ["dodgerblue", "aquamarine", "seagreen"],
+        ],
+    )
+    @pytest.mark.parametrize(
+        "df",
+        [
+            "iris",
+            DataFrame(
+                {
+                    "A": np.random.default_rng(2).standard_normal(10),
+                    "B": np.random.default_rng(2).standard_normal(10),
+                    "C": np.random.default_rng(2).standard_normal(10),
+                    "Name": ["A"] * 10,
+                }
+            ),
+        ],
+    )
+    def test_andrews_curves_linecolors(self, request, df, linecolors):
+        from pandas.plotting import andrews_curves
+
+        if isinstance(df, str):
+            df = request.getfixturevalue(df)
         ax = _check_plot_works(
-            andrews_curves, frame=df, class_column="Name", color=rgba
+            andrews_curves, frame=df, class_column="Name", color=linecolors
         )
-        self._check_colors(
-            ax.get_lines()[:10], linecolors=rgba, mapping=df["Name"][:10]
+        _check_colors(
+            ax.get_lines()[:10], linecolors=linecolors, mapping=df["Name"][:10]
         )
 
-        cnames = ["dodgerblue", "aquamarine", "seagreen"]
-        ax = _check_plot_works(
-            andrews_curves, frame=df, class_column="Name", color=cnames
-        )
-        self._check_colors(
-            ax.get_lines()[:10], linecolors=cnames, mapping=df["Name"][:10]
-        )
+    @pytest.mark.slow
+    @pytest.mark.parametrize(
+        "df",
+        [
+            "iris",
+            DataFrame(
+                {
+                    "A": np.random.default_rng(2).standard_normal(10),
+                    "B": np.random.default_rng(2).standard_normal(10),
+                    "C": np.random.default_rng(2).standard_normal(10),
+                    "Name": ["A"] * 10,
+                }
+            ),
+        ],
+    )
+    def test_andrews_curves_cmap(self, request, df):
+        from pandas.plotting import andrews_curves
 
-        ax = _check_plot_works(
-            andrews_curves, frame=df, class_column="Name", colormap=cm.jet
-        )
+        if isinstance(df, str):
+            df = request.getfixturevalue(df)
         cmaps = [cm.jet(n) for n in np.linspace(0, 1, df["Name"].nunique())]
-        self._check_colors(
-            ax.get_lines()[:10], linecolors=cmaps, mapping=df["Name"][:10]
-        )
-
-        length = 10
-        df = DataFrame(
-            {
-                "A": np.random.rand(length),
-                "B": np.random.rand(length),
-                "C": np.random.rand(length),
-                "Name": ["A"] * length,
-            }
-        )
-
-        _check_plot_works(andrews_curves, frame=df, class_column="Name")
-
-        rgba = ("#556270", "#4ECDC4", "#C7F464")
         ax = _check_plot_works(
-            andrews_curves, frame=df, class_column="Name", color=rgba
-        )
-        self._check_colors(
-            ax.get_lines()[:10], linecolors=rgba, mapping=df["Name"][:10]
+            andrews_curves, frame=df, class_column="Name", color=cmaps
         )
+        _check_colors(ax.get_lines()[:10], linecolors=cmaps, mapping=df["Name"][:10])
 
-        cnames = ["dodgerblue", "aquamarine", "seagreen"]
-        ax = _check_plot_works(
-            andrews_curves, frame=df, class_column="Name", color=cnames
-        )
-        self._check_colors(
-            ax.get_lines()[:10], linecolors=cnames, mapping=df["Name"][:10]
-        )
-
-        ax = _check_plot_works(
-            andrews_curves, frame=df, class_column="Name", colormap=cm.jet
-        )
-        cmaps = [cm.jet(n) for n in np.linspace(0, 1, df["Name"].nunique())]
-        self._check_colors(
-            ax.get_lines()[:10], linecolors=cmaps, mapping=df["Name"][:10]
-        )
+    @pytest.mark.slow
+    def test_andrews_curves_handle(self):
+        from pandas.plotting import andrews_curves
 
         colors = ["b", "g", "r"]
         df = DataFrame({"A": [1, 2, 3], "B": [1, 2, 3], "C": [1, 2, 3], "Name": colors})
         ax = andrews_curves(df, "Name", color=colors)
-        handles, labels = ax.get_legend_handles_labels()
-        self._check_colors(handles, linecolors=colors)
+        handles, _ = ax.get_legend_handles_labels()
+        _check_colors(handles, linecolors=colors)
 
     @pytest.mark.slow
-    def test_parallel_coordinates(self, iris):
+    @pytest.mark.parametrize(
+        "color",
+        [("#556270", "#4ECDC4", "#C7F464"), ["dodgerblue", "aquamarine", "seagreen"]],
+    )
+    def test_parallel_coordinates_colors(self, iris, color):
+        from pandas.plotting import parallel_coordinates
+
+        df = iris
+
+        ax = _check_plot_works(
+            parallel_coordinates, frame=df, class_column="Name", color=color
+        )
+        _check_colors(ax.get_lines()[:10], linecolors=color, mapping=df["Name"][:10])
+
+    @pytest.mark.slow
+    def test_parallel_coordinates_cmap(self, iris):
         from matplotlib import cm
 
         from pandas.plotting import parallel_coordinates
 
         df = iris
 
+        ax = _check_plot_works(
+            parallel_coordinates, frame=df, class_column="Name", colormap=cm.jet
+        )
+        cmaps = [cm.jet(n) for n in np.linspace(0, 1, df["Name"].nunique())]
+        _check_colors(ax.get_lines()[:10], linecolors=cmaps, mapping=df["Name"][:10])
+
+    @pytest.mark.slow
+    def test_parallel_coordinates_line_diff(self, iris):
+        from pandas.plotting import parallel_coordinates
+
+        df = iris
+
         ax = _check_plot_works(parallel_coordinates, frame=df, class_column="Name")
         nlines = len(ax.get_lines())
         nxticks = len(ax.xaxis.get_ticklabels())
 
-        rgba = ("#556270", "#4ECDC4", "#C7F464")
-        ax = _check_plot_works(
-            parallel_coordinates, frame=df, class_column="Name", color=rgba
-        )
-        self._check_colors(
-            ax.get_lines()[:10], linecolors=rgba, mapping=df["Name"][:10]
-        )
-
-        cnames = ["dodgerblue", "aquamarine", "seagreen"]
-        ax = _check_plot_works(
-            parallel_coordinates, frame=df, class_column="Name", color=cnames
-        )
-        self._check_colors(
-            ax.get_lines()[:10], linecolors=cnames, mapping=df["Name"][:10]
-        )
-
-        ax = _check_plot_works(
-            parallel_coordinates, frame=df, class_column="Name", colormap=cm.jet
-        )
-        cmaps = [cm.jet(n) for n in np.linspace(0, 1, df["Name"].nunique())]
-        self._check_colors(
-            ax.get_lines()[:10], linecolors=cmaps, mapping=df["Name"][:10]
-        )
-
         ax = _check_plot_works(
             parallel_coordinates, frame=df, class_column="Name", axvlines=False
         )
         assert len(ax.get_lines()) == (nlines - nxticks)
 
+    @pytest.mark.slow
+    def test_parallel_coordinates_handles(self, iris):
+        from pandas.plotting import parallel_coordinates
+
+        df = iris
         colors = ["b", "g", "r"]
         df = DataFrame({"A": [1, 2, 3], "B": [1, 2, 3], "C": [1, 2, 3], "Name": colors})
         ax = parallel_coordinates(df, "Name", color=colors)
-        handles, labels = ax.get_legend_handles_labels()
-        self._check_colors(handles, linecolors=colors)
+        handles, _ = ax.get_legend_handles_labels()
+        _check_colors(handles, linecolors=colors)
 
     # not sure if this is indicative of a problem
     @pytest.mark.filterwarnings("ignore:Attempting to set:UserWarning")
@@ -289,9 +308,7 @@ class TestDataFramePlots(TestPlotBase):
             # labels and colors are ordered strictly increasing
             assert prev[1] < nxt[1] and prev[0] < nxt[0]
 
-    def test_radviz(self, iris):
-        from matplotlib import cm
-
+    def test_radviz_no_warning(self, iris):
         from pandas.plotting import radviz
 
         df = iris
@@ -299,29 +316,40 @@ class TestDataFramePlots(TestPlotBase):
         with tm.assert_produces_warning(None):
             _check_plot_works(radviz, frame=df, class_column="Name")
 
-        rgba = ("#556270", "#4ECDC4", "#C7F464")
-        ax = _check_plot_works(radviz, frame=df, class_column="Name", color=rgba)
+    @pytest.mark.parametrize(
+        "color",
+        [("#556270", "#4ECDC4", "#C7F464"), ["dodgerblue", "aquamarine", "seagreen"]],
+    )
+    def test_radviz_color(self, iris, color):
+        from pandas.plotting import radviz
+
+        df = iris
+        ax = _check_plot_works(radviz, frame=df, class_column="Name", color=color)
         # skip Circle drawn as ticks
         patches = [p for p in ax.patches[:20] if p.get_label() != ""]
-        self._check_colors(patches[:10], facecolors=rgba, mapping=df["Name"][:10])
+        _check_colors(patches[:10], facecolors=color, mapping=df["Name"][:10])
 
-        cnames = ["dodgerblue", "aquamarine", "seagreen"]
-        _check_plot_works(radviz, frame=df, class_column="Name", color=cnames)
-        patches = [p for p in ax.patches[:20] if p.get_label() != ""]
-        self._check_colors(patches, facecolors=cnames, mapping=df["Name"][:10])
+    def test_radviz_color_cmap(self, iris):
+        from matplotlib import cm
 
-        _check_plot_works(radviz, frame=df, class_column="Name", colormap=cm.jet)
+        from pandas.plotting import radviz
+
+        df = iris
+        ax = _check_plot_works(radviz, frame=df, class_column="Name", colormap=cm.jet)
         cmaps = [cm.jet(n) for n in np.linspace(0, 1, df["Name"].nunique())]
         patches = [p for p in ax.patches[:20] if p.get_label() != ""]
-        self._check_colors(patches, facecolors=cmaps, mapping=df["Name"][:10])
+        _check_colors(patches, facecolors=cmaps, mapping=df["Name"][:10])
+
+    def test_radviz_colors_handles(self):
+        from pandas.plotting import radviz
 
         colors = [[0.0, 0.0, 1.0, 1.0], [0.0, 0.5, 1.0, 1.0], [1.0, 0.0, 0.0, 1.0]]
         df = DataFrame(
             {"A": [1, 2, 3], "B": [2, 1, 3], "C": [3, 2, 1], "Name": ["b", "g", "r"]}
         )
         ax = radviz(df, "Name", color=colors)
-        handles, labels = ax.get_legend_handles_labels()
-        self._check_colors(handles, facecolors=colors)
+        handles, _ = ax.get_legend_handles_labels()
+        _check_colors(handles, facecolors=colors)
 
     def test_subplot_titles(self, iris):
         df = iris.drop("Name", axis=1).head()
@@ -332,6 +360,10 @@ class TestDataFramePlots(TestPlotBase):
         plot = df.plot(subplots=True, title=title)
         assert [p.get_title() for p in plot] == title
 
+    def test_subplot_titles_too_much(self, iris):
+        df = iris.drop("Name", axis=1).head()
+        # Use the column names as the subplot titles
+        title = list(df.columns)
         # Case len(title) > len(df)
         msg = (
             "The length of `title` must equal the number of columns if "
@@ -340,10 +372,22 @@ class TestDataFramePlots(TestPlotBase):
         with pytest.raises(ValueError, match=msg):
             df.plot(subplots=True, title=title + ["kittens > puppies"])
 
+    def test_subplot_titles_too_little(self, iris):
+        df = iris.drop("Name", axis=1).head()
+        # Use the column names as the subplot titles
+        title = list(df.columns)
+        msg = (
+            "The length of `title` must equal the number of columns if "
+            "using `title` of type `list` and `subplots=True`"
+        )
         # Case len(title) < len(df)
         with pytest.raises(ValueError, match=msg):
             df.plot(subplots=True, title=title[:2])
 
+    def test_subplot_titles_subplots_false(self, iris):
+        df = iris.drop("Name", axis=1).head()
+        # Use the column names as the subplot titles
+        title = list(df.columns)
         # Case subplots=False and title is of type list
         msg = (
             "Using `title` of type `list` is not supported unless "
@@ -352,6 +396,10 @@ class TestDataFramePlots(TestPlotBase):
         with pytest.raises(ValueError, match=msg):
             df.plot(subplots=False, title=title)
 
+    def test_subplot_titles_numeric_square_layout(self, iris):
+        df = iris.drop("Name", axis=1).head()
+        # Use the column names as the subplot titles
+        title = list(df.columns)
         # Case df with 3 numeric columns but layout of (2,2)
         plot = df.drop("SepalWidth", axis=1).plot(
             subplots=True, layout=(2, 2), title=title[:-1]
@@ -363,13 +411,15 @@ class TestDataFramePlots(TestPlotBase):
         # GH17525
         df = DataFrame(np.zeros((10, 10)))
 
-        # Make sure that the np.random.seed isn't reset by get_standard_colors
+        # Make sure that the random seed isn't reset by get_standard_colors
         plotting.parallel_coordinates(df, 0)
-        rand1 = np.random.random()
+        rand1 = np.random.default_rng(None).random()
         plotting.parallel_coordinates(df, 0)
-        rand2 = np.random.random()
+        rand2 = np.random.default_rng(None).random()
         assert rand1 != rand2
 
+    def test_get_standard_colors_consistency(self):
+        # GH17525
         # Make sure it produces the same colors every time it's called
         from pandas.plotting._matplotlib.style import get_standard_colors
 
@@ -417,30 +467,30 @@ class TestDataFramePlots(TestPlotBase):
         color_after = get_standard_colors(1, color=color_before)
         assert len(color_after) == len(color_before)
 
-        df = DataFrame(np.random.randn(48, 4), columns=list("ABCD"))
+        df = DataFrame(
+            np.random.default_rng(2).standard_normal((48, 4)), columns=list("ABCD")
+        )
 
         color_list = cm.gnuplot(np.linspace(0, 1, 16))
         p = df.A.plot.bar(figsize=(16, 7), color=color_list)
         assert p.patches[1].get_facecolor() == p.patches[17].get_facecolor()
 
-    def test_dictionary_color(self):
+    @pytest.mark.parametrize("kind", ["bar", "line"])
+    def test_dictionary_color(self, kind):
         # issue-8193
         # Test plot color dictionary format
         data_files = ["a", "b"]
 
         expected = [(0.5, 0.24, 0.6), (0.3, 0.7, 0.7)]
 
-        df1 = DataFrame(np.random.rand(2, 2), columns=data_files)
+        df1 = DataFrame(np.random.default_rng(2).random((2, 2)), columns=data_files)
         dic_color = {"b": (0.3, 0.7, 0.7), "a": (0.5, 0.24, 0.6)}
 
-        # Bar color test
-        ax = df1.plot(kind="bar", color=dic_color)
-        colors = [rect.get_facecolor()[0:-1] for rect in ax.get_children()[0:3:2]]
-        assert all(color == expected[index] for index, color in enumerate(colors))
-
-        # Line color test
-        ax = df1.plot(kind="line", color=dic_color)
-        colors = [rect.get_color() for rect in ax.get_lines()[0:2]]
+        ax = df1.plot(kind=kind, color=dic_color)
+        if kind == "bar":
+            colors = [rect.get_facecolor()[0:-1] for rect in ax.get_children()[0:3:2]]
+        else:
+            colors = [rect.get_color() for rect in ax.get_lines()[0:2]]
         assert all(color == expected[index] for index, color in enumerate(colors))
 
     def test_bar_plot(self):
@@ -482,7 +532,7 @@ class TestDataFramePlots(TestPlotBase):
         # Test _has_externally_shared_axis() works for x-axis
         func = plotting._matplotlib.tools._has_externally_shared_axis
 
-        fig = self.plt.figure()
+        fig = mpl.pyplot.figure()
         plots = fig.subplots(2, 4)
 
         # Create *externally* shared axes for first and third columns
@@ -507,7 +557,7 @@ class TestDataFramePlots(TestPlotBase):
         # Test _has_externally_shared_axis() works for y-axis
         func = plotting._matplotlib.tools._has_externally_shared_axis
 
-        fig = self.plt.figure()
+        fig = mpl.pyplot.figure()
         plots = fig.subplots(4, 2)
 
         # Create *externally* shared axes for first and third rows
@@ -533,7 +583,7 @@ class TestDataFramePlots(TestPlotBase):
         # passed an invalid value as compare_axis parameter
         func = plotting._matplotlib.tools._has_externally_shared_axis
 
-        fig = self.plt.figure()
+        fig = mpl.pyplot.figure()
         plots = fig.subplots(4, 2)
 
         # Create arbitrary axes
@@ -547,10 +597,15 @@ class TestDataFramePlots(TestPlotBase):
     def test_externally_shared_axes(self):
         # Example from GH33819
         # Create data
-        df = DataFrame({"a": np.random.randn(1000), "b": np.random.randn(1000)})
+        df = DataFrame(
+            {
+                "a": np.random.default_rng(2).standard_normal(1000),
+                "b": np.random.default_rng(2).standard_normal(1000),
+            }
+        )
 
         # Create figure
-        fig = self.plt.figure()
+        fig = mpl.pyplot.figure()
         plots = fig.subplots(2, 3)
 
         # Create *externally* shared axes
