@@ -27,7 +27,7 @@ from pandas.core.indexes.period import (
 )
 from pandas.core.resample import _get_period_range_edges
 
-import pandas.tseries.offsets as offsets
+from pandas.tseries import offsets
 
 
 @pytest.fixture()
@@ -53,7 +53,7 @@ class TestPeriodIndex:
         else:
             start = obj.index[0].to_timestamp(how="start")
             end = (obj.index[-1] + obj.index.freq).to_timestamp(how="start")
-            new_index = date_range(start=start, end=end, freq=freq, closed="left")
+            new_index = date_range(start=start, end=end, freq=freq, inclusive="left")
             expected = obj.to_timestamp().reindex(new_index).to_period(freq)
         result = obj.resample(freq, kind=kind).asfreq()
         tm.assert_almost_equal(result, expected)
@@ -108,10 +108,12 @@ class TestPeriodIndex:
         self, targ, conv, meth, month, simple_period_range_series
     ):
         ts = simple_period_range_series("1/1/1990", "12/31/1991", freq=f"A-{month}")
-
-        result = getattr(ts.resample(targ, convention=conv), meth)()
-        expected = result.to_timestamp(targ, how=conv)
-        expected = expected.asfreq(targ, meth).to_period()
+        warn = FutureWarning if targ == "B" else None
+        msg = r"PeriodDtype\[B\] is deprecated"
+        with tm.assert_produces_warning(warn, match=msg):
+            result = getattr(ts.resample(targ, convention=conv), meth)()
+            expected = result.to_timestamp(targ, how=conv)
+            expected = expected.asfreq(targ, meth).to_period()
         tm.assert_series_equal(result, expected)
 
     def test_basic_downsample(self, simple_period_range_series):
@@ -157,7 +159,7 @@ class TestPeriodIndex:
 
     def test_upsample_with_limit(self):
         rng = period_range("1/1/2000", periods=5, freq="A")
-        ts = Series(np.random.randn(len(rng)), rng)
+        ts = Series(np.random.default_rng(2).standard_normal(len(rng)), rng)
 
         result = ts.resample("M", convention="end").ffill(limit=2)
         expected = ts.asfreq("M").reindex(result.index, method="ffill", limit=2)
@@ -187,18 +189,25 @@ class TestPeriodIndex:
     ):
         freq = f"Q-{month}"
         ts = simple_period_range_series("1/1/1990", "12/31/1995", freq=freq)
-        result = ts.resample(target, convention=convention).ffill()
-        expected = result.to_timestamp(target, how=convention)
-        expected = expected.asfreq(target, "ffill").to_period()
+        warn = FutureWarning if target == "B" else None
+        msg = r"PeriodDtype\[B\] is deprecated"
+        with tm.assert_produces_warning(warn, match=msg):
+            result = ts.resample(target, convention=convention).ffill()
+            expected = result.to_timestamp(target, how=convention)
+            expected = expected.asfreq(target, "ffill").to_period()
         tm.assert_series_equal(result, expected)
 
     @pytest.mark.parametrize("target", ["D", "B"])
     @pytest.mark.parametrize("convention", ["start", "end"])
     def test_monthly_upsample(self, target, convention, simple_period_range_series):
         ts = simple_period_range_series("1/1/1990", "12/31/1995", freq="M")
-        result = ts.resample(target, convention=convention).ffill()
-        expected = result.to_timestamp(target, how=convention)
-        expected = expected.asfreq(target, "ffill").to_period()
+
+        warn = None if target == "D" else FutureWarning
+        msg = r"PeriodDtype\[B\] is deprecated"
+        with tm.assert_produces_warning(warn, match=msg):
+            result = ts.resample(target, convention=convention).ffill()
+            expected = result.to_timestamp(target, how=convention)
+            expected = expected.asfreq(target, "ffill").to_period()
         tm.assert_series_equal(result, expected)
 
     def test_resample_basic(self):
@@ -233,7 +242,6 @@ class TestPeriodIndex:
         tm.assert_series_equal(result, expected)
 
     def test_resample_same_freq(self, resample_method):
-
         # GH12770
         series = Series(range(3), index=period_range(start="2000", periods=3, freq="M"))
         expected = series
@@ -335,7 +343,7 @@ class TestPeriodIndex:
             freq="D",
             tz="America/Sao_Paulo",
             nonexistent="shift_forward",
-            closed="left",
+            inclusive="left",
         )
         tm.assert_index_equal(result.index, expected)
 
@@ -364,9 +372,13 @@ class TestPeriodIndex:
     def test_weekly_upsample(self, day, target, convention, simple_period_range_series):
         freq = f"W-{day}"
         ts = simple_period_range_series("1/1/1990", "12/31/1995", freq=freq)
-        result = ts.resample(target, convention=convention).ffill()
-        expected = result.to_timestamp(target, how=convention)
-        expected = expected.asfreq(target, "ffill").to_period()
+
+        warn = None if target == "D" else FutureWarning
+        msg = r"PeriodDtype\[B\] is deprecated"
+        with tm.assert_produces_warning(warn, match=msg):
+            result = ts.resample(target, convention=convention).ffill()
+            expected = result.to_timestamp(target, how=convention)
+            expected = expected.asfreq(target, "ffill").to_period()
         tm.assert_series_equal(result, expected)
 
     def test_resample_to_timestamps(self, simple_period_range_series):
@@ -376,40 +388,40 @@ class TestPeriodIndex:
         expected = ts.to_timestamp(how="start").resample("A-DEC").mean()
         tm.assert_series_equal(result, expected)
 
-    def test_resample_to_quarterly(self, simple_period_range_series):
-        for month in MONTHS:
-            ts = simple_period_range_series("1990", "1992", freq=f"A-{month}")
-            quar_ts = ts.resample(f"Q-{month}").ffill()
+    @pytest.mark.parametrize("month", MONTHS)
+    def test_resample_to_quarterly(self, simple_period_range_series, month):
+        ts = simple_period_range_series("1990", "1992", freq=f"A-{month}")
+        quar_ts = ts.resample(f"Q-{month}").ffill()
 
-            stamps = ts.to_timestamp("D", how="start")
-            qdates = period_range(
-                ts.index[0].asfreq("D", "start"),
-                ts.index[-1].asfreq("D", "end"),
-                freq=f"Q-{month}",
-            )
+        stamps = ts.to_timestamp("D", how="start")
+        qdates = period_range(
+            ts.index[0].asfreq("D", "start"),
+            ts.index[-1].asfreq("D", "end"),
+            freq=f"Q-{month}",
+        )
 
-            expected = stamps.reindex(qdates.to_timestamp("D", "s"), method="ffill")
-            expected.index = qdates
+        expected = stamps.reindex(qdates.to_timestamp("D", "s"), method="ffill")
+        expected.index = qdates
 
-            tm.assert_series_equal(quar_ts, expected)
+        tm.assert_series_equal(quar_ts, expected)
 
+    @pytest.mark.parametrize("how", ["start", "end"])
+    def test_resample_to_quarterly_start_end(self, simple_period_range_series, how):
         # conforms, but different month
         ts = simple_period_range_series("1990", "1992", freq="A-JUN")
+        result = ts.resample("Q-MAR", convention=how).ffill()
+        expected = ts.asfreq("Q-MAR", how=how)
+        expected = expected.reindex(result.index, method="ffill")
 
-        for how in ["start", "end"]:
-            result = ts.resample("Q-MAR", convention=how).ffill()
-            expected = ts.asfreq("Q-MAR", how=how)
-            expected = expected.reindex(result.index, method="ffill")
+        # .to_timestamp('D')
+        # expected = expected.resample('Q-MAR').ffill()
 
-            # .to_timestamp('D')
-            # expected = expected.resample('Q-MAR').ffill()
-
-            tm.assert_series_equal(result, expected)
+        tm.assert_series_equal(result, expected)
 
     def test_resample_fill_missing(self):
         rng = PeriodIndex([2000, 2005, 2007, 2009], freq="A")
 
-        s = Series(np.random.randn(4), index=rng)
+        s = Series(np.random.default_rng(2).standard_normal(4), index=rng)
 
         stamps = s.to_timestamp()
         filled = s.resample("A").ffill()
@@ -418,7 +430,7 @@ class TestPeriodIndex:
 
     def test_cant_fill_missing_dups(self):
         rng = PeriodIndex([2000, 2005, 2005, 2007, 2007], freq="A")
-        s = Series(np.random.randn(5), index=rng)
+        s = Series(np.random.default_rng(2).standard_normal(5), index=rng)
         msg = "Reindexing only valid with uniquely valued Index objects"
         with pytest.raises(InvalidIndexError, match=msg):
             s.resample("A").ffill()
@@ -427,7 +439,7 @@ class TestPeriodIndex:
     @pytest.mark.parametrize("kind", ["period", None, "timestamp"])
     def test_resample_5minute(self, freq, kind):
         rng = period_range("1/1/2000", "1/5/2000", freq="T")
-        ts = Series(np.random.randn(len(rng)), index=rng)
+        ts = Series(np.random.default_rng(2).standard_normal(len(rng)), index=rng)
         expected = ts.to_timestamp().resample(freq).mean()
         if kind != "timestamp":
             expected = expected.to_period(freq)
@@ -459,7 +471,7 @@ class TestPeriodIndex:
 
     def test_resample_weekly_all_na(self):
         rng = date_range("1/1/2000", periods=10, freq="W-WED")
-        ts = Series(np.random.randn(len(rng)), index=rng)
+        ts = Series(np.random.default_rng(2).standard_normal(len(rng)), index=rng)
 
         result = ts.resample("W-THU").asfreq()
 
@@ -514,8 +526,8 @@ class TestPeriodIndex:
         rng = date_range("1/1/2011", periods=20000, freq="H")
         rng = rng.tz_localize("EST")
         ts = DataFrame(index=rng)
-        ts["first"] = np.random.randn(len(rng))
-        ts["second"] = np.cumsum(np.random.randn(len(rng)))
+        ts["first"] = np.random.default_rng(2).standard_normal(len(rng))
+        ts["second"] = np.cumsum(np.random.default_rng(2).standard_normal(len(rng)))
         expected = DataFrame(
             {
                 "first": ts.resample("A").sum()["first"],
@@ -525,7 +537,7 @@ class TestPeriodIndex:
         )
         result = (
             ts.resample("A")
-            .agg({"first": np.sum, "second": np.mean})
+            .agg({"first": "sum", "second": "mean"})
             .reindex(columns=["first", "second"])
         )
         tm.assert_frame_equal(result, expected)
@@ -533,10 +545,10 @@ class TestPeriodIndex:
     def test_closed_left_corner(self):
         # #1465
         s = Series(
-            np.random.randn(21),
+            np.random.default_rng(2).standard_normal(21),
             index=date_range(start="1/1/2012 9:30", freq="1min", periods=21),
         )
-        s[0] = np.nan
+        s.iloc[0] = np.nan
 
         result = s.resample("10min", closed="left", label="right").mean()
         exp = s[1:].resample("10min", closed="left", label="right").mean()
@@ -605,64 +617,69 @@ class TestPeriodIndex:
 
     def test_resample_bms_2752(self):
         # GH2753
-        foo = Series(index=pd.bdate_range("20000101", "20000201"), dtype=np.float64)
-        res1 = foo.resample("BMS").mean()
-        res2 = foo.resample("BMS").mean().resample("B").mean()
+        timeseries = Series(
+            index=pd.bdate_range("20000101", "20000201"), dtype=np.float64
+        )
+        res1 = timeseries.resample("BMS").mean()
+        res2 = timeseries.resample("BMS").mean().resample("B").mean()
         assert res1.index[0] == Timestamp("20000103")
         assert res1.index[0] == res2.index[0]
 
-    # def test_monthly_convention_span(self):
-    #     rng = period_range('2000-01', periods=3, freq='M')
-    #     ts = Series(np.arange(3), index=rng)
+    @pytest.mark.xfail(reason="Commented out for more than 3 years. Should this work?")
+    def test_monthly_convention_span(self):
+        rng = period_range("2000-01", periods=3, freq="M")
+        ts = Series(np.arange(3), index=rng)
 
-    #     # hacky way to get same thing
-    #     exp_index = period_range('2000-01-01', '2000-03-31', freq='D')
-    #     expected = ts.asfreq('D', how='end').reindex(exp_index)
-    #     expected = expected.fillna(method='bfill')
+        # hacky way to get same thing
+        exp_index = period_range("2000-01-01", "2000-03-31", freq="D")
+        expected = ts.asfreq("D", how="end").reindex(exp_index)
+        expected = expected.fillna(method="bfill")
 
-    #     result = ts.resample('D', convention='span').mean()
+        result = ts.resample("D").mean()
 
-    #     tm.assert_series_equal(result, expected)
+        tm.assert_series_equal(result, expected)
 
-    def test_default_right_closed_label(self):
-        end_freq = ["D", "Q", "M", "D"]
-        end_types = ["M", "A", "Q", "W"]
+    @pytest.mark.parametrize(
+        "from_freq, to_freq", [("D", "M"), ("Q", "A"), ("M", "Q"), ("D", "W")]
+    )
+    def test_default_right_closed_label(self, from_freq, to_freq):
+        idx = date_range(start="8/15/2012", periods=100, freq=from_freq)
+        df = DataFrame(np.random.default_rng(2).standard_normal((len(idx), 2)), idx)
 
-        for from_freq, to_freq in zip(end_freq, end_types):
-            idx = date_range(start="8/15/2012", periods=100, freq=from_freq)
-            df = DataFrame(np.random.randn(len(idx), 2), idx)
+        resampled = df.resample(to_freq).mean()
+        tm.assert_frame_equal(
+            resampled, df.resample(to_freq, closed="right", label="right").mean()
+        )
 
-            resampled = df.resample(to_freq).mean()
-            tm.assert_frame_equal(
-                resampled, df.resample(to_freq, closed="right", label="right").mean()
-            )
+    @pytest.mark.parametrize(
+        "from_freq, to_freq",
+        [("D", "MS"), ("Q", "AS"), ("M", "QS"), ("H", "D"), ("T", "H")],
+    )
+    def test_default_left_closed_label(self, from_freq, to_freq):
+        idx = date_range(start="8/15/2012", periods=100, freq=from_freq)
+        df = DataFrame(np.random.default_rng(2).standard_normal((len(idx), 2)), idx)
 
-    def test_default_left_closed_label(self):
-        others = ["MS", "AS", "QS", "D", "H"]
-        others_freq = ["D", "Q", "M", "H", "T"]
-
-        for from_freq, to_freq in zip(others_freq, others):
-            idx = date_range(start="8/15/2012", periods=100, freq=from_freq)
-            df = DataFrame(np.random.randn(len(idx), 2), idx)
-
-            resampled = df.resample(to_freq).mean()
-            tm.assert_frame_equal(
-                resampled, df.resample(to_freq, closed="left", label="left").mean()
-            )
+        resampled = df.resample(to_freq).mean()
+        tm.assert_frame_equal(
+            resampled, df.resample(to_freq, closed="left", label="left").mean()
+        )
 
     def test_all_values_single_bin(self):
         # 2070
         index = period_range(start="2012-01-01", end="2012-12-31", freq="M")
-        s = Series(np.random.randn(len(index)), index=index)
+        s = Series(np.random.default_rng(2).standard_normal(len(index)), index=index)
 
         result = s.resample("A").mean()
-        tm.assert_almost_equal(result[0], s.mean())
+        tm.assert_almost_equal(result.iloc[0], s.mean())
 
     def test_evenly_divisible_with_no_extra_bins(self):
         # 4076
         # when the frequency is evenly divisible, sometimes extra bins
 
-        df = DataFrame(np.random.randn(9, 3), index=date_range("2000-1-1", periods=9))
+        df = DataFrame(
+            np.random.default_rng(2).standard_normal((9, 3)),
+            index=date_range("2000-1-1", periods=9),
+        )
         result = df.resample("5D").mean()
         expected = pd.concat([df.iloc[0:5].mean(), df.iloc[5:].mean()], axis=1).T
         expected.index = pd.DatetimeIndex(
@@ -776,7 +793,7 @@ class TestPeriodIndex:
     @pytest.mark.parametrize(
         "freq, expected_values",
         [
-            ("1s", [3, np.NaN, 7, 11]),
+            ("1s", [3, np.nan, 7, 11]),
             ("2s", [3, (7 + 11) / 2]),
             ("3s", [(3 + 7) / 2, 11]),
         ],
@@ -825,12 +842,12 @@ class TestPeriodIndex:
     )
     def test_resample_with_offset(self, start, end, start_freq, end_freq, offset):
         # GH 23882 & 31809
-        s = Series(0, index=period_range(start, end, freq=start_freq))
-        s = s + np.arange(len(s))
-        result = s.resample(end_freq, offset=offset).mean()
+        pi = period_range(start, end, freq=start_freq)
+        ser = Series(np.arange(len(pi)), index=pi)
+        result = ser.resample(end_freq, offset=offset).mean()
         result = result.to_timestamp(end_freq)
 
-        expected = s.to_timestamp().resample(end_freq, offset=offset).mean()
+        expected = ser.to_timestamp().resample(end_freq, offset=offset).mean()
         if end_freq == "M":
             # TODO: is non-tick the relevant characteristic? (GH 33815)
             expected.index = expected.index._with_freq(None)
