@@ -1,57 +1,64 @@
 from datetime import datetime
+import re
 
 import numpy as np
 import pytest
 
+from pandas._libs import lib
+from pandas.errors import UnsupportedFunctionCall
+
 import pandas as pd
 from pandas import (
     DataFrame,
+    NamedAgg,
     Series,
 )
 import pandas._testing as tm
 from pandas.core.indexes.datetimes import date_range
 
-dti = date_range(start=datetime(2005, 1, 1), end=datetime(2005, 1, 10), freq="Min")
 
-test_series = Series(np.random.rand(len(dti)), dti)
-_test_frame = DataFrame({"A": test_series, "B": test_series, "C": np.arange(len(dti))})
+@pytest.fixture
+def dti():
+    return date_range(start=datetime(2005, 1, 1), end=datetime(2005, 1, 10), freq="Min")
 
 
 @pytest.fixture
-def test_frame():
-    return _test_frame.copy()
+def _test_series(dti):
+    return Series(np.random.default_rng(2).random(len(dti)), dti)
 
 
-def test_str():
+@pytest.fixture
+def test_frame(dti, _test_series):
+    return DataFrame({"A": _test_series, "B": _test_series, "C": np.arange(len(dti))})
 
-    r = test_series.resample("H")
+
+def test_str(_test_series):
+    r = _test_series.resample("H")
     assert (
         "DatetimeIndexResampler [freq=<Hour>, axis=0, closed=left, "
         "label=left, convention=start, origin=start_day]" in str(r)
     )
 
-    r = test_series.resample("H", origin="2000-01-01")
+    r = _test_series.resample("H", origin="2000-01-01")
     assert (
         "DatetimeIndexResampler [freq=<Hour>, axis=0, closed=left, "
         "label=left, convention=start, origin=2000-01-01 00:00:00]" in str(r)
     )
 
 
-def test_api():
-
-    r = test_series.resample("H")
+def test_api(_test_series):
+    r = _test_series.resample("H")
     result = r.mean()
     assert isinstance(result, Series)
     assert len(result) == 217
 
-    r = test_series.to_frame().resample("H")
+    r = _test_series.to_frame().resample("H")
     result = r.mean()
     assert isinstance(result, DataFrame)
     assert len(result) == 217
 
 
 def test_groupby_resample_api():
-
     # GH 12448
     # .groupby(...).resample(...) hitting warnings
     # when appropriate
@@ -75,7 +82,6 @@ def test_groupby_resample_api():
 
 
 def test_groupby_resample_on_api():
-
     # GH 15021
     # .groupby(...).resample(on=...) results in an unexpected
     # keyword warning.
@@ -83,21 +89,43 @@ def test_groupby_resample_on_api():
         {
             "key": ["A", "B"] * 5,
             "dates": date_range("2016-01-01", periods=10),
-            "values": np.random.randn(10),
+            "values": np.random.default_rng(2).standard_normal(10),
         }
     )
 
     expected = df.set_index("dates").groupby("key").resample("D").mean()
-
     result = df.groupby("key").resample("D", on="dates").mean()
     tm.assert_frame_equal(result, expected)
 
 
-def test_pipe(test_frame):
+def test_resample_group_keys():
+    df = DataFrame({"A": 1, "B": 2}, index=date_range("2000", periods=10))
+    expected = df.copy()
+
+    # group_keys=False
+    g = df.resample("5D", group_keys=False)
+    result = g.apply(lambda x: x)
+    tm.assert_frame_equal(result, expected)
+
+    # group_keys defaults to False
+    g = df.resample("5D")
+    result = g.apply(lambda x: x)
+    tm.assert_frame_equal(result, expected)
+
+    # group_keys=True
+    expected.index = pd.MultiIndex.from_arrays(
+        [pd.to_datetime(["2000-01-01", "2000-01-06"]).repeat(5), expected.index]
+    )
+    g = df.resample("5D", group_keys=True)
+    result = g.apply(lambda x: x)
+    tm.assert_frame_equal(result, expected)
+
+
+def test_pipe(test_frame, _test_series):
     # GH17905
 
     # series
-    r = test_series.resample("H")
+    r = _test_series.resample("H")
     expected = r.max() - r.mean()
     result = r.pipe(lambda x: x.max() - x.mean())
     tm.assert_series_equal(result, expected)
@@ -110,7 +138,6 @@ def test_pipe(test_frame):
 
 
 def test_getitem(test_frame):
-
     r = test_frame.resample("H")
     tm.assert_index_equal(r._selected_obj.columns, test_frame.columns)
 
@@ -136,44 +163,43 @@ def test_select_bad_cols(key, test_frame):
 
 
 def test_attribute_access(test_frame):
-
     r = test_frame.resample("H")
     tm.assert_series_equal(r.A.sum(), r["A"].sum())
 
 
-def test_api_compat_before_use():
-
+@pytest.mark.parametrize("attr", ["groups", "ngroups", "indices"])
+def test_api_compat_before_use(attr):
     # make sure that we are setting the binner
     # on these attributes
-    for attr in ["groups", "ngroups", "indices"]:
-        rng = date_range("1/1/2012", periods=100, freq="S")
-        ts = Series(np.arange(len(rng)), index=rng)
-        rs = ts.resample("30s")
+    rng = date_range("1/1/2012", periods=100, freq="S")
+    ts = Series(np.arange(len(rng)), index=rng)
+    rs = ts.resample("30s")
 
-        # before use
-        getattr(rs, attr)
+    # before use
+    getattr(rs, attr)
 
-        # after grouper is initialized is ok
-        rs.mean()
-        getattr(rs, attr)
+    # after grouper is initialized is ok
+    rs.mean()
+    getattr(rs, attr)
 
 
-def tests_skip_nuisance(test_frame):
-
+def tests_raises_on_nuisance(test_frame):
     df = test_frame
     df["D"] = "foo"
     r = df.resample("H")
-    result = r[["A", "B"]].sum()
-    expected = pd.concat([r.A.sum(), r.B.sum()], axis=1)
+    result = r[["A", "B"]].mean()
+    expected = pd.concat([r.A.mean(), r.B.mean()], axis=1)
     tm.assert_frame_equal(result, expected)
 
-    expected = r[["A", "B", "C"]].sum()
-    result = r.sum()
+    expected = r[["A", "B", "C"]].mean()
+    msg = re.escape("agg function failed [how->mean,dtype->object]")
+    with pytest.raises(TypeError, match=msg):
+        r.mean()
+    result = r.mean(numeric_only=True)
     tm.assert_frame_equal(result, expected)
 
 
 def test_downsample_but_actually_upsampling():
-
     # this is reindex / asfreq
     rng = date_range("1/1/2012", periods=100, freq="S")
     ts = Series(np.arange(len(rng), dtype="int64"), index=rng)
@@ -186,7 +212,6 @@ def test_downsample_but_actually_upsampling():
 
 
 def test_combined_up_downsampling_of_irregular():
-
     # since we are really doing an operation like this
     # ts2.resample('2s').mean().ffill()
     # preserve these semantics
@@ -241,54 +266,84 @@ def test_combined_up_downsampling_of_irregular():
     tm.assert_series_equal(result, expected)
 
 
-def test_transform():
-
-    r = test_series.resample("20min")
-    expected = test_series.groupby(pd.Grouper(freq="20min")).transform("mean")
+def test_transform_series(_test_series):
+    r = _test_series.resample("20min")
+    expected = _test_series.groupby(pd.Grouper(freq="20min")).transform("mean")
     result = r.transform("mean")
     tm.assert_series_equal(result, expected)
 
 
-def test_fillna():
+@pytest.mark.parametrize("on", [None, "date"])
+def test_transform_frame(on):
+    # GH#47079
+    index = date_range(datetime(2005, 1, 1), datetime(2005, 1, 10), freq="D")
+    index.name = "date"
+    df = DataFrame(
+        np.random.default_rng(2).random((10, 2)), columns=list("AB"), index=index
+    )
+    expected = df.groupby(pd.Grouper(freq="20min")).transform("mean")
+    if on == "date":
+        # Move date to being a column; result will then have a RangeIndex
+        expected = expected.reset_index(drop=True)
+        df = df.reset_index()
 
+    r = df.resample("20min", on=on)
+    result = r.transform("mean")
+    tm.assert_frame_equal(result, expected)
+
+
+def test_fillna():
     # need to upsample here
     rng = date_range("1/1/2012", periods=10, freq="2S")
     ts = Series(np.arange(len(rng), dtype="int64"), index=rng)
     r = ts.resample("s")
 
     expected = r.ffill()
-    result = r.fillna(method="ffill")
+    msg = "DatetimeIndexResampler.fillna is deprecated"
+    with tm.assert_produces_warning(FutureWarning, match=msg):
+        result = r.fillna(method="ffill")
     tm.assert_series_equal(result, expected)
 
     expected = r.bfill()
-    result = r.fillna(method="bfill")
+    with tm.assert_produces_warning(FutureWarning, match=msg):
+        result = r.fillna(method="bfill")
     tm.assert_series_equal(result, expected)
 
-    msg = (
+    msg2 = (
         r"Invalid fill method\. Expecting pad \(ffill\), backfill "
         r"\(bfill\) or nearest\. Got 0"
     )
-    with pytest.raises(ValueError, match=msg):
-        r.fillna(0)
+    with pytest.raises(ValueError, match=msg2):
+        with tm.assert_produces_warning(FutureWarning, match=msg):
+            r.fillna(0)
 
 
-def test_apply_without_aggregation():
-
+@pytest.mark.parametrize(
+    "func",
+    [
+        lambda x: x.resample("20min", group_keys=False),
+        lambda x: x.groupby(pd.Grouper(freq="20min"), group_keys=False),
+    ],
+    ids=["resample", "groupby"],
+)
+def test_apply_without_aggregation(func, _test_series):
     # both resample and groupby should work w/o aggregation
-    r = test_series.resample("20min")
-    g = test_series.groupby(pd.Grouper(freq="20min"))
+    t = func(_test_series)
+    result = t.apply(lambda x: x)
+    tm.assert_series_equal(result, _test_series)
 
-    for t in [g, r]:
-        result = t.apply(lambda x: x)
-        tm.assert_series_equal(result, test_series)
+
+def test_apply_without_aggregation2(_test_series):
+    grouped = _test_series.to_frame(name="foo").resample("20min", group_keys=False)
+    result = grouped["foo"].apply(lambda x: x)
+    tm.assert_series_equal(result, _test_series.rename("foo"))
 
 
 def test_agg_consistency():
-
     # make sure that we are consistent across
     # similar aggregations with and w/o selection list
     df = DataFrame(
-        np.random.randn(1000, 3),
+        np.random.default_rng(2).standard_normal((1000, 3)),
         index=date_range("1/1/2012", freq="S", periods=1000),
         columns=["A", "B", "C"],
     )
@@ -303,7 +358,7 @@ def test_agg_consistency():
 def test_agg_consistency_int_str_column_mix():
     # GH#39025
     df = DataFrame(
-        np.random.randn(1000, 2),
+        np.random.default_rng(2).standard_normal((1000, 2)),
         index=date_range("1/1/2012", freq="S", periods=1000),
         columns=[1, "a"],
     )
@@ -315,17 +370,18 @@ def test_agg_consistency_int_str_column_mix():
         r.agg({2: "mean", "b": "sum"})
 
 
-# TODO: once GH 14008 is fixed, move these tests into
+# TODO(GH#14008): once GH 14008 is fixed, move these tests into
 # `Base` test class
 
 
 def test_agg():
     # test with all three Resampler apis and TimeGrouper
 
-    np.random.seed(1234)
     index = date_range(datetime(2005, 1, 1), datetime(2005, 1, 10), freq="D")
     index.name = "date"
-    df = DataFrame(np.random.rand(10, 2), columns=list("AB"), index=index)
+    df = DataFrame(
+        np.random.default_rng(2).random((10, 2)), columns=list("AB"), index=index
+    )
     df_col = df.reset_index()
     df_mult = df_col.copy()
     df_mult.index = pd.MultiIndex.from_arrays(
@@ -348,13 +404,36 @@ def test_agg():
 
     expected = pd.concat([a_mean, a_std, b_mean, b_std], axis=1)
     expected.columns = pd.MultiIndex.from_product([["A", "B"], ["mean", "std"]])
+    msg = "using SeriesGroupBy.[mean|std]"
     for t in cases:
-        result = t.aggregate([np.mean, np.std])
-        tm.assert_frame_equal(result, expected)
+        # In case 2, "date" is an index and a column, so get included in the agg
+        if t == cases[2]:
+            date_mean = t["date"].mean()
+            date_std = t["date"].std()
+            exp = pd.concat([date_mean, date_std, expected], axis=1)
+            exp.columns = pd.MultiIndex.from_product(
+                [["date", "A", "B"], ["mean", "std"]]
+            )
+            with tm.assert_produces_warning(FutureWarning, match=msg):
+                result = t.aggregate([np.mean, np.std])
+            tm.assert_frame_equal(result, exp)
+        else:
+            with tm.assert_produces_warning(FutureWarning, match=msg):
+                result = t.aggregate([np.mean, np.std])
+            tm.assert_frame_equal(result, expected)
 
     expected = pd.concat([a_mean, b_std], axis=1)
     for t in cases:
-        result = t.aggregate({"A": np.mean, "B": np.std})
+        with tm.assert_produces_warning(FutureWarning, match=msg):
+            result = t.aggregate({"A": np.mean, "B": np.std})
+        tm.assert_frame_equal(result, expected, check_like=True)
+
+        with tm.assert_produces_warning(FutureWarning, match=msg):
+            result = t.aggregate(A=("A", np.mean), B=("B", np.std))
+        tm.assert_frame_equal(result, expected, check_like=True)
+
+        with tm.assert_produces_warning(FutureWarning, match=msg):
+            result = t.aggregate(A=NamedAgg("A", np.mean), B=NamedAgg("B", np.std))
         tm.assert_frame_equal(result, expected, check_like=True)
 
     expected = pd.concat([a_mean, a_std], axis=1)
@@ -367,11 +446,14 @@ def test_agg():
     expected.columns = ["mean", "sum"]
     for t in cases:
         result = t["A"].aggregate(["mean", "sum"])
-    tm.assert_frame_equal(result, expected)
+        tm.assert_frame_equal(result, expected)
+
+        result = t["A"].aggregate(mean="mean", sum="sum")
+        tm.assert_frame_equal(result, expected)
 
     msg = "nested renamer is not supported"
     for t in cases:
-        with pytest.raises(pd.core.base.SpecificationError, match=msg):
+        with pytest.raises(pd.errors.SpecificationError, match=msg):
             t.aggregate({"A": {"mean": "mean", "sum": "sum"}})
 
     expected = pd.concat([a_mean, a_sum, b_mean, b_sum], axis=1)
@@ -379,7 +461,7 @@ def test_agg():
         [("A", "mean"), ("A", "sum"), ("B", "mean2"), ("B", "sum2")]
     )
     for t in cases:
-        with pytest.raises(pd.core.base.SpecificationError, match=msg):
+        with pytest.raises(pd.errors.SpecificationError, match=msg):
             t.aggregate(
                 {
                     "A": {"mean": "mean", "sum": "sum"},
@@ -409,10 +491,11 @@ def test_agg():
 def test_agg_misc():
     # test with all three Resampler apis and TimeGrouper
 
-    np.random.seed(1234)
     index = date_range(datetime(2005, 1, 1), datetime(2005, 1, 10), freq="D")
     index.name = "date"
-    df = DataFrame(np.random.rand(10, 2), columns=list("AB"), index=index)
+    df = DataFrame(
+        np.random.default_rng(2).random((10, 2)), columns=list("AB"), index=index
+    )
     df_col = df.reset_index()
     df_mult = df_col.copy()
     df_mult.index = pd.MultiIndex.from_arrays(
@@ -428,12 +511,24 @@ def test_agg_misc():
     ]
 
     # passed lambda
+    msg = "using SeriesGroupBy.sum"
     for t in cases:
-        result = t.agg({"A": np.sum, "B": lambda x: np.std(x, ddof=1)})
+        with tm.assert_produces_warning(FutureWarning, match=msg):
+            result = t.agg({"A": np.sum, "B": lambda x: np.std(x, ddof=1)})
         rcustom = t["B"].apply(lambda x: np.std(x, ddof=1))
         expected = pd.concat([r["A"].sum(), rcustom], axis=1)
         tm.assert_frame_equal(result, expected, check_like=True)
 
+        with tm.assert_produces_warning(FutureWarning, match=msg):
+            result = t.agg(A=("A", np.sum), B=("B", lambda x: np.std(x, ddof=1)))
+        tm.assert_frame_equal(result, expected, check_like=True)
+
+        with tm.assert_produces_warning(FutureWarning, match=msg):
+            result = t.agg(
+                A=NamedAgg("A", np.sum), B=NamedAgg("B", lambda x: np.std(x, ddof=1))
+            )
+        tm.assert_frame_equal(result, expected, check_like=True)
+
     # agg with renamers
     expected = pd.concat(
         [t["A"].sum(), t["B"].sum(), t["A"].mean(), t["B"].mean()], axis=1
@@ -447,6 +542,14 @@ def test_agg_misc():
         with pytest.raises(KeyError, match=msg):
             t[["A", "B"]].agg({"result1": np.sum, "result2": np.mean})
 
+        with pytest.raises(KeyError, match=msg):
+            t[["A", "B"]].agg(A=("result1", np.sum), B=("result2", np.mean))
+
+        with pytest.raises(KeyError, match=msg):
+            t[["A", "B"]].agg(
+                A=NamedAgg("result1", np.sum), B=NamedAgg("result2", np.mean)
+            )
+
     # agg with different hows
     expected = pd.concat(
         [t["A"].sum(), t["A"].std(), t["B"].mean(), t["B"].std()], axis=1
@@ -467,10 +570,10 @@ def test_agg_misc():
 
     # series like aggs
     for t in cases:
-        with pytest.raises(pd.core.base.SpecificationError, match=msg):
+        with pytest.raises(pd.errors.SpecificationError, match=msg):
             t["A"].agg({"A": ["sum", "std"]})
 
-        with pytest.raises(pd.core.base.SpecificationError, match=msg):
+        with pytest.raises(pd.errors.SpecificationError, match=msg):
             t["A"].agg({"A": ["sum", "std"], "B": ["mean", "std"]})
 
     # errors
@@ -481,12 +584,32 @@ def test_agg_misc():
             t[["A"]].agg({"A": ["sum", "std"], "B": ["mean", "std"]})
 
 
-def test_agg_nested_dicts():
+@pytest.mark.parametrize(
+    "func", [["min"], ["mean", "max"], {"A": "sum"}, {"A": "prod", "B": "median"}]
+)
+def test_multi_agg_axis_1_raises(func):
+    # GH#46904
 
-    np.random.seed(1234)
     index = date_range(datetime(2005, 1, 1), datetime(2005, 1, 10), freq="D")
     index.name = "date"
-    df = DataFrame(np.random.rand(10, 2), columns=list("AB"), index=index)
+    df = DataFrame(
+        np.random.default_rng(2).random((10, 2)), columns=list("AB"), index=index
+    ).T
+    warning_msg = "DataFrame.resample with axis=1 is deprecated."
+    with tm.assert_produces_warning(FutureWarning, match=warning_msg):
+        res = df.resample("M", axis=1)
+        with pytest.raises(
+            NotImplementedError, match="axis other than 0 is not supported"
+        ):
+            res.agg(func)
+
+
+def test_agg_nested_dicts():
+    index = date_range(datetime(2005, 1, 1), datetime(2005, 1, 10), freq="D")
+    index.name = "date"
+    df = DataFrame(
+        np.random.default_rng(2).random((10, 2)), columns=list("AB"), index=index
+    )
     df_col = df.reset_index()
     df_mult = df_col.copy()
     df_mult.index = pd.MultiIndex.from_arrays(
@@ -502,17 +625,16 @@ def test_agg_nested_dicts():
 
     msg = "nested renamer is not supported"
     for t in cases:
-        with pytest.raises(pd.core.base.SpecificationError, match=msg):
+        with pytest.raises(pd.errors.SpecificationError, match=msg):
             t.aggregate({"r1": {"A": ["mean", "sum"]}, "r2": {"B": ["mean", "sum"]}})
 
     for t in cases:
-
-        with pytest.raises(pd.core.base.SpecificationError, match=msg):
+        with pytest.raises(pd.errors.SpecificationError, match=msg):
             t[["A", "B"]].agg(
                 {"A": {"ra": ["mean", "std"]}, "B": {"rb": ["mean", "std"]}}
             )
 
-        with pytest.raises(pd.core.base.SpecificationError, match=msg):
+        with pytest.raises(pd.errors.SpecificationError, match=msg):
             t.agg({"A": {"ra": ["mean", "std"]}, "B": {"rb": ["mean", "std"]}})
 
 
@@ -531,6 +653,31 @@ def test_try_aggregate_non_existing_column():
         df.resample("30T").agg({"x": ["mean"], "y": ["median"], "z": ["sum"]})
 
 
+def test_agg_list_like_func_with_args():
+    # 50624
+    df = DataFrame(
+        {"x": [1, 2, 3]}, index=date_range("2020-01-01", periods=3, freq="D")
+    )
+
+    def foo1(x, a=1, c=0):
+        return x + a + c
+
+    def foo2(x, b=2, c=0):
+        return x + b + c
+
+    msg = r"foo1\(\) got an unexpected keyword argument 'b'"
+    with pytest.raises(TypeError, match=msg):
+        df.resample("D").agg([foo1, foo2], 3, b=3, c=4)
+
+    result = df.resample("D").agg([foo1, foo2], 3, c=4)
+    expected = DataFrame(
+        [[8, 8], [9, 9], [10, 10]],
+        index=date_range("2020-01-01", periods=3, freq="D"),
+        columns=pd.MultiIndex.from_tuples([("x", "foo1"), ("x", "foo2")]),
+    )
+    tm.assert_frame_equal(result, expected)
+
+
 def test_selection_api_validation():
     # GH 13500
     index = date_range(datetime(2005, 1, 1), datetime(2005, 1, 10), freq="D")
@@ -545,7 +692,7 @@ def test_selection_api_validation():
     # non DatetimeIndex
     msg = (
         "Only valid with DatetimeIndex, TimedeltaIndex or PeriodIndex, "
-        "but got an instance of 'Int64Index'"
+        "but got an instance of 'Index'"
     )
     with pytest.raises(TypeError, match=msg):
         df.resample("2D", level="v")
@@ -574,10 +721,14 @@ def test_selection_api_validation():
 
     exp = df_exp.resample("2D").sum()
     exp.index.name = "date"
-    tm.assert_frame_equal(exp, df.resample("2D", on="date").sum())
+    result = df.resample("2D", on="date").sum()
+    tm.assert_frame_equal(exp, result)
 
     exp.index.name = "d"
-    tm.assert_frame_equal(exp, df.resample("2D", level="d").sum())
+    with pytest.raises(TypeError, match="datetime64 type does not support sum"):
+        df.resample("2D", level="d").sum()
+    result = df.resample("2D", level="d").sum(numeric_only=True)
+    tm.assert_frame_equal(exp, result)
 
 
 @pytest.mark.parametrize(
@@ -704,3 +855,209 @@ def test_end_and_end_day_origin(
     )
 
     tm.assert_series_equal(res, expected)
+
+
+@pytest.mark.parametrize(
+    # expected_data is a string when op raises a ValueError
+    "method, numeric_only, expected_data",
+    [
+        ("sum", True, {"num": [25]}),
+        ("sum", False, {"cat": ["cat_1cat_2"], "num": [25]}),
+        ("sum", lib.no_default, {"cat": ["cat_1cat_2"], "num": [25]}),
+        ("prod", True, {"num": [100]}),
+        ("prod", False, "can't multiply sequence"),
+        ("prod", lib.no_default, "can't multiply sequence"),
+        ("min", True, {"num": [5]}),
+        ("min", False, {"cat": ["cat_1"], "num": [5]}),
+        ("min", lib.no_default, {"cat": ["cat_1"], "num": [5]}),
+        ("max", True, {"num": [20]}),
+        ("max", False, {"cat": ["cat_2"], "num": [20]}),
+        ("max", lib.no_default, {"cat": ["cat_2"], "num": [20]}),
+        ("first", True, {"num": [5]}),
+        ("first", False, {"cat": ["cat_1"], "num": [5]}),
+        ("first", lib.no_default, {"cat": ["cat_1"], "num": [5]}),
+        ("last", True, {"num": [20]}),
+        ("last", False, {"cat": ["cat_2"], "num": [20]}),
+        ("last", lib.no_default, {"cat": ["cat_2"], "num": [20]}),
+        ("mean", True, {"num": [12.5]}),
+        ("mean", False, "Could not convert"),
+        ("mean", lib.no_default, "Could not convert"),
+        ("median", True, {"num": [12.5]}),
+        ("median", False, r"Cannot convert \['cat_1' 'cat_2'\] to numeric"),
+        ("median", lib.no_default, r"Cannot convert \['cat_1' 'cat_2'\] to numeric"),
+        ("std", True, {"num": [10.606601717798213]}),
+        ("std", False, "could not convert string to float"),
+        ("std", lib.no_default, "could not convert string to float"),
+        ("var", True, {"num": [112.5]}),
+        ("var", False, "could not convert string to float"),
+        ("var", lib.no_default, "could not convert string to float"),
+        ("sem", True, {"num": [7.5]}),
+        ("sem", False, "could not convert string to float"),
+        ("sem", lib.no_default, "could not convert string to float"),
+    ],
+)
+def test_frame_downsample_method(method, numeric_only, expected_data):
+    # GH#46442 test if `numeric_only` behave as expected for DataFrameGroupBy
+
+    index = date_range("2018-01-01", periods=2, freq="D")
+    expected_index = date_range("2018-12-31", periods=1, freq="Y")
+    df = DataFrame({"cat": ["cat_1", "cat_2"], "num": [5, 20]}, index=index)
+    resampled = df.resample("Y")
+    if numeric_only is lib.no_default:
+        kwargs = {}
+    else:
+        kwargs = {"numeric_only": numeric_only}
+
+    func = getattr(resampled, method)
+    if isinstance(expected_data, str):
+        if method in ("var", "mean", "median", "prod"):
+            klass = TypeError
+            msg = re.escape(f"agg function failed [how->{method},dtype->object]")
+        else:
+            klass = ValueError
+            msg = expected_data
+        with pytest.raises(klass, match=msg):
+            _ = func(**kwargs)
+    else:
+        result = func(**kwargs)
+        expected = DataFrame(expected_data, index=expected_index)
+        tm.assert_frame_equal(result, expected)
+
+
+@pytest.mark.parametrize(
+    "method, numeric_only, expected_data",
+    [
+        ("sum", True, ()),
+        ("sum", False, ["cat_1cat_2"]),
+        ("sum", lib.no_default, ["cat_1cat_2"]),
+        ("prod", True, ()),
+        ("prod", False, ()),
+        ("prod", lib.no_default, ()),
+        ("min", True, ()),
+        ("min", False, ["cat_1"]),
+        ("min", lib.no_default, ["cat_1"]),
+        ("max", True, ()),
+        ("max", False, ["cat_2"]),
+        ("max", lib.no_default, ["cat_2"]),
+        ("first", True, ()),
+        ("first", False, ["cat_1"]),
+        ("first", lib.no_default, ["cat_1"]),
+        ("last", True, ()),
+        ("last", False, ["cat_2"]),
+        ("last", lib.no_default, ["cat_2"]),
+    ],
+)
+def test_series_downsample_method(method, numeric_only, expected_data):
+    # GH#46442 test if `numeric_only` behave as expected for SeriesGroupBy
+
+    index = date_range("2018-01-01", periods=2, freq="D")
+    expected_index = date_range("2018-12-31", periods=1, freq="Y")
+    df = Series(["cat_1", "cat_2"], index=index)
+    resampled = df.resample("Y")
+    kwargs = {} if numeric_only is lib.no_default else {"numeric_only": numeric_only}
+
+    func = getattr(resampled, method)
+    if numeric_only and numeric_only is not lib.no_default:
+        msg = rf"Cannot use numeric_only=True with SeriesGroupBy\.{method}"
+        with pytest.raises(TypeError, match=msg):
+            func(**kwargs)
+    elif method == "prod":
+        msg = re.escape("agg function failed [how->prod,dtype->object]")
+        with pytest.raises(TypeError, match=msg):
+            func(**kwargs)
+    else:
+        result = func(**kwargs)
+        expected = Series(expected_data, index=expected_index)
+        tm.assert_series_equal(result, expected)
+
+
+@pytest.mark.parametrize(
+    "method, raises",
+    [
+        ("sum", True),
+        ("prod", True),
+        ("min", True),
+        ("max", True),
+        ("first", False),
+        ("last", False),
+        ("median", False),
+        ("mean", True),
+        ("std", True),
+        ("var", True),
+        ("sem", False),
+        ("ohlc", False),
+        ("nunique", False),
+    ],
+)
+def test_args_kwargs_depr(method, raises):
+    index = date_range("20180101", periods=3, freq="h")
+    df = Series([2, 4, 6], index=index)
+    resampled = df.resample("30min")
+    args = ()
+
+    func = getattr(resampled, method)
+
+    error_msg = "numpy operations are not valid with resample."
+    error_msg_type = "too many arguments passed in"
+    warn_msg = f"Passing additional args to DatetimeIndexResampler.{method}"
+
+    if raises:
+        with tm.assert_produces_warning(FutureWarning, match=warn_msg):
+            with pytest.raises(UnsupportedFunctionCall, match=error_msg):
+                func(*args, 1, 2, 3)
+    else:
+        with tm.assert_produces_warning(FutureWarning, match=warn_msg):
+            with pytest.raises(TypeError, match=error_msg_type):
+                func(*args, 1, 2, 3)
+
+
+def test_df_axis_param_depr():
+    index = date_range(datetime(2005, 1, 1), datetime(2005, 1, 10), freq="D")
+    index.name = "date"
+    df = DataFrame(
+        np.random.default_rng(2).random((10, 2)), columns=list("AB"), index=index
+    ).T
+
+    # Deprecation error when axis=1 is explicitly passed
+    warning_msg = "DataFrame.resample with axis=1 is deprecated."
+    with tm.assert_produces_warning(FutureWarning, match=warning_msg):
+        df.resample("M", axis=1)
+
+    # Deprecation error when axis=0 is explicitly passed
+    df = df.T
+    warning_msg = (
+        "The 'axis' keyword in DataFrame.resample is deprecated and "
+        "will be removed in a future version."
+    )
+    with tm.assert_produces_warning(FutureWarning, match=warning_msg):
+        df.resample("M", axis=0)
+
+
+def test_series_axis_param_depr(_test_series):
+    warning_msg = (
+        "The 'axis' keyword in Series.resample is "
+        "deprecated and will be removed in a future version."
+    )
+    with tm.assert_produces_warning(FutureWarning, match=warning_msg):
+        _test_series.resample("H", axis=0)
+
+
+def test_resample_empty():
+    # GH#52484
+    df = DataFrame(
+        index=pd.to_datetime(
+            ["2018-01-01 00:00:00", "2018-01-01 12:00:00", "2018-01-02 00:00:00"]
+        )
+    )
+    expected = DataFrame(
+        index=pd.to_datetime(
+            [
+                "2018-01-01 00:00:00",
+                "2018-01-01 08:00:00",
+                "2018-01-01 16:00:00",
+                "2018-01-02 00:00:00",
+            ]
+        )
+    )
+    result = df.resample("8H").mean()
+    tm.assert_frame_equal(result, expected)
