@@ -46,25 +46,23 @@ def test_resample_as_freq_with_subperiod():
 
 
 def test_resample_with_timedeltas():
-
     expected = DataFrame({"A": np.arange(1480)})
     expected = expected.groupby(expected.index // 30).sum()
-    expected.index = timedelta_range("0 days", freq="30T", periods=50)
+    expected.index = timedelta_range("0 days", freq="30min", periods=50)
 
     df = DataFrame(
-        {"A": np.arange(1480)}, index=pd.to_timedelta(np.arange(1480), unit="T")
+        {"A": np.arange(1480)}, index=pd.to_timedelta(np.arange(1480), unit="min")
     )
-    result = df.resample("30T").sum()
+    result = df.resample("30min").sum()
 
     tm.assert_frame_equal(result, expected)
 
     s = df["A"]
-    result = s.resample("30T").sum()
+    result = s.resample("30min").sum()
     tm.assert_series_equal(result, expected["A"])
 
 
 def test_resample_single_period_timedelta():
-
     s = Series(list(range(5)), index=timedelta_range("1 day", freq="s", periods=5))
     result = s.resample("2s").sum()
     expected = Series([1, 5, 4], index=timedelta_range("1 day", freq="2s", periods=3))
@@ -72,7 +70,6 @@ def test_resample_single_period_timedelta():
 
 
 def test_resample_timedelta_idempotency():
-
     # GH 12072
     index = timedelta_range("0", periods=9, freq="10L")
     series = Series(range(9), index=index)
@@ -84,7 +81,7 @@ def test_resample_timedelta_idempotency():
 def test_resample_offset_with_timedeltaindex():
     # GH 10530 & 31809
     rng = timedelta_range(start="0s", periods=25, freq="s")
-    ts = Series(np.random.randn(len(rng)), index=rng)
+    ts = Series(np.random.default_rng(2).standard_normal(len(rng)), index=rng)
 
     with_base = ts.resample("2s", offset="5s").mean()
     without_base = ts.resample("2s").mean()
@@ -150,14 +147,14 @@ def test_resample_timedelta_edge_case(start, end, freq, resample_freq):
     expected_index = timedelta_range(freq=resample_freq, start=start, end=end)
     tm.assert_index_equal(result.index, expected_index)
     assert result.index.freq == expected_index.freq
-    assert not np.isnan(result[-1])
+    assert not np.isnan(result.iloc[-1])
 
 
 @pytest.mark.parametrize("duplicates", [True, False])
 def test_resample_with_timedelta_yields_no_empty_groups(duplicates):
     # GH 10603
     df = DataFrame(
-        np.random.normal(size=(10000, 4)),
+        np.random.default_rng(2).normal(size=(10000, 4)),
         index=timedelta_range(start="0s", periods=10000, freq="3906250n"),
     )
     if duplicates:
@@ -174,10 +171,12 @@ def test_resample_with_timedelta_yields_no_empty_groups(duplicates):
     tm.assert_frame_equal(result, expected)
 
 
-def test_resample_quantile_timedelta():
+@pytest.mark.parametrize("unit", ["s", "ms", "us", "ns"])
+def test_resample_quantile_timedelta(unit):
     # GH: 29485
+    dtype = np.dtype(f"m8[{unit}]")
     df = DataFrame(
-        {"value": pd.to_timedelta(np.arange(4), unit="s")},
+        {"value": pd.to_timedelta(np.arange(4), unit="s").astype(dtype)},
         index=pd.date_range("20200101", periods=4, tz="UTC"),
     )
     result = df.resample("2D").quantile(0.99)
@@ -189,5 +188,19 @@ def test_resample_quantile_timedelta():
             ]
         },
         index=pd.date_range("20200101", periods=2, tz="UTC", freq="2D"),
-    )
+    ).astype(dtype)
     tm.assert_frame_equal(result, expected)
+
+
+def test_resample_closed_right():
+    # GH#45414
+    idx = pd.Index([pd.Timedelta(seconds=120 + i * 30) for i in range(10)])
+    ser = Series(range(10), index=idx)
+    result = ser.resample("T", closed="right", label="right").sum()
+    expected = Series(
+        [0, 3, 7, 11, 15, 9],
+        index=pd.TimedeltaIndex(
+            [pd.Timedelta(seconds=120 + i * 60) for i in range(6)], freq="T"
+        ),
+    )
+    tm.assert_series_equal(result, expected)
