@@ -21,7 +21,6 @@ from pandas import (
 )
 import pandas._testing as tm
 from pandas.api.types import CategoricalDtype as CDT
-from pandas.core.algorithms import quantile
 
 from pandas.tseries.offsets import (
     Day,
@@ -30,12 +29,12 @@ from pandas.tseries.offsets import (
 
 
 def test_qcut():
-    arr = np.random.randn(1000)
+    arr = np.random.default_rng(2).standard_normal(1000)
 
     # We store the bins as Index that have been
     # rounded to comparisons are a bit tricky.
-    labels, bins = qcut(arr, 4, retbins=True)
-    ex_bins = quantile(arr, [0, 0.25, 0.5, 0.75, 1.0])
+    labels, _ = qcut(arr, 4, retbins=True)
+    ex_bins = np.quantile(arr, [0, 0.25, 0.5, 0.75, 1.0])
 
     result = labels.categories.left.values
     assert np.allclose(result, ex_bins[:-1], atol=1e-2)
@@ -48,14 +47,14 @@ def test_qcut():
 
 
 def test_qcut_bounds():
-    arr = np.random.randn(1000)
+    arr = np.random.default_rng(2).standard_normal(1000)
 
     factor = qcut(arr, 10, labels=False)
     assert len(np.unique(factor)) == 10
 
 
 def test_qcut_specify_quantiles():
-    arr = np.random.randn(100)
+    arr = np.random.default_rng(2).standard_normal(100)
     factor = qcut(arr, [0, 0.25, 0.5, 0.75, 1.0])
 
     expected = qcut(arr, 4)
@@ -83,7 +82,7 @@ def test_qcut_include_lowest():
 
 
 def test_qcut_nas():
-    arr = np.random.randn(100)
+    arr = np.random.default_rng(2).standard_normal(100)
     arr[:20] = np.nan
 
     result = qcut(arr, 4)
@@ -293,8 +292,8 @@ def test_qcut_bool_coercion_to_int(bins, box, compare):
 
 
 @pytest.mark.parametrize("q", [2, 5, 10])
-def test_qcut_nullable_integer(q, any_nullable_numeric_dtype):
-    arr = pd.array(np.arange(100), dtype=any_nullable_numeric_dtype)
+def test_qcut_nullable_integer(q, any_numeric_ea_dtype):
+    arr = pd.array(np.arange(100), dtype=any_numeric_ea_dtype)
     arr[::2] = pd.NA
 
     result = qcut(arr, q)
