@@ -1,22 +1,60 @@
-from datetime import date, datetime, timedelta
+from datetime import (
+    date,
+    datetime,
+    timedelta,
+)
 
 import numpy as np
 import pytest
-import pytz
 
-from pandas._libs.tslibs import iNaT, period as libperiod
-from pandas._libs.tslibs.ccalendar import DAYS, MONTHS
+from pandas._libs.tslibs import (
+    iNaT,
+    period as libperiod,
+)
+from pandas._libs.tslibs.ccalendar import (
+    DAYS,
+    MONTHS,
+)
+from pandas._libs.tslibs.np_datetime import OutOfBoundsDatetime
 from pandas._libs.tslibs.parsing import DateParseError
-from pandas._libs.tslibs.period import INVALID_FREQ_ERR_MSG, IncompatibleFrequency
-from pandas._libs.tslibs.timezones import dateutil_gettz, maybe_get_tz
-from pandas.compat.numpy import np_datetime64_compat
+from pandas._libs.tslibs.period import (
+    INVALID_FREQ_ERR_MSG,
+    IncompatibleFrequency,
+)
 
 import pandas as pd
-from pandas import NaT, Period, Timedelta, Timestamp, offsets
+from pandas import (
+    NaT,
+    Period,
+    Timedelta,
+    Timestamp,
+    offsets,
+)
 import pandas._testing as tm
 
+bday_msg = "Period with BDay freq is deprecated"
+
 
 class TestPeriodConstruction:
+    def test_custom_business_day_freq_raises(self):
+        # GH#52534
+        msg = "CustomBusinessDay cannot be used with Period or PeriodDtype"
+        with pytest.raises(TypeError, match=msg):
+            Period("2023-04-10", freq="C")
+        with pytest.raises(TypeError, match=msg):
+            Period("2023-04-10", freq=offsets.CustomBusinessDay())
+
+    def test_from_td64nat_raises(self):
+        # GH#44507
+        td = NaT.to_numpy("m8[ns]")
+
+        msg = "Value must be Period, string, integer, or datetime"
+        with pytest.raises(ValueError, match=msg):
+            Period(td)
+
+        with pytest.raises(ValueError, match=msg):
+            Period(td, freq="D")
+
     def test_construction(self):
         i1 = Period("1/1/2005", freq="M")
         i2 = Period("Jan 2005")
@@ -33,18 +71,25 @@ class TestPeriodConstruction:
         i4 = Period("2005", freq="M")
         i5 = Period("2005", freq="m")
 
-        msg = r"Input has different freq=M from Period\(freq=A-DEC\)"
-        with pytest.raises(IncompatibleFrequency, match=msg):
-            i1 != i4
+        assert i1 != i4
         assert i4 == i5
 
-        i1 = Period.now("Q")
+        i1 = Period.now(freq="Q")
         i2 = Period(datetime.now(), freq="Q")
         i3 = Period.now("q")
 
         assert i1 == i2
         assert i1 == i3
 
+        # Pass in freq as a keyword argument sometimes as a test for
+        # https://github.com/pandas-dev/pandas/issues/53369
+        i1 = Period.now(freq="D")
+        i2 = Period(datetime.now(), freq="D")
+        i3 = Period.now(offsets.Day())
+
+        assert i1 == i2
+        assert i1 == i3
+
         i1 = Period("1982", freq="min")
         i2 = Period("1982", freq="MIN")
         assert i1 == i2
@@ -60,14 +105,14 @@ class TestPeriodConstruction:
         expected = Period(datetime(2007, 1, 1, 9, 0, 0, 1000), freq="L")
         assert i1 == expected
 
-        expected = Period(np_datetime64_compat("2007-01-01 09:00:00.001Z"), freq="L")
+        expected = Period("2007-01-01 09:00:00.001", freq="L")
         assert i1 == expected
 
         i1 = Period("2007-01-01 09:00:00.00101")
         expected = Period(datetime(2007, 1, 1, 9, 0, 0, 1010), freq="U")
         assert i1 == expected
 
-        expected = Period(np_datetime64_compat("2007-01-01 09:00:00.00101Z"), freq="U")
+        expected = Period("2007-01-01 09:00:00.00101", freq="U")
         assert i1 == expected
 
         msg = "Must supply freq for ordinal value"
@@ -82,26 +127,40 @@ class TestPeriodConstruction:
         with pytest.raises(TypeError, match="pass as a string instead"):
             Period("1982", freq=("Min", 1))
 
+    def test_construction_from_timestamp_nanos(self):
+        # GH#46811 don't drop nanos from Timestamp
+        ts = Timestamp("2022-04-20 09:23:24.123456789")
+        per = Period(ts, freq="ns")
+
+        # should losslessly round-trip, not lose the 789
+        rt = per.to_timestamp()
+        assert rt == ts
+
+        # same thing but from a datetime64 object
+        dt64 = ts.asm8
+        per2 = Period(dt64, freq="ns")
+        rt2 = per2.to_timestamp()
+        assert rt2.asm8 == dt64
+
     def test_construction_bday(self):
-
         # Biz day construction, roll forward if non-weekday
-        i1 = Period("3/10/12", freq="B")
-        i2 = Period("3/10/12", freq="D")
-        assert i1 == i2.asfreq("B")
-        i2 = Period("3/11/12", freq="D")
-        assert i1 == i2.asfreq("B")
-        i2 = Period("3/12/12", freq="D")
-        assert i1 == i2.asfreq("B")
+        with tm.assert_produces_warning(FutureWarning, match=bday_msg):
+            i1 = Period("3/10/12", freq="B")
+            i2 = Period("3/10/12", freq="D")
+            assert i1 == i2.asfreq("B")
+            i2 = Period("3/11/12", freq="D")
+            assert i1 == i2.asfreq("B")
+            i2 = Period("3/12/12", freq="D")
+            assert i1 == i2.asfreq("B")
 
-        i3 = Period("3/10/12", freq="b")
-        assert i1 == i3
+            i3 = Period("3/10/12", freq="b")
+            assert i1 == i3
 
-        i1 = Period(year=2012, month=3, day=10, freq="B")
-        i2 = Period("3/12/12", freq="B")
-        assert i1 == i2
+            i1 = Period(year=2012, month=3, day=10, freq="B")
+            i2 = Period("3/12/12", freq="B")
+            assert i1 == i2
 
     def test_construction_quarter(self):
-
         i1 = Period(year=2005, quarter=1, freq="Q")
         i2 = Period("1/1/2005", freq="Q")
         assert i1 == i2
@@ -137,7 +196,6 @@ class TestPeriodConstruction:
         assert i1 == lower
 
     def test_construction_month(self):
-
         expected = Period("2007-01", freq="M")
         i1 = Period("200701", freq="M")
         assert i1 == expected
@@ -158,8 +216,8 @@ class TestPeriodConstruction:
         i1 = Period(date(2007, 1, 1), freq="M")
         i2 = Period(datetime(2007, 1, 1), freq="M")
         i3 = Period(np.datetime64("2007-01-01"), freq="M")
-        i4 = Period(np_datetime64_compat("2007-01-01 00:00:00Z"), freq="M")
-        i5 = Period(np_datetime64_compat("2007-01-01 00:00:00.000Z"), freq="M")
+        i4 = Period("2007-01-01 00:00:00", freq="M")
+        i5 = Period("2007-01-01 00:00:00.000", freq="M")
         assert i1 == i2
         assert i1 == i3
         assert i1 == i4
@@ -171,9 +229,10 @@ class TestPeriodConstruction:
         )
         assert Period("2005", freq=offsets.YearEnd()) == Period("2005", freq="A")
         assert Period("2005", freq=offsets.MonthEnd()) == Period("2005", freq="M")
-        assert Period("3/10/12", freq=offsets.BusinessDay()) == Period(
-            "3/10/12", freq="B"
-        )
+        with tm.assert_produces_warning(FutureWarning, match=bday_msg):
+            assert Period("3/10/12", freq=offsets.BusinessDay()) == Period(
+                "3/10/12", freq="B"
+            )
         assert Period("3/10/12", freq=offsets.Day()) == Period("3/10/12", freq="D")
 
         assert Period(
@@ -186,17 +245,19 @@ class TestPeriodConstruction:
         assert Period(year=2005, month=3, day=1, freq=offsets.Day()) == Period(
             year=2005, month=3, day=1, freq="D"
         )
-        assert Period(year=2012, month=3, day=10, freq=offsets.BDay()) == Period(
-            year=2012, month=3, day=10, freq="B"
-        )
+        with tm.assert_produces_warning(FutureWarning, match=bday_msg):
+            assert Period(year=2012, month=3, day=10, freq=offsets.BDay()) == Period(
+                year=2012, month=3, day=10, freq="B"
+            )
 
         expected = Period("2005-03-01", freq="3D")
         assert Period(year=2005, month=3, day=1, freq=offsets.Day(3)) == expected
         assert Period(year=2005, month=3, day=1, freq="3D") == expected
 
-        assert Period(year=2012, month=3, day=10, freq=offsets.BDay(3)) == Period(
-            year=2012, month=3, day=10, freq="3B"
-        )
+        with tm.assert_produces_warning(FutureWarning, match=bday_msg):
+            assert Period(year=2012, month=3, day=10, freq=offsets.BDay(3)) == Period(
+                year=2012, month=3, day=10, freq="3B"
+            )
 
         assert Period(200701, freq=offsets.MonthEnd()) == Period(200701, freq="M")
 
@@ -213,8 +274,8 @@ class TestPeriodConstruction:
         i1 = Period(date(2007, 1, 1), freq="M")
         i2 = Period(datetime(2007, 1, 1), freq="M")
         i3 = Period(np.datetime64("2007-01-01"), freq="M")
-        i4 = Period(np_datetime64_compat("2007-01-01 00:00:00Z"), freq="M")
-        i5 = Period(np_datetime64_compat("2007-01-01 00:00:00.000Z"), freq="M")
+        i4 = Period("2007-01-01 00:00:00", freq="M")
+        i5 = Period("2007-01-01 00:00:00.000", freq="M")
         assert i1 == i2
         assert i1 == i3
         assert i1 == i4
@@ -224,14 +285,14 @@ class TestPeriodConstruction:
         expected = Period(datetime(2007, 1, 1, 9, 0, 0, 1000), freq="L")
         assert i1 == expected
 
-        expected = Period(np_datetime64_compat("2007-01-01 09:00:00.001Z"), freq="L")
+        expected = Period("2007-01-01 09:00:00.001", freq="L")
         assert i1 == expected
 
         i1 = Period("2007-01-01 09:00:00.00101")
         expected = Period(datetime(2007, 1, 1, 9, 0, 0, 1010), freq="U")
         assert i1 == expected
 
-        expected = Period(np_datetime64_compat("2007-01-01 09:00:00.00101Z"), freq="U")
+        expected = Period("2007-01-01 09:00:00.00101", freq="U")
         assert i1 == expected
 
     def test_invalid_arguments(self):
@@ -255,7 +316,7 @@ class TestPeriodConstruction:
         with pytest.raises(ValueError, match=msg):
             Period(month=1)
 
-        msg = "Given date string not likely a datetime"
+        msg = '^Given date string "-2000" not likely a datetime$'
         with pytest.raises(ValueError, match=msg):
             Period("-2000", "A")
         msg = "day is out of range for month"
@@ -293,8 +354,10 @@ class TestPeriodConstruction:
         p = Period("2007-01-01 07:10:15.123")
         assert p.freq == "L"
 
+        # We see that there are 6 digits after the decimal, so get microsecond
+        #  even though they are all zeros.
         p = Period("2007-01-01 07:10:15.123000")
-        assert p.freq == "L"
+        assert p.freq == "U"
 
         p = Period("2007-01-01 07:10:15.123400")
         assert p.freq == "U"
@@ -349,6 +412,19 @@ class TestPeriodConstruction:
         assert result == expected
         assert isinstance(result, Period)
 
+    def test_parse_week_str_roundstrip(self):
+        # GH#50803
+        per = Period("2017-01-23/2017-01-29")
+        assert per.freq.freqstr == "W-SUN"
+
+        per = Period("2017-01-24/2017-01-30")
+        assert per.freq.freqstr == "W-MON"
+
+        msg = "Could not parse as weekly-freq Period"
+        with pytest.raises(ValueError, match=msg):
+            # not 6 days apart
+            Period("2016-01-23/2017-01-29")
+
     def test_period_from_ordinal(self):
         p = Period("2011-01", freq="M")
         res = Period._from_ordinal(p.ordinal, freq="M")
@@ -486,11 +562,32 @@ class TestPeriodConstruction:
         with pytest.raises(ValueError, match=msg):
             Period("2011-01", freq="1D1W")
 
+    @pytest.mark.parametrize("day", ["1970/01/01 ", "2020-12-31 ", "1981/09/13 "])
+    @pytest.mark.parametrize("hour", ["00:00:00", "00:00:01", "23:59:59", "12:00:59"])
+    @pytest.mark.parametrize(
+        "sec_float, expected",
+        [
+            (".000000001", 1),
+            (".000000999", 999),
+            (".123456789", 789),
+            (".999999999", 999),
+            (".999999000", 0),
+            # Test femtoseconds, attoseconds, picoseconds are dropped like Timestamp
+            (".999999001123", 1),
+            (".999999001123456", 1),
+            (".999999001123456789", 1),
+        ],
+    )
+    def test_period_constructor_nanosecond(self, day, hour, sec_float, expected):
+        # GH 34621
+
+        assert Period(day + hour + sec_float).start_time.nanosecond == expected
+
     @pytest.mark.parametrize("hour", range(24))
     def test_period_large_ordinal(self, hour):
         # Issue #36430
         # Integer overflow for Period over the maximum timestamp
-        p = pd.Period(ordinal=2562048 + hour, freq="1H")
+        p = Period(ordinal=2562048 + hour, freq="1H")
         assert p.hour == hour
 
 
@@ -512,70 +609,6 @@ class TestPeriodMethods:
     # --------------------------------------------------------------
     # to_timestamp
 
-    @pytest.mark.parametrize("tzstr", ["Europe/Brussels", "Asia/Tokyo", "US/Pacific"])
-    def test_to_timestamp_tz_arg(self, tzstr):
-        # GH#34522 tz kwarg deprecated
-        with tm.assert_produces_warning(FutureWarning):
-            p = Period("1/1/2005", freq="M").to_timestamp(tz=tzstr)
-        exp = Timestamp("1/1/2005", tz="UTC").tz_convert(tzstr)
-        exp_zone = pytz.timezone(tzstr).normalize(p)
-
-        assert p == exp
-        assert p.tz == exp_zone.tzinfo
-        assert p.tz == exp.tz
-
-        with tm.assert_produces_warning(FutureWarning):
-            p = Period("1/1/2005", freq="3H").to_timestamp(tz=tzstr)
-        exp = Timestamp("1/1/2005", tz="UTC").tz_convert(tzstr)
-        exp_zone = pytz.timezone(tzstr).normalize(p)
-
-        assert p == exp
-        assert p.tz == exp_zone.tzinfo
-        assert p.tz == exp.tz
-
-        with tm.assert_produces_warning(FutureWarning):
-            p = Period("1/1/2005", freq="A").to_timestamp(freq="A", tz=tzstr)
-        exp = Timestamp("31/12/2005", tz="UTC").tz_convert(tzstr)
-        exp_zone = pytz.timezone(tzstr).normalize(p)
-
-        assert p == exp
-        assert p.tz == exp_zone.tzinfo
-        assert p.tz == exp.tz
-
-        with tm.assert_produces_warning(FutureWarning):
-            p = Period("1/1/2005", freq="A").to_timestamp(freq="3H", tz=tzstr)
-        exp = Timestamp("1/1/2005", tz="UTC").tz_convert(tzstr)
-        exp_zone = pytz.timezone(tzstr).normalize(p)
-
-        assert p == exp
-        assert p.tz == exp_zone.tzinfo
-        assert p.tz == exp.tz
-
-    @pytest.mark.parametrize(
-        "tzstr",
-        ["dateutil/Europe/Brussels", "dateutil/Asia/Tokyo", "dateutil/US/Pacific"],
-    )
-    def test_to_timestamp_tz_arg_dateutil(self, tzstr):
-        tz = maybe_get_tz(tzstr)
-        with tm.assert_produces_warning(FutureWarning):
-            p = Period("1/1/2005", freq="M").to_timestamp(tz=tz)
-        exp = Timestamp("1/1/2005", tz="UTC").tz_convert(tzstr)
-        assert p == exp
-        assert p.tz == dateutil_gettz(tzstr.split("/", 1)[1])
-        assert p.tz == exp.tz
-
-        with tm.assert_produces_warning(FutureWarning):
-            p = Period("1/1/2005", freq="M").to_timestamp(freq="3H", tz=tz)
-        exp = Timestamp("1/1/2005", tz="UTC").tz_convert(tzstr)
-        assert p == exp
-        assert p.tz == dateutil_gettz(tzstr.split("/", 1)[1])
-        assert p.tz == exp.tz
-
-    def test_to_timestamp_tz_arg_dateutil_from_string(self):
-        with tm.assert_produces_warning(FutureWarning):
-            p = Period("1/1/2005", freq="M").to_timestamp(tz="dateutil/Europe/Brussels")
-        assert p.tz == dateutil_gettz("Europe/Brussels")
-
     def test_to_timestamp_mult(self):
         p = Period("2011-01", freq="M")
         assert p.to_timestamp(how="S") == Timestamp("2011-01-01")
@@ -587,6 +620,9 @@ class TestPeriodMethods:
         expected = Timestamp("2011-04-01") - Timedelta(1, "ns")
         assert p.to_timestamp(how="E") == expected
 
+    @pytest.mark.filterwarnings(
+        "ignore:Period with BDay freq is deprecated:FutureWarning"
+    )
     def test_to_timestamp(self):
         p = Period("1982", freq="A")
         start_ts = p.to_timestamp(how="S")
@@ -607,9 +643,9 @@ class TestPeriodMethods:
         def _ex(p):
             if p.freq == "B":
                 return p.start_time + Timedelta(days=1, nanoseconds=-1)
-            return Timestamp((p + p.freq).start_time.value - 1)
+            return Timestamp((p + p.freq).start_time._value - 1)
 
-        for i, fcode in enumerate(from_lst):
+        for fcode in from_lst:
             p = Period("1982", freq=fcode)
             result = p.to_timestamp().to_period(fcode)
             assert result == p
@@ -651,10 +687,11 @@ class TestPeriodMethods:
         assert result == expected
 
     def test_to_timestamp_business_end(self):
-        per = pd.Period("1990-01-05", "B")  # Friday
-        result = per.to_timestamp("B", how="E")
+        with tm.assert_produces_warning(FutureWarning, match=bday_msg):
+            per = Period("1990-01-05", "B")  # Friday
+            result = per.to_timestamp("B", how="E")
 
-        expected = pd.Timestamp("1990-01-06") - pd.Timedelta(nanoseconds=1)
+        expected = Timestamp("1990-01-06") - Timedelta(nanoseconds=1)
         assert result == expected
 
     @pytest.mark.parametrize(
@@ -680,27 +717,44 @@ class TestPeriodMethods:
     # --------------------------------------------------------------
     # Rendering: __repr__, strftime, etc
 
-    def test_repr(self):
-        p = Period("Jan-2000")
-        assert "2000-01" in repr(p)
-
-        p = Period("2000-12-15")
-        assert "2000-12-15" in repr(p)
+    @pytest.mark.parametrize(
+        "str_ts,freq,str_res,str_freq",
+        (
+            ("Jan-2000", None, "2000-01", "M"),
+            ("2000-12-15", None, "2000-12-15", "D"),
+            (
+                "2000-12-15 13:45:26.123456789",
+                "N",
+                "2000-12-15 13:45:26.123456789",
+                "N",
+            ),
+            ("2000-12-15 13:45:26.123456789", "U", "2000-12-15 13:45:26.123456", "U"),
+            ("2000-12-15 13:45:26.123456", None, "2000-12-15 13:45:26.123456", "U"),
+            ("2000-12-15 13:45:26.123456789", "L", "2000-12-15 13:45:26.123", "L"),
+            ("2000-12-15 13:45:26.123", None, "2000-12-15 13:45:26.123", "L"),
+            ("2000-12-15 13:45:26", "S", "2000-12-15 13:45:26", "S"),
+            ("2000-12-15 13:45:26", "T", "2000-12-15 13:45", "T"),
+            ("2000-12-15 13:45:26", "H", "2000-12-15 13:00", "H"),
+            ("2000-12-15", "Y", "2000", "A-DEC"),
+            ("2000-12-15", "Q", "2000Q4", "Q-DEC"),
+            ("2000-12-15", "M", "2000-12", "M"),
+            ("2000-12-15", "W", "2000-12-11/2000-12-17", "W-SUN"),
+            ("2000-12-15", "D", "2000-12-15", "D"),
+            ("2000-12-15", "B", "2000-12-15", "B"),
+        ),
+    )
+    @pytest.mark.filterwarnings(
+        "ignore:Period with BDay freq is deprecated:FutureWarning"
+    )
+    def test_repr(self, str_ts, freq, str_res, str_freq):
+        p = Period(str_ts, freq=freq)
+        assert str(p) == str_res
+        assert repr(p) == f"Period('{str_res}', '{str_freq}')"
 
     def test_repr_nat(self):
         p = Period("nat", freq="M")
         assert repr(NaT) in repr(p)
 
-    def test_millisecond_repr(self):
-        p = Period("2000-01-01 12:15:02.123")
-
-        assert repr(p) == "Period('2000-01-01 12:15:02.123', 'L')"
-
-    def test_microsecond_repr(self):
-        p = Period("2000-01-01 12:15:02.123567")
-
-        assert repr(p) == "Period('2000-01-01 12:15:02.123567', 'U')"
-
     def test_strftime(self):
         # GH#3363
         p = Period("2000-1-1 12:34:12", freq="S")
@@ -749,6 +803,9 @@ class TestPeriodProperties:
         assert i1.freq == offsets.Minute()
         assert i1.freqstr == "T"
 
+    @pytest.mark.filterwarnings(
+        "ignore:Period with BDay freq is deprecated:FutureWarning"
+    )
     def test_period_deprecated_freq(self):
         cases = {
             "M": ["MTH", "MONTH", "MONTHLY", "Mth", "month", "monthly"],
@@ -776,20 +833,51 @@ class TestPeriodProperties:
             assert isinstance(p1, Period)
             assert isinstance(p2, Period)
 
+    @staticmethod
+    def _period_constructor(bound, offset):
+        return Period(
+            year=bound.year,
+            month=bound.month,
+            day=bound.day,
+            hour=bound.hour,
+            minute=bound.minute,
+            second=bound.second + offset,
+            freq="us",
+        )
+
+    @pytest.mark.parametrize("bound, offset", [(Timestamp.min, -1), (Timestamp.max, 1)])
+    @pytest.mark.parametrize("period_property", ["start_time", "end_time"])
+    def test_outer_bounds_start_and_end_time(self, bound, offset, period_property):
+        # GH #13346
+        period = TestPeriodProperties._period_constructor(bound, offset)
+        with pytest.raises(OutOfBoundsDatetime, match="Out of bounds nanosecond"):
+            getattr(period, period_property)
+
+    @pytest.mark.parametrize("bound, offset", [(Timestamp.min, -1), (Timestamp.max, 1)])
+    @pytest.mark.parametrize("period_property", ["start_time", "end_time"])
+    def test_inner_bounds_start_and_end_time(self, bound, offset, period_property):
+        # GH #13346
+        period = TestPeriodProperties._period_constructor(bound, -offset)
+        expected = period.to_timestamp().round(freq="S")
+        assert getattr(period, period_property).round(freq="S") == expected
+        expected = (bound - offset * Timedelta(1, unit="S")).floor("S")
+        assert getattr(period, period_property).floor("S") == expected
+
     def test_start_time(self):
         freq_lst = ["A", "Q", "M", "D", "H", "T", "S"]
         xp = datetime(2012, 1, 1)
         for f in freq_lst:
             p = Period("2012", freq=f)
             assert p.start_time == xp
-        assert Period("2012", freq="B").start_time == datetime(2012, 1, 2)
+        with tm.assert_produces_warning(FutureWarning, match=bday_msg):
+            assert Period("2012", freq="B").start_time == datetime(2012, 1, 2)
         assert Period("2012", freq="W").start_time == datetime(2011, 12, 26)
 
     def test_end_time(self):
         p = Period("2012", freq="A")
 
         def _ex(*args):
-            return Timestamp(Timestamp(datetime(*args)).value - 1)
+            return Timestamp(Timestamp(datetime(*args)).as_unit("ns")._value - 1)
 
         xp = _ex(2013, 1, 1)
         assert xp == p.end_time
@@ -810,9 +898,10 @@ class TestPeriodProperties:
         xp = _ex(2012, 1, 1, 1)
         assert xp == p.end_time
 
-        p = Period("2012", freq="B")
-        xp = _ex(2012, 1, 3)
-        assert xp == p.end_time
+        with tm.assert_produces_warning(FutureWarning, match=bday_msg):
+            p = Period("2012", freq="B")
+            xp = _ex(2012, 1, 3)
+            assert xp == p.end_time
 
         p = Period("2012", freq="W")
         xp = _ex(2012, 1, 2)
@@ -833,15 +922,16 @@ class TestPeriodProperties:
 
     def test_end_time_business_friday(self):
         # GH#34449
-        per = Period("1990-01-05", "B")
-        result = per.end_time
+        with tm.assert_produces_warning(FutureWarning, match=bday_msg):
+            per = Period("1990-01-05", "B")
+            result = per.end_time
 
-        expected = pd.Timestamp("1990-01-06") - pd.Timedelta(nanoseconds=1)
+        expected = Timestamp("1990-01-06") - Timedelta(nanoseconds=1)
         assert result == expected
 
     def test_anchor_week_end_time(self):
         def _ex(*args):
-            return Timestamp(Timestamp(datetime(*args)).value - 1)
+            return Timestamp(Timestamp(datetime(*args)).as_unit("ns")._value - 1)
 
         p = Period("2013-1-1", "W-SAT")
         xp = _ex(2013, 1, 6)
@@ -910,7 +1000,8 @@ class TestPeriodProperties:
 
     def test_properties_daily(self):
         # Test properties on Periods with daily frequency.
-        b_date = Period(freq="B", year=2007, month=1, day=1)
+        with tm.assert_produces_warning(FutureWarning, match=bday_msg):
+            b_date = Period(freq="B", year=2007, month=1, day=1)
         #
         assert b_date.year == 2007
         assert b_date.quarter == 1
@@ -919,7 +1010,8 @@ class TestPeriodProperties:
         assert b_date.weekday == 0
         assert b_date.dayofyear == 1
         assert b_date.days_in_month == 31
-        assert Period(freq="B", year=2012, month=2, day=1).days_in_month == 29
+        with tm.assert_produces_warning(FutureWarning, match=bday_msg):
+            assert Period(freq="B", year=2012, month=2, day=1).days_in_month == 29
 
         d_date = Period(freq="D", year=2007, month=1, day=1)
 
@@ -1025,11 +1117,9 @@ class TestPeriodComparisons:
         jan = Period("2000-01", "M")
         day = Period("2012-01-01", "D")
 
+        assert not jan == day
+        assert jan != day
         msg = r"Input has different freq=D from Period\(freq=M\)"
-        with pytest.raises(IncompatibleFrequency, match=msg):
-            jan == day
-        with pytest.raises(IncompatibleFrequency, match=msg):
-            jan != day
         with pytest.raises(IncompatibleFrequency, match=msg):
             jan < day
         with pytest.raises(IncompatibleFrequency, match=msg):
@@ -1048,7 +1138,6 @@ class TestPeriodComparisons:
         int_or_per = "'(Period|int)'"
         msg = f"not supported between instances of {int_or_per} and {int_or_per}"
         for left, right in [(jan, 1), (1, jan)]:
-
             with pytest.raises(TypeError, match=msg):
                 left > right
             with pytest.raises(TypeError, match=msg):
@@ -1084,8 +1173,31 @@ class TestPeriodComparisons:
             assert not left <= right
             assert not left >= right
 
+    @pytest.mark.parametrize(
+        "zerodim_arr, expected",
+        ((np.array(0), False), (np.array(Period("2000-01", "M")), True)),
+    )
+    def test_comparison_numpy_zerodim_arr(self, zerodim_arr, expected):
+        p = Period("2000-01", "M")
+
+        assert (p == zerodim_arr) is expected
+        assert (zerodim_arr == p) is expected
+
 
 class TestArithmetic:
+    @pytest.mark.parametrize("unit", ["ns", "us", "ms", "s", "m"])
+    def test_add_sub_td64_nat(self, unit):
+        # GH#47196
+        per = Period("2022-06-01", "D")
+        nat = np.timedelta64("NaT", unit)
+
+        assert per + nat is NaT
+        assert nat + per is NaT
+        assert per - nat is NaT
+
+        with pytest.raises(TypeError, match="unsupported operand"):
+            nat - per
+
     def test_sub_delta(self):
         left, right = Period("2011", freq="A"), Period("2007", freq="A")
         result = left - right
@@ -1223,20 +1335,8 @@ class TestArithmetic:
                 msg = "Input has different freq|Input cannot be converted to Period"
                 with pytest.raises(IncompatibleFrequency, match=msg):
                     p + o
-
-                if isinstance(o, np.timedelta64):
-                    msg = "cannot use operands with types"
-                    with pytest.raises(TypeError, match=msg):
-                        o + p
-                else:
-                    msg = "|".join(
-                        [
-                            "Input has different freq",
-                            "Input cannot be converted to Period",
-                        ]
-                    )
-                    with pytest.raises(IncompatibleFrequency, match=msg):
-                        o + p
+                with pytest.raises(IncompatibleFrequency, match=msg):
+                    o + p
 
         for freq in ["M", "2M", "3M"]:
             p = Period("2011-03", freq=freq)
@@ -1248,6 +1348,13 @@ class TestArithmetic:
             assert p + offsets.MonthEnd(12) == exp
             assert offsets.MonthEnd(12) + p == exp
 
+            msg = "|".join(
+                [
+                    "Input has different freq",
+                    "Input cannot be converted to Period",
+                ]
+            )
+
             for o in [
                 offsets.YearBegin(2),
                 offsets.MonthBegin(1),
@@ -1255,23 +1362,10 @@ class TestArithmetic:
                 np.timedelta64(365, "D"),
                 timedelta(365),
             ]:
-                msg = "Input has different freq|Input cannot be converted to Period"
                 with pytest.raises(IncompatibleFrequency, match=msg):
                     p + o
-
-                if isinstance(o, np.timedelta64):
-                    msg = "cannot use operands with types"
-                    with pytest.raises(TypeError, match=msg):
-                        o + p
-                else:
-                    msg = "|".join(
-                        [
-                            "Input has different freq",
-                            "Input cannot be converted to Period",
-                        ]
-                    )
-                    with pytest.raises(IncompatibleFrequency, match=msg):
-                        o + p
+                with pytest.raises(IncompatibleFrequency, match=msg):
+                    o + p
 
         # freq is Tick
         for freq in ["D", "2D", "3D"]:
@@ -1287,14 +1381,11 @@ class TestArithmetic:
 
             exp = Period("2011-04-03", freq=freq)
             assert p + np.timedelta64(2, "D") == exp
-            msg = "cannot use operands with types"
-            with pytest.raises(TypeError, match=msg):
-                np.timedelta64(2, "D") + p
+            assert np.timedelta64(2, "D") + p == exp
 
             exp = Period("2011-04-02", freq=freq)
             assert p + np.timedelta64(3600 * 24, "s") == exp
-            with pytest.raises(TypeError, match=msg):
-                np.timedelta64(3600 * 24, "s") + p
+            assert np.timedelta64(3600 * 24, "s") + p == exp
 
             exp = Period("2011-03-30", freq=freq)
             assert p + timedelta(-2) == exp
@@ -1304,6 +1395,13 @@ class TestArithmetic:
             assert p + timedelta(hours=48) == exp
             assert timedelta(hours=48) + p == exp
 
+            msg = "|".join(
+                [
+                    "Input has different freq",
+                    "Input cannot be converted to Period",
+                ]
+            )
+
             for o in [
                 offsets.YearBegin(2),
                 offsets.MonthBegin(1),
@@ -1311,23 +1409,10 @@ class TestArithmetic:
                 np.timedelta64(4, "h"),
                 timedelta(hours=23),
             ]:
-                msg = "Input has different freq|Input cannot be converted to Period"
                 with pytest.raises(IncompatibleFrequency, match=msg):
                     p + o
-
-                if isinstance(o, np.timedelta64):
-                    msg = "cannot use operands with types"
-                    with pytest.raises(TypeError, match=msg):
-                        o + p
-                else:
-                    msg = "|".join(
-                        [
-                            "Input has different freq",
-                            "Input cannot be converted to Period",
-                        ]
-                    )
-                    with pytest.raises(IncompatibleFrequency, match=msg):
-                        o + p
+                with pytest.raises(IncompatibleFrequency, match=msg):
+                    o + p
 
         for freq in ["H", "2H", "3H"]:
             p = Period("2011-04-01 09:00", freq=freq)
@@ -1343,13 +1428,11 @@ class TestArithmetic:
             msg = "cannot use operands with types"
             exp = Period("2011-04-01 12:00", freq=freq)
             assert p + np.timedelta64(3, "h") == exp
-            with pytest.raises(TypeError, match=msg):
-                np.timedelta64(3, "h") + p
+            assert np.timedelta64(3, "h") + p == exp
 
             exp = Period("2011-04-01 10:00", freq=freq)
             assert p + np.timedelta64(3600, "s") == exp
-            with pytest.raises(TypeError, match=msg):
-                np.timedelta64(3600, "s") + p
+            assert np.timedelta64(3600, "s") + p == exp
 
             exp = Period("2011-04-01 11:00", freq=freq)
             assert p + timedelta(minutes=120) == exp
@@ -1359,6 +1442,13 @@ class TestArithmetic:
             assert p + timedelta(days=4, minutes=180) == exp
             assert timedelta(days=4, minutes=180) + p == exp
 
+            msg = "|".join(
+                [
+                    "Input has different freq",
+                    "Input cannot be converted to Period",
+                ]
+            )
+
             for o in [
                 offsets.YearBegin(2),
                 offsets.MonthBegin(1),
@@ -1366,27 +1456,20 @@ class TestArithmetic:
                 np.timedelta64(3200, "s"),
                 timedelta(hours=23, minutes=30),
             ]:
-                msg = "Input has different freq|Input cannot be converted to Period"
                 with pytest.raises(IncompatibleFrequency, match=msg):
                     p + o
-
-                if isinstance(o, np.timedelta64):
-                    msg = "cannot use operands with types"
-                    with pytest.raises(TypeError, match=msg):
-                        o + p
-                else:
-                    msg = "|".join(
-                        [
-                            "Input has different freq",
-                            "Input cannot be converted to Period",
-                        ]
-                    )
-                    with pytest.raises(IncompatibleFrequency, match=msg):
-                        o + p
+                with pytest.raises(IncompatibleFrequency, match=msg):
+                    o + p
 
     def test_sub_offset(self):
         # freq is DateOffset
-        msg = "Input has different freq|Input cannot be converted to Period"
+        msg = "|".join(
+            [
+                "Input has different freq",
+                "Input cannot be converted to Period",
+            ]
+        )
+
         for freq in ["A", "2A", "3A"]:
             p = Period("2011", freq=freq)
             assert p - offsets.YearEnd(2) == Period("2009", freq=freq)
@@ -1520,7 +1603,14 @@ def test_negone_ordinals():
         repr(period)
         assert period.year == 1969
 
-    period = Period(ordinal=-1, freq="B")
+    with tm.assert_produces_warning(FutureWarning, match=bday_msg):
+        period = Period(ordinal=-1, freq="B")
     repr(period)
     period = Period(ordinal=-1, freq="W")
     repr(period)
+
+
+def test_invalid_frequency_error_message():
+    msg = "Invalid frequency: <WeekOfMonth: week=0, weekday=0>"
+    with pytest.raises(ValueError, match=msg):
+        Period("2012-01-02", freq="WOM-1MON")
