@@ -1,18 +1,18 @@
 from datetime import (
     date,
     datetime,
+    timedelta,
+    timezone,
 )
 
 from dateutil.tz.tz import tzoffset
 import numpy as np
 import pytest
-import pytz
 
 from pandas._libs import (
     iNaT,
     tslib,
 )
-from pandas.compat import np_array_datetime64_compat
 
 from pandas import Timestamp
 import pandas._testing as tm
@@ -24,15 +24,15 @@ import pandas._testing as tm
         (
             ["01-01-2013", "01-02-2013"],
             [
-                "2013-01-01T00:00:00.000000000-0000",
-                "2013-01-02T00:00:00.000000000-0000",
+                "2013-01-01T00:00:00.000000000",
+                "2013-01-02T00:00:00.000000000",
             ],
         ),
         (
             ["Mon Sep 16 2013", "Tue Sep 17 2013"],
             [
-                "2013-09-16T00:00:00.000000000-0000",
-                "2013-09-17T00:00:00.000000000-0000",
+                "2013-09-16T00:00:00.000000000",
+                "2013-09-17T00:00:00.000000000",
             ],
         ),
     ],
@@ -41,7 +41,7 @@ def test_parsing_valid_dates(data, expected):
     arr = np.array(data, dtype=object)
     result, _ = tslib.array_to_datetime(arr)
 
-    expected = np_array_datetime64_compat(expected, dtype="M8[ns]")
+    expected = np.array(expected, dtype="M8[ns]")
     tm.assert_numpy_array_equal(result, expected)
 
 
@@ -64,18 +64,20 @@ def test_parsing_timezone_offsets(dt_string, expected_tz):
     result, result_tz = tslib.array_to_datetime(arr)
 
     tm.assert_numpy_array_equal(result, expected)
-    assert result_tz is pytz.FixedOffset(expected_tz)
+    assert result_tz == timezone(timedelta(minutes=expected_tz))
 
 
 def test_parsing_non_iso_timezone_offset():
     dt_string = "01-01-2013T00:00:00.000000000+0000"
     arr = np.array([dt_string], dtype=object)
 
-    result, result_tz = tslib.array_to_datetime(arr)
+    with tm.assert_produces_warning(None):
+        # GH#50949 should not get tzlocal-deprecation warning here
+        result, result_tz = tslib.array_to_datetime(arr)
     expected = np.array([np.datetime64("2013-01-01 00:00:00.000000000")])
 
     tm.assert_numpy_array_equal(result, expected)
-    assert result_tz is pytz.FixedOffset(0)
+    assert result_tz is timezone.utc
 
 
 def test_parsing_different_timezone_offsets():
@@ -83,7 +85,9 @@ def test_parsing_different_timezone_offsets():
     data = ["2015-11-18 15:30:00+05:30", "2015-11-18 15:30:00+06:30"]
     data = np.array(data, dtype=object)
 
-    result, result_tz = tslib.array_to_datetime(data)
+    msg = "parsing datetimes with mixed time zones will raise an error"
+    with tm.assert_produces_warning(FutureWarning, match=msg):
+        result, result_tz = tslib.array_to_datetime(data)
     expected = np.array(
         [
             datetime(2015, 11, 18, 15, 30, tzinfo=tzoffset(None, 19800)),
@@ -126,7 +130,7 @@ def test_coerce_outside_ns_bounds(invalid_date, errors):
     kwargs = {"values": arr, "errors": errors}
 
     if errors == "raise":
-        msg = "Out of bounds nanosecond timestamp"
+        msg = "^Out of bounds nanosecond timestamp: .*, at position 0$"
 
         with pytest.raises(ValueError, match=msg):
             tslib.array_to_datetime(**kwargs)
@@ -141,8 +145,8 @@ def test_coerce_outside_ns_bounds_one_valid():
     arr = np.array(["1/1/1000", "1/1/2000"], dtype=object)
     result, _ = tslib.array_to_datetime(arr, errors="coerce")
 
-    expected = [iNaT, "2000-01-01T00:00:00.000000000-0000"]
-    expected = np_array_datetime64_compat(expected, dtype="M8[ns]")
+    expected = [iNaT, "2000-01-01T00:00:00.000000000"]
+    expected = np.array(expected, dtype="M8[ns]")
 
     tm.assert_numpy_array_equal(result, expected)
 
@@ -160,11 +164,9 @@ def test_coerce_of_invalid_datetimes(errors):
     else:  # coerce.
         # With coercing, the invalid dates becomes iNaT
         result, _ = tslib.array_to_datetime(arr, errors="coerce")
-        expected = ["2013-01-01T00:00:00.000000000-0000", iNaT, iNaT]
+        expected = ["2013-01-01T00:00:00.000000000", iNaT, iNaT]
 
-        tm.assert_numpy_array_equal(
-            result, np_array_datetime64_compat(expected, dtype="M8[ns]")
-        )
+        tm.assert_numpy_array_equal(result, np.array(expected, dtype="M8[ns]"))
 
 
 def test_to_datetime_barely_out_of_bounds():
@@ -173,7 +175,7 @@ def test_to_datetime_barely_out_of_bounds():
     # Close enough to bounds that dropping nanos
     # would result in an in-bounds datetime.
     arr = np.array(["2262-04-11 23:47:16.854775808"], dtype=object)
-    msg = "Out of bounds nanosecond timestamp: 2262-04-11 23:47:16"
+    msg = "^Out of bounds nanosecond timestamp: 2262-04-11 23:47:16, at position 0$"
 
     with pytest.raises(tslib.OutOfBoundsDatetime, match=msg):
         tslib.array_to_datetime(arr)
@@ -186,9 +188,9 @@ class SubDatetime(datetime):
 @pytest.mark.parametrize(
     "data,expected",
     [
-        ([SubDatetime(2000, 1, 1)], ["2000-01-01T00:00:00.000000000-0000"]),
-        ([datetime(2000, 1, 1)], ["2000-01-01T00:00:00.000000000-0000"]),
-        ([Timestamp(2000, 1, 1)], ["2000-01-01T00:00:00.000000000-0000"]),
+        ([SubDatetime(2000, 1, 1)], ["2000-01-01T00:00:00.000000000"]),
+        ([datetime(2000, 1, 1)], ["2000-01-01T00:00:00.000000000"]),
+        ([Timestamp(2000, 1, 1)], ["2000-01-01T00:00:00.000000000"]),
     ],
 )
 def test_datetime_subclass(data, expected):
@@ -199,5 +201,5 @@ def test_datetime_subclass(data, expected):
     arr = np.array(data, dtype=object)
     result, _ = tslib.array_to_datetime(arr)
 
-    expected = np_array_datetime64_compat(expected, dtype="M8[ns]")
+    expected = np.array(expected, dtype="M8[ns]")
     tm.assert_numpy_array_equal(result, expected)
