@@ -25,25 +25,24 @@ For more information, refer to the ``pytest`` documentation on ``skipif``.
 """
 from __future__ import annotations
 
-from contextlib import contextmanager
 import locale
 from typing import (
+    TYPE_CHECKING,
     Callable,
-    Iterator,
 )
-import warnings
 
 import numpy as np
 import pytest
 
 from pandas._config import get_option
 
-from pandas._typing import F
+if TYPE_CHECKING:
+    from pandas._typing import F
+
 from pandas.compat import (
     IS64,
     is_platform_windows,
 )
-from pandas.compat._optional import import_optional_dependency
 
 from pandas.core.computation.expressions import (
     NUMEXPR_INSTALLED,
@@ -66,70 +65,28 @@ def safe_import(mod_name: str, min_version: str | None = None):
     object
         The imported module if successful, or False
     """
-    with warnings.catch_warnings():
-        # Suppress warnings that we can't do anything about,
-        #  e.g. from aiohttp
-        warnings.filterwarnings(
-            "ignore",
-            category=DeprecationWarning,
-            module="aiohttp",
-            message=".*decorator is deprecated since Python 3.8.*",
-        )
-
-        # fastparquet import accesses pd.Int64Index
-        warnings.filterwarnings(
-            "ignore",
-            category=FutureWarning,
-            module="fastparquet",
-            message=".*Int64Index.*",
-        )
-
-        warnings.filterwarnings(
-            "ignore",
-            category=DeprecationWarning,
-            message="distutils Version classes are deprecated.*",
-        )
-
-        try:
-            mod = __import__(mod_name)
-        except ImportError:
-            return False
-        except SystemError:
-            # TODO: numba is incompatible with numpy 1.24+.
-            # Once that's fixed, this block should be removed.
-            if mod_name == "numba":
-                return False
-            else:
-                raise
+    try:
+        mod = __import__(mod_name)
+    except ImportError:
+        return False
 
     if not min_version:
         return mod
     else:
         import sys
 
-        try:
-            version = getattr(sys.modules[mod_name], "__version__")
-        except AttributeError:
-            # xlrd uses a capitalized attribute name
-            version = getattr(sys.modules[mod_name], "__VERSION__")
+        version = getattr(sys.modules[mod_name], "__version__")
         if version and Version(version) >= Version(min_version):
             return mod
 
     return False
 
 
-def _skip_if_no_mpl():
-    mod = safe_import("matplotlib")
-    if mod:
-        mod.use("Agg")
-    else:
-        return True
-
-
-def _skip_if_not_us_locale():
+def _skip_if_not_us_locale() -> bool:
     lang, _ = locale.getlocale()
     if lang != "en_US":
         return True
+    return False
 
 
 def _skip_if_no_scipy() -> bool:
@@ -141,9 +98,7 @@ def _skip_if_no_scipy() -> bool:
     )
 
 
-# TODO(pytest#7469): return type, _pytest.mark.structures.MarkDecorator is not public
-# https://github.com/pytest-dev/pytest/issues/7469
-def skip_if_installed(package: str):
+def skip_if_installed(package: str) -> pytest.MarkDecorator:
     """
     Skip a test if a package is installed.
 
@@ -151,15 +106,19 @@ def skip_if_installed(package: str):
     ----------
     package : str
         The name of the package.
+
+    Returns
+    -------
+    pytest.MarkDecorator
+        a pytest.mark.skipif to use as either a test decorator or a
+        parametrization mark.
     """
     return pytest.mark.skipif(
         safe_import(package), reason=f"Skipping because {package} is installed."
     )
 
 
-# TODO(pytest#7469): return type, _pytest.mark.structures.MarkDecorator is not public
-# https://github.com/pytest-dev/pytest/issues/7469
-def skip_if_no(package: str, min_version: str | None = None):
+def skip_if_no(package: str, min_version: str | None = None) -> pytest.MarkDecorator:
     """
     Generic function to help skip tests when required packages are not
     present on the testing system.
@@ -168,9 +127,10 @@ def skip_if_no(package: str, min_version: str | None = None):
     evaluated during test collection. An attempt will be made to import the
     specified ``package`` and optionally ensure it meets the ``min_version``
 
-    The mark can be used as either a decorator for a test function or to be
+    The mark can be used as either a decorator for a test class or to be
     applied to parameters in pytest.mark.parametrize calls or parametrized
-    fixtures.
+    fixtures. Use pytest.importorskip if an imported moduled is later needed
+    or for test functions.
 
     If the import and version check are unsuccessful, then the test function
     (or test case when used in conjunction with parametrization) will be
@@ -185,7 +145,7 @@ def skip_if_no(package: str, min_version: str | None = None):
 
     Returns
     -------
-    _pytest.mark.structures.MarkDecorator
+    pytest.MarkDecorator
         a pytest.mark.skipif to use as either a test decorator or a
         parametrization mark.
     """
@@ -197,14 +157,14 @@ def skip_if_no(package: str, min_version: str | None = None):
     )
 
 
-skip_if_no_mpl = pytest.mark.skipif(
-    _skip_if_no_mpl(), reason="Missing matplotlib dependency"
+skip_if_mpl = pytest.mark.skipif(
+    bool(safe_import("matplotlib")), reason="matplotlib is present"
 )
-skip_if_mpl = pytest.mark.skipif(not _skip_if_no_mpl(), reason="matplotlib is present")
 skip_if_32bit = pytest.mark.skipif(not IS64, reason="skipping for 32 bit")
 skip_if_windows = pytest.mark.skipif(is_platform_windows(), reason="Running on Windows")
 skip_if_not_us_locale = pytest.mark.skipif(
-    _skip_if_not_us_locale(), reason=f"Specific locale is set {locale.getlocale()[0]}"
+    _skip_if_not_us_locale(),
+    reason=f"Specific locale is set {locale.getlocale()[0]}",
 )
 skip_if_no_scipy = pytest.mark.skipif(
     _skip_if_no_scipy(), reason="Missing SciPy requirement"
@@ -215,9 +175,9 @@ skip_if_no_ne = pytest.mark.skipif(
 )
 
 
-# TODO(pytest#7469): return type, _pytest.mark.structures.MarkDecorator is not public
-# https://github.com/pytest-dev/pytest/issues/7469
-def skip_if_np_lt(ver_str: str, *args, reason: str | None = None):
+def skip_if_np_lt(
+    ver_str: str, *args, reason: str | None = None
+) -> pytest.MarkDecorator:
     if reason is None:
         reason = f"NumPy {ver_str} or greater required"
     return pytest.mark.skipif(
@@ -254,52 +214,6 @@ def parametrize_fixture_doc(*args) -> Callable[[F], F]:
     return documented_fixture
 
 
-def check_file_leaks(func) -> Callable:
-    """
-    Decorate a test function to check that we are not leaking file descriptors.
-    """
-    with file_leak_context():
-        return func
-
-
-@contextmanager
-def file_leak_context() -> Iterator[None]:
-    """
-    ContextManager analogue to check_file_leaks.
-    """
-    psutil = safe_import("psutil")
-    if not psutil or is_platform_windows():
-        # Checking for file leaks can hang on Windows CI
-        yield
-    else:
-        proc = psutil.Process()
-        flist = proc.open_files()
-        conns = proc.connections()
-
-        try:
-            yield
-        finally:
-            flist2 = proc.open_files()
-            # on some builds open_files includes file position, which we _dont_
-            #  expect to remain unchanged, so we need to compare excluding that
-            flist_ex = [(x.path, x.fd) for x in flist]
-            flist2_ex = [(x.path, x.fd) for x in flist2]
-            assert flist2_ex == flist_ex, (flist2, flist)
-
-            conns2 = proc.connections()
-            assert conns2 == conns, (conns2, conns)
-
-
-def async_mark():
-    try:
-        import_optional_dependency("pytest_asyncio")
-        async_mark = pytest.mark.asyncio
-    except ImportError:
-        async_mark = pytest.mark.skip(reason="Missing dependency pytest-asyncio")
-
-    return async_mark
-
-
 def mark_array_manager_not_yet_implemented(request) -> None:
     mark = pytest.mark.xfail(reason="Not yet implemented for ArrayManager")
     request.node.add_marker(mark)
@@ -314,3 +228,13 @@ skip_array_manager_invalid_test = pytest.mark.skipif(
     get_option("mode.data_manager") == "array",
     reason="Test that relies on BlockManager internals or specific behaviour",
 )
+
+skip_copy_on_write_not_yet_implemented = pytest.mark.xfail(
+    get_option("mode.copy_on_write"),
+    reason="Not yet implemented/adapted for Copy-on-Write mode",
+)
+
+skip_copy_on_write_invalid_test = pytest.mark.skipif(
+    get_option("mode.copy_on_write"),
+    reason="Test not valid for Copy-on-Write mode",
+)
